within ;
package PreFlexMS
  "Models for Concentrated Solar Power Plants dynamic simulation"

  package FullScale_280degC
    "Package containing the models regarding the OTSG design with 280 degC as FW OTSG nominal inlet temperature"

    package HeatExchangers
      "Package including all the heat exchangers model (OTSG and preheating train)"
      package BaseClasses "Partial models of the heat exchangers"
        partial model BaseWaterMSHeatExchanger
          "Base model for water/steam-MS fluid heat exchanger"
          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA inletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,-110},{
                    10,-90}}, rotation=0)));
          ThermoPower.Water.FlangeB outletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,90},{10,
                    110}}, rotation=0)));
          ThermoPower.Water.FlangeA inletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{-110,-10},{
                    -90,10}}, rotation=0)));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{90,-10},{110,
                    10}}, rotation=0)));
          annotation (Icon(graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{40,-82},{40,-24}}, color={135,135,135}),
                Line(points={{60,-60},{40,-24}}, color={135,135,135}),
                Line(points={{20,-60},{40,-24}}, color={135,135,135}),
                Line(points={{-48,0},{-74,-16}}, color={0,0,255}),
                Line(points={{-74,16},{-48,0}}, color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-110,-110},{110,110}}),
                                          graphics));

        end BaseWaterMSHeatExchanger;

        partial model BaseFeedwaterHeater
          "Base model for feedwater/steam extraction heat exchanger with drain inlet flow"
          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          parameter Boolean use_drainIN = true;

          ThermoPower.Water.FlangeA ST_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,90},{-40,110}},rotation=0),
                iconTransformation(extent={{-10,90},{10,110}})));
          ThermoPower.Water.FlangeB DR_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,-110},{-40,-90}},rotation=
                   0), iconTransformation(extent={{-10,-110},{10,-90}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,-110},{60,-90}}, rotation=0),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeB FW_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,90},{60,110}},    rotation=
                   0), iconTransformation(extent={{-110,-10},{-90,10}})));
          ThermoPower.Water.FlangeA DR_in(redeclare package Medium = Medium)
            if                                                                  use_drainIN
            annotation (Placement(transformation(extent={{-110,-10},{-90,10}}),
                                         iconTransformation(extent={{-80,90},{-60,110}})));
        protected
          ThermoPower.Water.FlangeA DR_in_internal(redeclare package Medium = Medium);
        equation

          if not use_drainIN then
            DR_in_internal.m_flow = 0;
            DR_in_internal.h_outflow = 1e5;
          end if;

          // Connect protected connectors to public conditional connectors
          connect(DR_in, DR_in_internal);

          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                    {100,100}}),
                           graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{-40,80},{-40,20}}, color={135,135,135}),
                Line(points={{-20,56},{-40,20}}, color={135,135,135}),
                Line(points={{-60,56},{-40,20}}, color={135,135,135}),
                Line(points={{50,0},{74,-14}},   color={0,0,255}),
                Line(points={{72,14},{50,0}},   color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-100,-100},{100,100}}),
                                          graphics));
        end BaseFeedwaterHeater;

        partial model BaseFeedwaterHeater_noOpt
          "Base model for feedwater/steam extraction heat exchanger with drain inlet flow"
          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA ST_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,90},{-40,110}},rotation=0),
                iconTransformation(extent={{-10,90},{10,110}})));
          ThermoPower.Water.FlangeB DR_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,-110},{-40,-90}},rotation=
                   0), iconTransformation(extent={{-10,-110},{10,-90}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,-110},{60,-90}}, rotation=0),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeB FW_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,90},{60,110}},    rotation=
                   0), iconTransformation(extent={{-110,-10},{-90,10}})));
          ThermoPower.Water.FlangeA DR_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-110,-10},{-90,10}}),
                                         iconTransformation(extent={{-80,90},{-60,110}})));
        equation

          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                    {100,100}}),
                           graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{-40,80},{-40,20}}, color={135,135,135}),
                Line(points={{-20,56},{-40,20}}, color={135,135,135}),
                Line(points={{-60,56},{-40,20}}, color={135,135,135}),
                Line(points={{50,0},{74,-14}},   color={0,0,255}),
                Line(points={{72,14},{50,0}},   color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-100,-100},{100,100}}),
                                          graphics));
        end BaseFeedwaterHeater_noOpt;

        partial model BaseOTSG "Base model of the OTSG "

          replaceable package coldMedium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              PreFlexMS.Media.MoltenSalt60_40_quad "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA RH_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,150},{200,170}}),
                                              iconTransformation(extent={{180,210},
                    {200,230}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,-250},{200,-230}}),
                                                iconTransformation(extent={{180,
                    -240},{200,-220}})));
          ThermoPower.Water.FlangeB RH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{90,300},{110,320}}), iconTransformation(extent={{10,300},
                    {30,320}})));
          ThermoPower.Water.FlangeB SH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{-10,300},{10,320}}),
                                              iconTransformation(extent={{90,300},
                    {110,320}})));
          ThermoPower.Water.FlangeB MS_HPH_out(redeclare package Medium = coldMedium)
                                                                                      annotation (Placement(
                transformation(extent={{-70,-320},{-50,-300}}),
                                                              iconTransformation(
                  extent={{10,-320},{30,-300}})));
          ThermoPower.Water.FlangeA MS_in(redeclare package Medium = hotMedium)
                                                                                annotation (Placement(transformation(extent={{-110,
                    300},{-90,320}}),      iconTransformation(extent={{-110,300},
                    {-90,320}})));
          ThermoPower.Water.FlangeB MS_out(redeclare package Medium = hotMedium)
                                                                                 annotation (Placement(transformation(extent={{10,-320},
                    {30,-300}}),           iconTransformation(extent={{-110,-320},
                    {-90,-300}})));
          ThermoPower.Water.FlangeB SEP_out(redeclare package Medium = coldMedium)
                                                                                   annotation (Placement(transformation(extent={{180,-90},{200,-70}})));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -300},{180,300}}),      graphics={
                Rectangle(extent={{-180,300},{180,-300}}, lineColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  fillColor={255,255,255}),
                Line(
                  points={{178,-228},{20,-228},{20,-244},{0,-248},{40,-258},{20,
                      -268},{20,-298}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{20,-228},{20,-150},{0,-140},{40,-130},{20,-120},{20,
                      -100},{0,-90},{40,-80},{20,-72},{20,20},{80,20}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{80,54},{120,-26}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid,
                  radius=10),
                Rectangle(
                  extent={{86,18},{114,-20}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Rectangle(
                  extent={{86,48},{114,10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Line(
                  points={{100,54},{100,116},{80,128},{120,138},{100,148},{100,
                      228},{100,238},{100,298}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Ellipse(
                  extent={{90,-46},{110,-66}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{92,-50},{108,-50},{100,-66},{92,-50}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{100,-66},{100,-80},{180,-80}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{100,-26},{100,-38},{100,-46}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{94,220},{94,222},{96,224},{100,226},{104,224},{106,222},
                      {106,220},{178,220}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Text(
                  extent={{-44,248},{28,212}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="RH"),
                Line(
                  points={{94,220},{70,220},{60,240},{50,200},{40,220},{20,220},{
                      20,300}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{120,150},{174,114}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="SH"),
                Text(
                  extent={{-68,-68},{-8,-110}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="EVA"),
                Text(
                  extent={{-64,-120},{-6,-164}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="ECO"),
                Text(
                  extent={{-80,-218},{-8,-284}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="MS_HPH"),
                Line(
                  points={{-100,298},{-100,220},{-80,208},{-120,200},{-80,190},{
                      -120,180},{-80,170},{-100,160},{-100,-60},{-120,-70},{-80,
                      -80},{-120,-90},{-80,-100},{-120,-110},{-80,-120},{-120,
                      -130},{-80,-140},{-120,-150},{-80,-160},{-120,-172},{-100,
                      -180},{-100,-298}},
                  color={255,0,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-78,134},{66,20}},
                  lineColor={0,0,0},
                  textString="OTSG")}),  Diagram(coordinateSystem(extent={{-180,
                    -300},{180,300}},
                           preserveAspectRatio=false)));
        end BaseOTSG;

        partial model BaseHPHTrain
          "Base model of the high pressure heaters train"

          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA MS_HPH_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{30,-120},{50,-100}})));
          ThermoPower.Water.FlangeA SEP_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-130,100},{-110,120}}),
                iconTransformation(extent={{-130,100},{-110,120}})));
          ThermoPower.Water.FlangeA SP1(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,100},{-40,120}}),
                iconTransformation(extent={{-60,100},{-40,120}})));
          ThermoPower.Water.FlangeA SP2(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{80,100},{100,120}}),
                iconTransformation(extent={{70,100},{90,120}})));
          ThermoPower.Water.FlangeA FW_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{180,-10},{200,10}})));
          ThermoPower.Water.FlangeB FW_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-200,-10},{-180,10}})));
          ThermoPower.Water.FlangeB DR_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{180,-70},{200,-50}}),
                iconTransformation(extent={{180,50},{200,70}})));
        equation

          annotation (Diagram(coordinateSystem(extent={{-180,-100},{180,100}},
                  preserveAspectRatio=false), graphics), Icon(coordinateSystem(extent={{-180,
                    -100},{180,100}}, preserveAspectRatio=false), graphics={
                Rectangle(
                  extent={{-180,100},{180,-100}},
                  lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{140,10},{160,-10}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{156,8},{156,-8},{140,0},{156,8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{30,-50},{50,-70}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{48,-66},{32,-66},{40,-50},{48,-66}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{60,20},{100,-20}},
                  lineColor={0,0,255}),
                Rectangle(
                  extent={{-60,20},{-20,-20}},
                  lineColor={0,0,255}),
                Rectangle(
                  extent={{-4,4},{4,-4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255}),
                Rectangle(
                  extent={{36,4},{44,-4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255}),
                Rectangle(
                  extent={{-128,8},{-112,-8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-50,-44},{-50,-36},{-40,-40},{-30,-36},{-30,-44},{-40,
                      -40},{-50,-44}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-120,100},{-120,10},{-120,0},{-60,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-180,0},{-140,0},{-120,0},{-120,-40},{-48,-40}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-50,100},{-50,72},{-50,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{80,100},{80,76},{80,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{180,0},{168,0},{160,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{140,0},{114,0},{100,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{60,0},{36,0},{-20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{40,-100},{40,-84},{40,-70}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-30,-40},{0,-40},{0,-4}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{40,-4},{40,-24},{40,-50}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-30,20},{-30,30},{70,30},{70,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{90,20},{90,40},{90,60},{180,60}},
                  color={127,127,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-40,-40},{-40,-50}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Polygon(
                  points={{-44,-46},{-36,-46},{-36,-48},{-38,-50},{-42,-50},{-44,
                      -48},{-44,-46}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-60,-54},{-16,-88}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="HPH2"),
                Text(
                  extent={{62,-52},{104,-86}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="HPH1"),
                Line(
                  points={{-60,0},{-52,0},{-50,8},{-46,-6},{-42,8},{-38,-6},{-34,8},{-30,
                      -6},{-28,0},{-20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{60,0},{68,0},{70,8},{74,-6},{78,8},{82,-6},{86,8},{90,-6},{92,
                      0},{100,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end BaseHPHTrain;

        partial model BaseLPHTrain
          "Base model of the high pressure heaters train"

          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA SP7(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{150,100},{170,120}}),
                iconTransformation(extent={{150,100},{170,120}})));
          ThermoPower.Water.FlangeA SP4(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-180,100},{-160,120}}),
                iconTransformation(extent={{-180,100},{-160,120}})));
          ThermoPower.Water.FlangeA SP5(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-70,100},{-50,120}}),
                iconTransformation(extent={{-70,100},{-50,120}})));
          ThermoPower.Water.FlangeA SP6(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,100},{60,120}}),
                iconTransformation(extent={{40,100},{60,120}})));
          ThermoPower.Water.FlangeA FW_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{240,-10},{260,10}})));
          ThermoPower.Water.FlangeB FW_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-260,-10},{-240,10}})));
        equation

          annotation (Diagram(coordinateSystem(extent={{-240,-100},{240,100}},
                  preserveAspectRatio=false), graphics), Icon(coordinateSystem(extent={{-240,
                    -100},{240,100}}, preserveAspectRatio=false), graphics={
                Rectangle(
                  extent={{-240,100},{240,-100}},
                  lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{200,10},{220,-10}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{216,8},{216,-8},{200,0},{216,8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{134,-28},{146,-40}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{144,-30},{144,-38},{134,-34},{144,-30}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{30,20},{70,-20}},
                  lineColor={0,0,255}),
                Rectangle(
                  extent={{-190,20},{-150,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{-60,100},{-60,72},{-60,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{240,0},{228,0},{220,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{140,0},{84,0},{70,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-50,20},{-50,30},{40,30},{40,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{140,-52},{182,-82}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH1"),
                Line(
                  points={{-190,0},{-182,0},{-180,8},{-176,-6},{-172,8},{-168,-6},
                      {-164,8},{-160,-6},{-158,0},{-150,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{30,0},{38,0},{40,8},{44,-6},{48,8},{52,-6},{56,8},{60,
                      -6},{62,0},{70,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Rectangle(
                  extent={{-80,20},{-40,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{-80,0},{-72,0},{-70,8},{-66,-6},{-62,8},{-58,-6},{-54,
                      8},{-50,-6},{-48,0},{-40,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-170,100},{-170,72},{-170,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-160,20},{-160,30},{-70,30},{-70,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{50,100},{50,72},{50,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{60,20},{60,30},{150,30},{150,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{160,100},{160,72},{160,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{140,20},{180,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{140,0},{148,0},{150,8},{154,-6},{158,8},{162,-6},{166,
                      8},{170,-6},{172,0},{180,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{200,0},{188,0},{180,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{30,0},{-32,0},{-40,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-80,0},{-142,0},{-150,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-190,0},{-232,0},{-240,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{116,4},{124,-4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255}),
                Line(
                  points={{134,-34},{124,-34},{120,-34},{120,-4}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{146,-34},{150,-34},{160,-34},{160,-20}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Text(
                  extent={{32,-50},{74,-84}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH2"),
                Text(
                  extent={{-78,-50},{-36,-84}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH3"),
                Text(
                  extent={{-188,-50},{-146,-84}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH4")}));
        end BaseLPHTrain;
      end BaseClasses;

      package Components "Package of heat transfer-related components"
        model HE "Model of MS/steam heat exchanger"

          extends
            PreFlexMS.FullScale_280degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";

          ThermoPower.Water.Flow1DFV coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}),
                              graphics),
                               Icon(graphics));
        end HE;

        model HE_2ph "Model of MS/steam heat exchanger with phase change"

          extends
            PreFlexMS.FullScale_280degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          ThermoPower.Water.Flow1DFV2ph coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                                annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}),
                              graphics),
                               Icon(graphics));
        end HE_2ph;

        model Equilibrium2phVessel
          "Base model of an adiabatic steam/liquid separator at thermodynamic equilibrium"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Length D "tank diameter";
          parameter Modelica.SIunits.Height H "Height of the tank";
          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
            "Cross Sectional Area";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.AbsolutePressure p_start "Start pressure";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));
          parameter Boolean noInitialLevel=true
            "Remove initial equation on level"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,-50},{-40,-30}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeB steam_out(
                                           redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}},  rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));

          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{40,-80},{60,-60}})));
          Modelica.Blocks.Interfaces.RealOutput DT_sh annotation (Placement(transformation(
                  extent={{-228,68},{-208,88}}), iconTransformation(extent={{40,40},{60,
                    60}})));

          Medium.ThermodynamicState state
            "Thermodynamic state of the separator";
          Medium.SaturationProperties sat
            "Saturation properties of the separator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate w_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_in
            "Medium inflow mass flow rate (liquid fraction)";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate wv_out "Medium steam outflow mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hv_out
            "Medium steam outlet specific enthalpy";
          Medium.SpecificEnthalpy hl "Bubble point specific enthalpy";
          Medium.SpecificEnthalpy hv "Dew-point specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Saturation temperature";
          Medium.AbsolutePressure p(start = p_start, stateSelect=StateSelect.prefer)
            "Medium pressure";
          Modelica.SIunits.SpecificEnthalpy h(start = h_start, stateSelect=StateSelect.prefer)
            "Specific mixture enthalpy";
          Modelica.SIunits.Density rho "Mixture density";
          ThermoPower.Units.LiquidDensity rho_l "Density of the liquid medium";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.MassFraction  x_in = Medium.vapourQuality(Medium.setState_ph(p,hl_in))
            "Inlet steam quality";
          Modelica.SIunits.MassFraction  x "Mixture steam quality";

          Real vf "Void fraction";
          Integer phase(start = 1)
            "Definition of thermodynamic state in the separator";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          phase = if h >= hv then 1 else 2;
          state = Medium.setState_ph(p,h,phase);
          T = Medium.temperature(state);
          T_sat = Medium.saturationTemperature(p);
          hv = Medium.dewEnthalpy(sat);
          hl = Medium.bubbleEnthalpy(sat);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(state);
          drdh = Medium.density_derh_p(state);
          wl_in = w_in*(1-x_in);

          //Mass and energy balances
          V*(drdp*der(p) + drdh*der(h)) = w_in - wl_out - wv_out;
          V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = w_in*hl_in - wl_out*hl_out - wv_out*hv_out;
          rho = Medium.density(state);
          x = Medium.vapourQuality(state);
          M = V*rho;
          Ml = M*(1-x);
          Ml = A*zl*rho_l;
          vf =(H-zl)/H;

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hv_out = if phase == 1 then h else hv;
          hl_out = if phase == 1 then h else hl;

          steam_out.h_outflow = hv_out;
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(steam_out.h_outflow)
            "Dummy equation for flow reversal";

          w_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          wv_out = -steam_out.m_flow;
          assert(w_in > -w_small, "Flow reversal not supported at phase separator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at phase separator liquid outlet");
          assert(wv_out > -w_small, "Flow reversal not supported at phase separator steam outlet");
          water_in.p = p;
          steam_out.p = p;
          drained_out.p = p;
          assert(vf>0,"Separator full");

          // Level sensor output
          level = zl;
          // Degree of superheating sensor
          DT_sh = max(0,T - T_sat);

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            if not noInitialLevel then
              zl = zl_start;
            end if;
            h = h_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<html>
<p>Modelling assumptions:</p>
<ul>
<li>The state can be either saturated liquid and saturated steam at thermodynamic equilibrium, or superheated steam.</li>
<li>Full liquid state not supported</li>
<li>No flow reversal at the ports</li>
<li>Reference zero level @ empty tank</li>
</ul>
</html>"));
        end Equilibrium2phVessel;

        model NusseltCondenser
          "Base model of condensing section based on Nusselt theory"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));
          Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                    {-60,0}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{-118,-74},{-98,-54}}),
                                              iconTransformation(extent={{-40,-80},{-60,
                    -60}})));

          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour";
          Medium.ThermodynamicState steamIn_state
            "Thermodynamic state of the inlet vapour";
          Medium.ThermodynamicState drainedIn_state
            "Thermodynamic state of the inlet drain";
          Medium.SaturationProperties sat "Saturation properties of the vapour";

          parameter Integer Nw "Number of volumes, tube side";
          parameter Modelica.SIunits.Volume V "Total volume";
          parameter Modelica.SIunits.Area A "Cross Sectional Area";
          parameter Modelica.SIunits.Height H=V/A
            "Height of the condensing volume";
          parameter Modelica.SIunits.Area S "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC";
          parameter Modelica.SIunits.Height zl_set "Liquid level set point";
          parameter Modelica.SIunits.Height zl_start "Liquid level start";
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        public
          Medium.MassFlowRate ws_in "Steam mass flow rate";
          Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
          Medium.MassFlowRate wd_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
          Modelica.SIunits.Height zl(start = zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = hv)
            "Specific internal enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv
            "Specific saturated steam enthalpy";
          Modelica.SIunits.Density rho_v "Steam density";
          Modelica.SIunits.Density rho_l "Liquid density";
          Real x_s "Vapour quality at steam inlet";
          Real x_d "Vapour quality at drained inlet";
          Modelica.SIunits.Power Q_cond "Condensation thermal load";
          Modelica.SIunits.Power Q_des_st
            "De-superheating power of steam inlet";
          Modelica.SIunits.Power Q_des_dr
            "De-superheating power of drained inlet";
          Modelica.SIunits.Power Qw[Nw]
            "Condensation thermal load on a single volume";
          Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

          ThermoPower.Thermal.DHTVolumes DHT(
            N = Nw) annotation (Placement(
                transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                    {50,20}})));
        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          vapour_state = Medium.setState_ph(p,h);
          steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
          drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
          T = Medium.temperature(vapour_state);
          rho_v = Medium.density(vapour_state);
          hv = Medium.dewEnthalpy(sat);
          hd_out = Medium.bubbleEnthalpy(sat);
          T_sat = Medium.saturationTemperature(p);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(vapour_state);
          drdh = Medium.density_derh_p(vapour_state);
          x_s = Medium.vapourQuality(steamIn_state);
          x_d = Medium.vapourQuality(drainedIn_state);

          //Mass and energy balances
          //Liquid mass balance
          rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond + wd_out;
          //Vapour mass balance
          Vv*(drdp*der(p) + drdh*der(h)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d - w_cond;
          //ws_in*x_s + wd_in*x_d - w_cond = 0;
          Vl = A*zl;
          Vv = V - Vl;
          //Vapour energy balance
          //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
          Q_des_st = max(0,ws_in*(hs_in - hv));
          Q_des_dr = max(0,wd_in*(hd_in - hv));
          for j in 1:Nw loop
            Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
          end for;
          Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
          w_cond = Q_cond/(h - hd_out);

          // Boundary conditions
          hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
             else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
            steam_in.h_outflow));
          hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
             else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
            drained_in.h_outflow));
          drained_out.h_outflow = hd_out;
          steam_in.h_outflow = inStream(drained_out.h_outflow);
          drained_in.h_outflow = inStream(drained_out.h_outflow);

          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          wd_out = drained_out.m_flow;
          steam_in.p = p;
          drained_in.p = p;
          drained_out.p = p;

          Tw = DHT.T;
          Qw = -DHT.Q;

          // Level set-point definition
          zl_SP = zl_set;
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(zl) = 0;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = hv;
            zl = zl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end NusseltCondenser;

        model NusseltCondenser_noLevel
          "Base model of condensing section based on Nusselt theory"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));

          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour";
          Medium.ThermodynamicState steamIn_state
            "Thermodynamic state of the inlet vapour";
          Medium.ThermodynamicState drainedIn_state
            "Thermodynamic state of the inlet drain";
          Medium.SaturationProperties sat "Saturation properties of the vapour";

          parameter Integer Nw "Number of volumes, tube side";
          parameter Modelica.SIunits.Volume V "Total volume";
          parameter Modelica.SIunits.Area A "Cross Sectional Area";
          parameter Modelica.SIunits.Height H=V/A
            "Height of the condensing volume";
          parameter Modelica.SIunits.Area S "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC";
          parameter Modelica.SIunits.Height zl
            "Liquid level (ideally controlled)";
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        public
          Medium.MassFlowRate ws_in "Steam mass flow rate";
          Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
          Medium.MassFlowRate wd_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
          Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = hv)
            "Specific internal enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv
            "Specific saturated steam enthalpy";
          Modelica.SIunits.Density rho_v "Steam density";
          Modelica.SIunits.Density rho_l "Liquid density";
          Real x_s "Vapour quality at steam inlet";
          Real x_d "Vapour quality at drained inlet";
          Modelica.SIunits.Power Q_cond "Condensation thermal load";
          Modelica.SIunits.Power Q_des_st
            "De-superheating power of steam inlet";
          Modelica.SIunits.Power Q_des_dr
            "De-superheating power of drained inlet";
          Modelica.SIunits.Power Qw[Nw]
            "Condensation thermal load on a single volume";
          Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

          ThermoPower.Thermal.DHTVolumes DHT(
            N = Nw) annotation (Placement(
                transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                    {50,20}})));
        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          vapour_state = Medium.setState_ph(p,h);
          steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
          drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
          T = Medium.temperature(vapour_state);
          rho_v = Medium.density(vapour_state);
          hv = Medium.dewEnthalpy(sat);
          hd_out = Medium.bubbleEnthalpy(sat);
          T_sat = Medium.saturationTemperature(p);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(vapour_state);
          drdh = Medium.density_derh_p(vapour_state);
          x_s = Medium.vapourQuality(steamIn_state);
          x_d = Medium.vapourQuality(drainedIn_state);

          //Mass and energy balances
          //Liquid mass balance
          //w_cond + ws_in*(1-x_s) + wd_in*(1-x_d) + wd_out = 0;
         // wd_out = theta_valve*Kv*
          //Vapour mass balance
          Vv*(drdp*der(p) + drdh*der(h))= ws_in*x_s + wd_in*x_d - w_cond;
          //ws_in*x_s + wd_in*x_d - w_cond = 0;
          Vl = A*zl;
          Vv = V - Vl;
          //Vapour energy balance
          //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
          Q_des_st = max(0,ws_in*(hs_in - hv));
          Q_des_dr = max(0,wd_in*(hd_in - hv));
          for j in 1:Nw loop
            Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
          end for;
          Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
          w_cond = Q_cond/(h - hd_out);

          // Boundary conditions
          hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
             else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
            steam_in.h_outflow));
          hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
             else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
            drained_in.h_outflow));
          drained_out.h_outflow = hd_out;
          steam_in.h_outflow = inStream(drained_out.h_outflow);
          drained_in.h_outflow = inStream(drained_out.h_outflow);

          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          wd_out = drained_out.m_flow;
          steam_in.p = p;
          drained_in.p = p;
          drained_out.p = p;

          Tw = DHT.T;
          Qw = -DHT.Q;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = hv;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end NusseltCondenser_noLevel;

        model Separator_controlledLevel
          "Model of a water/steam separator with control level "

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Length D "tank diameter";
          final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
            "Cross Sectional Area";
          parameter Modelica.SIunits.Height H "Height of the tank";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
          parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
          parameter Real PVmin "Minimum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVmax "Maximum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real CSstart=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real actuatorGain=0.5 "Actuator gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));

          ThermoPower.PowerPlants.Control.PID PID_level(
          Kp=Kp,
          Ti=Ti,
          Td=Td,
          Nd=Nd,
          PVmin=PVmin,
          PVmax=PVmax,
          CSmin=CSmin,
          CSmax=CSmax,
          CSstart=CSstart,
          PVstart=PVstart) annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={50,-10})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-64})));
          Equilibrium2phVessel             vessel(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            D=D,
            H=H,
            zl_start=zl_start,
            h_start=h_start,
            p_start=p_start)
            annotation (Placement(transformation(extent={{-58,-18},{58,88}})));
          ThermoPower.Water.FlangeA inlet(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-120,-10},{-100,10}}),
                iconTransformation(extent={{-60,-50},{-40,-30}})));
          ThermoPower.Water.FlangeB outlet_vap(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-10,100},{10,120}})));
          ThermoPower.Water.FlangeB outlet_liq(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-10,-120},{10,-100}}),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpDynamic(
            k=actuatorGain,
            T=Ta) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={50,-40})));
          Modelica.Blocks.Sources.Constant zl_SP(k=4)
            annotation (Placement(transformation(extent={{80,20},{60,40}})));
        equation
          connect(vessel.drained_out, waterPump.inlet) annotation (Line(
              points={{7.10543e-015,0.928571},{7.10543e-015,-40},{1.77636e-015,
                  -40},{1.77636e-015,-54}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(inlet, inlet) annotation (Line(
              points={{-110,0},{-110,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(inlet, vessel.water_in) annotation (Line(
              points={{-110,0},{-60,0},{-60,19.8571},{-20.7143,19.8571}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(waterPump.outlet, outlet_liq) annotation (Line(
              points={{-1.77636e-015,-74},{-1.77636e-015,-92},{0,-92},{0,-110}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(vessel.steam_out, outlet_vap) annotation (Line(
              points={{7.10543e-015,80.4286},{7.10543e-015,82},{0,82},{0,110}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(vessel.level, PID_level.PV) annotation (Line(
              points={{20.7143,8.5},{46,8.5},{46,0}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_level.CS, pumpDynamic.u) annotation (Line(
              points={{50,-20},{50,-28}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(pumpDynamic.y, waterPump.in_w0) annotation (Line(
              points={{50,-51},{50,-60},{6,-60}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(zl_SP.y, PID_level.SP) annotation (Line(
              points={{59,30},{54,30},{54,0}},
              color={0,0,127},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}), graphics),
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end Separator_controlledLevel;

        model Deaerator "Base model of an adiabatic deaerator"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=L*H "Cross Sectional Area";
          parameter Modelica.SIunits.Length L "tank length";
          parameter Modelica.SIunits.Height H "Height of the tank (squared)";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{26,70},{46,90}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-120},{10,-100}})));
          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-140,-80},{-120,-60}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-48,10},{-28,30}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{120,-90},{140,
                    -70}})));

          Medium.ThermodynamicState state
            "Thermodynamic state of the deaerator";
          Medium.SaturationProperties sat
            "Saturation properties of the deaerator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate wl_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate ws_in "Medium steam inlet mass flow rate";
          Medium.MassFlowRate wd_in "Medium drained inlet mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hs_in "Medium steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in
            "Medium drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hl "Medium internal specific enthalpy";
          Medium.SpecificEnthalpy hv "Medium internal specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          ThermoPower.Units.LiquidDensity rho_l "Density of the liquid medium";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = h_start, stateSelect=StateSelect.prefer)
            "Specific internal enthalpy";
          Medium.AbsolutePressure p( start = p_start, stateSelect=StateSelect.prefer)
            "Medium pressure";
          Modelica.SIunits.Density rho "Density";
          Modelica.SIunits.MassFraction  x "Mixture steam quality";
          Real vf "Void fraction";
          Integer phase(start = 2)
            "Definition of thermodynamic state in the separator";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          phase = if h >= hv then 1 else 2;
          state = Medium.setState_ph(p,h,phase);
          T = Medium.temperature(state);
          T_sat = Medium.saturationTemperature(p);
          hv = Medium.dewEnthalpy(sat);
          hl = Medium.bubbleEnthalpy(sat);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(state);
          drdh = Medium.density_derh_p(state);

          //Mass and energy balances
          V*(drdp*der(p) + drdh*der(h)) = wl_in - wl_out + ws_in + wd_in;
          V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = wl_in*hl_in - wl_out*hl_out + ws_in*hs_in + wd_in*hd_in;
          rho = Medium.density(state);
          x = Medium.vapourQuality(state);
          M = V*rho;
          Ml = M*(1-x);
          Ml = A*zl*rho_l;
          Vl = A*zl;
          Vv = V - Vl;
          vf = (H-zl)/H;

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hs_in = inStream(steam_in.h_outflow);
          hd_in = inStream(drained_in.h_outflow);
          hl_out = if phase == 1 then h else hl;

          steam_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";

          wl_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          assert(wl_in > -w_small, "Flow reversal not supported at deaerator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at deaerator liquid outlet");
          assert(ws_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          assert(wd_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          water_in.p = p;
          steam_in.p = p;
          drained_out.p = p;
          drained_in.p = p;
          assert(vf>0,"Separator full");

          // Level set-point definition
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = h_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-120,-10},{120,-92}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-10},{-116,-4},{-106,0},{-90,0},{-84,0},{-78,0},{-70,0},
                      {110,0},{116,-4},{120,-10},{-62,-10},{-120,-10}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-92},{-118,-98},{-114,-100},{-110,-100},{-106,-100},{-100,
                      -100},{-92,-100},{-86,-100},{114,-100},{118,-96},{120,-92},{-120,-92}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-34},{112,-88}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-16},{112,-34}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-16},{-110,-10},{-102,-8},{104,-8},{110,-10},{112,-16},{
                      -106,-16},{-112,-16}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-88},{-110,-92},{-104,-94},{0,-94},{106,-94},{110,-92},{
                      112,-88},{-112,-88}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,90},{26,0}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,90},{-26,96},{-20,100},{2,100},{8,100},{14,100},{16,100},
                      {22,98},{24,96},{26,90},{26,90},{-28,90}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-20,84},{-20,90},{-16,92},{14,92},{18,90},{18,84},{-14,84},{-20,
                      84}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,84},{18,-10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,76},{18,74}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,64},{10,62}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,40},{10,38}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,52},{18,50}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,28},{18,26}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,16},{10,14}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,4},{18,2}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end Deaerator;

        package Test

          model test_2ph_vessel_dryout
            "The vessel starts with some liquid, which is blown away by incoming steam"

            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              w0=95.31,
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{100,100},{120,120}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=500,
              offset=2872800,
              startTime=1000,
              height=-0*(2872800 - 2272800))
              annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
            Equilibrium2phVessel             vessel(
              D=0.56,
              H=8,
              zl_start=0,
              h_start=2e6,
              phase(start=1),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true,
              p_start=17710000)
              annotation (Placement(transformation(extent={{-18,-18},{38,32}})));
            ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,50},{40,70}})));
          equation
            connect(ramp.y, sourceMassFlow.in_h) annotation (Line(
                points={{-59,40},{-26,40},{-26,6}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(vessel.water_in, sourceMassFlow.flange) annotation (Line(
                points={{0,-0.142857},{0,0},{-20,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(vessel.steam_out, sinkMassFlow.flange) annotation (Line(
                points={{10,28.4286},{10,60},{20,60}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                      -120},{120,120}}),        graphics), Icon(coordinateSystem(extent={{
                      -120,-120},{120,120}})),
              experiment(StopTime=5000),
              __Dymola_experimentSetupOutput);
          end test_2ph_vessel_dryout;

          model test_2ph_vessel_filling
            "The vessel starts completely dry, then is filled by incoming wet steam"

            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              w0=95.31,
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{100,100},{120,120}})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=2872800,
              height=-(2872800 - 2272800),
              duration=100,
              startTime=5)
              annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
            Equilibrium2phVessel             vessel(
              D=0.56,
              H=8,
              zl_start=0,
              h_start=2e6,
              phase(start=1),
              noInitialPressure=true,
              p_start=17710000,
              initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-18,-18},{38,32}})));
            ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,50},{40,70}})));
          equation
            connect(ramp.y, sourceMassFlow.in_h) annotation (Line(
                points={{-59,40},{-26,40},{-26,6}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(vessel.water_in, sourceMassFlow.flange) annotation (Line(
                points={{0,-0.142857},{0,0},{-20,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(vessel.steam_out, sinkMassFlow.flange) annotation (Line(
                points={{10,28.4286},{10,60},{20,60}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                      -120},{120,120}}),        graphics), Icon(coordinateSystem(extent={{
                      -120,-120},{120,120}})),
              experiment(StopTime=200),
              __Dymola_experimentSetupOutput);
          end test_2ph_vessel_filling;

          model test_NusseltCondenser_HPH2
            "Test of the condensing section of the last high pressure preheater"

            NusseltCondenser baseNusseltCondenser(
              zl_set=0.1,
              zl_start=0.1,
              V=2.99*0.8,
              A=1,
              S=210*0.8,
              noInitialPressure=true,
              initOpt=ThermoPower.Choices.Init.Options.steadyState,
              gamma=8000,
              Nw=5,
              p_start=8150000)
              annotation (Placement(transformation(extent={{-28,12},{28,68}})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-62,36},{-42,56}})));
            ThermoPower.Water.SourcePressure sourceMassFlow1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=8150000,
              h=2760e3)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=1.095752222e-6)
              annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={0,-38})));
            ThermoPower.PowerPlants.Control.PID PID_level(
              PVmin=0,
              CSmin=0,
              Ti=15,
              Kp=-20,
              steadyStateInit=true,
              PVmax=1,
              CSmax=1,
              PVstart=0.1,
              CSstart=0.6) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-40,-10})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=2037000)
              annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
            ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={34,40})));
            Modelica.Blocks.Sources.Constant T_in(k=563.15) annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,60})));
            Modelica.Blocks.Sources.Constant T_out(k=567.15) annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,20})));
          equation
            connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
              annotation (Line(
                points={{-20,80},{0,80},{0,64}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
              annotation (Line(
                points={{-42,46},{-26,46},{-26,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                points={{-10,26},{-44,26},{-44,0}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-10,38},{-36,38},{-36,0}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDrain.cmd) annotation (Line(points={{-40,
                    -20},{-40,-20},{-40,-38},{-8,-38}}, color={0,0,127}));
            connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                  points={{0,-48},{0,-60},{20,-60}}, color={0,0,255}));
            connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
              annotation (Line(points={{0,22},{0,22},{0,-28}}, color={0,0,255}));
            connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
               Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
            connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                  points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
            connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                  points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})));
          end test_NusseltCondenser_HPH2;

          model test_Separator
            "Controlled separator test, with filling and dryout procedure"

            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              w0=95.31,
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{100,100},{120,120}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=500,
              startTime=10,
              offset=2772800,
              height=-9e5)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            Separator_controlledLevel base_2ph_vessel(
              Kp=-250,
              Ti=20,
              Td=0,
              Nd=1,
              PVmin=0,
              PVmax=20,
              CSmin=0,
              CSmax=150,
              actuatorGain=1,
              Ta=5,
              h_start=2740000,
              D=0.56,
              H=8,
              zl_start=4,
              vessel(initOpt=ThermoPower.Choices.Init.Options.fixedState,
                  noInitialPressure=true),
              p_start=17710000)
              annotation (Placement(transformation(extent={{-18,-20},{38,36}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,-50},{40,-30}})));
            Modelica.Blocks.Sources.Ramp ramp1(
              duration=500,
              offset=0,
              startTime=1500,
              height=9e5)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
          equation
            connect(sourceMassFlow.flange, base_2ph_vessel.inlet) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(base_2ph_vessel.outlet_vap, sinkPressure.flange) annotation (
                Line(
                points={{10,30},{10,60},{20,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(base_2ph_vessel.outlet_liq, sinkPressure1.flange) annotation (
                Line(
                points={{10,-10},{10,-40},{20,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(add.y, sourceMassFlow.in_h) annotation (Line(
                points={{-39,60},{-26,60},{-26,6}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(ramp.y, add.u2) annotation (Line(
                points={{-79,40},{-70,40},{-70,54},{-62,54}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(ramp1.y, add.u1) annotation (Line(
                points={{-79,80},{-70,80},{-70,66},{-62,66}},
                color={0,0,127},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                      -120},{120,120}}),        graphics), Icon(coordinateSystem(extent={{
                      -120,-120},{120,120}})),
              experiment(StopTime=2500),
              __Dymola_experimentSetupOutput);
          end test_Separator;

          model test_deaerator "Test model of the deaerator"

            Deaerator deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              p_start=900000,
              h_start=746000)
              annotation (Placement(transformation(extent={{-30,-26},{30,36}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=7.727,
              h=782000)
              annotation (Placement(transformation(extent={{-80,-30},{-60,-10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3102000,
              w0=3.551)
              annotation (Placement(transformation(extent={{-60,30},{-40,50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=77.31,
              h=630300)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
            ThermoPower.PowerPlants.Control.PID PID_level(
              Td=0,
              Nd=1,
              PVmin=0,
              CSmin=0,
              PVstart=0.78,
              CSstart=0.8859,
              PVmax=2.6,
              CSmax=100,
              Ti=10000,
              Kp=-500)       annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={66,-28})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=5)
                    annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={66,-60})));
            Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.SinkMassFlow    waterPump(
              allowFlowReversal=false,
              use_in_w0=true,
              w0=88.59,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-84})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
          equation
            connect(deaerator.drained_in, sourceMassFlow_DR.flange) annotation (
                Line(
                points={{-27.8571,-10.5},{-40,-10.5},{-40,-20},{-60,-20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.steam_in, sourceMassFlow_ST.flange) annotation (Line(
                points={{-8.14286,9.42857},{-20,9.42857},{-20,40},{-40,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.water_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{7.71429,22.7143},{8,22.7143},{8,60},{0,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PID_level.CS,pumpDynamic. u) annotation (Line(
                points={{66,-38},{66,-48}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(pumpDynamic.y,waterPump. in_w0) annotation (Line(
                points={{66,-71},{66,-80},{6,-80}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{79,0},{70,0},{70,-18}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.level, PID_level.PV) annotation (Line(
                points={{27.8571,-12.7143},{62,-12.7143},{62,-18}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.drained_out, waterPump.flange) annotation (Line(
                points={{0,-19.3571},{0,-74}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent=
                      {{-100,-100},{100,100}}), graphics),
              experiment(StopTime=5000),
              __Dymola_experimentSetupOutput);
          end test_deaerator;
        end Test;

      end Components;

      package OTSG
        "Package containing all the Once Through Steam Generator models"

        model OTSG_init100_5nodes_lin
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            Vhot=33.634,
            Vcold=6.027,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.28146e+006,1.32175e+006,1.35546e+006,
                  1.38444e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {560.978,569.126,575.7,581.167}),
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={136706,129914,122014,112572,100947},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                  1.66591e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                623.137}),
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={199579,192529,183185,168175,136603},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                  1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                  2.29575e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                629.917,629.888,630.182,630.842,632.016,634.097}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                  199646,197679},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                gamma_nom_2ph=10000,
                alpha=1.6),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                  2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                  2.69972e+006,2.74645e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                656.757,670.379,679.959,684.074,688.573,693.427}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                  295435,288187},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=0,
            h_start=2.7e6,
            D=0.56,
            p_start=17710000,
            noInitialPressure=true)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=false)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            Vhot=3.68,
            Vcold=2.683,
            tubeWalls(Tvolstart(displayUnit="K") = {725.391,769.727,804.861,
                826.169}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                  3.42731e+006},
              noInitialPressure=true),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,502443,472016,421345,355895},
              noInitialPressure=true),
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            Vhot=1.522,
            Vcold=5.092,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                  3.56013e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {734.495,783.217,812.321,
                829.047}),
            Shot=1339,
            Scold=1198,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,503128,476511,430304,353343},
              noInitialPressure=true),
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8)        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=582.8,
            dpnom=(0.52492/2)*10^5) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97)           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=12.52)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            wnom=88.59,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-240},{190,
                  -240}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,220},{-40,220},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,220},{90,220},{90,220},{90,220},{90,218},
                  {90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,192},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{6.66134e-016,200},{6.66134e-016,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
              points={{0,160},{0,136}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-264},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
              points={{50,10},{50,10},{50,64},{50,66},{10,66}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init100_5nodes_lin;

        model OTSG_init100_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            Vhot=33.634,
            Vcold=6.027,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.28146e+006,1.32175e+006,1.35546e+006,
                  1.38444e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {560.978,569.126,575.7,581.167}),
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={136706,129914,122014,112572,100947},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                  1.66591e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                623.137}),
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={199579,192529,183185,168175,136603},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                  1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                  2.29575e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                629.917,629.888,630.182,630.842,632.016,634.097}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                  199646,197679},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                gamma_nom_2ph=10000,
                alpha=1.6),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                  2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                  2.69972e+006,2.74645e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                656.757,670.379,679.959,684.074,688.573,693.427}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                  295435,288187},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=0,
            h_start=2.7e6,
            D=0.56,
            p_start=17710000,
            noInitialPressure=true)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            Vhot=3.68,
            Vcold=2.683,
            tubeWalls(Tvolstart(displayUnit="K") = {725.391,769.727,804.861,
                826.169}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                  3.42731e+006},
              noInitialPressure=true),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,502443,472016,421345,355895},
              noInitialPressure=true),
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            Vhot=1.522,
            Vcold=5.092,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                  3.56013e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {734.495,783.217,812.321,
                829.047}),
            Shot=1339,
            Scold=1198,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,503128,476511,430304,353343},
              noInitialPressure=true),
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8)        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=582.8,
            dpnom=(0.52492/2)*10^5) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97)           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=12.52)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            wnom=88.59,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-240},{190,
                  -240}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{30,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-152},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,220},{-40,220},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,220},{90,220},{90,220},{90,220},{90,218},
                  {90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,192},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-230},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{6.66134e-016,200},{6.66134e-016,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
              points={{0,160},{0,136}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init100_5nodes;

        model OTSG_init100_20nodes_lin
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 20 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 20
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 40
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            Vhot=33.634,
            Vcold=6.027,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.23186e+006,1.24323e+006,1.25407e+006,1.26441e+006,
                  1.27429e+006,1.28375e+006,1.2928e+006,1.30149e+006,1.30984e+006,
                  1.31787e+006,1.3256e+006,1.33306e+006,1.34026e+006,1.34721e+006,
                  1.35395e+006,1.36047e+006,1.3668e+006,1.37294e+006,1.37891e+006,
                  1.38472e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.505,559.549,561.488,
                563.332,565.087,566.76,568.358,569.885,571.347,572.748,574.093,
                575.386,576.629,577.827,578.983,580.099,581.178,582.223,583.235}),
            nominalColdPressure=17910000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={136842,135480,134081,132641,131159,129630,128052,126422,
                  124735,122987,121175,119293,117337,115300,113178,110962,108647,
                  106223,103683,101018},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.29102e+006,1.34032e+006,1.38192e+006,
                  1.41747e+006,1.44818e+006,1.47501e+006,1.49868e+006,
                  1.51977e+006,1.53874e+006,1.55595e+006,1.5717e+006,1.58622e+006,
                  1.59972e+006,1.61237e+006,1.6243e+006,1.63565e+006,1.64651e+006,
                  1.65699e+006,1.66716e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {571.123,579.527,586.384,
                592.055,596.803,600.827,604.275,607.262,609.876,612.186,614.245,
                616.096,617.776,619.311,620.724,622.036,623.262,624.415,625.509}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={200329,198854,197334,195758,194112,192380,190545,188586,
                  186479,184195,181698,178946,175885,172451,168559,164103,158946,
                  152909,145756,137173},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.66877e+006,1.67191e+006,1.67502e+006,
                  1.67812e+006,1.68121e+006,1.68428e+006,1.68735e+006,
                  1.69042e+006,1.69348e+006,1.69655e+006,1.69963e+006,
                  1.70272e+006,1.70582e+006,1.70894e+006,1.71209e+006,
                  1.71526e+006,1.71847e+006,1.72265e+006,1.72826e+006,
                  1.73465e+006,1.74192e+006,1.7502e+006,1.75963e+006,1.77037e+006,
                  1.78259e+006,1.7965e+006,1.81235e+006,1.83038e+006,1.85091e+006,
                  1.87429e+006,1.90089e+006,1.93118e+006,1.96565e+006,
                  2.00489e+006,2.04954e+006,2.10036e+006,2.15819e6,2.224e6,
                  2.29887e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {625.47,625.791,626.108,
                626.421,626.729,627.034,627.336,627.635,627.931,628.225,628.518,
                628.808,629.097,629.386,629.673,629.96,630.247,629.956,629.469,
                629.529,629.597,629.674,629.763,629.863,629.978,630.108,630.257,
                630.426,630.618,630.837,631.086,631.37,631.692,632.059,632.477,
                632.952,633.492,634.106,634.805}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289788,278889,269309,260890,253491,246990,241278,236260,
                  231851,227978,224575,221586,218961,216655,214629,212850,211287,
                  209914,208708,207650,206719,205903,205295,204828,204366,203908,
                  203453,203001,202552,202104,201657,201211,200764,200318,199870,
                  199421,198970,198516,198059,197599},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            tubeWalls(Tvolstart(displayUnit="K") = {650.47,650.866,651.269,
                651.679,652.097,652.522,652.956,653.397,653.846,654.304,654.769,
                655.244,655.726,656.218,656.719,657.228,660.331,675.049,675.851,
                676.675,677.521,678.389,679.279,680.19,681.124,682.078,683.052,
                684.047,685.063,686.099,687.154,688.23,689.324,690.436,691.567,
                692.714,693.877,695.057,696.25}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.29887e+006,2.31027e+006,2.32187e+006,2.33369e+006,
                  2.34573e+006,2.35799e+006,2.37047e+006,2.38319e+006,
                  2.39613e+006,2.40932e+006,2.42274e+006,2.43641e+006,
                  2.45034e+006,2.46452e+006,2.47896e+006,2.49366e+006,
                  2.50864e+006,2.52311e+006,2.53359e+006,2.54414e+006,
                  2.55474e+006,2.56539e+006,2.57608e+006,2.58682e+006,
                  2.59759e+006,2.60839e+006,2.61922e+006,2.63006e+006,
                  2.64092e+006,2.65179e+006,2.66265e+006,2.67351e+006,
                  2.68437e+006,2.6952e+006,2.70601e+006,2.71679e+006,2.72754e+006,
                  2.73825e6,2.7415e6,2.74562e6}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={356849,355304,353752,352194,350629,349059,347485,345908,
                  344328,342747,341165,339583,338003,336424,334848,333276,331707,
                  330144,328587,327037,325494,323959,322433,320326,318146,316005,
                  313903,311839,309812,307821,305867,303947,302063,300212,298395,
                  296610,294858,293137,291447,289788},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            h_start=2.7e6,
            D=0.56,
            zl_start=0,
            p_start=17710000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=false)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.74562e+006,2.80708e+006,2.8685e+006,2.92872e+006,2.98671e+006,3.04161e+006,
                  3.09279e+006,3.13986e+006,3.18267e+006,3.22121e+006,3.25563e+006,3.28615e+006,
                  3.31308e+006,3.33672e+006,3.35741e+006,3.37544e+006,3.39112e+006,3.40473e+006,
                  3.41652e+006,3.42672e+006},
              noInitialPressure=true),
            tubeWalls(Tvolstart(displayUnit="K") = {707.073,716.706,726.786,737.095,747.398,
                757.467,767.107,776.172,784.565,792.234,799.164,805.37,810.887,815.761,820.047,
                823.8,827.075,829.926,832.401}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={518322,
                  515892,513082,509839,506102,501805,496878,491244,484828,477554,469353,
                  460170,449971,438754,426559,413478,399661,385312,370679,356034},
              noInitialPressure=true),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={518322,
                  515738,512837,509580,505925,501823,497219,492053,486258,479757,472467,
                  464297,455144,444899,433444,420654,406405,390575,373063,353803},
              noInitialPressure=true),
            tubeWalls(Tvolstart(displayUnit="K") = {711.921,726.264,739.382,
                751.286,762.029,771.688,780.347,788.096,795.022,801.205,806.722,
                811.642,816.028,819.937,823.42,826.524,829.288,831.751,833.944}),
            Vhot=1.522,
            Vcold=5.092,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.0832e+006,3.13888e+006,3.1895e+006,3.23526e+006,
                  3.27646e+006,3.31343e+006,3.34654e+006,3.37616e+006,
                  3.40262e+006,3.42624e+006,3.44731e+006,3.46611e+006,
                  3.48286e+006,3.4978e+006,3.51111e+006,3.52296e+006,3.53353e+006,
                  3.54294e+006,3.55133e+006,3.5588e+006},
              noInitialPressure=false),
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8)        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=582.2,
            dpnom=(0.52492/2)*10^5) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97)           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            wnom=88.59,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-236},{82,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160},{-4.44089e-016,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-230},{98,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-38,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,220},{-40,220},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,220},{90,220},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,260},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,300},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(points={{-60,
                  -196},{-60,-204}},                color={0,0,255}));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(points={{-60,
                  -256},{-60,-260},{-60,-264}}, color={0,0,255}));
          connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-220},{84,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
              points={{50,10},{50,10},{50,66},{10,66}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init100_20nodes_lin;

        model OTSG_init100_20nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 20 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 20
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 40
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            Vhot=33.634,
            Vcold=6.027,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.23186e+006,1.24323e+006,1.25407e+006,1.26441e+006,
                  1.27429e+006,1.28375e+006,1.2928e+006,1.30149e+006,1.30984e+006,
                  1.31787e+006,1.3256e+006,1.33306e+006,1.34026e+006,1.34721e+006,
                  1.35395e+006,1.36047e+006,1.3668e+006,1.37294e+006,1.37891e+006,
                  1.38472e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {136842,135480,134081,132641,131159,129630,128052,126422,124735,
                  122987,121175,119293,117337,115300,113178,110962,108647,106223,
                  103683,101018}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.505,559.549,561.488,
                563.332,565.087,566.76,568.358,569.885,571.347,572.748,574.093,
                575.386,576.629,577.827,578.983,580.099,581.178,582.223,583.235}),
            nominalColdPressure=17910000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.29102e+006,1.34032e+006,1.38192e+006,
                  1.41747e+006,1.44818e+006,1.47501e+006,1.49868e+006,
                  1.51977e+006,1.53874e+006,1.55595e+006,1.5717e+006,1.58622e+006,
                  1.59972e+006,1.61237e+006,1.6243e+006,1.63565e+006,1.64651e+006,
                  1.65699e+006,1.66716e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {571.123,579.527,586.384,
                592.055,596.803,600.827,604.275,607.262,609.876,612.186,614.245,
                616.096,617.776,619.311,620.724,622.036,623.262,624.415,625.509}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {200329,198854,197334,195758,194112,192380,190545,188586,186479,
                  184195,181698,178946,175885,172451,168559,164103,158946,152909,
                  145756,137173}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            nominalHotPressure=1000000)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.66877e+006,1.67191e+006,1.67502e+006,
                  1.67812e+006,1.68121e+006,1.68428e+006,1.68735e+006,
                  1.69042e+006,1.69348e+006,1.69655e+006,1.69963e+006,
                  1.70272e+006,1.70582e+006,1.70894e+006,1.71209e+006,
                  1.71526e+006,1.71847e+006,1.72265e+006,1.72826e+006,
                  1.73465e+006,1.74192e+006,1.7502e+006,1.75963e+006,1.77037e+006,
                  1.78259e+006,1.7965e+006,1.81235e+006,1.83038e+006,1.85091e+006,
                  1.87429e+006,1.90089e+006,1.93118e+006,1.96565e+006,
                  2.00489e+006,2.04954e+006,2.10036e+006,2.15819e6,2.224e6,
                  2.29887e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {625.47,625.791,626.108,
                626.421,626.729,627.034,627.336,627.635,627.931,628.225,628.518,
                628.808,629.097,629.386,629.673,629.96,630.247,629.956,629.469,
                629.529,629.597,629.674,629.763,629.863,629.978,630.108,630.257,
                630.426,630.618,630.837,631.086,631.37,631.692,632.059,632.477,
                632.952,633.492,634.106,634.805}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {289788,278889,269309,260890,253491,246990,241278,236260,231851,
                  227978,224575,221586,218961,216655,214629,212850,211287,209914,
                  208708,207650,206719,205903,205295,204828,204366,203908,203453,
                  203001,202552,202104,201657,201211,200764,200318,199870,199421,
                  198970,198516,198059,197599}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            tubeWalls(Tvolstart(displayUnit="K") = {650.47,650.866,651.269,
                651.679,652.097,652.522,652.956,653.397,653.846,654.304,654.769,
                655.244,655.726,656.218,656.719,657.228,660.331,675.049,675.851,
                676.675,677.521,678.389,679.279,680.19,681.124,682.078,683.052,
                684.047,685.063,686.099,687.154,688.23,689.324,690.436,691.567,
                692.714,693.877,695.057,696.25}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {356849,355304,353752,352194,350629,349059,347485,345908,344328,
                  342747,341165,339583,338003,336424,334848,333276,331707,330144,
                  328587,327037,325494,323959,322433,320326,318146,316005,313903,
                  311839,309812,307821,305867,303947,302063,300212,298395,296610,
                  294858,293137,291447,289788}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.29887e+006,2.31027e+006,2.32187e+006,2.33369e+006,
                  2.34573e+006,2.35799e+006,2.37047e+006,2.38319e+006,
                  2.39613e+006,2.40932e+006,2.42274e+006,2.43641e+006,
                  2.45034e+006,2.46452e+006,2.47896e+006,2.49366e+006,
                  2.50864e+006,2.52311e+006,2.53359e+006,2.54414e+006,
                  2.55474e+006,2.56539e+006,2.57608e+006,2.58682e+006,
                  2.59759e+006,2.60839e+006,2.61922e+006,2.63006e+006,
                  2.64092e+006,2.65179e+006,2.66265e+006,2.67351e+006,
                  2.68437e+006,2.6952e+006,2.70601e+006,2.71679e+006,2.72754e+006,
                  2.73825e6,2.7415e6,2.74562e6}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            h_start=2.7e6,
            D=0.56,
            zl_start=0,
            p_start=17710000,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.74562e+006,2.80708e+006,2.8685e+006,2.92872e+006,2.98671e+006,3.04161e+006,
                  3.09279e+006,3.13986e+006,3.18267e+006,3.22121e+006,3.25563e+006,3.28615e+006,
                  3.31308e+006,3.33672e+006,3.35741e+006,3.37544e+006,3.39112e+006,3.40473e+006,
                  3.41652e+006,3.42672e+006},
              noInitialPressure=true),
            tubeWalls(Tvolstart(displayUnit="K") = {707.073,716.706,726.786,737.095,747.398,
                757.467,767.107,776.172,784.565,792.234,799.164,805.37,810.887,815.761,820.047,
                823.8,827.075,829.926,832.401}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={518322,
                  515892,513082,509839,506102,501805,496878,491244,484828,477554,469353,
                  460170,449971,438754,426559,413478,399661,385312,370679,356034},
              noInitialPressure=true),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={518322,
                  515738,512837,509580,505925,501823,497219,492053,486258,479757,472467,
                  464297,455144,444899,433444,420654,406405,390575,373063,353803},
              noInitialPressure=true),
            tubeWalls(Tvolstart(displayUnit="K") = {711.921,726.264,739.382,
                751.286,762.029,771.688,780.347,788.096,795.022,801.205,806.722,
                811.642,816.028,819.937,823.42,826.524,829.288,831.751,833.944}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.0832e+006,3.13888e+006,3.1895e+006,3.23526e+006,
                  3.27646e+006,3.31343e+006,3.34654e+006,3.37616e+006,
                  3.40262e+006,3.42624e+006,3.44731e+006,3.46611e+006,
                  3.48286e+006,3.4978e+006,3.51111e+006,3.52296e+006,3.53353e+006,
                  3.54294e+006,3.55133e+006,3.5588e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8)        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=582.2,
            dpnom=(0.52492/2)*10^5) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97)           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            wnom=88.59,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-236},{82,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160},{-4.44089e-016,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-230},{98,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-38,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{30,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-152},{50,-220},{84,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,220},{-40,220},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,220},{90,220},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,260},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-258},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,300},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(points={{-60,
                  -196},{-60,-204}},                color={0,0,255}));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(points={{-60,
                  -256},{-60,-260},{-60,-264}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init100_20nodes;

        model OTSG_init50_5nodes_lin
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26667e+006,1.25173e+006,1.26683e+006,
                  1.25157e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.843,557.837,557.843,
                557.837}),
            Vhot=33.634,
            Vcold=6.027,
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={93356,93346.5,93356.1,93346.6,93356.1},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                  1.3288e+006}),
            tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                569.474}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={119114,110526,103784,98376.4,93969.4},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                  1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                  1.45658e+006,1.56606e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                577.742,579.999,582.568,585.511,585.959,587.035}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={193708,157918,143681,138009,133137,128914,125226,121985,
                  119121,116578},
              noInitialPressure=true))          annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                  1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                  1.94272e+006,2.02642e+006}),
            tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                602.087,604.627,607.543,610.89,614.73,619.134}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            Shot=429.2,
            Scold=338,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={344122,316769,292958,272234,254202,238514,224868,213001,
                  202681,193708},
              noInitialPressure=true),
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=902.3,
            nominalColdOutletTemperature=921.8,
            nominalHotInletTemperature=1005.2,
            nominalHotOutletTemperature=961.1)  annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=4,
            phase(start=2, fixed=true),
            D=0.56,
            w_small=1e4,
            h_start=2416500,
            p_start=10100000,
            noInitialPressure=false,
            noInitialLevel=true,
            T(start=584.85))
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            tubeWalls(Tvolstart={733.236,797.905,827.469,835.959}),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,514827,501414,454805,353814},
              noInitialPressure=true),
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72364e+006,3.22113e+006,3.45073e+006,3.5168e+006,
                  3.53402e+006},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12533e+006,3.32376e+006,3.45094e+006,3.53171e+006,
                  3.58318e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {712.396,768.496,804.215,
                826.852}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,493431,454370,392870,296910},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            pin(start=10200000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=768.15,
            dpnom=(0.52492/2)*10^5,
            pin(start=10300000))           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            pin(start=10150000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            dpnom=(177.1 - 176.1)*10^5,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-236},{82,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-212})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-124},{-60,-130}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160},{-6.66134e-016,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-230},{98,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.inlet, HPH.outletHot) annotation (Line(
              points={{-16,-280},{-44,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{10,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,70},{50,218},{-40,218},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,288},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,226},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,246},{-100,186},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-42,48},{-50,48},{-60,48},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,258},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-4,-230},{-60,-230},{-60,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet)
            annotation (Line(points={{-60,-196},{-60,-202}}, color={0,0,255}));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(points={{-60,
                  -256},{-60,-256},{-60,-264}}, color={0,0,255}));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,310},{0,298},{4.44089e-016,298},{4.44089e-016,
                  290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{-6.66134e-016,270},{-6.66134e-016,200},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{6,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{48,10},{48,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init50_5nodes_lin;

        model OTSG_init50_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26667e+006,1.25173e+006,1.26683e+006,
                  1.25157e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {93356,93346.5,93356.1,93346.6,93356.1}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.843,557.837,557.843,
                557.837}),
            Vhot=33.634,
            Vcold=6.027,
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                  1.3288e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {119114,110526,103784,98376.4,93969.4}),
            tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                569.474}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                  1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                  1.45658e+006,1.56606e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {193708,157918,143681,138009,133137,128914,125226,121985,119121,
                  116578}),
            tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                577.742,579.999,582.568,585.511,585.959,587.035}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                  1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                  1.94272e+006,2.02642e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {344122,316769,292958,272234,254202,238514,224868,213001,202681,
                  193708}),
            tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                602.087,604.627,607.543,610.89,614.73,619.134}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=177600000,
            nominalHotPressure=7308000,
            nominalColdInletTemperature=902.3,
            nominalColdOutletTemperature=921.8,
            nominalHotInletTemperature=1005.2,
            nominalHotOutletTemperature=961.1)  annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=4,
            phase(start=2, fixed=true),
            D=0.56,
            w_small=1e4,
            noInitialPressure=false,
            h_start=2416500,
            noInitialLevel=false,
            p_start=10100000,
            T(start=584.85))
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72364e+006,3.22113e+006,3.45073e+006,3.5168e+006,
                  3.53402e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {518322,514827,501414,454805,353814}),
            tubeWalls(Tvolstart={733.236,797.905,827.469,835.959}),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12533e+006,3.32376e+006,3.45094e+006,3.53171e+006,
                  3.58318e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {518322,493431,454370,392870,296910}),
            tubeWalls(Tvolstart(displayUnit="K") = {712.396,768.496,804.215,
                826.852}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            pin(start=10200000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=768.15,
            dpnom=(0.52492/2)*10^5,
            pin(start=10300000))           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            pin(start=10150000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            dpnom=(177.1 - 176.1)*10^5,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-236},{82,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-212})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-124},{-60,-130}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160},{-6.66134e-016,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-230},{98,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.inlet, HPH.outletHot) annotation (Line(
              points={{-16,-280},{-44,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{10,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{6,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,70},{50,218},{-40,218},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-226},{50,-220},{84,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,288},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,226},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,246},{-100,186},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-42,48},{-50,48},{-60,48},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-252},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,258},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-4,-230},{-60,-230},{-60,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet)
            annotation (Line(points={{-60,-196},{-60,-202}}, color={0,0,255}));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(points={{-60,
                  -256},{-60,-256},{-60,-264}}, color={0,0,255}));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,310},{0,298},{4.44089e-016,298},{4.44089e-016,
                  290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{-6.66134e-016,270},{-6.66134e-016,200},{0,200}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init50_5nodes;

        model OTSG_init50_5nodes_noHPH
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                  1.3288e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {119114,110526,103784,98376.4,93969.4}),
            tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                569.474}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                  1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                  1.45658e+006,1.56606e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {193708,157918,143681,138009,133137,128914,125226,121985,119121,
                  116578}),
            tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                577.742,579.999,582.568,585.511,585.959,587.035}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                  1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                  1.94272e+006,2.02642e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {344122,316769,292958,272234,254202,238514,224868,213001,202681,
                  193708}),
            tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                602.087,604.627,607.543,610.89,614.73,619.134}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=4,
            h_start=2016500,
            phase(start=2, fixed=true),
            D=0.56,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            p_start=10100000,
            T(start=584.85))
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72364e+006,3.22113e+006,3.45073e+006,3.5168e+006,
                  3.53402e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {518322,514827,501414,454805,353814}),
            tubeWalls(Tvolstart={733.236,797.905,827.469,835.959}),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12533e+006,3.32376e+006,3.45094e+006,3.53171e+006,
                  3.58318e+006}),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                 {518322,493431,454370,392870,296910}),
            tubeWalls(Tvolstart(displayUnit="K") = {712.396,768.496,804.215,
                826.852}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            pin(start=10200000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            rhonom=768.15,
            dpnom=(0.52492/2)*10^5,
            pin(start=10300000))           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            pin(start=10150000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            dpnom=(177.1 - 176.1)*10^5,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-236},{82,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-212})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160},{-6.66134e-016,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-230},{98,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{10,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{6,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,70},{50,218},{-40,218},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-226},{50,-220},{84,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,288},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,226},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,246},{-100,186},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-42,48},{-50,48},{-60,48},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-252},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,258},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{86,-230},{86,-230},{-4,-230},{-60,-230},{-60,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet)
            annotation (Line(points={{-60,-196},{-60,-202}}, color={0,0,255}));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(ECO.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-76,-180},{-100,-180},{-100,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_FW.outlet, MS_HPH_out) annotation (Line(
              points={{86,-230},{14,-230},{-60,-230},{-60,-310}},
              color={0,0,255},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(points={{0,310},{
                  6.66134e-016,310},{6.66134e-016,290}}, color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange)
            annotation (Line(points={{0,270},{0,270},{0,200}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init50_5nodes_noHPH;

        model OTSG_init50_20nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 20 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 20
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 40
            "Number of nodes for biphase heat exchangers";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            tubeWalls(Tvolstart(displayUnit="K")),
            Nhex=60,
            Vhot=33.634,
            Vcold=6.027,
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=556.45,
            nominalColdOutletTemperature=556.55,
            nominalHotInletTemperature=558.25,
            nominalHotOutletTemperature=558.15,
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))        annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.25451e+006,1.25725e+006,1.26011e+006,
                  1.26308e+006,1.26619e+006,1.26943e+006,1.27281e+006,
                  1.27635e+006,1.28004e+006,1.28392e+006,1.28797e+006,
                  1.29222e+006,1.29668e+006,1.30136e+006,1.30628e+006,
                  1.31146e+006,1.31691e+006,1.32267e+006,1.32874e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.251,557.785,558.341,
                558.919,559.522,560.149,560.803,561.486,562.198,562.941,563.717,
                564.529,565.379,566.268,567.2,568.177,569.203,570.281,571.414}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={119114,117128,115248,113465,111773,110164,108634,107177,
                  105788,104462,103197,101988,100832,99725.3,98665.9,97650.9,
                  96677.8,95744.5,94848.9,93988.9},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.33e+006,1.33177e+006,1.33359e+006,1.33546e+006,
                  1.33738e+006,1.33935e+006,1.34138e+006,1.34346e+006,
                  1.34561e+006,1.34781e+006,1.35008e+006,1.35242e+006,
                  1.35482e+006,1.3573e+006,1.35985e+006,1.36248e+006,1.36519e+006,
                  1.36798e+006,1.37086e+006,1.37384e+006,1.37691e+006,
                  1.38008e+006,1.38335e+006,1.38674e+006,1.39024e+006,
                  1.39387e+006,1.39762e+006,1.4015e+006,1.40553e+006,1.4097e+006,
                  1.41406e+006,1.42073e+006,1.42889e+006,1.43884e+006,1.451e+006,
                  1.46584e+006,1.48395e+006,1.50606e+006,1.53e6,1.56596e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {571.855,572.198,572.549,
                572.91,573.28,573.66,574.05,574.451,574.862,575.285,575.719,
                576.166,576.625,577.097,577.582,578.081,578.595,579.124,579.669,
                580.23,580.808,581.403,582.017,582.651,583.304,583.978,584.674,
                585.393,586.135,586.886,585.708,585.807,585.936,586.094,586.287,
                586.522,586.809,587.159,587.586}),
            Vhot=26.587,
            Vcold=8.651,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                alpha=1.6,
                gamma_nom_2ph=10000),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={193815,183049,174227,166998,161076,156224,152250,148995,
                  146328,144147,142724,141359,140043,138773,137547,136363,135218,
                  134112,133041,132005,131002,130031,129089,128177,127292,126434,
                  125601,124793,124008,123246,122506,121786,121087,120407,119745,
                  119102,118476,117866,117273,116696},
              noInitialPressure=true),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.56596e+006,1.57196e+006,1.57816e+006,1.58456e+006,
                  1.59118e+006,1.59801e+006,1.60506e+006,1.61234e+006,
                  1.61986e+006,1.62763e+006,1.63565e+006,1.64394e+006,
                  1.65249e+006,1.66133e+006,1.67045e+006,1.67987e+006,1.6896e+006,
                  1.69965e+006,1.71003e+006,1.72074e+006,1.7318e+006,1.74323e+006,
                  1.75503e+006,1.76721e+006,1.77979e+006,1.79278e+006,
                  1.80619e+006,1.82004e+006,1.83434e+006,1.84911e+006,
                  1.86435e+006,1.88009e+006,1.89635e+006,1.91313e+006,
                  1.93046e+006,1.94835e+006,1.96682e+006,1.98589e6,1.996e6,2.02e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {595.682,596.028,596.386,
                596.755,597.136,597.53,597.936,598.356,598.789,599.237,599.699,
                600.176,600.668,601.177,601.702,602.244,602.804,603.381,603.978,
                604.594,605.229,605.886,606.563,607.263,607.984,608.73,609.499,
                610.293,611.113,611.959,612.832,613.733,614.663,615.624,616.614,
                617.637,618.692,619.781,620.905}),
            Vhot=3.905,
            Vcold=1.065,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={344122,337479,331044,324811,318775,312928,307265,301780,
                  296468,291323,286340,281515,276841,272315,267932,263687,259576,
                  255595,251739,248006,244390,240889,237498,234215,231036,227957,
                  224976,222089,219293,216586,213965,211427,208969,206590,204285,
                  202054,199894,197802,195776,193815},
              noInitialPressure=true),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=4,
            phase(start=2, fixed=true),
            D=0.56,
            h_start=2e6,
            p_start=10100000,
            T(start=584.85))
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            tubeWalls(Tvolstart(displayUnit="K") = {701.192,720.859,740.557,
                758.771,774.634,787.907,798.731,807.419,814.323,819.772,824.056,
                827.413,830.038,832.088,833.687,834.934,835.905,836.661,837.25}),
            Vhot=3.68,
            Vcold=2.683,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,517811,517154,516309,515225,513832,512044,509752,
                  506814,503054,498249,492123,484340,474500,462153,446842,428199,
                  406136,381092,354210},
              noInitialPressure=true),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72364e+006,2.85606e+006,2.97943e+006,3.08812e+006,
                  3.17995e+006,3.25538e+006,3.3162e+006,3.36467e+006,3.40301e+006,
                  3.43319e+006,3.45686e+006,3.47538e+006,3.48985e+006,
                  3.50115e+006,3.50995e+006,3.51681e+006,3.52215e+006,
                  3.52631e+006,3.52955e+006,3.53207e+006},
              noInitialPressure=true),
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12533e+006,3.17417e+006,3.21887e+006,3.25968e+006,
                  3.29688e+006,3.33075e+006,3.36159e+006,3.38966e+006,3.4152e+006,
                  3.43844e+006,3.45959e+006,3.47885e+006,3.49637e+006,
                  3.51234e+006,3.52687e+006,3.54011e+006,3.55218e+006,
                  3.56317e+006,3.57319e+006,3.58232e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {686.808,702.938,717.69,
                731.147,743.403,754.555,764.697,773.919,782.303,789.927,796.861,
                803.168,808.906,814.128,818.881,823.208,827.149,830.739,834.01}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,513905,509059,503742,497908,491505,484475,476756,
                  468280,458969,448740,437500,425150,411577,396664,380281,362292,
                  342558,320942,297321},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));

          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-66,242},{-46,222}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            rhonom=582.24,
            wnom=88.59,
            pin(start=102e5))    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-58})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492)*10^5,
            rhonom=768.15,
            pin(start=103e5))              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=250,
            pin(start=10150000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            rhonom=96.586,
            wnom=88.59)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,170})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{104,-236},{84,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-248})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-46,232},{140,232},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-48},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-68}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,160}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{100,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-30,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{50,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-204},{50,-220},{86,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,34},{50,218},{-60,218},{-60,226}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,246},{-100,140},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,232},{-66,232}},
              color={255,0,0},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,180},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-42,48},{-52,48},{-60,48},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-252},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{88,-230},{88,-230},{14,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{88,-230},{88,-230},{-60,-230},{-60,-238}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet)
            annotation (Line(points={{-60,-196},{-60,-204}}, color={0,0,255}));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(points={{-60,
                  -258},{-60,-258},{-60,-264}},            color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init50_20nodes;

        model OTSG_init20_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 20% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            tubeWalls(Tvolstart(displayUnit="K") = {557.65,557.653,557.662,557.69}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={93204,93107.6,93079.6,93070.9,93067.6},
              noInitialPressure=true),
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25835e+006,1.25836e+006,1.25838e+006,1.25843e+006,
                  1.25862e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_2ph=25350,
                gamma_nom_vap=3875,
                alpha=1.6),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25835e+006,1.2597e+006,1.26181e+006,1.2651e+006,
                  1.27023e+006,1.27828e+006,1.29095e+006,1.31099e+006,
                  1.34301e+006,1.39506e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.961,558.395,559.071,
                560.126,561.776,564.358,568.414,574.81,584.965}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={165420,138076,121257,110733,104086,99862.4,97169.5,95448.2,
                  94345.9,93638.9},
              noInitialPressure=true),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_2ph=6000,
                gamma_nom_liq=2600,
                gamma_nom_vap=2600),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.39506e+006,1.40604e+006,1.42359e+006,1.44608e+006,
                  1.47414e+006,1.50913e+006,1.55276e+006,1.60714e+006,
                  1.67488e+006,1.75921e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {596.362,594.413,596.184,
                599.13,602.802,607.374,613.064,620.14,628.927}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={356546,312270,276709,248166,225266,206901,192178,180378,
                  171175,165420},
              noInitialPressure=true),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            zl_start=4,
            phase(fixed=true, start=2),
            noInitialPressure=false,
            noInitialLevel=true,
            w_small=1e4,
            h_start=1.5e6,
            p_start=10010000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            Vhot=3.68,
            Vcold=2.683,
            tubeWalls(Tvolstart(displayUnit="K") = {764.198,822.03,836.654,
                838.039}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72529e+006,3.35384e+006,3.52174e+006,3.53772e+006,
                  3.53903e+006},
              noInitialPressure=true),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,518096,515357,486572,378819},
              noInitialPressure=true),
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            Vhot=1.522,
            Vcold=5.092,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12459e+006,3.31132e+006,3.44042e+006,3.53111e+006,
                  3.59583e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {686.149,749.323,792.977,
                823.682}),
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,480112,426575,350366,240145},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            rhonom=582.24,
            wnom=88.59)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492)*10^5,
            rhonom=768.15)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=250)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            dpnom=(177.1 - 176.1)*10^5,
            rhonom=51.9)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,160})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            tubeWalls(Tvolstart(displayUnit="K") = {557.843,557.837,557.843,
                557.837}),
            Vhot=33.634,
            Vcold=6.027,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={93356,93346.5,93356.1,93346.6,93356.1},
              noInitialPressure=true),
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=581.85,
            nominalHotInletTemperature=586.85,
            nominalHotOutletTemperature=563.15,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25188e+006,1.26667e+006,1.25173e+006,1.26683e+006,
                  1.25157e+006},
              noInitialPressure=false))         annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-212})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{130,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{30,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-152},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,218},{-40,218},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,260},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,170}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
              points={{-6.66134e-016,150},{0,150},{0,136}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,300},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,270},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{84,-230},{84,-230},{-4,-230},{-60,-230},{-60,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{84,-230},{84,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet,HPH. inletCold) annotation (Line(points={{-60,
                  -256},{-60,-256},{-60,-264}}, color={0,0,255}));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-30,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(PDSteamECO1.outlet, ECO.inletCold) annotation (Line(points={{
                  -60,-202},{-60,-202},{-60,-196}}, color={0,0,255}));
          connect(HPH.outletCold, MS_HPH_out)
            annotation (Line(points={{-60,-296},{-60,-310}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init20_5nodes;

        model OTSG_init20_20nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 20% load and 20 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 20
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 40
            "Number of nodes for biphase heat exchangers";

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25835e+006,1.25835e+006,1.25835e+006,1.25835e+006,1.25836e+006,1.25836e+006,
                  1.25836e+006,1.25836e+006,1.25837e+006,1.25837e+006,1.25838e+006,1.25839e+006,
                  1.2584e+006,1.25841e+006,1.25843e+006,1.25845e+006,1.25848e+006,1.25852e+006,
                  1.25856e+006,1.25862e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.649,557.65,557.65,557.65,557.651,
                557.651,557.652,557.653,557.654,557.655,557.657,557.659,557.662,557.666,
                557.671,557.676,557.684,557.693,557.705}),
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={93204,93175.1,93152.3,93134.2,93120,93108.7,93099.8,93092.7,
                  93087.1,93082.7,93079.2,93076.4,93074.2,93072.5,93071.1,93069.9,
                  93069.1,93068.3,93067.8,93067.3},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_2ph=25350,
                gamma_nom_vap=3875,
                alpha=1.6),
            nominalColdFlow=88.59,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25835e+006,1.25863e+006,1.25893e+006,1.25927e+006,1.25965e+006,1.26006e+006,
                  1.26052e+006,1.26102e+006,1.26158e+006,1.2622e+006,1.26289e+006,1.26364e+006,
                  1.26448e+006,1.26541e+006,1.26644e+006,1.26757e+006,1.26883e+006,1.27022e+006,
                  1.27177e+006,1.27347e+006,1.27537e+006,1.27746e+006,1.27978e+006,1.28236e+006,
                  1.28521e+006,1.28837e+006,1.29188e+006,1.29577e+006,1.30009e+006,1.30489e+006,
                  1.31022e+006,1.31614e+006,1.32272e+006,1.33005e+006,1.33821e+006,1.3473e+006,
                  1.35745e+006,1.36878e6,1.38e6,1.39564e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {557.837,557.911,557.991,558.081,558.179,
                558.289,558.409,558.543,558.691,558.854,559.035,559.235,559.457,559.702,
                559.972,560.272,560.604,560.971,561.378,561.827,562.325,562.877,563.487,
                564.163,564.911,565.741,566.659,567.677,568.805,570.055,571.441,572.978,
                574.683,576.574,578.674,581.006,583.596,586.473,589.673}),
            Vhot=26.587,
            Vcold=8.651,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={165796,158329,151664,145706,140372,135593,131305,127456,
                  123997,120887,118090,115571,113304,111261,109420,107760,106264,
                  104914,103696,102597,101605,100709,99900.7,99170.6,98511.2,
                  97915.6,97377.6,96891.6,96452.5,96055.7,95697.1,95373,95080.1,
                  94815.4,94576.1,94359.8,94164.3,93987.5,93827.6,93683.1},
              noInitialPressure=true),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_2ph=6000,
                gamma_nom_liq=2600,
                gamma_nom_vap=2600),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.39564e+006,1.3981e+006,1.40061e+006,1.40317e+006,1.40579e+006,1.40851e+006,
                  1.41247e+006,1.41666e+006,1.42105e+006,1.42567e+006,1.43052e+006,1.43562e+006,
                  1.44099e+006,1.44664e+006,1.45258e+006,1.45883e+006,1.46541e+006,1.47233e+006,
                  1.47961e+006,1.48727e+006,1.49533e+006,1.5038e+006,1.51272e+006,1.5221e+006,
                  1.53197e+006,1.54236e+006,1.55328e+006,1.56477e+006,1.57685e+006,1.58956e+006,
                  1.60294e+006,1.617e+006,1.63179e+006,1.64735e+006,1.66371e+006,1.68092e+006,
                  1.69902e+006,1.71806e+006,1.738e6,1.758e6}),
            tubeWalls(Tvolstart(displayUnit="K") = {595.418,596.076,596.746,597.427,598.122,
                593.494,593.825,594.323,594.848,595.399,595.98,596.59,597.232,597.908,598.619,
                599.366,600.153,600.98,601.85,602.765,603.727,604.739,605.804,606.923,608.101,
                609.339,610.64,612.009,613.448,614.961,616.552,618.224,619.982,621.83,623.772,
                625.813,627.958,630.212,632.58}),
            Vhot=3.905,
            Vcold=1.065,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={356546,345492,334980,324985,315480,306442,297849,289679,
                  281911,274525,267504,260830,254484,248452,242718,237267,232086,
                  227161,222479,218029,213800,209780,205959,202327,198875,195595,
                  192477,189514,186698,184021,181478,179060,176763,174580,172520,
                  171124,169754,168410,167091,165796},
              noInitialPressure=true),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_start=4,
            phase(start=2, fixed=true),
            D=0.56,
            h_start=1.5e6,
            p_start=10010000,
            w_small=1e4)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            tubeWalls(Tvolstart(displayUnit="K") = {731.796,755.354,776.539,793.603,806.462,
                815.817,822.5,827.226,830.55,832.88,834.509,835.647,836.441,836.995,837.382,
                837.651,837.838,837.969,838.06}),
            Vhot=3.68,
            Vcold=2.683,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.72529e+006,2.91596e+006,3.07983e+006,3.20863e+006,
                  3.30452e+006,3.37387e+006,3.42325e+006,3.45811e+006,3.4826e+006,
                  3.49975e+006,3.51175e+006,3.52012e+006,3.52597e+006,
                  3.53004e+006,3.53289e+006,3.53487e+006,3.53625e+006,
                  3.53721e+006,3.53788e+006,3.53834e+006},
              noInitialPressure=true),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,518242,518127,517962,517726,517386,516899,516200,
                  515199,513763,511706,508765,504566,498590,490125,478237,461797,
                  439716,411624,378937},
              noInitialPressure=true),
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={3.12459e+006,3.16961e+006,3.21122e+006,3.2497e+006,3.28529e+006,3.31823e+006,
                  3.34874e+006,3.37702e+006,3.40325e+006,3.4276e+006,3.45023e+006,3.47127e+006,
                  3.49084e+006,3.50907e+006,3.52605e+006,3.54188e+006,3.55665e+006,3.57043e+006,
                  3.5833e+006,3.59532e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {657.909,675.332,691.412,706.255,719.965,
                732.636,744.358,755.211,765.269,774.598,783.257,791.302,798.782,805.742,
                812.222,818.259,823.888,829.139,834.039}),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45,
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={518322,511224,503626,495489,486771,477425,467400,456641,
                  445085,432665,419308,404931,389445,372752,354743,335298,314289,
                  291576,267010,240439},
              noInitialPressure=true))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,210})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.05828)*10^5,
            rhonom=582.24,
            wnom=88.59,
            pin(start=10030000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492)*10^5,
            rhonom=768.15,
            pin(start=10050000))           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-138})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=250,
            pin(start=10010000)) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = EVA1.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            rhonom=96.586,
            wnom=88.59)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,160})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            w0=610.6,
            use_in_w0=true,
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,200})));
          ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph,
            Av=0.046406353,
            wnom=88.59,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17610000,
            dpnom=110000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            Shot=2429.5,
            Scold=1913.2,
            Mm=29335,
            nominalColdFlow=143.1,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.447465),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=5000, alpha=0.536143),
            Vhot=33.634,
            Vcold=6.027,
            nominalColdPressure=17910000,
            nominalHotPressure=400000,
            nominalColdInletTemperature=559.15,
            nominalColdOutletTemperature=560.15,
            nominalHotInletTemperature=561.15,
            nominalHotOutletTemperature=560.15,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              noInitialPressure=false),
            tubeWalls(Tvolstart(displayUnit="K")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))        annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            pin(start=103.5e5))            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-212})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=767.7,
            wnom=143.1,
            dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,216}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
              points={{-60,-164},{-60,-148}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
              points={{-60,-116},{-60,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,150},{-6.66134e-016,150}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,204},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{160,-230},{160,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,218},{52,218},{-40,218},{-40,224}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,218},{90,218}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{6,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,310},{-100,266},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,120},{-16,120}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
              points={{0,200},{0,185},{0,170}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-42,48},{-50,48},{-60,48},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,10},{50,10},{50,198},{50,192},{10,192}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,10},{50,10},{50,280},{8,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,300},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{-6.66134e-016,270},{-6.66134e-016,235},{0,235},{0,200}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(sensT_FW.outlet,PDSteamECO1. inlet) annotation (Line(
              points={{84,-230},{84,-230},{-2,-230},{-60,-230},{-60,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet,PDSteamHPH. inlet) annotation (Line(
              points={{84,-230},{84,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet,HPH. inletCold) annotation (Line(points={{-60,
                  -256},{-60,-256},{-60,-264}}, color={0,0,255}));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet)
            annotation (Line(points={{-60,-196},{-60,-202}}, color={0,0,255}));
          connect(HPH.outletCold, MS_HPH_out)
            annotation (Line(points={{-60,-296},{-60,-310}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init20_20nodes;

        model OTSG_init4_5nodes_noDP
          "Complete dynamic model of the once through steam generator, with separate 2ph HTC"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";

          Components.HE ECO(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            Vhot=45.011,
            Vcold=5.752,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72)
            annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_2ph=25350,
                gamma_nom_vap=3875,
                alpha=1.6),
            nominalColdFlow=88.59,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Vhot=26.587,
            Vcold=8.651,
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));

          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_2ph=6000,
                gamma_nom_liq=2600,
                gamma_nom_vap=2600),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Vhot=3.905,
            Vcold=1.065,
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            zl_min=0,
            zl_max=7,
            zl_start=0,
            h_start=2.7e6,
            D=0.56,
            p_start=17710000,
            initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,4})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            Mm=15353,
            nominalColdFlow=88.59,
            nominalHotFlow=371.8,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2200, alpha=0.847436),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.28867),
            Nhex=Nhex_mono,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Vhot=3.68,
            Vcold=2.683,
            Shot=1153.8,
            Scold=879.8,
            nominalColdPressure=17710000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=648.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=732.02)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,120})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Mm=10081,
            nominalColdFlow=82.57,
            nominalHotFlow=238.7,
            Shot=1339,
            Scold=1198,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=970),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2600, alpha=0.320782),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Vhot=1.522,
            Vcold=5.092,
            nominalColdPressure=4698000,
            nominalHotPressure=1000000,
            nominalColdInletTemperature=625.65,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.15,
            nominalHotOutletTemperature=731.45)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));

          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            w0=238.7,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-46,270},{-26,250}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,230})));

          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T;
          Modelica.SIunits.Temperature T_outMS = sensT_MS.T;
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            dpnom=(177.1 - 176.1189)*10^5,
            rhonom=96.586,
            wnom=88.59)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,188})));
          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=82.57,
            dpnom=(0.55113)*10^5,
            rhonom=17.86)                  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,190})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-276},{0,-256}})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{102,-246},{82,-226}})));
          ThermoPower.Water.SensP sensP_ECO(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-56,-140})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{190,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,260},{140,260},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(MS_in, valveRH.inlet) annotation (Line(
              points={{-100,310},{-100,260},{-46,260}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,236}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(MS_in, SH.inletHot) annotation (Line(
              points={{-100,310},{-100,120},{-16,120}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,14},{1.77636e-015,14}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.inletCold, separator.steam_out) annotation (Line(
              points={{0,104},{0,80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,120},{140,120},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-210},{-44,-210}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-6},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
              points={{0,136},{0,178}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(SH_out, PDSteamSH.outlet) annotation (Line(
              points={{0,310},{0,198}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,224},{100,200}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,-20},{50,8},{6,8}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,246},{50,244},{-40,244},{-40,254}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
              points={{50,10},{50,10},{50,244},{90,244},{90,238}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-270},{20,-270},{20,-310}},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled},
              color={255,0,0}));
          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{98,-240},{98,-240},{190,-240}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(sensT_FW.outlet, ECO.inletCold) annotation (Line(
              points={{86,-240},{86,-240},{-60,-240},{-60,-226}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-200},{50,-230},{84,-230}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_MS.T) annotation (Line(
              points={{50,10},{50,10},{50,-260},{-2,-260}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, sensP_ECO.flange) annotation (Line(
              points={{-60,-116},{-60,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, sensP_ECO.p) annotation (Line(
              points={{50,10},{50,10},{50,-158},{-50,-158},{-50,-148}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA2.inletCold, EVA1.outletCold)
            annotation (Line(points={{-60,-36},{-60,-84}},           color={0,0,255}));
          connect(sensP_ECO.flange, ECO.outletCold) annotation (Line(points={{-60,
                  -140},{-60,-140},{-60,-194}},      color={0,0,255}));
          connect(EVA2.outletCold, separator.water_in) annotation (Line(points={{-60,-4},
                  {-60,-4},{-60,48},{-10,48}},          color={0,0,255}));
          connect(ECO.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-76,-210},{-100,-210},{-100,-270},{-16,-270}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
        end OTSG_init4_5nodes_noDP;

        package Test

          package HE "Package of single heat exchanger test model"

            model test_heatExchangers
              "Test model of all the heat exchangers, at nominal point, steady-state initialisation"

              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                w0=371.8,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322,
                use_in_w0=false,
                p0=1000000) annotation (Placement(transformation(extent={{-200,
                        80},{-180,100}})));

              ThermoPower.Water.SourceMassFlow sourceSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=2745621,
                p0=17710000)
                annotation (Placement(transformation(extent={{-200,60},{-180,80}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17611890)
                annotation (Placement(transformation(extent={{-140,120},{-120,140}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-110,
                        80},{-90,100}})));

              ThermoPower.Water.PressDrop PDMSSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=371.8,
                dpnom=(10 - 8.39319)*10^5,
                rhonom=1730.7,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-140,80},{-120,
                        100}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(177.1 - 176.1189)*10^5,
                rhonom=96.586,
                wnom=88.59)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-160,120})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{220,160},{240,180}})));
              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Shot=1153.8,
                Scold=879.8,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                generateInitCode=true,
                Nhex=5,
                Vhot=3.68,
                Vcold=2.683,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02)
                annotation (Placement(transformation(extent={{-170,80},{-150,100}})));

              ThermoPower.Water.SourceMassFlow sourceMS1(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=238.7,
                h=518322,
                p0=1000000) annotation (Placement(transformation(extent={{-40,
                        80},{-20,100}})));

              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000)
                annotation (Placement(transformation(extent={{-40,60},{-20,80}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887)
                annotation (Placement(transformation(extent={{20,120},{40,140}})));
              ThermoPower.Water.SinkPressure sinkMS1(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=878222) annotation (Placement(transformation(extent={{50,80},
                        {70,100}})));

              ThermoPower.Water.PressDrop PDMSRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                rhonom=1730.47,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_lin,
                wnom=238.7,
                dpnom=(10 - 8.78222)*10^5) annotation (Placement(transformation(
                      extent={{20,80},{40,100}})));

              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=82.57,
                dpnom=(0.55113)*10^5,
                rhonom=17.86)                  annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={0,120})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                Shot=1339,
                Scold=1198,
                Nhex=5,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                generateInitCode=true,
                Vhot=1.522,
                Vcold=5.092,
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45)
                annotation (Placement(transformation(extent={{-10,80},{10,100}})));

              ThermoPower.Water.SourceMassFlow sourceMS2(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=199579,
                p0=569600) annotation (Placement(transformation(extent={{120,80},
                        {140,100}})));

              ThermoPower.Water.SourceMassFlow sourceSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=88.59,
                p0=17910000)
                annotation (Placement(transformation(extent={{120,60},{140,80}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17857510)
                annotation (Placement(transformation(extent={{180,120},{200,140}})));
              ThermoPower.Water.SinkPressure sinkMS2(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=404671) annotation (Placement(transformation(extent={{210,80},
                        {230,100}})));

              ThermoPower.Water.PressDrop PDMSECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.64929)*10^5,
                rhonom=1863.84) annotation (Placement(transformation(extent={{
                        180,80},{200,100}})));

              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={160,120})));
              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                generateInitCode=true,
                Nhex=5,
                Vhot=45.011,
                Vcold=5.752,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72)
                annotation (Placement(transformation(extent={{150,80},{170,100}})));
              ThermoPower.Water.SourceMassFlow sourceMS3(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=136706,
                p0=400000) annotation (Placement(transformation(extent={{-200,-100},
                        {-180,-80}})));

              ThermoPower.Water.SourceMassFlow sourceSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=143.1,
                p0=17910000)
                annotation (Placement(transformation(extent={{-200,-120},{-180,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17814720)
                annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
              ThermoPower.Water.SinkPressure sinkMS3(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-110,-100},
                        {-90,-80}})));

              ThermoPower.Water.PressDrop PDMSHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.38922)*10^5,
                rhonom=1890.49) annotation (Placement(transformation(extent={{-140,
                        -100},{-120,-80}})));

              ThermoPower.Water.PressDrop PDSteamHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                rhonom=768.15,
                wnom=143.1,
                dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-160,-60})));
              Components.HE HPH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Shot=2429.5,
                Scold=1913.2,
                Mm=29335,
                nominalColdFlow=143.1,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=5000, alpha=0.536143),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2000, alpha=0.447465),
                generateInitCode=true,
                Nhex=5,
                Vhot=33.634,
                Vcold=6.027,
                nominalColdPressure=17910000,
                nominalHotPressure=400000,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=581.85,
                nominalHotInletTemperature=586.85,
                nominalHotOutletTemperature=563.15) annotation (Placement(
                    transformation(extent={{-170,-100},{-150,-80}})));

              ThermoPower.Water.SourceMassFlow sourceMS4(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=289063,
                p0=730800) annotation (Placement(transformation(extent={{-40,-100},
                        {-20,-80}})));

              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.55,
                p0=17810000,
                h=1665608)
                annotation (Placement(transformation(extent={{-40,-120},{-20,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17804170)
                annotation (Placement(transformation(extent={{20,-60},{40,-40}})));
              ThermoPower.Water.SinkPressure sinkMS4(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=605957) annotation (Placement(transformation(extent={{50,-100},
                        {70,-80}})));

              ThermoPower.Water.PressDrop PDMSEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.24843)*10^5,
                rhonom=1826.13) annotation (Placement(transformation(extent={{
                        20,-100},{40,-80}})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.55,
                dpnom=(0.05828)*10^5,
                rhonom=582.24)       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={0,-60})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Mm=43100,
                Shot=2251.9,
                Scold=1765.5,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_2ph=25350,
                    gamma_nom_vap=3875,
                    alpha=1.6),
                nominalColdFlow=88.59,
                generateInitCode=true,
                Nhex=10,
                Vhot=26.587,
                Vcold=8.651,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15) annotation (Placement(
                    transformation(extent={{-10,-100},{10,-80}})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=355877,
                p0=730800) annotation (Placement(transformation(extent={{120,-100},
                        {140,-80}})));

              ThermoPower.Water.SourceMassFlow sourceSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=2279896,
                p0=17760000)
                annotation (Placement(transformation(extent={{120,-120},{140,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17748830)
                annotation (Placement(transformation(extent={{180,-60},{200,-40}})));
              ThermoPower.Water.SinkPressure sinkMS5(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=696272) annotation (Placement(transformation(extent={{210,-100},
                        {230,-80}})));

              ThermoPower.Water.PressDrop PDMSEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(0.34528)*10^5,
                rhonom=1798.12) annotation (Placement(transformation(extent={{
                        180,-100},{200,-80}})));

              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250)          annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={160,-60})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_2ph=6000,
                    gamma_nom_liq=2600,
                    gamma_nom_vap=2600),
                Shot=429.2*0.90,
                Scold=338*0.90,
                generateInitCode=true,
                Nhex=10,
                Vhot=3.905,
                Vcold=1.065,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{150,-100},{170,-80}})));
            equation
              connect(sinkMS.flange, PDMSSH.outlet) annotation (Line(
                  points={{-110,90},{-120,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.outlet, sinkSteam.flange) annotation (Line(
                  points={{-160,130},{-140,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange, SH.inletCold) annotation (Line(
                  points={{-180,70},{-160,70},{-160,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-180,90},{-170,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SH.outletHot, PDMSSH.inlet) annotation (Line(
                  points={{-150,90},{-140,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-160,110},{-160,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS1.flange, PDMSRH.outlet) annotation (Line(
                  points={{50,90},{40,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.outlet, sinkSteam1.flange) annotation (Line(
                  points={{0,130},{20,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam1.flange, RH.inletCold) annotation (Line(
                  points={{-20,70},{0,70},{0,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS1.flange, RH.inletHot) annotation (Line(
                  points={{-20,90},{-10,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.outletHot,PDMSRH. inlet) annotation (Line(
                  points={{10,90},{20,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.inlet,RH. outletCold) annotation (Line(
                  points={{0,110},{0,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS2.flange, PDMSECO.outlet) annotation (Line(
                  points={{210,90},{200,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.outlet, sinkSteam2.flange) annotation (Line(
                  points={{160,130},{180,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam2.flange, ECO.inletCold) annotation (Line(
                  points={{140,70},{160,70},{160,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS2.flange, ECO.inletHot) annotation (Line(
                  points={{140,90},{150,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(ECO.outletHot, PDMSECO.inlet) annotation (Line(
                  points={{170,90},{180,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{160,110},{160,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS3.flange, PDMSHPH.outlet) annotation (Line(
                  points={{-110,-90},{-120,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.outlet, sinkSteam3.flange) annotation (Line(
                  points={{-160,-50},{-140,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam3.flange, HPH.inletCold) annotation (Line(
                  points={{-180,-110},{-160,-110},{-160,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS3.flange, HPH.inletHot) annotation (Line(
                  points={{-180,-90},{-170,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(HPH.outletHot, PDMSHPH.inlet) annotation (Line(
                  points={{-150,-90},{-140,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.inlet, HPH.outletCold) annotation (Line(
                  points={{-160,-70},{-160,-80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS4.flange,PDMSEVA1. outlet) annotation (Line(
                  points={{50,-90},{40,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.outlet,sinkSteam4. flange) annotation (Line(
                  points={{0,-50},{20,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange,EVA1. inletCold) annotation (Line(
                  points={{-20,-110},{0,-110},{0,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS4.flange,EVA1. inletHot) annotation (Line(
                  points={{-20,-90},{-10,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot,PDMSEVA1. inlet) annotation (Line(
                  points={{10,-90},{20,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.inlet,EVA1. outletCold) annotation (Line(
                  points={{0,-70},{0,-80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS5.flange,PDMSEVA2. outlet) annotation (Line(
                  points={{210,-90},{200,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.outlet,sinkSteam5. flange) annotation (Line(
                  points={{160,-50},{180,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam5.flange,EVA2. inletCold) annotation (Line(
                  points={{140,-110},{160,-110},{160,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS5.flange,EVA2. inletHot) annotation (Line(
                  points={{140,-90},{150,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,PDMSEVA2. inlet) annotation (Line(
                  points={{170,-90},{180,-90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.inlet,EVA2. outletCold) annotation (Line(
                  points={{160,-70},{160,-80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                        -180},{240,180}}),        graphics={Text(
                      extent={{-160,70},{-120,50}},
                      lineColor={0,0,255},
                      textString="SH"), Text(
                      extent={{0,70},{40,50}},
                      lineColor={0,0,255},
                      textString="RH"), Text(
                      extent={{160,70},{200,50}},
                      lineColor={0,0,255},
                      textString="ECO"),Text(
                      extent={{-160,-110},{-120,-130}},
                      lineColor={0,0,255},
                      textString="HPH"),Text(
                      extent={{0,-110},{40,-130}},
                      lineColor={0,0,255},
                      textString="EVA1"),
                                        Text(
                      extent={{160,-110},{200,-130}},
                      lineColor={0,0,255},
                      textString="EVA2")}),
                                          Icon(coordinateSystem(extent={{-240,-180},{
                        240,180}})));
            end test_heatExchangers;

            model test_heatExchangers_offDesign
              "Test model of all the heat exchangers, from nominal load to 20% load, steady-state initialisation"

              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                w0=371.8,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322,
                p0=1000000,
                use_in_w0=true) annotation (Placement(transformation(extent={{-250,
                        120},{-230,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=2745621,
                p0=17710000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{-250,20},{-230,40}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17611890,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{-190,180},{-170,200}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-160,
                        120},{-140,140}})));

              ThermoPower.Water.PressDrop PDMSSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=371.8,
                dpnom=(10 - 8.39319)*10^5,
                rhonom=1730.7,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-190,120},{-170,
                        140}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(177.1 - 176.1189)*10^5,
                rhonom=96.586,
                wnom=88.59)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-210,160})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-340,240},{-320,260}})));
              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Shot=1153.8,
                Scold=879.8,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                generateInitCode=true,
                Nhex=20,
                Vhot=3.68,
                Vcold=2.683,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02)
                annotation (Placement(transformation(extent={{-220,120},{-200,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS1(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=238.7,
                h=518322,
                use_in_w0=true,
                p0=1000000,
                use_in_h=false) annotation (Placement(transformation(extent={{-40,
                        120},{-20,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{-40,20},{-20,40}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{20,178},{40,198}})));
              ThermoPower.Water.SinkPressure sinkMS1(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=878222) annotation (Placement(transformation(extent={{50,120},
                        {70,140}})));

              ThermoPower.Water.PressDrop PDMSRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                rhonom=1730.47,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_lin,
                wnom=238.7,
                dpnom=(10 - 8.78222)*10^5) annotation (Placement(transformation(
                      extent={{20,120},{40,140}})));

              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=82.57,
                dpnom=(0.55113)*10^5,
                rhonom=17.86)                  annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={0,160})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                Shot=1339,
                Scold=1198,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                generateInitCode=true,
                Nhex=20,
                Vhot=1.522,
                Vcold=5.092,
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45)
                annotation (Placement(transformation(extent={{-10,120},{10,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS2(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=199579,
                p0=569600,
                use_in_w0=true,
                use_in_h=true) annotation (Placement(transformation(extent={{
                        170,120},{190,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=88.59,
                p0=17910000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{172,20},{192,40}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17857510,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{230,178},{250,198}})));
              ThermoPower.Water.SinkPressure sinkMS2(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=404671) annotation (Placement(transformation(extent={{260,
                        120},{280,140}})));

              ThermoPower.Water.PressDrop PDMSECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.64929)*10^5,
                rhonom=1863.84) annotation (Placement(transformation(extent={{
                        230,120},{250,140}})));

              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={210,160})));
              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                generateInitCode=true,
                Nhex=20,
                Vhot=45.011,
                Vcold=5.752,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72)
                annotation (Placement(transformation(extent={{200,120},{220,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.55,
                h=1665608,
                p0=17810000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{-100,-220},{-80,-200}})));
              ThermoPower.Water.SinkPressure sinkMS4(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=605957) annotation (Placement(transformation(extent={{-120,-120},
                        {-140,-100}})));

              ThermoPower.Water.PressDrop PDMSEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.24843)*10^5,
                rhonom=1826.13) annotation (Placement(transformation(extent={{-80,
                        -120},{-100,-100}})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.55,
                dpnom=(0.05828)*10^5,
                rhonom=582.24)       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={0,-60})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Mm=43100,
                Shot=2251.9,
                Scold=1765.5,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                generateInitCode=true,
                Nhex=40,
                Vhot=26.587,
                Vcold=8.651,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_2ph=25350,
                    gamma_nom_vap=3875,
                    alpha=1.6),
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15) annotation (Placement(
                    transformation(extent={{-50,-120},{-70,-100}})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=355877,
                p0=730800,
                use_in_w0=true,
                use_in_h=true) annotation (Placement(transformation(extent={{
                        120,-120},{100,-100}})));

              ThermoPower.Water.SinkPressure sinkSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17748830,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{90,-220},{110,-200}})));
              ThermoPower.Water.PressDrop PDMSEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(0.34528)*10^5,
                rhonom=1798.12) annotation (Placement(transformation(extent={{
                        10,-120},{-10,-100}})));

              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250)          annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=90,
                    origin={70,-150})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_2ph=6000,
                    gamma_nom_liq=2600,
                    gamma_nom_vap=2600),
                generateInitCode=true,
                Nhex=40,
                Vhot=3.905,
                Vcold=1.065,
                Shot=429.2,
                Scold=338,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{80,-100},{60,-120}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_SH(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    371.8; 1e6,354.2; 2e6,329.7; 3e6,300.5; 4e6,263.9; 5e6,226.7; 6e6,
                    186.6; 7e6,144.2; 8e6,99.4; 10e6,99.4])
                annotation (Placement(transformation(extent={{-270,150},{-250,170}})));
              Modelica.Blocks.Sources.RealExpression realExpression(y=time)
                annotation (Placement(transformation(extent={{-310,150},{-290,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    2745621; 1e6,2941653; 2e6,2899377; 3e6,2908498; 4e6,2828363; 5e6,
                    2723640; 6e6,2724375; 7e6,2725107; 8e6,2725290; 10e6,0.0])
                annotation (Placement(transformation(extent={{-270,80},{-250,100}})));
              Modelica.Blocks.Sources.RealExpression realExpression1(y=time)
                annotation (Placement(transformation(extent={{-310,80},{-290,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    88.59; 1e6,81.03; 2e6,72.9; 3e6,64.64; 4e6,56.19; 5e6,46.02; 6e6,
                    36.01; 7e6,26.36; 8e6,17.04; 10e6,17.04])
                annotation (Placement(transformation(extent={{-270,50},{-250,70}})));
              Modelica.Blocks.Sources.RealExpression realExpression2(y=time)
                annotation (Placement(transformation(extent={{-310,50},{-290,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    176.1e5; 1e6,161.1e5; 2e6,144.9e5; 3e6,128.5e5; 4e6,112.1e5; 5e6,
                    100.5e5; 6e6,100.3e5; 7e6,100.3e5; 8e6,100.1e5; 10e6,100.1e5])
                                                             annotation (Placement(
                    transformation(extent={{-230,210},{-210,230}})));
              Modelica.Blocks.Sources.RealExpression realExpression3(y=time)
                annotation (Placement(transformation(extent={{-270,210},{-250,230}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(table=[0,46.4e5; 1e6,
                    40.98e5; 2e6,35.77e5; 3e6,30.66e5; 4e6,26.32e5; 5e6,21.61e5; 6e6,
                    16.92e5; 7e6,12.28e5; 8e6,7.67e5; 10e6,22e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-20,210},{0,230}})));
              Modelica.Blocks.Sources.RealExpression realExpression4(y=time)
                annotation (Placement(transformation(extent={{-60,210},{-40,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(table=[0,3083198; 1e6,
                    3093346; 2e6,3100618; 3e6,3108752; 4e6,3116961; 5e6,3125327; 6e6,
                    3128892; 7e6,3130270; 8e6,3124593; 10e6,3092400], smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-60,80},{-40,100}})));
              Modelica.Blocks.Sources.RealExpression realExpression6(y=time)
                annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(table=[0,82.57; 1e6,72.70;
                    2e6,63.31; 3e6,54.15; 4e6,46.38; 5e6,38.01; 6e6,29.69; 7e6,21.50;
                    8e6,13.40; 10e6,4.18], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
              Modelica.Blocks.Sources.RealExpression realExpression7(y=time)
                annotation (Placement(transformation(extent={{-100,50},{-80,70}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_RH(table=[0,238.7; 1e6,195.2;
                    2e6,158.7; 3e6,126.9; 4e6,102.4; 5e6,78.6; 6e6,57.6; 7e6,39; 8e6,
                    22.7; 10e6,4], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-60,150},{-40,170}})));
              Modelica.Blocks.Sources.RealExpression realExpression8(y=time)
                annotation (Placement(transformation(extent={{-100,150},{-80,170}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    178.1e5; 1e6,163.1e5; 2e6,146.7e5; 3e6,130.1e5; 4e6,113.4e5; 5e6,
                    102.1e5; 6e6,101.5e5; 7e6,100.9e5; 8e6,100.5e5; 10e6,100.5e5])
                annotation (Placement(transformation(extent={{190,210},{210,230}})));
              Modelica.Blocks.Sources.RealExpression realExpression9(y=time)
                annotation (Placement(transformation(extent={{150,210},{170,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_ECO(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    200329; 1e6,193208; 2e6,179571; 3e6,164722; 4e6,148509; 5e6,
                    119114; 6e6,107296; 7e6,98811; 8e6,93204; 10e6,93204])
                annotation (Placement(transformation(extent={{150,180},{170,200}})));
              Modelica.Blocks.Sources.RealExpression realExpression10(
                                                                     y=time)
                annotation (Placement(transformation(extent={{110,180},{130,200}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    610.6; 1e6,549.4; 2e6,488.4; 3e6,427.4; 4e6,366.3; 5e6,305.3; 6e6,
                    244.2; 7e6,183.2; 8e6,122.1; 10e6,122.1])
                annotation (Placement(transformation(extent={{150,150},{170,170}})));
              Modelica.Blocks.Sources.RealExpression realExpression11(
                                                                     y=time)
                annotation (Placement(transformation(extent={{110,150},{130,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    1231860; 1e6,1182452; 2e6,1133837; 3e6,1126638; 4e6,1111212; 5e6,
                    1251884; 6e6,1258763; 7e6,1260394; 8e6,1258351; 10e6,1258351])
                annotation (Placement(transformation(extent={{150,80},{170,100}})));
              Modelica.Blocks.Sources.RealExpression realExpression12(
                                                                     y=time)
                annotation (Placement(transformation(extent={{110,80},{130,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    88.59; 1e6,81.03; 2e6,72.9; 3e6,64.64; 4e6,56.19; 5e6,99.85; 6e6,
                    95.83; 7e6,83.77; 8e6,64.19; 10e6,64.19])
                annotation (Placement(transformation(extent={{150,50},{170,70}})));
              Modelica.Blocks.Sources.RealExpression realExpression13(
                                                                     y=time)
                annotation (Placement(transformation(extent={{110,50},{130,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    177.1e5; 1e6,162e5; 2e6,145.7e5; 3e6,129.3e5; 4e6,112.7e5; 5e6,
                    101e5; 6e6,100.6e5; 7e6,100.3e5; 8e6,100.1e5; 10e6,100.1e5])
                annotation (Placement(transformation(extent={{140,-190},{120,-170}})));
              Modelica.Blocks.Sources.RealExpression realExpression18(
                                                                     y=time)
                annotation (Placement(transformation(extent={{180,-190},{160,-170}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    356849; 1e6,382911; 2e6,374426; 3e6,373365; 4e6,357758; 5e6,
                    344122; 6e6,347304; 7e6,351243; 8e6,356546; 10e6,356546])
                annotation (Placement(transformation(extent={{140,-60},{120,-40}})));
              Modelica.Blocks.Sources.RealExpression realExpression19(
                                                                     y=time)
                annotation (Placement(transformation(extent={{180,-60},{160,-40}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    610.6; 1e6,549.4; 2e6,488.4; 3e6,427.4; 4e6,366.3; 5e6,305.3; 6e6,
                    244.2; 7e6,183.2; 8e6,122.1; 10e6,122.1])
                annotation (Placement(transformation(extent={{140,-90},{120,-70}})));
              Modelica.Blocks.Sources.RealExpression realExpression20(
                                                                     y=time)
                annotation (Placement(transformation(extent={{180,-90},{160,-70}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    1665608; 1e6,1656900; 2e6,1594900; 3e6,1531800; 4e6,1465700; 5e6,
                    1330000; 6e6,1293900; 7e6,1272400; 8e6,1258351; 10e6,1258351])
                annotation (Placement(transformation(extent={{-120,-160},{-100,-140}})));
              Modelica.Blocks.Sources.RealExpression realExpression21(
                                                                     y=time)
                annotation (Placement(transformation(extent={{-160,-160},{-140,-140}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                    88.59; 1e6,81.03; 2e6,72.9; 3e6,64.64; 4e6,56.19; 5e6,99.85; 6e6,
                    95.83; 7e6,83.77; 8e6,64.19; 10e6,64.19])
                annotation (Placement(transformation(extent={{-120,-190},{-100,-170}})));
              Modelica.Blocks.Sources.RealExpression realExpression22(
                                                                     y=time)
                annotation (Placement(transformation(extent={{-160,-190},{-140,-170}})));

              Real load = sourceMS2.w/sourceMS2.w0;
            equation
              connect(sinkMS.flange, PDMSSH.outlet) annotation (Line(
                  points={{-160,130},{-170,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.outlet, sinkSteam.flange) annotation (Line(
                  points={{-210,170},{-210,190},{-190,190}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange, SH.inletCold) annotation (Line(
                  points={{-230,30},{-210,30},{-210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-230,130},{-220,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SH.outletHot, PDMSSH.inlet) annotation (Line(
                  points={{-200,130},{-190,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-210,150},{-210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS1.flange, PDMSRH.outlet) annotation (Line(
                  points={{50,130},{40,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.outlet, sinkSteam1.flange) annotation (Line(
                  points={{4.44089e-016,170},{0,170},{0,188},{20,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam1.flange, RH.inletCold) annotation (Line(
                  points={{-20,30},{0,30},{0,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS1.flange, RH.inletHot) annotation (Line(
                  points={{-20,130},{-10,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.outletHot,PDMSRH. inlet) annotation (Line(
                  points={{10,130},{20,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.inlet,RH. outletCold) annotation (Line(
                  points={{0,150},{0,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS2.flange, PDMSECO.outlet) annotation (Line(
                  points={{260,130},{250,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.outlet, sinkSteam2.flange) annotation (Line(
                  points={{210,170},{210,188},{230,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam2.flange, ECO.inletCold) annotation (Line(
                  points={{192,30},{210,30},{210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS2.flange, ECO.inletHot) annotation (Line(
                  points={{190,130},{200,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(ECO.outletHot, PDMSECO.inlet) annotation (Line(
                  points={{220,130},{230,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{210,150},{210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS4.flange,PDMSEVA1. outlet) annotation (Line(
                  points={{-120,-110},{-100,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange,EVA1. inletCold) annotation (Line(
                  points={{-80,-210},{-60,-210},{-60,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot,PDMSEVA1. inlet) annotation (Line(
                  points={{-70,-110},{-80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.inlet,EVA1. outletCold) annotation (Line(
                  points={{-10,-60},{-60,-60},{-60,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.outlet,sinkSteam5. flange) annotation (Line(
                  points={{70,-160},{70,-210},{90,-210}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS5.flange,EVA2. inletHot) annotation (Line(
                  points={{100,-110},{80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,PDMSEVA2. inlet) annotation (Line(
                  points={{60,-110},{10,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.inlet,EVA2. outletCold) annotation (Line(
                  points={{70,-140},{70,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(w_MS_SH.y[1], sourceMS.in_w0) annotation (Line(
                  points={{-249,160},{-244,160},{-244,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_SH.u[1], realExpression.y) annotation (Line(
                  points={{-272,160},{-289,160}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_SH.u[1], realExpression1.y) annotation (Line(
                  points={{-272,90},{-289,90}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_SH.u[1], realExpression2.y) annotation (Line(
                  points={{-272,60},{-289,60}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_SH.y[1], sourceSteam.in_w0) annotation (Line(
                  points={{-249,60},{-244,60},{-244,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_SH.y[1], sourceSteam.in_h) annotation (Line(
                  points={{-249,90},{-236,90},{-236,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(realExpression3.y, p_ST_SH.u[1]) annotation (Line(
                  points={{-249,220},{-232,220}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_SH.y[1], sinkSteam.in_p0) annotation (Line(
                  points={{-209,220},{-184,220},{-184,198.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(realExpression4.y, p_ST_RH.u[1]) annotation (Line(
                  points={{-39,220},{-22,220}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_RH.u[1], realExpression6.y) annotation (Line(
                  points={{-62,90},{-79,90}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_RH.u[1], realExpression7.y) annotation (Line(
                  points={{-62,60},{-79,60}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_RH.u[1], realExpression8.y) annotation (Line(
                  points={{-62,160},{-79,160}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_RH.y[1], sourceSteam1.in_w0) annotation (Line(
                  points={{-39,60},{-34,60},{-34,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_RH.y[1], sourceSteam1.in_h) annotation (Line(
                  points={{-39,90},{-26,90},{-26,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_RH.y[1], sourceMS1.in_w0) annotation (Line(
                  points={{-39,160},{-34,160},{-34,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_RH.y[1], sinkSteam1.in_p0) annotation (Line(
                  points={{1,220},{26,220},{26,196.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(realExpression9.y, p_ST_ECO.u[1]) annotation (Line(
                  points={{171,220},{188,220}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_MS_ECO.u[1], realExpression10.y) annotation (Line(
                  points={{148,190},{131,190}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_ECO.u[1], realExpression12.y) annotation (Line(
                  points={{148,90},{131,90}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_ECO.u[1], realExpression13.y) annotation (Line(
                  points={{148,60},{131,60}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_MS_ECO.y[1], sourceMS2.in_h)
                annotation (Line(points={{171,190},{184,190},{184,136}}, color={0,0,127}));
              connect(p_ST_ECO.y[1], sinkSteam2.in_p0) annotation (Line(points={{211,220},{222,
                      220},{236,220},{236,196.8}}, color={0,0,127}));
              connect(w_MS_ECO.y[1], sourceMS2.in_w0) annotation (Line(points={{171,160},{174,
                      160},{176,160},{176,136}}, color={0,0,127}));
              connect(h_ST_ECO.y[1], sourceSteam2.in_h) annotation (Line(points={{171,90},{176,
                      90},{186,90},{186,36}}, color={0,0,127}));
              connect(w_ST_ECO.y[1], sourceSteam2.in_w0)
                annotation (Line(points={{171,60},{178,60},{178,36}}, color={0,0,127}));
              connect(realExpression11.y, w_MS_ECO.u[1])
                annotation (Line(points={{131,160},{140,160},{148,160}}, color={0,0,127}));
              connect(realExpression18.y, p_ST_EVA.u[1]) annotation (Line(
                  points={{159,-180},{142,-180}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_MS_EVA.u[1], realExpression19.y) annotation (Line(
                  points={{142,-50},{159,-50}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(realExpression20.y, w_MS_EVA.u[1]) annotation (Line(points={{159,-80},
                      {159,-80},{142,-80}},   color={0,0,127}));
              connect(h_ST_EVA.u[1], realExpression21.y) annotation (Line(
                  points={{-122,-150},{-139,-150}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(realExpression22.y, w_ST_EVA.u[1]) annotation (Line(points={{-139,-180},
                      {-130,-180},{-122,-180}},
                                              color={0,0,127}));
              connect(h_ST_EVA.y[1], sourceSteam4.in_h) annotation (Line(points={{-99,-150},
                      {-92,-150},{-86,-150},{-86,-204}}, color={0,0,127}));
              connect(w_ST_EVA.y[1], sourceSteam4.in_w0) annotation (Line(points={{-99,-180},
                      {-94,-180},{-94,-204}}, color={0,0,127}));
              connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(points={{10,-60},
                      {42,-60},{70,-60},{70,-100}},    color={0,0,255}));
              connect(EVA1.inletHot, PDMSEVA2.outlet)
                annotation (Line(points={{-50,-110},{-10,-110}},         color={0,0,255}));
              connect(h_MS_EVA.y[1], sourceMS5.in_h) annotation (Line(points={{119,-50},{106,
                      -50},{106,-104}}, color={0,0,127}));
              connect(w_MS_EVA.y[1], sourceMS5.in_w0) annotation (Line(points={{119,-80},{116,
                      -80},{114,-80},{114,-104}},   color={0,0,127}));
              connect(p_ST_EVA.y[1], sinkSteam5.in_p0) annotation (Line(points={{119,-180},{
                      106,-180},{96,-180},{96,-201.2}},   color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-340,
                        -260},{340,260}}),        graphics={Text(
                      extent={{-210,110},{-170,90}},
                      lineColor={0,0,255},
                      textString="SH"), Text(
                      extent={{0,110},{40,90}},
                      lineColor={0,0,255},
                      textString="RH"), Text(
                      extent={{210,110},{250,90}},
                      lineColor={0,0,255},
                      textString="ECO"),Text(
                      extent={{-18,-130},{22,-150}},
                      lineColor={0,0,255},
                      textString="EVA"),
                    Text(
                      extent={{-348,258},{-88,244}},
                      lineColor={0,0,255},
                      textString="Tempo di simulazione richiesto: 8e6 s")}),
                                          Icon(coordinateSystem(extent={{-340,-260},{
                        340,260}})),
                experiment(StopTime=8e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign;

            model test_heatExchangers_offDesign_HPH
              "Test model of the MS_HPH, from nominal load to 20% load, steady-state initialisation"

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,120},{-100,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS3(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=136706,
                p0=400000,
                use_in_w0=true,
                use_in_h=true) annotation (Placement(transformation(extent={{-30,
                        -20},{-10,0}})));

              ThermoPower.Water.SourceMassFlow sourceSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=143.1,
                p0=17910000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{-30,-120},{-10,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17814720,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{30,40},{50,60}})));
              ThermoPower.Water.SinkPressure sinkMS3(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{60,-20},
                        {80,0}})));

              ThermoPower.Water.PressDrop PDMSHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.38922)*10^5,
                rhonom=1890.49) annotation (Placement(transformation(extent={{
                        30,-20},{50,0}})));

              ThermoPower.Water.PressDrop PDSteamHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                rhonom=768.15,
                wnom=143.1,
                dpnom=(0.9528)*10^5) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={10,20})));
              Components.HE HPH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Shot=2429.5,
                Scold=1913.2,
                Mm=29335,
                nominalColdFlow=143.1,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=5000, alpha=0.536143),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2000, alpha=0.447465),
                generateInitCode=true,
                Vhot=33.634,
                Vcold=6.027,
                Nhex=20,
                nominalColdPressure=17910000,
                nominalHotPressure=400000,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=581.85,
                nominalHotInletTemperature=586.85,
                nominalHotOutletTemperature=563.15) annotation (Placement(
                    transformation(extent={{0,-20},{20,0}})));

              Modelica.Blocks.Tables.CombiTable1D p_ST_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,
                    178.1e5; 1e6,163.8e5; 2e6,147.3e5; 3e6,130.6e5; 4e6,113.8e5; 5e6,
                    103.2e5; 6e6,102.5e5; 7e6,101.7e5; 8e6,100.5e5; 10e6,100.5e5])
                annotation (Placement(transformation(extent={{-10,90},{10,110}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,
                    136842; 1e6,122751; 2e6,110175; 3e6,103053; 4e6,93659; 5e6,93356;
                    6e6,93356; 7e6,93356; 8e6,93356; 10e6,93356])
                annotation (Placement(transformation(extent={{-50,50},{-30,70}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,
                    610.6; 1e6,549.4; 2e6,488.4; 3e6,427.4; 4e6,366.3; 5e6,305.3; 6e6,
                    244.2; 7e6,183.2; 8e6,122.1; 10e6,122.1])
                annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_HPH(
                                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,
                    1231860; 1e6,1182452; 2e6,1133837; 3e6,1126638; 4e6,1111212; 5e6,
                    1251884; 6e6,1258763; 7e6,1260394; 8e6,1258351; 10e6,1258351])
                annotation (Placement(transformation(extent={{-50,-60},{-30,-40}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_HPH(       smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,
                    143.1; 1e6,67.83; 2e6,24.44; 3e6,5.26; 4e6,0.01; 5e6,0.01; 6e6,
                    0.01; 7e6,0.01; 8e6,0.01; 10e6,0.01])
                annotation (Placement(transformation(extent={{-50,-90},{-30,-70}})));

              //Real load = sourceMS2.w/sourceMS2.w0;
              Modelica.Blocks.Sources.Ramp ramp(height=6e6, duration=6e6) annotation (
                 Placement(transformation(extent={{-40,90},{-20,110}})));
              Modelica.Blocks.Sources.Ramp ramp1(height=6e6, duration=6e6)
                annotation (Placement(transformation(extent={{-90,50},{-70,70}})));
              Modelica.Blocks.Sources.Ramp ramp2(height=6e6, duration=6e6)
                annotation (Placement(transformation(extent={{-90,20},{-70,40}})));
              Modelica.Blocks.Sources.Ramp ramp3(height=6e6, duration=6e6)
                annotation (Placement(transformation(extent={{-90,-60},{-70,-40}})));
              Modelica.Blocks.Sources.Ramp ramp4(height=6e6, duration=6e6)
                annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            equation
              connect(sinkMS3.flange, PDMSHPH.outlet) annotation (Line(
                  points={{60,-10},{50,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.outlet, sinkSteam3.flange) annotation (Line(
                  points={{10,30},{10,50},{30,50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam3.flange, HPH.inletCold) annotation (Line(
                  points={{-10,-110},{10,-110},{10,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS3.flange, HPH.inletHot) annotation (Line(
                  points={{-10,-10},{0,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(HPH.outletHot, PDMSHPH.inlet) annotation (Line(
                  points={{20,-10},{30,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.inlet, HPH.outletCold) annotation (Line(
                  points={{10,10},{10,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(p_ST_HPH.y[1], sinkSteam3.in_p0) annotation (Line(points={{11,100},{24,
                      100},{36,100},{36,58.8}},           color={0,0,127}));
              connect(h_MS_HPH.y[1], sourceMS3.in_h) annotation (Line(points={{-29,60},{-16,
                      60},{-16,-4}},     color={0,0,127}));
              connect(w_MS_HPH.y[1], sourceMS3.in_w0) annotation (Line(points={{-29,30},{-24,
                      30},{-24,-4}},     color={0,0,127}));
              connect(h_ST_HPH.y[1], sourceSteam3.in_h) annotation (Line(points={{-29,-50},{
                      -29,-50},{-16,-50},{-16,-104}},       color={0,0,127}));
              connect(w_ST_HPH.y[1], sourceSteam3.in_w0) annotation (Line(points={{-29,-80},
                      {-24,-80},{-24,-104}},    color={0,0,127}));
              connect(p_ST_HPH.u[1], ramp.y) annotation (Line(points={{-12,100},{
                      -14,100},{-19,100}},                                    color={
                      0,0,127}));
              connect(h_MS_HPH.u[1], ramp1.y) annotation (Line(points={{-52,60},{-60,60},{-69,
                      60}},                  color={0,0,127}));
              connect(w_MS_HPH.u[1], ramp2.y)
                annotation (Line(points={{-52,30},{-69,30}},     color={0,0,127}));
              connect(h_ST_HPH.u[1], ramp3.y)
                annotation (Line(points={{-52,-50},{-69,-50}},     color={0,0,127}));
              connect(w_ST_HPH.u[1], ramp4.y) annotation (Line(points={{-52,-80},{-60,-80},{
                      -69,-80}},               color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -140},{120,140}}),        graphics={
                                        Text(
                      extent={{10,-30},{50,-50}},
                      lineColor={0,0,255},
                      textString="HPH"),
                    Text(
                      extent={{-128,138},{132,124}},
                      lineColor={0,0,255},
                      textString="Tempo di simulazione richiesto: 4e6 s")}),
                                          Icon(coordinateSystem(extent={{-120,-140},{120,140}})),
                experiment(StopTime=4e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign_HPH;

            model test_EVA12_2ph
              "Test of EVA1 and EVA2, at nominal load, to evaluate the 2ph h.t.c."

              ThermoPower.Water.SourceMassFlow sourceMS4(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=289063,
                p0=730800) annotation (Placement(transformation(extent={{-60,40},
                        {-40,60}})));

              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1665608,
                w0=88.59,
                p0=17810000)
                annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
              ThermoPower.Water.SinkPressure sinkSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17804170)
                annotation (Placement(transformation(extent={{0,80},{20,100}})));
              ThermoPower.Water.SinkPressure sinkMS4(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=605957) annotation (Placement(transformation(extent={{30,40},
                        {50,60}})));

              ThermoPower.Water.PressDrop PDMSEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.24843)*10^5,
                rhonom=1863.6)
                annotation (Placement(transformation(extent={{0,40},{20,60}})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.55,
                dpnom=(0.05828)*10^5,
                rhonom=168.791)      annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-20,80})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=355877,
                p0=730800) annotation (Placement(transformation(extent={{-60,-60},
                        {-40,-40}})));

              ThermoPower.Water.SourceMassFlow sourceSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=2279896,
                p0=17760000)
                annotation (Placement(transformation(extent={{-60,-80},{-40,-60}})));
              ThermoPower.Water.SinkPressure sinkSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17748830)
                annotation (Placement(transformation(extent={{0,-20},{20,0}})));
              ThermoPower.Water.SinkPressure sinkMS5(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=696272) annotation (Placement(transformation(extent={{30,-60},
                        {50,-40}})));

              ThermoPower.Water.PressDrop PDMSEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=610.6,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(0.34528)*10^5,
                rhonom=1826.2) annotation (Placement(transformation(extent={{0,
                        -60},{20,-40}})));

              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=97.019)       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-20,-20})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                Nhex=20,
                nominalHotFlow=610.6,
                Vcold=721.2,
                nominalColdFlow=88.59,
                Vhot=3.9,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                generateInitCode=true,
                Shot=429.2,
                Scold=338,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_2ph=5000,
                    gamma_nom_liq=2000,
                    gamma_nom_vap=2000),
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{-30,-60},{-10,-40}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{80,80},{100,100}})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare package coldMedium = coldMedium,
                redeclare package hotMedium = hotMedium,
                Nhex=Nhex_bi,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                tubeWalls(Tvolstart(displayUnit="K") = {650.47,650.866,651.269,
                    651.679,652.097,652.522,652.956,653.397,653.846,654.304,654.769,
                    655.244,655.726,656.218,656.719,657.228,660.331,675.049,675.851,
                    676.675,677.521,678.389,679.279,680.19,681.124,682.078,683.052,
                    684.047,685.063,686.099,687.154,688.23,689.324,690.436,691.567,
                    692.714,693.877,695.057,696.25}),
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                     {356849,355304,353752,352194,350629,349059,347485,345908,344328,
                      342747,341165,339583,338003,336424,334848,333276,331707,330144,
                      328587,327037,325494,323959,322433,320326,318146,316005,313903,
                      311839,309812,307821,305867,303947,302063,300212,298395,296610,
                      294858,293137,291447,289788}),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={2.29887e+006,2.31027e+006,2.32187e+006,2.33369e+006,
                      2.34573e+006,2.35799e+006,2.37047e+006,2.38319e+006,
                      2.39613e+006,2.40932e+006,2.42274e+006,2.43641e+006,
                      2.45034e+006,2.46452e+006,2.47896e+006,2.49366e+006,
                      2.50864e+006,2.52311e+006,2.53359e+006,2.54414e+006,
                      2.55474e+006,2.56539e+006,2.57608e+006,2.58682e+006,
                      2.59759e+006,2.60839e+006,2.61922e+006,2.63006e+006,
                      2.64092e+006,2.65179e+006,2.66265e+006,2.67351e+006,
                      2.68437e+006,2.6952e+006,2.70601e+006,2.71679e+006,2.72754e+006,
                      2.73825e6,2.7415e6,2.74562e6}),
                Vhot=3.905,
                Vcold=1.065,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000),
                Shot=429.2,
                Scold=338,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{-30,40},{-10,60}})));
            equation
              connect(sinkMS4.flange,PDMSEVA1. outlet) annotation (Line(
                  points={{30,50},{20,50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.outlet,sinkSteam4. flange) annotation (Line(
                  points={{-20,90},{0,90}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS5.flange,PDMSEVA2. outlet) annotation (Line(
                  points={{30,-50},{20,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.outlet,sinkSteam5. flange) annotation (Line(
                  points={{-20,-10},{0,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam5.flange,EVA2. inletCold) annotation (Line(
                  points={{-40,-70},{-20,-70},{-20,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS5.flange,EVA2. inletHot) annotation (Line(
                  points={{-40,-50},{-30,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,PDMSEVA2. inlet) annotation (Line(
                  points={{-10,-50},{0,-50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.inlet,EVA2. outletCold) annotation (Line(
                  points={{-20,-30},{-20,-40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS4.flange, EVA1.inletHot) annotation (Line(points={{
                      -40,50},{-35,50},{-30,50}}, color={0,0,255}));
              connect(EVA1.outletHot, PDMSEVA1.inlet) annotation (Line(points={{
                      -10,50},{-5,50},{0,50}}, color={0,0,255}));
              connect(PDSteamEVA1.inlet, EVA1.outletCold) annotation (Line(points=
                     {{-20,70},{-20,65},{-20,60}}, color={0,0,255}));
              connect(sourceSteam4.flange, EVA1.inletCold) annotation (Line(
                    points={{-40,30},{-20,30},{-20,40}}, color={0,0,255}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false,
                      extent={{-100,-100},{100,100}}),
                                  graphics={
                                        Text(
                      extent={{-20,30},{20,10}},
                      lineColor={0,0,255},
                      textString="EVA1"),
                                        Text(
                      extent={{-20,-70},{20,-90}},
                      lineColor={0,0,255},
                      textString="EVA2")}));
            end test_EVA12_2ph;

            model partial_OTSG

              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Shot=1153.8,
                Scold=879.8,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                Nhex=20,
                Vhot=3.68,
                Vcold=2.683,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02)
                annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-20,30})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                Shot=1339,
                Scold=1198,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                Nhex=20,
                Vhot=1.522,
                Vcold=5.092,
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45)
                annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={110,30})));
              ThermoPower.Water.ThroughMassFlow throughMassFlow(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=238.7,
                use_in_w0=true) annotation (Placement(transformation(extent={{
                        20,120},{40,100}})));

              ThermoPower.Water.SensT sensT(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={86,44})));
              ThermoPower.PowerPlants.Control.PID PID_T_RH(
                Ti=20,
                PVmin=600,
                PVmax=1000,
                CSmin=1,
                CSmax=300,
                PVstart=0.5,
                CSstart=0.8,
                Kp=5)
                annotation (Placement(transformation(extent={{54,20},{34,0}})));
              Modelica.Blocks.Sources.Constant const(k=826.05)
                annotation (Placement(transformation(extent={{90,-4},{70,16}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17710000)
                annotation (Placement(transformation(extent={{0,50},{20,70}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000)
                annotation (Placement(transformation(extent={{160,20},{140,40}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887)
                annotation (Placement(transformation(extent={{80,70},{60,90}})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322,
                w0=610.6,
                use_in_w0=false) annotation (Placement(transformation(extent={{
                        -70,100},{-50,120}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-60,-130},
                        {-40,-110}})));

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
                                              annotation (Placement(transformation(
                      extent={{-180,140},{-160,160}})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Mm=43100,
                Shot=2251.9,
                Scold=1765.5,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=4100, alpha=0.440883),
                nominalColdFlow=88.59,
                Nhex=20,
                Vhot=26.587,
                Vcold=8.651,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15) annotation (Placement(
                    transformation(extent={{-110,-130},{-90,-110}})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=429.2,
                Scold=338,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3100, alpha=0.440883),
                Nhex=20,
                Vhot=3.905,
                Vcold=1.065,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{-90,-70},{-110,-50}})));
              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.55,
                dpnom=(0.05828)*10^5,
                rhonom=582.24)       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,-90})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250)          annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,-20})));
              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1665608,
                w0=88.59,
                p0=17810000)
                annotation (Placement(transformation(extent={{-140,-160},{-120,-140}})));
              ThermoPower.Water.SinkPressure sinkMS3(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{124,-80},
                        {144,-60}})));

              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={106,-46})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=610.6,
                h=355877,
                p0=730800,
                use_in_h=true) annotation (Placement(transformation(extent={{-40,
                        -50},{-60,-70}})));

              Components.Separator_controlledLevel Separator(
                zl_min=0,
                Kp=-250,
                Ti=20,
                Td=0,
                Nd=1,
                PVmin=0,
                PVmax=20,
                CSmin=0,
                actuatorGain=1,
                Ta=5,
                H=8,
                zl_max=7,
                zl_start=0,
                PVstart=0,
                CSstart=0,
                D=0.56,
                vessel(initOpt=ThermoPower.Choices.Init.Options.fixedState, T(start=
                        648.15)),
                h_start=2740000,
                CSmax=150)
                annotation (Placement(transformation(extent={{-44,-40},{4,16}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17748830)
                annotation (Placement(transformation(extent={{-14,-50},{6,-30}})));
              Modelica.Blocks.Sources.Ramp ramp(
                height=-15000,
                duration=2000,
                offset=355000,
                startTime=50000)
                annotation (Placement(transformation(extent={{0,-100},{-20,-80}})));
            equation
              connect(const.y,PID_T_RH. SP) annotation (Line(
                  points={{69,6},{54,6}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sensT.T,PID_T_RH. PV) annotation (Line(
                  points={{80,52},{80,60},{60,60},{60,14},{54,14}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sensT.inlet,RH. outletCold) annotation (Line(
                  points={{90,38},{90,30},{100,30}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.inletCold, sourceSteam1.flange) annotation (Line(
                  points={{120,30},{140,30}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, throughMassFlow.inlet) annotation (Line(
                  points={{-50,110},{20,110}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(throughMassFlow.outlet, RH.inletHot) annotation (Line(
                  points={{40,110},{110,110},{110,40}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-50,110},{-40,110},{-40,30},{-30,30}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(SH.outletCold, sinkSteam.flange) annotation (Line(
                  points={{-20,40},{-20,60},{0,60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sensT.outlet, sinkSteam1.flange) annotation (Line(
                  points={{90,50},{90,80},{80,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,EVA1. inletHot) annotation (Line(
                  points={{-110,-60},{-120,-60},{-120,-120},{-110,-120}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                  points={{-100,-110},{-100,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-100,-70},{-100,-80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot, sinkMS.flange) annotation (Line(
                  points={{-90,-120},{-60,-120}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange, EVA1.inletCold) annotation (Line(
                  points={{-120,-150},{-100,-150},{-100,-130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(throughMassFlow.in_w0, PID_T_RH.CS) annotation (Line(
                  points={{26,104},{26,10},{34,10}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(flowJoin.in1, RH.outletHot) annotation (Line(
                  points={{110,-40},{110,20}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(SH.outletHot, flowJoin.in2) annotation (Line(
                  points={{-10,30},{10,30},{10,-40},{102,-40}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(Separator.outlet_liq, sinkSteam2.flange) annotation (Line(
                  points={{-20,-30},{-20,-40},{-14,-40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(Separator.outlet_vap, SH.inletCold) annotation (Line(
                  points={{-20,10},{-20,20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(Separator.inlet, PDSteamEVA2.outlet) annotation (Line(
                  points={{-28.5714,-20},{-60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                  points={{-100,-50},{-100,-20},{-80,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(flowJoin.out, sinkMS3.flange) annotation (Line(
                  points={{106,-52},{106,-70},{124,-70}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(EVA2.inletHot, sourceMS5.flange) annotation (Line(
                  points={{-90,-60},{-60,-60}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(sourceMS5.in_h, ramp.y) annotation (Line(
                  points={{-54,-66},{-54,-90},{-21,-90}},
                  color={0,0,127},
                  smooth=Smooth.None));
              annotation (Diagram(coordinateSystem(extent={{-180,-160},{180,160}},
                      preserveAspectRatio=false), graphics), Icon(coordinateSystem(
                      extent={{-180,-160},{180,160}})));
            end partial_OTSG;

            model partial_OTSGbis

              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                Nhex=20,
                Shot=1153.8*0.88,
                Scold=879.8*0.88,
                Vhot=3.68,
                Vcold=2.683,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02)
                annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-20,30})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                Shot=1339,
                Scold=1198,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                Nhex=20,
                Vhot=1.522,
                Vcold=5.092,
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45)
                annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={110,30})));
              ThermoPower.Water.ThroughMassFlow throughMassFlow(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=238.7,
                use_in_w0=true) annotation (Placement(transformation(extent={{
                        20,120},{40,100}})));

              ThermoPower.Water.SensT sensT(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={86,44})));
              ThermoPower.PowerPlants.Control.PID PID_T_RH(
                PVmin=600,
                PVmax=1000,
                CSmin=1,
                CSmax=300,
                PVstart=0.5,
                CSstart=0.8,
                Kp=14,
                Ti=56)
                annotation (Placement(transformation(extent={{54,20},{34,0}})));
              Modelica.Blocks.Sources.Constant const(k=826.05)
                annotation (Placement(transformation(extent={{90,-4},{70,16}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17710000)
                annotation (Placement(transformation(extent={{0,50},{20,70}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000)
                annotation (Placement(transformation(extent={{160,20},{140,40}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887)
                annotation (Placement(transformation(extent={{80,70},{60,90}})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322,
                w0=610.6,
                use_in_w0=false) annotation (Placement(transformation(extent={{
                        -70,100},{-50,120}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-60,-130},
                        {-40,-110}})));

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
                                              annotation (Placement(transformation(
                      extent={{-180,140},{-160,160}})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                Mm=43100,
                Shot=2251.9,
                Scold=1765.5,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=4100, alpha=0.440883),
                nominalColdFlow=88.59,
                Nhex=20,
                Vhot=26.587,
                Vcold=8.651,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15) annotation (Placement(
                    transformation(extent={{-110,-130},{-90,-110}})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3100, alpha=0.440883),
                Nhex=20,
                Shot=429.2*1.1,
                Scold=338*1.1,
                Vhot=3.905,
                Vcold=1.065,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95) annotation (Placement(
                    transformation(extent={{-90,-70},{-110,-50}})));
              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.55,
                dpnom=(0.05828)*10^5,
                rhonom=582.24)       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,-90})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250)          annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,-20})));
              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1665608,
                w0=88.59,
                p0=17810000)
                annotation (Placement(transformation(extent={{-140,-160},{-120,-140}})));
              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={106,-46})));
              Components.Separator_controlledLevel Separator(
                zl_min=0,
                Kp=-250,
                Ti=20,
                Td=0,
                Nd=1,
                PVmin=0,
                PVmax=20,
                CSmin=0,
                actuatorGain=1,
                Ta=5,
                H=8,
                zl_max=7,
                zl_set=4,
                zl_start=0,
                PVstart=0,
                CSstart=0,
                D=0.56,
                vessel(initOpt=ThermoPower.Choices.Init.Options.fixedState, T(start=
                        648.15)),
                h_start=2740000,
                CSmax=150)
                annotation (Placement(transformation(extent={{-44,-40},{4,16}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17748830)
                annotation (Placement(transformation(extent={{-14,-50},{6,-30}})));
            equation
              connect(const.y,PID_T_RH. SP) annotation (Line(
                  points={{69,6},{54,6}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sensT.T,PID_T_RH. PV) annotation (Line(
                  points={{80,52},{80,60},{60,60},{60,14},{54,14}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sensT.inlet,RH. outletCold) annotation (Line(
                  points={{90,38},{90,30},{100,30}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.inletCold, sourceSteam1.flange) annotation (Line(
                  points={{120,30},{140,30}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, throughMassFlow.inlet) annotation (Line(
                  points={{-50,110},{20,110}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(throughMassFlow.outlet, RH.inletHot) annotation (Line(
                  points={{40,110},{110,110},{110,40}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-50,110},{-40,110},{-40,30},{-30,30}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(SH.outletCold, sinkSteam.flange) annotation (Line(
                  points={{-20,40},{-20,60},{0,60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sensT.outlet, sinkSteam1.flange) annotation (Line(
                  points={{90,50},{90,80},{80,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,EVA1. inletHot) annotation (Line(
                  points={{-110,-60},{-120,-60},{-120,-120},{-110,-120}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                  points={{-100,-110},{-100,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-100,-70},{-100,-80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot, sinkMS.flange) annotation (Line(
                  points={{-90,-120},{-60,-120}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange, EVA1.inletCold) annotation (Line(
                  points={{-120,-150},{-100,-150},{-100,-130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(flowJoin.in1, RH.outletHot) annotation (Line(
                  points={{110,-40},{110,20}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(SH.outletHot, flowJoin.in2) annotation (Line(
                  points={{-10,30},{10,30},{10,-40},{102,-40}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(Separator.outlet_liq, sinkSteam2.flange) annotation (Line(
                  points={{-20,-30},{-20,-40},{-14,-40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(Separator.outlet_vap, SH.inletCold) annotation (Line(
                  points={{-20,10},{-20,20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(Separator.inlet, PDSteamEVA2.outlet) annotation (Line(
                  points={{-28.5714,-20},{-60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                  points={{-100,-50},{-100,-20},{-80,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.inletHot, flowJoin.out) annotation (Line(
                  points={{-90,-60},{106,-60},{106,-52}},
                  color={255,0,0},
                  smooth=Smooth.None));
              connect(PID_T_RH.CS, throughMassFlow.in_w0) annotation (Line(
                  points={{34,10},{26,10},{26,104}},
                  color={0,0,127},
                  smooth=Smooth.None));
              annotation (Diagram(coordinateSystem(extent={{-180,-160},{180,160}},
                      preserveAspectRatio=false), graphics), Icon(coordinateSystem(
                      extent={{-180,-160},{180,160}})));
            end partial_OTSGbis;

            model test_wFW_sensitivity
              "Test model to analyse the sensitivity of the EVA1/EVA2 operational point against the feedwater mass flow"
              import PreFlexMS;

              //Heat exchangers parameter
              parameter Integer Nhex_mono = 5
                "Number of nodes for single phase heat exchangers";
              parameter Integer Nhex_bi = 10
                "Number of nodes for biphase heat exchangers";

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                Nhex=Nhex_mono,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                Vhot=45.011,
                Vcold=5.752,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                      1.66591e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                    623.137}),
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={199579,192529,183185,168175,136603},
                  noInitialPressure=true),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-104,-276},{-136,-244}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Nhex=Nhex_bi,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                Vhot=26.587,
                Vcold=8.651,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                      1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                      2.29575e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                    629.917,629.888,630.182,630.842,632.016,634.097}),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                      199646,197679},
                  noInitialPressure=true),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    gamma_nom_2ph=10000,
                    alpha=1.6),
                Shot=2251.9,
                Scold=1765.5,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                                                    annotation (Placement(
                    transformation(extent={{-136,-196},{-104,-164}})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Nhex=Nhex_bi,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                Vhot=3.905,
                Vcold=1.065,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                      2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                      2.69972e+006,2.74645e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                    656.757,670.379,679.959,684.074,688.573,693.427}),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                      295435,288187},
                  noInitialPressure=true),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000,
                    alpha=1.1),
                Shot=429.2,
                Scold=338,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                                                    annotation (Placement(
                    transformation(extent={{-104,-116},{-136,-84}})));

              Components.Equilibrium2phVessel separator(
                H=8,
                zl_start=0,
                h_start=2.7e6,
                D=0.56,
                noInitialPressure=true,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p_start=17710000)
                annotation (Placement(transformation(extent={{-88,-52},{-32,4}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                w0=0,
                use_in_w0=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-60,-74})));

              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                Nhex=Nhex_mono,
                Vhot=3.68,
                Vcold=2.683,
                tubeWalls(Tvolstart(displayUnit="K") = {725.391,769.727,804.861,
                    826.169}),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                      3.42731e+006},
                  noInitialPressure=true),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={518322,502443,472016,421345,355895},
                  noInitialPressure=true),
                Shot=1153.8,
                Scold=879.8,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                    rotation=0,
                    origin={-60,40})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                Nhex=Nhex_mono,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                Vhot=1.522,
                Vcold=5.092,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                      3.56013e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {734.495,783.217,812.321,
                    829.047}),
                Shot=1339,
                Scold=1198,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={518322,503128,476511,430304,353343},
                  noInitialPressure=true),
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                    rotation=-90,
                    origin={20,80})));
              ThermoPower.Water.ThroughMassFlow valveRH(
                w0=238.7,
                use_in_w0=true,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-200,150},{-180,
                        170}})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                wnom=88.59,
                rhonom=168.8,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-140})));
              ThermoPower.Water.PressDrop PDSteamECO2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                rhonom=582.8,
                dpnom=(0.52492/2)*10^5,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                        annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-220})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=97,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-92,-32})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Temperature T_RH = sensT_RH.T;
              Modelica.SIunits.Length sep_lev = separator.zl;
              Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
              Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
              Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
              Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              //Modelica.SIunits.TemperatureDifference deltaT_SH_star = ((ECO.coldFluid.T[end] - ECO.coldFluid.T[1]) - (ECO.hotFluid.T[1] - ECO.hotFluid.T[end]))/(ECO.coldFluid.T[end] - ECO.coldFluid.T[1]);
              //Modelica.SIunits.TemperatureDifference deltaT_EVA2_star = ((EVA2.coldFluid.T[end] - EVA2.coldFluid.T[1]) - (EVA2.hotFluid.T[1] - EVA2.hotFluid.T[end]))/(EVA2.hotFluid.T[1] - EVA2.hotFluid.T[end]);
              //Modelica.SIunits.TemperatureDifference deltaT_EVA1_star = ((EVA1.coldFluid.T[end] - EVA1.coldFluid.T[1]) - (EVA1.hotFluid.T[1] - EVA1.hotFluid.T[end]))/(EVA1.hotFluid.T[1] - EVA1.hotFluid.T[end]);
              Modelica.SIunits.TemperatureDifference deltaT_SH_hot = SH.hotFluid.T[1] - SH.hotFluid.T[end];
              Modelica.SIunits.TemperatureDifference deltaT_SH_cold = SH.coldFluid.T[end] - SH.coldFluid.T[1];
              Modelica.SIunits.Power Q_sh = separator.w_in*(separator.h - separator.hv);
              Modelica.SIunits.Power Q_eva = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Real Q_sh_perc = Q_sh/Q_tot;

              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=82.57,
                dpnom=(0.55113)*10^5,
                rhonom=12.52,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-20,100})));
              ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph)
                annotation (Placement(transformation(extent={{-30,-316},{-50,-296}})));
              ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                    PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                    transformation(extent={{-150,-266},{-170,-246}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(177.1 - 176.1189)*10^5,
                wnom=88.59,
                rhonom=51.9,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-60,80})));
              ThermoPower.Water.PressDrop PDSteamECO1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492/2)*10^5,
                rhonom=767.7,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-294})));
              PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                load_end=100,
                t_ramp=0) annotation (Placement(transformation(extent={{-320,-60},
                        {-280,-20}})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                h=518322,
                w0=610.6,
                use_in_w0=true,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-248,150},{-228,
                        170}})));
              Modelica.Blocks.Sources.Ramp LOAD(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-330,120})));
              Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                  table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                    488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-300,170},{-280,190}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-200,-270},
                        {-220,-250}})));

              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=17700000)
                annotation (Placement(transformation(extent={{-40,-130},{-20,-110}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(            smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,3092400;
                    20,3124593; 30,3130270; 40,3128892; 50,3125327; 60,3116961; 70,3108752;
                    80,3100618; 90,3093346; 100,3083198])
                annotation (Placement(transformation(extent={{140,170},{120,190}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    4.18; 20,13.4; 30,21.5; 40,29.69; 50,38.01; 60,46.38; 70,54.15; 80,63.31;
                    90,72.7; 100,82.57])
                annotation (Placement(transformation(extent={{140,130},{120,150}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{100,70},{80,90}})));
              Modelica.Blocks.Sources.Ramp LOAD1(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={330,180})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{20,180},{40,200}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    22e5; 20,7.67e5; 30,12.28e5; 40,16.92e5; 50,21.61e5; 60,26.32e5; 70,30.66e5;
                    80,35.77e5; 90,40.98e5; 100,46.4e5])
                annotation (Placement(transformation(extent={{140,210},{120,230}})));
              ThermoPower.Water.SensT sensT_RH(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=90,
                    origin={-16,140})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17611890,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{-80,90},{-100,110}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    100.1e5; 20,100.1e5; 30,100.3e5; 40,100.3e5; 50,100.5e5; 60,112.1e5; 70,
                    128.5e5; 80,144.9e5; 90,161.1e5; 100,176.1e5])
                                                             annotation (Placement(
                    transformation(extent={{-160,110},{-140,130}})));
              ThermoPower.Water.SourceMassFlow sourceSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=88.59,
                p0=17910000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{60,-320},{40,-300}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    1258351; 20,1258351; 30,1260394; 40,1258763; 50,1251884; 60,1111212; 70,
                    1126638; 80,1133837; 90,1182452; 100,1231860])
                annotation (Placement(transformation(extent={{20,-280},{40,-260}})));
              Modelica.Blocks.Sources.Ramp LOAD2(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-10,-270})));
              Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
                initType=Modelica.Blocks.Types.Init.SteadyState,
                k=1,
                T=0.3)
                annotation (Placement(transformation(extent={{-140,260},{-160,280}})));
              IndustrialControlSystems.Controllers.PI PID_valveRH(
                AntiWindup=true,
                useTS=true,
                CSmin=-0.9,
                CSmax=0.2,
                Kp=0.17,
                Ti=16,
                CS_start=0)
                annotation (Placement(transformation(extent={{20,280},{-20,320}})));
              Modelica.Blocks.Sources.Constant valveRH_TS(k=0)
                annotation (Placement(transformation(extent={{40,330},{20,350}})));
              Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.4; 70,
                    127.897; 80,158.7; 90,197.125; 100,240.532])
                annotation (Placement(transformation(extent={{-40,240},{-60,260}})));
              Modelica.Blocks.Math.Product product
                annotation (Placement(transformation(extent={{-100,272},{-108,280}})));
              Modelica.Blocks.Math.Add3 add
                annotation (Placement(transformation(extent={{-120,266},{-128,274}})));
              Modelica.Blocks.Sources.Constant T_RH_SP(k=826.05)
                annotation (Placement(transformation(extent={{72,302},{52,322}})));
              Modelica.Blocks.Sources.BooleanStep     valveRH_ts(startTime=-500)
                annotation (Placement(transformation(extent={{-40,330},{-20,350}})));
              Modelica.Blocks.Sources.Step step_wRH(
                offset=0,
                startTime=0,
                height=0)
                annotation (Placement(transformation(extent={{-40,200},{-60,220}})));
              IndustrialControlSystems.Controllers.PID PID_pumpFW_high(
                AntiWindup=true,
                useTS=true,
                CSmin=-0.9,
                CSmax=0.5,
                Ti=100,
                Td=5,
                N=20,
                CS_start=0,
                Kp=-0.01)
                annotation (Placement(transformation(extent={{220,-158},{180,-118}})));
             Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
                initType=Modelica.Blocks.Types.Init.SteadyState,
                k=1,
                T=2)         annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=180,
                    origin={90,-150})));
              Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=0)
                annotation (Placement(transformation(extent={{280,-90},{260,-70}})));
              Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                    3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.7; 70,64.0423;
                    80,72.1907; 90,80.1795; 100,88.2715])
                                                annotation (Placement(transformation(
                      extent={{200,-200},{180,-180}})));
              Modelica.Blocks.Math.Product product1
                annotation (Placement(transformation(extent={{148,-144},{140,-136}})));
              Modelica.Blocks.Math.Add3 add1
                annotation (Placement(transformation(extent={{120,-154},{112,-146}})));
              Modelica.Blocks.Sources.Constant DT_sh_SP(k=20)
                annotation (Placement(transformation(extent={{280,-134},{260,-114}})));
              Modelica.Blocks.Sources.BooleanStep     pumpFW_ts(
                  startValue=false, startTime=-200)
                annotation (Placement(transformation(extent={{160,-90},{180,-70}})));
              Modelica.Blocks.Sources.Step step_wFW(
                offset=0,
                startTime=0,
                height=1)
                annotation (Placement(transformation(extent={{180,100},{160,120}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-360,340},{-340,360}})));
              Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{-4,-4},{4,4}},
                    rotation=-90,
                    origin={94,96})));
              Modelica.Blocks.Math.Add add3
                annotation (Placement(transformation(extent={{-258,178},{-248,188}})));
              Modelica.Blocks.Sources.Step step_w_MS(
                offset=0,
                startTime=0,
                height=0)
                annotation (Placement(transformation(extent={{-300,212},{-280,232}})));
            equation
              connect(valveRH.outlet, RH.inletHot) annotation (Line(
                  points={{-180,160},{20,160},{20,96}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                  points={{-120,-244},{-120,-230}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{-60,-42},{-60,-64}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-82,-32},{-70,-32}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));
              connect(SH.inletCold, separator.steam_out) annotation (Line(
                  points={{-60,24},{-60,0}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}));
              connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                  points={{-120,-130},{-120,-116}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                  points={{-120,-164},{-120,-150}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                  points={{-120,-84},{-120,-32},{-102,-32}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                  points={{20,64},{20,-100},{-104,-100}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                  points={{-44,40},{20,40},{20,-100},{-104,-100}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-136,-100},{-160,-100},{-160,-180},{-136,-180}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-104,-180},{-80,-180},{-80,-260},{-104,-260}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                  points={{4,80},{-20,80},{-20,90}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                  points={{-120,-196},{-120,-210}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-60,70},{-60,56}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                  points={{-120,-276},{-120,-284}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                  points={{-46,-310},{-46,-310},{-66,-310},{-120,-310},{-120,-304}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sensT_MS.inlet, ECO.outletHot) annotation (Line(
                  points={{-154,-260},{-136,-260}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(sourceMS.flange, valveRH.inlet) annotation (Line(
                  points={{-228,160},{-200,160}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-228,160},{-228,160},{-220,160},{-220,40},{-76,40}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(LOAD.y, table_w_MS.u[1]) annotation (Line(points={{-319,120},{-319,120},
                      {-311,120},{-311,180},{-302,180}}, color={0,0,127}));
              connect(sinkMS.flange, sensT_MS.outlet) annotation (Line(
                  points={{-200,-260},{-184,-260},{-166,-260}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(waterPump.outlet, sinkPressure1.flange) annotation (Line(
                  points={{-60,-84},{-60,-120},{-40,-120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD1.y, h_ST_RH.u[1])
                annotation (Line(points={{319,180},{319,180},{142,180}}, color={0,0,127}));
              connect(LOAD1.y, w_ST_RH.u[1]) annotation (Line(points={{319,180},{319,180},{150,
                      180},{150,140},{142,140}}, color={0,0,127}));
              connect(h_ST_RH.y[1], sourceSteam1.in_h) annotation (Line(points={{119,180},{119,
                      180},{86,180},{86,86}}, color={0,0,127}));
              connect(RH.inletCold, sourceSteam1.flange) annotation (Line(
                  points={{36,80},{80,80}},
                  color={0,0,255},
                  thickness=0.5));
              connect(p_ST_RH.y[1],sinkSteam1. in_p0) annotation (Line(
                  points={{119,220},{26,220},{26,198.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(LOAD1.y, p_ST_RH.u[1]) annotation (Line(points={{319,180},{150,180},{150,
                      220},{142,220}}, color={0,0,127}));
              connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                  points={{-20,134},{-20,134},{-20,110}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSteam1.flange, sensT_RH.outlet) annotation (Line(
                  points={{20,190},{0,190},{-20,190},{-20,146}},
                  color={0,0,255},
                  thickness=0.5));
              connect(p_ST_SH.y[1],sinkSteam. in_p0) annotation (Line(
                  points={{-139,120},{-86,120},{-86,108.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sinkSteam.flange, PDSteamSH.outlet) annotation (Line(
                  points={{-80,100},{-60,100},{-60,90}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD.y, p_ST_SH.u[1]) annotation (Line(points={{-319,120},{-238,120},{
                      -162,120}}, color={0,0,127}));
              connect(h_ST_ECO.y[1],sourceSteam2. in_h) annotation (Line(points={{41,-270},{
                      46,-270},{46,-304}},    color={0,0,127}));
              connect(sensT_FW.inlet, sourceSteam2.flange) annotation (Line(
                  points={{-34,-310},{40,-310}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD2.y, h_ST_ECO.u[1])
                annotation (Line(points={{1,-270},{9.5,-270},{18,-270}}, color={0,0,127}));
              connect(add.y,valveRH_dynamic. u) annotation (Line(points={{-128.4,270},{-128.4,
                      270},{-138,270}},  color={0,0,127}));
              connect(T_RH_SP.y,PID_valveRH. SP) annotation (Line(points={{51,312},{50,312},
                      {16,312}},         color={0,0,127}));
              connect(add.u1, product.y) annotation (Line(points={{-119.2,273.2},{-114,273.2},
                      {-114,276},{-108.4,276}}, color={0,0,127}));
              connect(valveRH_dynamic.y, valveRH.in_w0) annotation (Line(
                  points={{-161,270},{-194,270},{-194,166}},
                  color={255,215,52},
                  thickness=0.5));
              connect(valveRH_ts.y, PID_valveRH.TS)
                annotation (Line(points={{-19,340},{-8,340},{-8,316}}, color={255,0,255}));
              connect(PID_valveRH.CS, product.u1) annotation (Line(points={{-18,300},{-80,300},
                      {-80,278.4},{-99.2,278.4}}, color={0,0,127}));
              connect(LOAD1.y, table_w_RH.u[1]) annotation (Line(points={{319,180},{319,180},
                      {150,180},{150,250},{-38,250}}, color={0,0,127}));
              connect(table_w_RH.y[1], add.u2) annotation (Line(points={{-61,250},{-90,250},
                      {-90,270},{-119.2,270}}, color={0,0,127}));
              connect(table_w_RH.y[1], product.u2) annotation (Line(points={{-61,250},{-90,250},
                      {-90,273.6},{-99.2,273.6}}, color={0,0,127}));
              connect(step_wRH.y, add.u3) annotation (Line(points={{-61,210},{-86,210},{-108,
                      210},{-108,266.8},{-119.2,266.8}}, color={0,0,127}));

              connect(product1.y,add1. u1)
                annotation (Line(points={{139.6,-140},{140,-140},{134,-140},{134,
                      -146.8},{120.8,-146.8}},                      color={0,0,127}));
              connect(add1.u2,table_w_FW. y[1]) annotation (Line(points={{120.8,
                      -150},{120.8,-150},{140,-150},{160,-150},{160,-190},{179,
                      -190}},           color={0,0,127}));
              connect(product1.u2,table_w_FW. y[1]) annotation (Line(points={{148.8,-142.4},
                      {160,-142.4},{160,-190},{179,-190}},
                                          color={0,0,127}));
              connect(product1.u1,PID_pumpFW_high. CS) annotation (Line(points={{148.8,-137.6},
                      {182,-137.6},{182,-138}},
                                          color={0,0,127}));
              connect(DT_sh_SP.y,PID_pumpFW_high. SP)
                annotation (Line(points={{259,-124},{216,-124},{216,-126}},
                                                                 color={0,0,127}));
              connect(pumpFW_dynamic.u, add1.y)
                annotation (Line(points={{102,-150},{111.6,-150}}, color={0,0,127}));
              connect(pumpFW_dynamic.y, sourceSteam2.in_w0) annotation (Line(points={{79,-150},
                      {64,-150},{54,-150},{54,-304}}, color={255,215,52},
                  thickness=0.5));
              connect(separator.DT_sh, PID_pumpFW_high.PV) annotation (Line(points={{-50,-14},
                      {94,-14},{240,-14},{240,-140},{216,-140}}, color={255,215,
                      52},
                  thickness=0.5));
              connect(pumpFW_ts.y, PID_pumpFW_high.TS) annotation (Line(points={{181,-80},{192,
                      -80},{192,-122}}, color={255,0,255}));
              connect(LOAD1.y, table_w_FW.u[1]) annotation (Line(points={{319,180},{314,180},
                      {300,180},{300,-190},{202,-190}}, color={0,0,127}));
              connect(step_wFW.y, add1.u3) annotation (Line(points={{159,110},{159,110},{130,
                      110},{130,-153.2},{120.8,-153.2}},  color={0,0,127}));
              connect(PID_pumpFW_high.CS, PID_pumpFW_high.TR) annotation (Line(
                    points={{182,-138},{172,-138},{160,-138},{160,-108},{200,-108},
                      {200,-122}}, color={0,0,127}));
              connect(add2.y, sourceSteam1.in_w0) annotation (Line(points={{94,
                      91.6},{94,86},{94,86}}, color={0,0,127}));
              connect(w_ST_RH.y[1], add2.u2) annotation (Line(points={{119,140},{
                      108,140},{91.6,140},{91.6,100.8}}, color={0,0,127}));
              connect(step_wFW.y, add2.u1) annotation (Line(points={{159,110},{130,110},{96.4,
                      110},{96.4,100.8}}, color={0,0,127}));
              connect(PID_valveRH.CS, PID_valveRH.TR) annotation (Line(points={{-18,300},{-24,
                      300},{-26,300},{-26,324},{0,324},{0,316}}, color={0,0,127}));
              connect(sensT_RH.T, PID_valveRH.PV) annotation (Line(
                  points={{-10,148},{-10,148},{-10,238},{-10,240},{40,240},{40,
                      298},{16,298}},
                  color={254,235,86},
                  thickness=0.5));
              connect(table_w_MS.y[1], add3.u2)
                annotation (Line(points={{-279,180},{-259,180}}, color={0,0,127}));
              connect(step_w_MS.y, add3.u1) annotation (Line(points={{-279,222},{-268,222},{
                      -268,186},{-259,186}}, color={0,0,127}));
              connect(add3.y, sourceMS.in_w0) annotation (Line(points={{-247.5,183},{-242,183},
                      {-242,166}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-360,-360},{360,360}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-360,-360},{360,360}}, preserveAspectRatio=false)),
                experiment(
                  StartTime=-2000,
                  StopTime=5000,
                  __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_wFW_sensitivity;

            model test_wFW_sensitivity_2
              "Test model to analyse the sensitivity of the EVA1/EVA2 operational point against the feedwater mass flow"
              import PreFlexMS;

              //Heat exchangers parameter
              parameter Integer Nhex_mono = 5
                "Number of nodes for single phase heat exchangers";
              parameter Integer Nhex_bi = 10
                "Number of nodes for biphase heat exchangers";

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                Nhex=Nhex_mono,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                Vhot=45.011,
                Vcold=5.752,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                      1.66591e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                    623.137}),
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={199579,192529,183185,168175,136603},
                  noInitialPressure=true),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-104,-276},{-136,-244}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Nhex=Nhex_bi,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                Vhot=26.587,
                Vcold=8.651,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                      1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                      2.29575e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                    629.917,629.888,630.182,630.842,632.016,634.097}),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                      199646,197679},
                  noInitialPressure=true),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    gamma_nom_2ph=10000,
                    alpha=1.6),
                Shot=2251.9,
                Scold=1765.5,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                                                    annotation (Placement(
                    transformation(extent={{-136,-196},{-104,-164}})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Nhex=Nhex_bi,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                Vhot=3.905,
                Vcold=1.065,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                      2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                      2.69972e+006,2.74645e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                    656.757,670.379,679.959,684.074,688.573,693.427}),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                      295435,288187},
                  noInitialPressure=true),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000,
                    alpha=1.1),
                Shot=429.2,
                Scold=338,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                                                    annotation (Placement(
                    transformation(extent={{-104,-116},{-136,-84}})));

              Components.Equilibrium2phVessel separator(
                H=8,
                zl_start=0,
                h_start=2.7e6,
                D=0.56,
                noInitialPressure=true,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p_start=17710000)
                annotation (Placement(transformation(extent={{-88,-52},{-32,4}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                w0=0,
                use_in_w0=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-60,-74})));

              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Mm=15353,
                nominalColdFlow=88.59,
                nominalHotFlow=371.8,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2200, alpha=0.847436),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.28867),
                Nhex=Nhex_mono,
                Vhot=3.68,
                Vcold=2.683,
                tubeWalls(Tvolstart(displayUnit="K") = {725.391,769.727,804.861,
                    826.169}),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                      3.42731e+006},
                  noInitialPressure=true),
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={518322,502443,472016,421345,355895},
                  noInitialPressure=true),
                Shot=1153.8,
                Scold=879.8,
                nominalColdPressure=17710000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=648.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=732.02,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                    rotation=0,
                    origin={-60,40})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                Mm=10081,
                nominalColdFlow=82.57,
                nominalHotFlow=238.7,
                Nhex=Nhex_mono,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=970),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2600, alpha=0.320782),
                Vhot=1.522,
                Vcold=5.092,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                      3.56013e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {734.495,783.217,812.321,
                    829.047}),
                Shot=1339,
                Scold=1198,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={518322,503128,476511,430304,353343},
                  noInitialPressure=true),
                nominalColdPressure=4698000,
                nominalHotPressure=1000000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.15,
                nominalHotOutletTemperature=731.45,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                    rotation=-90,
                    origin={20,80})));
              ThermoPower.Water.ThroughMassFlow valveRH(
                w0=238.7,
                use_in_w0=true,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-200,150},{-180,
                        170}})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                wnom=88.59,
                rhonom=168.8,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-140})));
              ThermoPower.Water.PressDrop PDSteamECO2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                rhonom=582.8,
                dpnom=(0.52492/2)*10^5,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                        annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-220})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=97,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-92,-32})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Temperature T_RH = sensT_RH.T;
              Modelica.SIunits.Length sep_lev = separator.zl;
              Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
              Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
              Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
              Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              //Modelica.SIunits.TemperatureDifference deltaT_SH_star = ((ECO.coldFluid.T[end] - ECO.coldFluid.T[1]) - (ECO.hotFluid.T[1] - ECO.hotFluid.T[end]))/(ECO.coldFluid.T[end] - ECO.coldFluid.T[1]);
              //Modelica.SIunits.TemperatureDifference deltaT_EVA2_star = ((EVA2.coldFluid.T[end] - EVA2.coldFluid.T[1]) - (EVA2.hotFluid.T[1] - EVA2.hotFluid.T[end]))/(EVA2.hotFluid.T[1] - EVA2.hotFluid.T[end]);
              //Modelica.SIunits.TemperatureDifference deltaT_EVA1_star = ((EVA1.coldFluid.T[end] - EVA1.coldFluid.T[1]) - (EVA1.hotFluid.T[1] - EVA1.hotFluid.T[end]))/(EVA1.hotFluid.T[1] - EVA1.hotFluid.T[end]);
              Modelica.SIunits.TemperatureDifference deltaT_SH_hot = SH.hotFluid.T[1] - SH.hotFluid.T[end];
              Modelica.SIunits.TemperatureDifference deltaT_SH_cold = SH.coldFluid.T[end] - SH.coldFluid.T[1];
              Modelica.SIunits.Power Q_sh = separator.w_in*(separator.h - separator.hv);
              Modelica.SIunits.Power Q_eva = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Real Q_sh_perc = Q_sh/Q_tot;

              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=82.57,
                dpnom=(0.55113)*10^5,
                rhonom=12.52,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-20,100})));
              ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph)
                annotation (Placement(transformation(extent={{-30,-316},{-50,-296}})));
              ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                    PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                    transformation(extent={{-150,-266},{-170,-246}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(177.1 - 176.1189)*10^5,
                wnom=88.59,
                rhonom=51.9,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-60,80})));
              ThermoPower.Water.PressDrop PDSteamECO1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492/2)*10^5,
                rhonom=767.7,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-120,-294})));
              PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
                t_start=0,
                load_start=100,
                load_end=60,
                t_ramp=60*10) annotation (Placement(transformation(extent={{-320,
                        -60},{-280,-20}})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                h=518322,
                w0=610.6,
                use_in_w0=true,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
                annotation (Placement(transformation(extent={{-248,150},{-228,
                        170}})));
              Modelica.Blocks.Sources.Ramp LOAD(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-330,120})));
              Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                  table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                    488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-300,170},{-280,190}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=839319) annotation (Placement(transformation(extent={{-200,-270},
                        {-220,-250}})));

              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=17700000)
                annotation (Placement(transformation(extent={{-40,-130},{-20,-110}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(            smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,3092400;
                    20,3124593; 30,3130270; 40,3128892; 50,3125327; 60,3116961; 70,3108752;
                    80,3100618; 90,3093346; 100,3083198])
                annotation (Placement(transformation(extent={{140,170},{120,190}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    4.18; 20,13.4; 30,21.5; 40,29.69; 50,38.01; 60,46.38; 70,54.15; 80,63.31;
                    90,72.7; 100,82.57])
                annotation (Placement(transformation(extent={{140,130},{120,150}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                p0=4698000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{100,70},{80,90}})));
              Modelica.Blocks.Sources.Ramp LOAD1(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={330,180})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=4642887,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{20,180},{40,200}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    22e5; 20,7.67e5; 30,12.28e5; 40,16.92e5; 50,21.61e5; 60,26.32e5; 70,30.66e5;
                    80,35.77e5; 90,40.98e5; 100,46.4e5])
                annotation (Placement(transformation(extent={{140,210},{120,230}})));
              ThermoPower.Water.SensT sensT_RH(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=90,
                    origin={-16,140})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17611890,
                use_in_p0=true)
                annotation (Placement(transformation(extent={{-80,90},{-100,110}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    100.1e5; 20,100.1e5; 30,100.3e5; 40,100.3e5; 50,100.5e5; 60,112.1e5; 70,
                    128.5e5; 80,144.9e5; 90,161.1e5; 100,176.1e5])
                                                             annotation (Placement(
                    transformation(extent={{-160,110},{-140,130}})));
              ThermoPower.Water.SourceMassFlow sourceSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                w0=88.59,
                p0=17910000,
                use_in_w0=true,
                use_in_h=true)
                annotation (Placement(transformation(extent={{60,-320},{40,-300}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    1258351; 20,1258351; 30,1260394; 40,1258763; 50,1251884; 60,1111212; 70,
                    1126638; 80,1133837; 90,1182452; 100,1231860])
                annotation (Placement(transformation(extent={{20,-280},{40,-260}})));
              Modelica.Blocks.Sources.Ramp LOAD2(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-10,-270})));
              Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
                initType=Modelica.Blocks.Types.Init.SteadyState,
                k=1,
                T=0.3)
                annotation (Placement(transformation(extent={{-140,260},{-160,280}})));
              IndustrialControlSystems.Controllers.PI PID_valveRH(
                AntiWindup=true,
                useTS=true,
                CSmin=-0.9,
                CSmax=0.2,
                Kp=0.17,
                Ti=16,
                CS_start=0)
                annotation (Placement(transformation(extent={{20,280},{-20,320}})));
              Modelica.Blocks.Sources.Constant valveRH_TS(k=0)
                annotation (Placement(transformation(extent={{40,330},{20,350}})));
              Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                    6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.4; 70,
                    127.897; 80,158.7; 90,197.125; 100,240.532])
                annotation (Placement(transformation(extent={{-40,240},{-60,260}})));
              Modelica.Blocks.Math.Product product
                annotation (Placement(transformation(extent={{-100,272},{-108,280}})));
              Modelica.Blocks.Math.Add3 add
                annotation (Placement(transformation(extent={{-120,266},{-128,274}})));
              Modelica.Blocks.Sources.Constant T_RH_SP(k=826.05)
                annotation (Placement(transformation(extent={{72,302},{52,322}})));
              Modelica.Blocks.Sources.BooleanStep     valveRH_ts(startTime=5000)
                annotation (Placement(transformation(extent={{-40,330},{-20,350}})));
              Modelica.Blocks.Sources.Step step_wRH(
                offset=0,
                startTime=0,
                height=0)
                annotation (Placement(transformation(extent={{-40,200},{-60,220}})));
              IndustrialControlSystems.Controllers.PID PID_pumpFW_high(
                AntiWindup=true,
                useTS=true,
                CSmin=-0.9,
                N=20,
                CS_start=0,
                CSmax=1,
                Kp=-0.007514,
                Ti=243.4,
                Td=45)
                annotation (Placement(transformation(extent={{220,-158},{180,-118}})));
             Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
                initType=Modelica.Blocks.Types.Init.SteadyState,
                k=1,
                T=2)         annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=180,
                    origin={90,-150})));
              Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=0)
                annotation (Placement(transformation(extent={{280,-90},{260,-70}})));
              Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                    3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.7; 70,64.0423;
                    80,72.1907; 90,80.1795; 100,88.2715])
                                                annotation (Placement(transformation(
                      extent={{200,-200},{180,-180}})));
              Modelica.Blocks.Math.Product product1
                annotation (Placement(transformation(extent={{148,-144},{140,-136}})));
              Modelica.Blocks.Math.MultiSum
                                        add1(nu=3)
                annotation (Placement(transformation(extent={{120,-154},{112,-146}})));
              Modelica.Blocks.Sources.BooleanStep     pumpFW_ts(
                  startValue=false, startTime=5000)
                annotation (Placement(transformation(extent={{160,-90},{180,-70}})));
              Modelica.Blocks.Sources.Step step_wFW(
                offset=0,
                startTime=0,
                height=-1)
                annotation (Placement(transformation(extent={{180,100},{160,120}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-360,340},{-340,360}})));
              Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{-4,-4},{4,4}},
                    rotation=-90,
                    origin={94,96})));
              Modelica.Blocks.Math.Add add3
                annotation (Placement(transformation(extent={{-258,178},{-248,188}})));
              Modelica.Blocks.Sources.Step step_w_MS(
                offset=0,
                startTime=0,
                height=0)
                annotation (Placement(transformation(extent={{-300,212},{-280,232}})));
              Modelica.Blocks.Sources.RealExpression realExpression(y=SH.hotFluid.T[
                    end] - RH.hotFluid.T[end]) annotation (Placement(
                    transformation(extent={{280,-170},{260,-150}})));
              Modelica.Blocks.Tables.CombiTable1D DT_MS_sp(           smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    60,40.54; 70,31.85; 80,22.12; 90,11.71; 100,1.16])
                annotation (Placement(transformation(extent={{280,-134},{260,-114}})));
            equation
              connect(valveRH.outlet, RH.inletHot) annotation (Line(
                  points={{-180,160},{20,160},{20,96}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                  points={{-120,-244},{-120,-230}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{-60,-42},{-60,-64}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-82,-32},{-70,-32}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));
              connect(SH.inletCold, separator.steam_out) annotation (Line(
                  points={{-60,24},{-60,0}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}));
              connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                  points={{-120,-130},{-120,-116}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                  points={{-120,-164},{-120,-150}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                  points={{-120,-84},{-120,-32},{-102,-32}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                  points={{20,64},{20,-100},{-104,-100}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                  points={{-44,40},{20,40},{20,-100},{-104,-100}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-136,-100},{-160,-100},{-160,-180},{-136,-180}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-104,-180},{-80,-180},{-80,-260},{-104,-260}},
                  color={255,0,0},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                  points={{4,80},{-20,80},{-20,90}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                  points={{-120,-196},{-120,-210}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-60,70},{-60,56}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                  points={{-120,-276},{-120,-284}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                  points={{-46,-310},{-46,-310},{-66,-310},{-120,-310},{-120,-304}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sensT_MS.inlet, ECO.outletHot) annotation (Line(
                  points={{-154,-260},{-136,-260}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(sourceMS.flange, valveRH.inlet) annotation (Line(
                  points={{-228,160},{-200,160}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-228,160},{-228,160},{-220,160},{-220,40},{-76,40}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(LOAD.y, table_w_MS.u[1]) annotation (Line(points={{-319,120},{-319,120},
                      {-311,120},{-311,180},{-302,180}}, color={0,0,127}));
              connect(sinkMS.flange, sensT_MS.outlet) annotation (Line(
                  points={{-200,-260},{-184,-260},{-166,-260}},
                  thickness=0.5,
                  color={255,0,0}));
              connect(waterPump.outlet, sinkPressure1.flange) annotation (Line(
                  points={{-60,-84},{-60,-120},{-40,-120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD1.y, h_ST_RH.u[1])
                annotation (Line(points={{319,180},{319,180},{142,180}}, color={0,0,127}));
              connect(LOAD1.y, w_ST_RH.u[1]) annotation (Line(points={{319,180},{319,180},{150,
                      180},{150,140},{142,140}}, color={0,0,127}));
              connect(h_ST_RH.y[1], sourceSteam1.in_h) annotation (Line(points={{119,180},
                      {119,180},{86,180},{86,86}},
                                              color={0,0,127}));
              connect(RH.inletCold, sourceSteam1.flange) annotation (Line(
                  points={{36,80},{80,80}},
                  color={0,0,255},
                  thickness=0.5));
              connect(p_ST_RH.y[1],sinkSteam1. in_p0) annotation (Line(
                  points={{119,220},{26,220},{26,198.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(LOAD1.y, p_ST_RH.u[1]) annotation (Line(points={{319,180},{150,180},{150,
                      220},{142,220}}, color={0,0,127}));
              connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                  points={{-20,134},{-20,134},{-20,110}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSteam1.flange, sensT_RH.outlet) annotation (Line(
                  points={{20,190},{0,190},{-20,190},{-20,146}},
                  color={0,0,255},
                  thickness=0.5));
              connect(p_ST_SH.y[1],sinkSteam. in_p0) annotation (Line(
                  points={{-139,120},{-86,120},{-86,108.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(sinkSteam.flange, PDSteamSH.outlet) annotation (Line(
                  points={{-80,100},{-60,100},{-60,90}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD.y, p_ST_SH.u[1]) annotation (Line(points={{-319,120},{-238,120},{
                      -162,120}}, color={0,0,127}));
              connect(h_ST_ECO.y[1],sourceSteam2. in_h) annotation (Line(points={{41,-270},{
                      46,-270},{46,-304}},    color={0,0,127}));
              connect(sensT_FW.inlet, sourceSteam2.flange) annotation (Line(
                  points={{-34,-310},{40,-310}},
                  color={0,0,255},
                  thickness=0.5));
              connect(LOAD2.y, h_ST_ECO.u[1])
                annotation (Line(points={{1,-270},{9.5,-270},{18,-270}}, color={0,0,127}));
              connect(add.y,valveRH_dynamic. u) annotation (Line(points={{-128.4,270},{-128.4,
                      270},{-138,270}},  color={0,0,127}));
              connect(T_RH_SP.y,PID_valveRH. SP) annotation (Line(points={{51,312},{50,312},
                      {16,312}},         color={0,0,127}));
              connect(add.u1, product.y) annotation (Line(points={{-119.2,273.2},{-114,273.2},
                      {-114,276},{-108.4,276}}, color={0,0,127}));
              connect(valveRH_dynamic.y, valveRH.in_w0) annotation (Line(
                  points={{-161,270},{-194,270},{-194,166}},
                  color={255,215,52},
                  thickness=0.5));
              connect(valveRH_ts.y, PID_valveRH.TS)
                annotation (Line(points={{-19,340},{-8,340},{-8,316}}, color={255,0,255}));
              connect(PID_valveRH.CS, product.u1) annotation (Line(points={{-18,300},{-80,300},
                      {-80,278.4},{-99.2,278.4}}, color={0,0,127}));
              connect(LOAD1.y, table_w_RH.u[1]) annotation (Line(points={{319,180},{319,180},
                      {150,180},{150,250},{-38,250}}, color={0,0,127}));
              connect(table_w_RH.y[1], add.u2) annotation (Line(points={{-61,250},{-90,250},
                      {-90,270},{-119.2,270}}, color={0,0,127}));
              connect(table_w_RH.y[1], product.u2) annotation (Line(points={{-61,250},{-90,250},
                      {-90,273.6},{-99.2,273.6}}, color={0,0,127}));
              connect(step_wRH.y, add.u3) annotation (Line(points={{-61,210},{-86,210},{-108,
                      210},{-108,266.8},{-119.2,266.8}}, color={0,0,127}));

              connect(product1.u2,table_w_FW. y[1]) annotation (Line(points={{148.8,-142.4},
                      {160,-142.4},{160,-190},{179,-190}},
                                          color={0,0,127}));
              connect(product1.u1,PID_pumpFW_high. CS) annotation (Line(points={{148.8,-137.6},
                      {182,-137.6},{182,-138}},
                                          color={0,0,127}));
              connect(pumpFW_dynamic.u, add1.y)
                annotation (Line(points={{102,-150},{111.32,-150}},color={0,0,127}));
              connect(pumpFW_dynamic.y, sourceSteam2.in_w0) annotation (Line(points={{79,-150},
                      {64,-150},{54,-150},{54,-304}}, color={255,215,52},
                  thickness=0.5));
              connect(pumpFW_ts.y, PID_pumpFW_high.TS) annotation (Line(points={{181,-80},{192,
                      -80},{192,-122}}, color={255,0,255}));
              connect(LOAD1.y, table_w_FW.u[1]) annotation (Line(points={{319,180},{314,180},
                      {300,180},{300,-190},{202,-190}}, color={0,0,127}));
              connect(PID_pumpFW_high.CS, PID_pumpFW_high.TR) annotation (Line(
                    points={{182,-138},{172,-138},{160,-138},{160,-108},{200,-108},
                      {200,-122}}, color={0,0,127}));
              connect(add2.y, sourceSteam1.in_w0) annotation (Line(points={{94,
                      91.6},{94,86},{94,86}}, color={0,0,127}));
              connect(w_ST_RH.y[1], add2.u2) annotation (Line(points={{119,140},{
                      108,140},{91.6,140},{91.6,100.8}}, color={0,0,127}));
              connect(step_wFW.y, add2.u1) annotation (Line(points={{159,110},{130,110},{96.4,
                      110},{96.4,100.8}}, color={0,0,127}));
              connect(PID_valveRH.CS, PID_valveRH.TR) annotation (Line(points={{-18,300},{-24,
                      300},{-26,300},{-26,324},{0,324},{0,316}}, color={0,0,127}));
              connect(sensT_RH.T, PID_valveRH.PV) annotation (Line(
                  points={{-10,148},{-10,148},{-10,238},{-10,240},{40,240},{40,
                      298},{16,298}},
                  color={254,235,86},
                  thickness=0.5));
              connect(table_w_MS.y[1], add3.u2)
                annotation (Line(points={{-279,180},{-259,180}}, color={0,0,127}));
              connect(step_w_MS.y, add3.u1) annotation (Line(points={{-279,222},{-268,222},{
                      -268,186},{-259,186}}, color={0,0,127}));
              connect(add3.y, sourceMS.in_w0) annotation (Line(points={{-247.5,183},{-242,183},
                      {-242,166}}, color={0,0,127}));
              connect(realExpression.y, PID_pumpFW_high.PV) annotation (Line(
                    points={{259,-160},{240,-160},{240,-140},{216,-140}}, color={
                      0,0,127}));
              connect(product1.y, add1.u[1]) annotation (Line(points={{139.6,
                      -140},{130,-140},{130,-148.133},{120,-148.133}},
                                                                 color={0,0,127}));
              connect(table_w_FW.y, add1.u[2:2]) annotation (Line(points={{179,
                      -190},{156,-190},{130,-190},{130,-150},{120,-150}}, color={
                      0,0,127}));
              connect(step_wFW.y, add1.u[3]) annotation (Line(points={{159,110},
                      {159,110},{128,110},{128,-151.867},{120,-151.867}},color={0,
                      0,127}));
              connect(PID_pumpFW_high.SP, DT_MS_sp.y[1]) annotation (Line(points=
                      {{216,-126},{259,-126},{259,-124}}, color={0,0,127}));
              connect(LOAD1.y, DT_MS_sp.u[1]) annotation (Line(points={{319,180},
                      {318,180},{300,180},{300,-124},{282,-124}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-360,-360},{360,360}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-360,-360},{360,360}}, preserveAspectRatio=false)),
                experiment(
                  StartTime=-2000,
                  StopTime=5000,
                  __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_wFW_sensitivity_2;

            model simplifiedSystem
              "Test model for the simplified analysis of the DTsh sensitivity over wFW"

              //Temperature
              parameter Modelica.SIunits.Temperature T_hot_SH_in;
              parameter Modelica.SIunits.Temperature T_hot_EVA1_out;
              parameter Modelica.SIunits.Temperature T_hot_RH_out;
              parameter Modelica.SIunits.Temperature T_cold_SH_out;
              parameter Modelica.SIunits.Temperature T_cold_EVA1_in;

              //Number of Thermal Units
              parameter Real NTU_SH;
              parameter Real NTU_EVA2;
              parameter Real NTU_EVA1;

              //Temperature difference ratio
              parameter Real deltaT_SH_star;
              parameter Real deltaT_EVA1_star;

              Modelica.Blocks.Interfaces.RealInput a annotation (Placement(transformation(
                      extent={{-140,40},{-100,80}}), iconTransformation(extent={{-140,40},{-100,
                        80}})));
              Modelica.Blocks.Interfaces.RealInput deltaT_EVA2_star annotation (Placement(
                    transformation(extent={{-140,-80},{-100,-40}}), iconTransformation(
                      extent={{-140,-80},{-100,-40}})));

              Modelica.SIunits.Temperature T_cold_EVA2_out(start = 649);
              Modelica.SIunits.Temperature T_hot_EVA2_in(start = 731);
              Modelica.SIunits.Temperature T_hot_EVA1_in(start = 687);
              Modelica.SIunits.Temperature T_hot_SH_out(start = 730);

            equation
              (T_cold_SH_out - T_hot_SH_in)/(T_cold_EVA2_out - T_hot_SH_out) = exp(NTU_SH*deltaT_SH_star);
              (T_cold_EVA2_out - T_hot_EVA2_in)/(T_cold_EVA1_in - T_hot_EVA1_in) = exp(NTU_EVA2*deltaT_EVA2_star);
              (T_cold_EVA1_in - T_hot_EVA1_in)/(T_cold_EVA1_in - T_hot_EVA1_out) = exp(NTU_EVA1*deltaT_EVA1_star);
              T_hot_EVA2_in = a*T_hot_RH_out + (1-a)*T_hot_SH_out;

              annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                        {100,100}}), graphics={Rectangle(extent={{-100,100},{100,-100}},
                        lineColor={0,0,127}), Text(
                      extent={{-80,80},{80,-80}},
                      lineColor={0,0,127},
                      fillPattern=FillPattern.Solid,
                      textString="System",
                      textStyle={TextStyle.Bold})}));
            end simplifiedSystem;

            model simplifiedSystem_2
              "Test model for the simplified analysis of the DTsh sensitivity over wFW"

              //Temperature
              parameter Modelica.SIunits.Temperature T_A;
              parameter Modelica.SIunits.Temperature T_F;
              parameter Modelica.SIunits.Temperature T_B;
              parameter Modelica.SIunits.Temperature T_4;
              parameter Modelica.SIunits.Temperature T_1;

              //Number of Thermal Units
              parameter Real NTU_SH;
              parameter Real NTU_EVA2;
              parameter Real NTU_EVA1;

              //Temperature difference ratio
              //parameter Real deltaT_SH_star;
              //parameter Real deltaT_EVA1_star;

              Modelica.Blocks.Interfaces.RealInput a annotation (Placement(transformation(
                      extent={{-140,40},{-100,80}}), iconTransformation(extent={{-140,40},{-100,
                        80}})));
              Modelica.Blocks.Interfaces.RealInput deltaT_EVA2_star annotation (Placement(
                    transformation(extent={{-140,-80},{-100,-40}}), iconTransformation(
                      extent={{-140,-80},{-100,-40}})));

              Modelica.SIunits.Temperature T_3(start = 649);
              Modelica.SIunits.Temperature T_D(start = 731);
              Modelica.SIunits.Temperature T_E(start = 687);
              Modelica.SIunits.Temperature T_C(start = 730);

              Real deltaT_SH_star;
              Real deltaT_EVA1_star;

            equation
              (T_4 - T_A)/(T_3 - T_C) = exp(NTU_SH*deltaT_SH_star);
              (T_3 - T_D)/(T_1 - T_E) = exp(NTU_EVA2*deltaT_EVA2_star);
              (T_1 - T_E)/(T_1 - T_F) = exp(NTU_EVA1*deltaT_EVA1_star);
              T_D = a*T_B + (1-a)*T_C;
              deltaT_SH_star = ((T_4 - T_3) - (T_A - T_C))/(T_4 - T_3);
              deltaT_EVA1_star = ((T_1 - T_1) - (T_E - T_F))/(T_E - T_F);

              annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                        {100,100}}), graphics={Rectangle(extent={{-100,100},{100,-100}},
                        lineColor={0,0,127}), Text(
                      extent={{-80,80},{80,-80}},
                      lineColor={0,0,127},
                      fillPattern=FillPattern.Solid,
                      textString="System",
                      textStyle={TextStyle.Bold})}));
            end simplifiedSystem_2;

            model test_solvedSystem

              simplifiedSystem_2 simplifiedSys(
                NTU_SH=2.78,
                NTU_EVA2=0.87,
                NTU_EVA1=4.66,
                T_A=838.15,
                T_F=627.15,
                T_B=731.15,
                T_4=825.75,
                T_1=622.15,
                T_C(start=725.15))
                annotation (Placement(transformation(extent={{0,-10},{20,10}})));
              Modelica.Blocks.Sources.Ramp a(
                height=0,
                duration=0,
                offset=0.394,
                startTime=0) annotation (Placement(transformation(extent={{-60,10},
                        {-40,30}})));
              Modelica.Blocks.Sources.Ramp dT_star(
                height=0,
                duration=0,
                offset=-0.5429,
                startTime=0) annotation (Placement(transformation(extent={{-60,
                        -30},{-40,-10}})));
            equation
              connect(a.y, simplifiedSys.a) annotation (Line(points={{-39,20},{
                      -30,20},{-20,20},{-20,6},{-2,6}}, color={0,0,127}));
              connect(dT_star.y, simplifiedSys.deltaT_EVA2_star) annotation (Line(
                    points={{-39,-20},{-20,-20},{-20,-6},{-2,-6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(__Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_solvedSystem;
          end HE;

          package OTSG "Package of whole OTSG test models"

            model test_OTSG_100 "Test model of the OTSG at 100% load"

              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1231860,
                use_in_w0=false,
                w0=231.43)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=82.57,
                h=3083198,
                use_in_w0=false,
                p0=4698000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4642887)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322,
                p0=1000000) annotation (Placement(transformation(extent={{-60,
                        90},{-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1000000) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17814720)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=17500000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=143.1,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Old.plant_controller_HPpart_old controllers(
                actuatorGain_valveRH=1,
                Ta_valveRH=2,
                Ti_pumpSEP=56.7,
                Td_pumpSEP=0,
                Nd_pumpSEP=1,
                CSstart_pumpSEP=0,
                actuatorGain_pumpSEP=1,
                Ta_pumpSEP=5,
                TS_pumpSEP=0,
                Ta_pumpFW=5,
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                P_mec_sp=79.7258e6,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmax_pumpFW=0.3,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                Nd_valveRH=10,
                Ti_valveRH=16,
                Td_valveRH=0,
                useTS_pumpSEP=false,
                t_ramp=0,
                t_start=0,
                load_start=100,
                load_end=100,
                Kp_pumpFW=-1,
                Ti_pumpFW=28.59,
                Td_pumpFW=7.147,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpFW=true,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                Kp_valveRH=0.177,
                CSmin_valveRH=-0.9,
                CSmax_valveRH=1,
                CSstart_valveRH=0,
                TS_valveRH=0,
                l_sp=0,
                Kp_pumpSEP=-1.45,
                CSmin_pumpSEP=-1,
                CSmax_pumpSEP=1,
                useTS_valveRH=true,
                T_RH_sp=826.05,
                T_MS_sp=563.15,
                T_FW_sp=553.15,
                p_sp=17610000,
                useTS_valveTURB=true,
                table_w_FW(table=[4,3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02;
                      60,56.19; 70,64.64; 80,72.9; 90,81.03; 100,87.9]))
                annotation (Placement(transformation(extent={{-92,-2},{-68,22}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-88,-28},{-74,-12}})));
              OTSG_init100_20nodes OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
            equation
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-100},{6,-100},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
                  points={{-60,-20},{-73.3,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                      {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},
                      {-6.66667,100},{-6.66667,61.6667}},
                                           color={0,0,255}));
              connect(sinkSH.flange, OTSG.SH_out) annotation (Line(points={{40,80},
                      {6.66667,80},{6.66667,61.6667}},
                                            color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -26.6667,-41.6667},{-26.6667,-60},{-30,-60}},
                                            color={0,0,255}));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                      -6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                                                   color={0,0,255}));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{21.6667,
                      46.6667},{40,46.6667},{40,40},{60,40}},         color={0,0,
                      255}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}})),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_100;

            model test_OTSG_50 "Test model of the OTSG at 50% load"

              OTSG_init50_20nodes                     OTSG
                annotation (Placement(transformation(extent={{-40,-40},{20,60}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=45.93,
                use_in_w0=true,
                h=1062500)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=38.01,
                h=3126000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=2161000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322) annotation (Placement(transformation(extent={{-60,90},
                        {-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(
                  allowFlowReversal=false, initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=10320000)
                annotation (Placement(transformation(extent={{32,-70},{52,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10000000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=0,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}})));
              Control.Old.plant_controller_HPpart_old controllers(
                actuatorGain_valveRH=1,
                Ta_valveRH=2,
                Ti_pumpSEP=56.7,
                Td_pumpSEP=0,
                Nd_pumpSEP=1,
                actuatorGain_pumpSEP=1,
                Ta_pumpSEP=5,
                Ta_pumpFW=5,
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                P_mec_sp=79.7258e6,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmax_pumpFW=0.3,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                Nd_valveRH=10,
                Ti_valveRH=16,
                Td_valveRH=0,
                l_sp=4,
                t_ramp=0,
                t_start=0,
                Kp_pumpFW=-1,
                Ti_pumpFW=28.59,
                Td_pumpFW=7.147,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                load_start=50,
                load_end=50,
                useTS_pumpSEP=false,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                useTS_pumpFW=true,
                Kp_valveRH=0.177,
                CSmin_valveRH=-0.9,
                CSmax_valveRH=1,
                CSstart_valveRH=0,
                TS_valveRH=0,
                useTS_valveRH=true,
                useTS_valveTURB=true,
                CSmin_pumpSEP=0,
                CSmax_pumpSEP=100,
                Kp_pumpSEP=-14,
                T_RH_sp=826.05,
                T_MS_sp=563.15,
                T_FW_sp=553.15,
                p_sp=17610000) annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-88,-28},{-74,-12}})));
            equation
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(
                  points={{21.6667,-28.3333},{40,-28.3333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(
                  points={{21.6667,46.6667},{40,46.6667},{40,40},{60,40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                  points={{-40,100},{-26.6667,100},{-26.6667,61.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS.flange, OTSG.MS_out) annotation (Line(
                  points={{-30,-60},{-26,-60},{-26,-41.6667},{-26.6667,-41.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(
                  points={{-6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{32,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_out, sinkRH.flange) annotation (Line(
                  points={{-6.66667,61.6667},{-6.66667,100},{20,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SH_out, sinkSH.flange) annotation (Line(
                  points={{6.66667,61.6667},{6.66667,80},{40,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{21.6667,-3.33333},{40,-3.33333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-100},{8,-100},{6,-100},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-100},{74,-100},{74,-26}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
                  points={{-60,-20},{-66,-20},{-73.3,-20}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model has to be initialized  in steady-state, through the system component, so that the pressure terms do no influence the mass flow balances. The OTSG can be selected between the 5 nodes and 20 nodes model. </span></p>
</html>"));
            end test_OTSG_50;

            model test_OTSG_20 "Test model of the OTSG at 20% load"

              OTSG_init20_20nodes                     OTSG
                annotation (Placement(transformation(extent={{-40,-40},{20,60}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=17.01,
                h=840600)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                h=3125000,
                w0=13.4)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=767000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322) annotation (Placement(transformation(extent={{-60,90},
                        {-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=10200000)
                annotation (Placement(transformation(extent={{32,-70},{52,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10000000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=0.001,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}})));
              Control.Old.plant_controller_HPpart_old controllers(
                actuatorGain_valveRH=1,
                Ta_valveRH=2,
                Ti_pumpSEP=56.7,
                Td_pumpSEP=0,
                Nd_pumpSEP=1,
                actuatorGain_pumpSEP=1,
                Ta_pumpSEP=5,
                Ta_pumpFW=5,
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                P_mec_sp=79.7258e6,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmax_pumpFW=0.3,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                Nd_valveRH=10,
                Ti_valveRH=16,
                Td_valveRH=0,
                l_sp=4,
                t_ramp=0,
                t_start=0,
                Kp_pumpFW=-1,
                Ti_pumpFW=28.59,
                Td_pumpFW=7.147,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                useTS_pumpFW=true,
                load_start=20,
                load_end=20,
                useTS_pumpSEP=false,
                Kp_valveRH=0.177,
                CSmin_valveRH=-1,
                CSmax_valveRH=1,
                CSstart_valveRH=0,
                TS_valveRH=0,
                useTS_valveRH=true,
                useTS_valveTURB=true,
                CSmin_pumpSEP=0,
                CSmax_pumpSEP=100,
                T_RH_sp=826.05,
                Kp_pumpSEP=-14,
                T_MS_sp=563.15,
                T_FW_sp=553.15,
                p_sp=17610000) annotation (Placement(transformation(extent={{-90,
                        -2},{-68,22}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-88,-28},{-74,-12}})));
            equation
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(
                  points={{21.6667,-28.3333},{30,-28.3333},{30,-28},{40,-28},{40,
                      -20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(
                  points={{21.6667,46.6667},{40,46.6667},{40,40},{60,40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                  points={{-40,100},{-26.6667,100},{-26.6667,61.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS.flange, OTSG.MS_out) annotation (Line(
                  points={{-30,-60},{-26,-60},{-26,-41.6667},{-26.6667,-41.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(
                  points={{-6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{32,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_out, sinkRH.flange) annotation (Line(
                  points={{-6.66667,61.6667},{-6.66667,100},{20,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SH_out, sinkSH.flange) annotation (Line(
                  points={{6.66667,61.6667},{6.66667,80},{40,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{21.6667,-3.33333},{40,-3.33333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));

              connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
                  points={{-60,-20},{-73.3,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.45,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.45,10},{-67.45,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-80},{6,-80},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{74,-80},{74,-26}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model has to be initialized in fixed-state, through the system component, since the steady-state initialisation fails. The OTSG can be selected between the 5 nodes and 20 nodes model. </span></p>
</html>"));
            end test_OTSG_20;

            model test_OTSG_4_optA "Test model of the OTSG at 4% of load"

              OTSG_init20_20nodes OTSG(
                separator(
                  initOpt=ThermoPower.Choices.Init.Options.fixedState,
                  h_start=1697500,
                  p_start=8540000),
                PDSteamEVA1(pin(start=8620000)),
                PDSteamECO(pin(start=8660000)),
                PDSteamEVA2(pin(start=8580000)),
                PDSteamRH(pin(start=22.05e5)))
                annotation (Placement(transformation(extent={{-44,-36},{12,56}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=17.01,
                h=515800)
                annotation (Placement(transformation(extent={{100,-4},{80,-24}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-40,-58},
                        {-60,-38}})));

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-140,120},{-120,140}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=4.18,
                h=3092400)
                annotation (Placement(transformation(extent={{76,34},{56,54}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=2200000)
                annotation (Placement(transformation(extent={{22,114},{42,134}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=8500000)
                annotation (Placement(transformation(extent={{62,94},{82,114}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=518322) annotation (Placement(transformation(extent={{-60,82},
                        {-40,102}})));

              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=0.001,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-38},{20,-58}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=10200000)
                annotation (Placement(transformation(extent={{32,-58},{52,-38}})));
              Control.Old.plant_controller_HPpart_old controllers(
                actuatorGain_valveRH=1,
                Ta_valveRH=2,
                Ti_pumpSEP=56.7,
                Td_pumpSEP=0,
                Nd_pumpSEP=1,
                actuatorGain_pumpSEP=1,
                Ta_pumpSEP=5,
                Ta_pumpFW=5,
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                P_mec_sp=79.7258e6,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                Nd_valveRH=10,
                Kp_valveRH=1.77,
                Ti_valveRH=16,
                Td_valveRH=0,
                l_sp=4,
                Kp_pumpFW=-1,
                Ti_pumpFW=28.59,
                Td_pumpFW=7.147,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                useTS_valveTURB=true,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                useTS_pumpSEP=false,
                t_ramp=0,
                t_start=0,
                CSmax_pumpFW=2,
                CSmin_pumpFW=-0.53,
                load_start=4.5,
                load_end=4.5,
                CSmin_valveRH=-1,
                CSmax_valveRH=1,
                CSstart_valveRH=0,
                useTS_valveRH=true,
                TS_valveRH=0,
                Kp_pumpSEP=-14,
                CSmin_pumpSEP=0,
                CSmax_pumpSEP=100,
                useTS_pumpFW=true,
                T_RH_sp=826.05,
                T_MS_sp=563.15,
                T_FW_sp=553.15,
                p_sp=17610000,
                TS_valveTURB=-0.2) annotation (Placement(transformation(extent={{
                        -108,2},{-92,18}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-108,-18},{-94,-2}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-90,-20},{-70,0}})));
            equation
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{13.5556,-2.26667},{44,-2.26667},{44,-14},{80,-14}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in,sourceRH. flange) annotation (Line(
                  points={{13.5556,43.7333},{54,43.7333},{54,44},{56,44}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SH_out,sinkSH. flange) annotation (Line(
                  points={{-0.444444,57.5333},{-0.444444,104},{62,104}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{22,124},
                      {4,124},{-12.8889,124},{-12.8889,57.5333}},
                                                        color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -31.5556,-37.5333},{-31.5556,-48},{-40,-48}},
                                                             color={0,0,255}));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,92},
                      {-31.5556,92},{-31.5556,57.5333}}, color={0,0,255}));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                      -12.8889,-37.5333},{-12.8889,-48},{0,-48}}, color={0,0,255}));
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(points={{20,
                      -48},{26,-48},{32,-48}}, color={0,0,255}));
              connect(OTSG.SEP_out, OTSG.FW_in) annotation (Line(points={{13.5556,
                      -2.26667},{44,-2.26667},{44,-25.2667},{13.5556,-25.2667}},
                    color={0,0,255}));
              connect(signalBus.pumpMS_PV,Power_sensor. y) annotation (Line(
                  points={{-80,-10},{-93.3,-10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus,signalBus)  annotation (Line(
                  points={{-91.6,10},{-80,10},{-80,-10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-91.6,10},{-46.1778,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-80,-10},{-80,-10},{-80,-70},{-80,-70},{6,-70},{6,-54}},
                  color={255,204,51},
                  thickness=0.5));

              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-80,-10},{-80,-70},{94,-70},{94,-20}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,
                        -140},{140,140}})),                  Icon(coordinateSystem(
                      extent={{-140,-140},{140,140}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput);
            end test_OTSG_4_optA;

            model test_recirculationSection
              "Test model to check the need of decoupling between feedwater and recirculated mass flow"

              Components.Equilibrium2phVessel separator(
                H=8,
                zl_start=4,
                phase(start=2, fixed=true),
                D=0.56,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                noInitialPressure=true,
                noInitialLevel=true,
                h_start=1.7e6,
                p_start=10100000,
                T(start=584.85))
                annotation (Placement(transformation(extent={{-68,68},{-12,124}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                use_in_w0=true,
                w0=10,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-40,16})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                rhonom=582.24,
                wnom=88.59,
                pin(start=102e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-180,22})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15,
                pin(start=103e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-180,-60})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250,
                pin(start=10150000),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-130,88})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Length sep_lev = separator.zl;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              Modelica.SIunits.MassFlowRate Fpos = ECO.coldFluid.w*(1-x_EVA2_out);
              Modelica.SIunits.MassFlowRate Fneg = separator.wl_out;
              Modelica.SIunits.SpecificEnthalpy Q1 = ECO.coldFluid.h[1];
              Modelica.SIunits.SpecificEnthalpy Q2 = Q_tot/ECO.coldFluid.w;

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-260,140},{-240,160}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062500,
                w0=45.93,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{110,-150},{90,-130}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-220,-110},
                        {-240,-90}})));

              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10100000)
                annotation (Placement(transformation(extent={{80,130},{100,150}})));
              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=180,
                    origin={-46,-136})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=305.3,
                h=328503,
                use_in_w0=false) annotation (Placement(transformation(extent={{
                        -130,70},{-150,50}})));

              ThermoPower.PowerPlants.Control.PID PID_levelControl(
                Ti=56,
                PVmin=0,
                PVmax=8,
                CSmin=0,
                PVstart=0.5392,
                CSstart=0.5,
                holdWhenSimplified=true,
                steadyStateInit=true,
                Kp=-14,
                CSmax=250)            annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,66})));
              Modelica.Blocks.Continuous.FirstOrder firstOrder(
                k=1,
                initType=Modelica.Blocks.Types.Init.SteadyState,
                y_start=53.92,
                T=2)           annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,38})));
              Modelica.Blocks.Sources.Constant const(k=4) annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={130,82})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                      1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                      1.94272e+006,2.02642e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                    602.087,604.627,607.543,610.89,614.73,619.134}),
                Vhot=3.905,
                Vcold=1.065,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000),
                Shot=429.2*1,
                Scold=338*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={344122,316769,292958,272234,254202,238514,224868,213001,202681,193708},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-164,44},{-196,76}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                      1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                      1.45658e+006,1.56606e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                    577.742,579.999,582.568,585.511,585.959,587.035}),
                Vhot=26.587,
                Vcold=8.651,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    alpha=1.6,
                    gamma_nom_2ph=10000),
                Shot=2251.9*1,
                Scold=1765.5*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={193708,157918,143681,138009,133137,128914,125226,121985,119121,116578},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-196,-36},{-164,-4}})));

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                      1.3288e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                    569.474}),
                Vhot=45.011,
                Vcold=5.752,
                Nhex=5,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={119114,110526,103784,98376.4,93969.4},
                  noInitialPressure=true))
                annotation (Placement(transformation(extent={{-164,-116},{-196,
                        -84}})));
              Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,-40})));
              Modelica.Blocks.Sources.Constant const1(k=0)
                annotation (Placement(transformation(extent={{140,-80},{120,-60}})));
              Modelica.Blocks.Sources.BooleanStep booleanStep3(startValue=true, startTime=1000)
                annotation (Placement(transformation(extent={{140,-50},{120,-30}})));
              Modelica.Blocks.Logical.Switch switch1 annotation (Placement(
                    transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={98,-78})));
              Modelica.Blocks.Math.Add add(k1=-1, k2=1) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={90,-10})));
              Modelica.Blocks.Sources.Constant const2(k=53.92)
                annotation (Placement(transformation(extent={{140,0},{120,20}})));
              Modelica.Blocks.Math.Add add1(k1=1, k2=-1) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={104,-114})));
              Modelica.Blocks.Sources.Constant const3(k=45.93)
                annotation (Placement(transformation(extent={{160,-120},{140,-100}})));
              Modelica.Blocks.Sources.Step step(
                offset=305.3,
                startTime=1010,
                height=30) annotation (Placement(transformation(extent={{-80,30},
                        {-100,50}})));
            equation
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{-40,78},{-40,26}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-120,88},{-50,88}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(flowJoin.in1, sourceFW.flange) annotation (Line(
                  points={{-40,-140},{-40,-140},{90,-140}},
                  color={0,0,255},
                  thickness=0.5));
              connect(waterPump.outlet, flowJoin.in2) annotation (Line(
                  points={{-40,6},{-40,-132}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSH.flange, separator.steam_out) annotation (Line(
                  points={{80,140},{-40,140},{-40,120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(separator.level, PID_levelControl.PV)
                annotation (Line(points={{-30,82},{86,82},{86,76}},color={0,0,127}));
              connect(PID_levelControl.CS, firstOrder.u)
                annotation (Line(points={{90,56},{90,50}}, color={0,0,127}));
              connect(firstOrder.y, waterPump.in_w0)
                annotation (Line(points={{90,27},{90,20},{-34,20}},
                                                                  color={0,0,127}));
              connect(const.y, PID_levelControl.SP) annotation (Line(points={{119,82},
                      {108,82},{94,82},{94,76}},
                                        color={0,0,127}));
              connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
                  points={{-140,88},{-162,88},{-180,88},{-180,76}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletHot, sourceMS.flange) annotation (Line(
                  points={{-164,60},{-150,60}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-196,60},{-220,60},{-220,-20},{-196,-20}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-164,-20},{-152,-20},{-140,-20},{-140,-100},{-164,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(sinkMS.flange, ECO.outletHot) annotation (Line(
                  points={{-220,-100},{-208,-100},{-196,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{-180,-70},{-180,-77},{-180,-84}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                  points={{-180,-36},{-180,-36},{-180,-50}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamEVA1.inlet, EVA1.outletCold) annotation (Line(
                  points={{-180,12},{-180,12},{-180,-4}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-180,44},{-180,32}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, flowJoin.out) annotation (Line(
                  points={{-180,-116},{-140,-116},{-140,-136},{-52,-136}},
                  color={0,0,255},
                  thickness=0.5));
              connect(const1.y,switch1. u3) annotation (Line(points={{119,-70},{
                      119,-70},{112,-70},{112,-60},{106,-60},{106,-66}},
                                                      color={0,0,127}));
              connect(booleanStep3.y,switch1. u2) annotation (Line(points={{119,-40},
                      {119,-40},{112,-40},{112,-48},{98,-48},{98,-66}},    color={255,0,
                      255}));
              connect(gain.y, switch1.u1)
                annotation (Line(points={{90,-51},{90,-68},{90,-66}}, color={0,0,127}));
              connect(add.y, gain.u)
                annotation (Line(points={{90,-21},{90,-28}}, color={0,0,127}));
              connect(firstOrder.y, add.u2) annotation (Line(points={{90,27},{90,
                      27},{90,12},{84,12},{84,2}},
                                       color={0,0,127}));
              connect(const2.y, add.u1)
                annotation (Line(points={{119,10},{96,10},{96,2}}, color={0,0,127}));
              connect(switch1.y, add1.u2)
                annotation (Line(points={{98,-89},{98,-89},{98,-102}}, color={0,0,127}));
              connect(add1.y, sourceFW.in_w0) annotation (Line(points={{104,-125},
                      {104,-125},{104,-134}},
                                   color={0,0,127}));
              connect(const3.y, add1.u1) annotation (Line(points={{139,-110},{134,
                      -110},{124,-110},{124,-94},{110,-94},{110,-102}},
                                                             color={0,0,127}));
              connect(sourceMS.in_w0, step.y) annotation (Line(points={{-136,54},
                      {-136,40},{-101,40}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-260,-160},{260,160}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-260,-160},{260,160}}, preserveAspectRatio=false)),
                Documentation(info="<html>
<p>Test model to chek the need of a decoupler between separator pump and feedwater mass flow rate. The model is initialised at 50&percnt; load with the decoupler active. After 1000 s the decoupler is switched off, so that an equivalent step on the feedwater flow is performed. </p>
<p>The separator pump reacts and increases the recirculated mass flow, leading to the instability. If x is the vapor quality at evaporator outlet we can write:</p>
<p><img src=\"modelica://PreFlexMS/Images/equations/equation-LkR73UrL.png\" alt=\"rho*A*der(l) = (w_FW + w_SEP)*(1-x) - w_SEP  \"/>            --&GT;liquid mass balance on the separator</p>
<p><img src=\"modelica://PreFlexMS/Images/equations/equation-yxtUkHRo.png\" alt=\"x = (h_ECOin + (Q_ECO + Q_EVA)/(w_FW + w_SEP) + h_ls)/(h_vs - h_ls) \"/>                <img src=\"modelica://PreFlexMS/Images/equations/equation-EZkMMYs8.png\" alt=\"x = (Q1 + Q2 + h_ls)/(h_vs - h_ls) \"/>                     --&GT; vapor quality</p>
<p><br>As the results of the simulation show, the instability is due to a permanent dl/dt &GT; 0 after the the FW step.</p>
</html>"),      experiment(StopTime=1500),
                __Dymola_experimentSetupOutput);
            end test_recirculationSection;

            model test_feedwaterLevelControl
              "Test model to show the feasibility of the level control through the feedwater"

              Components.Equilibrium2phVessel separator(
                H=8,
                zl_start=4,
                phase(start=2, fixed=true),
                D=0.56,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                noInitialPressure=true,
                noInitialLevel=true,
                h_start=2.2e6,
                p_start=10100000,
                T(start=584.85))
                annotation (Placement(transformation(extent={{-28,68},{28,124}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=53.92,
                use_in_w0=true)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={0,16})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                rhonom=582.24,
                wnom=88.59,
                pin(start=102e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,22})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15,
                pin(start=103e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,-60})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250,
                pin(start=10150000),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-64,88})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Length sep_lev = separator.zl;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              Modelica.SIunits.MassFlowRate Fpos = ECO.coldFluid.w*(1-x_EVA2_out);
              Modelica.SIunits.MassFlowRate Fneg = separator.wl_out;
              Modelica.SIunits.SpecificEnthalpy Q1 = ECO.coldFluid.h[1];
              Modelica.SIunits.SpecificEnthalpy Q2 = Q_tot/ECO.coldFluid.w;

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-180,140},{-160,160}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062500,
                w0=45.93,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{86,-152},{66,-132}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-140,-110},
                        {-160,-90}})));

              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10100000)
                annotation (Placement(transformation(extent={{70,128},{90,148}})));
              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=180,
                    origin={-6,-136})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=305.3,
                h=328503,
                use_in_w0=false) annotation (Placement(transformation(extent={{
                        -50,70},{-70,50}})));

              ThermoPower.PowerPlants.Control.PID PID_levelControl(
                PVmin=0,
                PVmax=8,
                CSmin=0,
                PVstart=0.5392,
                holdWhenSimplified=true,
                Ti=50,
                CSmax=120,
                CSstart=0.4,
                steadyStateInit=false,
                Kp=1)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={80,8})));
              Modelica.Blocks.Continuous.FirstOrder firstOrder(
                k=1,
                initType=Modelica.Blocks.Types.Init.SteadyState,
                y_start=53.92,
                T=2)           annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={80,-52})));
              Modelica.Blocks.Sources.Step     const(
                startTime=1000,
                offset=4,
                height=0)                                 annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={120,82})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                      1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                      1.94272e+006,2.02642e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                    602.087,604.627,607.543,610.89,614.73,619.134}),
                Vhot=3.905,
                Vcold=1.065,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000),
                Shot=429.2*1,
                Scold=338*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={344122,316769,292958,272234,254202,238514,224868,213001,202681,193708},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-84,44},{-116,76}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                      1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                      1.45658e+006,1.56606e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                    577.742,579.999,582.568,585.511,585.959,587.035}),
                Vhot=26.587,
                Vcold=8.651,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    alpha=1.6,
                    gamma_nom_2ph=10000),
                Shot=2251.9*1,
                Scold=1765.5*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={193708,157918,143681,138009,133137,128914,125226,121985,119121,116578},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-116,-36},{-84,-4}})));

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                      1.3288e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                    569.474}),
                Vhot=45.011,
                Vcold=5.752,
                Nhex=5,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={119114,110526,103784,98376.4,93969.4},
                  noInitialPressure=true))
                annotation (Placement(transformation(extent={{-84,-116},{-116,-84}})));
              Modelica.Blocks.Sources.Step step(
                offset=305.3,
                height=30,
                startTime=3000)
                           annotation (Placement(transformation(extent={{-20,30},
                        {-40,50}})));
              Modelica.Blocks.Sources.Step step1(
                offset=53.92,
                startTime=3000,
                height=-50)
                annotation (Placement(transformation(extent={{48,10},{28,30}})));
            equation
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{0,78},{0,26}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-54,88},{-10,88}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(flowJoin.in1, sourceFW.flange) annotation (Line(
                  points={{8.88178e-016,-140},{8.88178e-016,-142},{66,-142}},
                  color={0,0,255},
                  thickness=0.5));
              connect(waterPump.outlet, flowJoin.in2) annotation (Line(
                  points={{0,6},{0,-132}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSH.flange, separator.steam_out) annotation (Line(
                  points={{70,138},{0,138},{0,120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(separator.level, PID_levelControl.PV)
                annotation (Line(points={{10,82},{76,82},{76,18}}, color={0,0,127}));
              connect(PID_levelControl.CS, firstOrder.u)
                annotation (Line(points={{80,-2},{80,-2},{80,-40}},
                                                           color={0,0,127}));
              connect(const.y, PID_levelControl.SP) annotation (Line(points={{109,82},
                      {98,82},{84,82},{84,18}},
                                        color={0,0,127}));
              connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
                  points={{-74,88},{-74,88},{-100,88},{-100,76}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletHot, sourceMS.flange) annotation (Line(
                  points={{-84,60},{-70,60}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-116,60},{-140,60},{-140,-20},{-116,-20}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-84,-20},{-72,-20},{-60,-20},{-60,-100},{-84,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(sinkMS.flange, ECO.outletHot) annotation (Line(
                  points={{-140,-100},{-128,-100},{-116,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{-100,-70},{-100,-77},{-100,-84}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                  points={{-100,-36},{-100,-36},{-100,-50}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamEVA1.inlet, EVA1.outletCold) annotation (Line(
                  points={{-100,12},{-100,12},{-100,-4}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-100,44},{-100,32}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, flowJoin.out) annotation (Line(
                  points={{-100,-116},{-100,-116},{-100,-136},{-12,-136}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sourceMS.in_w0, step.y) annotation (Line(points={{-56,54},{
                      -56,40},{-41,40}},    color={0,0,127}));
              connect(firstOrder.y, sourceFW.in_w0) annotation (Line(points={{80,
                      -63},{80,-63},{80,-136}}, color={0,0,127}));
              connect(waterPump.in_w0, step1.y) annotation (Line(points={{6,20},{
                      6,20},{27,20}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-180,-160},{180,160}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-180,-160},{180,160}}, preserveAspectRatio=false)),
                Documentation(info="<html>
<p>Test model to chek the feasibility of controlling the separator level through the feedwater mass flow rate. The model is initialised at 50&percnt; load. After 1000 s the level set point is changed from 4m to 6m, in order to evaluate the y0/y step response. At 3000 s the MS mass flow is increased, and the controller react correctly by increasing the FW mass flow. According to this test, the control philosophy is correct. </p>
<p>Note that the decoupler between the feedwater and recirculating pump is not necessary, since the sysyem is naturally decoupled.</p>
</html>"),      experiment(StopTime=4000),
                __Dymola_experimentSetupOutput);
            end test_feedwaterLevelControl;
          end OTSG;

        end Test;

        package Old

          model OTSG_full_localControl
            "Complete dynamic model of the once through steam generator with local controllers"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";

            //Controllers parameter
            //--LEVEL CONTROL--
            parameter Modelica.SIunits.Height zl_sp "Tank level set point" annotation (Dialog(tab="Separator level controller"));
            parameter Real Kp_l "Controller proportional gain" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Ti_l "Controller integral time" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Td_l "Controller derivative time" annotation (Dialog(tab="Separator level controller"));
            parameter Real Nd_l
              "Controller derivative action up to Nd/Td rad/s"                   annotation (Dialog(tab="Separator level controller"));
            parameter Real PVmin_l
              "Minimum value of process variable for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real PVmax_l
              "Maximum value of process variable for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real CSmin_l
              "Minimum value of control signal for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real CSmax_l
              "Maximum value of control signal for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real PVstart_l=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Separator level controller"));
            parameter Real CSstart_l=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="Separator level controller"));
            parameter Real actuatorGain_l=0.5 "Actuator gain" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Ta_l "Actuator time constant" annotation (Dialog(tab="Separator level controller"));

            //--REHEAT STEAM TEMPERATURE--
            parameter Modelica.SIunits.Temperature T_RH_sp
              "Reheat steam temperature set point"                                              annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real Kp_T "Controller proportional gain" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Ti_T "Controller integral time" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Td_T "Controller derivative time" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real Nd_T
              "Controller derivative action up to Nd/Td rad/s"                   annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVmin_T
              "Minimum value of process variable for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVmax_T
              "Maximum value of process variable for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSmin_T
              "Minimum value of control signal for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSmax_T
              "Maximum value of control signal for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVstart_T=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSstart_T=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real actuatorGain_T=0.5 "Actuator gain" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Ta_T "Actuator time constant" annotation (Dialog(tab="RH steam temperature controller"));

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              Vhot=77,
              Vcold=114.7,
              Shot=2429.5,
              Scold=1913.2,
              Mm=29335,
              nominalColdFlow=143.1,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=5000, alpha=0.536143),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2000, alpha=0.447465),
              Nhex=Nhex_mono,
              nominalColdPressure=17910000,
              nominalHotPressure=400000,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=581.85,
              nominalHotInletTemperature=586.85,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-254},{-44,-286}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4400),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2200),
              Vhot=99.6,
              Vcold=101.3,
              Shot=2394.2,
              Scold=1855.5,
              Mm=30395,
              Nhex=Nhex_mono,
              nominalColdPressure=17910000,
              nominalHotPressure=569600,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=623.79,
              nominalHotInletTemperature=628.75,
              nominalHotOutletTemperature=586.72)
              annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              Vhot=67.2,
              Vcold=494.3,
              Mm=43100,
              nominalColdFlow=88.55,
              Shot=2251.9,
              Scold=1765.5,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=4100, alpha=0.440883),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2300, alpha=0.447498),
              nominalColdPressure=17810000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=623.75,
              nominalColdOutletTemperature=629.32,
              nominalHotInletTemperature=688.04,
              nominalHotOutletTemperature=629.15) annotation (Placement(
                  transformation(extent={{-76,-156},{-44,-124}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              Vcold=721.2,
              nominalColdFlow=88.59,
              Vhot=3.9,
              Mm=5182,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              Nhex=Nhex_bi,
              Shot=429.2*1.05,
              Scold=338*1.05,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3100, alpha=0.440883),
              nominalColdPressure=17760000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=629.15,
              nominalColdOutletTemperature=648.65,
              nominalHotInletTemperature=732.05,
              nominalHotOutletTemperature=687.95) annotation (Placement(
                  transformation(extent={{-44,-76},{-76,-44}})));
            Components.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              D=0.56,
              H=8,
              zl_min=0,
              zl_max=7,
              zl_start=0,
              h_start=2.7e6)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              use_in_w0=true,
              w0=10) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-28})));
            Modelica.Blocks.Sources.Constant zl_SP(
              k=zl_sp)
              annotation (Placement(transformation(extent={{80,60},{60,80}})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              Vhot=12,
              Vcold=174.3,
              Mm=15353,
              nominalColdFlow=88.59,
              nominalHotFlow=371.8,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2200, alpha=0.847436),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.28867),
              Nhex=Nhex_mono,
              Shot=1153.8*0.95,
              Scold=879.8*0.95,
              nominalColdPressure=17710000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=648.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=732.02)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,120})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Vhot=9.4,
              Vcold=446.2,
              Mm=10081,
              nominalColdFlow=82.57,
              nominalHotFlow=238.7,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              Shot=1339,
              Scold=1198,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=970),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2600, alpha=0.320782),
              nominalColdPressure=4698000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=625.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=731.45)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              w0=238.7,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-46,270},{-26,250}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  coldMedium) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,174})));
            ThermoPower.PowerPlants.Control.PID PID_T_RH(
              Ti=Ti_T,
              PVmin=PVmin_T,
              PVmax=PVmax_T,
              CSmin=CSmin_T,
              CSmax=CSmax_T,
              PVstart=PVstart_T,
              CSstart=CSstart_T,
              Kp=Kp_T,
              Td=Td_T,
              Nd=Nd_T)
              annotation (Placement(transformation(extent={{40,194},{20,214}})));
            Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
              annotation (Placement(transformation(extent={{80,220},{60,240}})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              dpnom=(0.05828)*10^5,
              rhonom=582.24,
              wnom=88.59)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-100})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.52492)*10^5,
              rhonom=768.15)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-176})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.11171)*10^5,
              rhonom=250)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            ThermoPower.PowerPlants.Control.PID PID_level(
            Kp=Kp_l,
            Ti=Ti_l,
            Td=Td_l,
            Nd=Nd_l,
            PVmin=PVmin_l,
            PVmax=PVmax_l,
            CSmin=CSmin_l,
            CSmax=CSmax_l,
            CSstart=CSstart_l,
            PVstart=PVstart_l) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={50,26})));

           Modelica.Blocks.Continuous.FirstOrder pumpDynamic(
              k=actuatorGain_l,
              T=Ta_l) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={50,-4})));
            Modelica.Blocks.Continuous.FirstOrder valveDynamic(
              k=actuatorGain_T,
              T=Ta_T)
              annotation (Placement(transformation(extent={{-10,194},{-30,214}})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);

          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{190,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,260},{140,260},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(MS_in, valveRH.inlet) annotation (Line(
                points={{-100,310},{-100,260},{-46,260}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-60},{-44,-60}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-60},{-100,-60},{-100,-140},{-76,-140}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-140},{-20,-140},{-20,-210},{-44,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-270},{-98,-270},{-98,-210},{-76,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(T_RH_SP.y, PID_T_RH.SP) annotation (Line(
                points={{59,230},{56,230},{56,208},{40,208}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(sensT.T, PID_T_RH.PV) annotation (Line(
                points={{90,182},{90,200},{40,200}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(sensT.inlet, RH.outletCold) annotation (Line(
                points={{100,168},{100,160},{124,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-286},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT.outlet) annotation (Line(
                points={{100,310},{100,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(MS_in, SH.inletHot) annotation (Line(
                points={{-100,310},{-100,120},{-16,120}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,120},{140,120},{140,-60},{-44,-60}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH_out, SH.outletCold) annotation (Line(
                points={{0,310},{0,136}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                points={{-60,-156},{-60,-166}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
                points={{-60,-194},{-60,-186}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-124},{-60,-110}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                points={{-60,-76},{-60,-90}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-44},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.outletHot, MS_out) annotation (Line(
                points={{-44,-270},{20,-270},{20,-310}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-18}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.level, PID_level.PV) annotation (Line(
                points={{10,42},{46,42},{46,36}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(PID_level.CS,pumpDynamic. u) annotation (Line(
                points={{50,16},{50,8}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(pumpDynamic.y,waterPump. in_w0) annotation (Line(
                points={{50,-15},{50,-24},{6,-24}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveDynamic.u, PID_T_RH.CS) annotation (Line(
                points={{-8,204},{20,204}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveRH.in_w0, valveDynamic.y) annotation (Line(
                points={{-40,254},{-40,204},{-31,204}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(SH.inletCold, separator.steam_out) annotation (Line(
                points={{0,104},{0,80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(zl_SP.y, PID_level.SP) annotation (Line(
                points={{59,70},{54,70},{54,36}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{0,-38},{0,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(FW_in, HPH.inletCold) annotation (Line(
                points={{190,-240},{-60,-240},{-60,-254}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(FW_in, ECO.inletCold) annotation (Line(
                points={{190,-240},{-60,-240},{-60,-226}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false), graphics), Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}})));
          end OTSG_full_localControl;

          model OTSG_full_2ph_localControl
            "Complete dynamic model of the once through steam generator, with separate 2ph HTC and local controllers"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";

            //Controllers parameter
            //--LEVEL CONTROL--
            parameter Modelica.SIunits.Height zl_sp "Tank level set point" annotation (Dialog(tab="Separator level controller"));
            parameter Real Kp_l "Controller proportional gain" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Ti_l "Controller integral time" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Td_l "Controller derivative time" annotation (Dialog(tab="Separator level controller"));
            parameter Real Nd_l
              "Controller derivative action up to Nd/Td rad/s"                   annotation (Dialog(tab="Separator level controller"));
            parameter Real PVmin_l
              "Minimum value of process variable for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real PVmax_l
              "Maximum value of process variable for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real CSmin_l
              "Minimum value of control signal for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real CSmax_l
              "Maximum value of control signal for scaling"                      annotation (Dialog(tab="Separator level controller"));
            parameter Real PVstart_l=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Separator level controller"));
            parameter Real CSstart_l=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="Separator level controller"));
            parameter Real actuatorGain_l=0.5 "Actuator gain" annotation (Dialog(tab="Separator level controller"));
            parameter Modelica.SIunits.Time Ta_l "Actuator time constant" annotation (Dialog(tab="Separator level controller"));

            //--REHEAT STEAM TEMPERATURE--
            parameter Modelica.SIunits.Temperature T_RH_sp
              "Reheat steam temperature set point"                                              annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real Kp_T "Controller proportional gain" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Ti_T "Controller integral time" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Td_T "Controller derivative time" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real Nd_T
              "Controller derivative action up to Nd/Td rad/s"                   annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVmin_T
              "Minimum value of process variable for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVmax_T
              "Maximum value of process variable for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSmin_T
              "Minimum value of control signal for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSmax_T
              "Maximum value of control signal for scaling"                      annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real PVstart_T=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real CSstart_T=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Real actuatorGain_T=0.5 "Actuator gain" annotation (Dialog(tab="RH steam temperature controller"));
            parameter Modelica.SIunits.Time Ta_T "Actuator time constant" annotation (Dialog(tab="RH steam temperature controller"));

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              Shot=2429.5,
              Scold=1913.2,
              Mm=29335,
              nominalColdFlow=143.1,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2000, alpha=0.447465),
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=5000, alpha=0.536143),
              Vhot=33.634,
              Vcold=6.027,
              nominalColdPressure=17910000,
              nominalHotPressure=400000,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=581.85,
              nominalHotInletTemperature=586.85,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-254},{-44,-286}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Shot=2394.2,
              Scold=1855.5,
              Mm=30395,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4400),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2200),
              Vhot=45.011,
              Vcold=5.752,
              nominalColdPressure=17910000,
              nominalHotPressure=569600,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=623.79,
              nominalHotInletTemperature=628.75,
              nominalHotOutletTemperature=586.72)
              annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              Mm=43100,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2300, alpha=0.447498),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=3875,
                  gamma_nom_2ph=25350,
                  gamma_nom_vap=3875,
                  alpha=1.6),
              nominalColdFlow=88.59,
              Shot=2251.9*0.94,
              Scold=1765.5*0.94,
              Vhot=26.587,
              Vcold=8.651,
              nominalColdPressure=17810000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=623.75,
              nominalColdOutletTemperature=629.32,
              nominalHotInletTemperature=688.04,
              nominalHotOutletTemperature=629.15) annotation (Placement(
                  transformation(extent={{-76,-156},{-44,-124}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Mm=5182,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              Shot=429.2*0.88,
              Scold=338*0.88,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_2ph=6000,
                  gamma_nom_liq=2600,
                  gamma_nom_vap=2600),
              Vhot=3.905,
              Vcold=1.065,
              nominalColdPressure=17760000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=629.15,
              nominalColdOutletTemperature=648.65,
              nominalHotInletTemperature=732.05,
              nominalHotOutletTemperature=687.95) annotation (Placement(
                  transformation(extent={{-44,-76},{-76,-44}})));

            Components.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              D=0.56,
              H=8,
              zl_min=0,
              zl_max=7,
              zl_start=0,
              h_start=2.7e6)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              use_in_w0=true,
              w0=10) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-28})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    518322,502443,472016,421345,355895}),
              redeclare package coldMedium = coldMedium,
              Mm=15353,
              nominalColdFlow=88.59,
              nominalHotFlow=371.8,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                    3.42731e+006}),
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2200, alpha=0.847436),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.28867),
              Nhex=Nhex_mono,
              Shot=1153.8*0.95,
              Scold=879.8*0.95,
              tubeWalls(Tvolstart={725.391,769.727,804.861,826.169}),
              Vhot=3.68,
              Vcold=2.683,
              nominalColdPressure=17710000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=648.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=732.02)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,120})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Mm=10081,
              nominalColdFlow=82.57,
              nominalHotFlow=238.7,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1),
              Shot=1339,
              Scold=1198,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=970),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2600, alpha=0.320782),
              Vhot=1.522,
              Vcold=5.092,
              nominalColdPressure=4698000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=625.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=731.45)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              w0=238.7,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-46,270},{-26,250}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  coldMedium) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,174})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              dpnom=(0.05828)*10^5,
              rhonom=582.24,
              wnom=88.59)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-100})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.52492)*10^5,
              rhonom=768.15)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-176})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.11171)*10^5,
              rhonom=250)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));

            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(
              k=actuatorGain_T,
              T=Ta_T)
              annotation (Placement(transformation(extent={{-10,200},{-30,220}})));
            ThermoPower.PowerPlants.Control.PID PID_T_RH(
              Ti=Ti_T,
              PVmin=PVmin_T,
              PVmax=PVmax_T,
              CSmin=CSmin_T,
              CSmax=CSmax_T,
              PVstart=PVstart_T,
              CSstart=CSstart_T,
              Kp=Kp_T,
              Td=Td_T,
              Nd=Nd_T)
              annotation (Placement(transformation(extent={{50,200},{30,220}})));
            Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
              annotation (Placement(transformation(extent={{88,220},{68,240}})));
            Modelica.Blocks.Sources.Constant zl_SP(
              k=zl_sp)
              annotation (Placement(transformation(extent={{80,50},{60,70}})));
            ThermoPower.PowerPlants.Control.PID PID_level(
            Kp=Kp_l,
            Ti=Ti_l,
            Td=Td_l,
            Nd=Nd_l,
            PVmin=PVmin_l,
            PVmax=PVmax_l,
            CSmin=CSmin_l,
            CSmax=CSmax_l,
            CSstart=CSstart_l,
            PVstart=PVstart_l) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={50,26})));
           Modelica.Blocks.Continuous.FirstOrder pumpDynamic(
              k=actuatorGain_l,
              T=Ta_l) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={50,-2})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{190,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,260},{140,260},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(MS_in, valveRH.inlet) annotation (Line(
                points={{-100,310},{-100,260},{-46,260}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-270},{-98,-270},{-98,-210},{-76,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(sensT.inlet, RH.outletCold) annotation (Line(
                points={{100,168},{100,160},{124,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-286},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT.outlet) annotation (Line(
                points={{100,310},{100,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(MS_in, SH.inletHot) annotation (Line(
                points={{-100,310},{-100,120},{-16,120}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH_out, SH.outletCold) annotation (Line(
                points={{0,310},{0,136}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
                points={{-60,-194},{-60,-186}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.outletHot, MS_out) annotation (Line(
                points={{-44,-270},{20,-270},{20,-310}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-18}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(SH.inletCold, separator.steam_out) annotation (Line(
                points={{0,104},{0,80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-90},{-60,-76}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-124},{-60,-110}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                points={{-60,-156},{-60,-166}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-44},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-60},{-44,-60}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,120},{140,120},{140,-60},{-44,-60}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-60},{-100,-60},{-100,-140},{-76,-140}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-140},{-20,-140},{-20,-210},{-44,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(FW_in, HPH.inletCold) annotation (Line(
                points={{190,-240},{-60,-240},{-60,-254}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(FW_in, ECO.inletCold) annotation (Line(
                points={{190,-240},{-60,-240},{-60,-226}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-38},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(T_RH_SP.y,PID_T_RH. SP) annotation (Line(
                points={{67,230},{60,230},{60,214},{50,214}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(sensT.T,PID_T_RH. PV) annotation (Line(
                points={{90,182},{90,206},{50,206}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveDynamic.u,PID_T_RH. CS) annotation (Line(
                points={{-8,210},{30,210}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(separator.level,PID_level. PV) annotation (Line(
                points={{10,42},{46,42},{46,36}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(PID_level.CS,pumpDynamic. u) annotation (Line(
                points={{50,16},{50,10}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(pumpDynamic.y,waterPump. in_w0) annotation (Line(
                points={{50,-13},{50,-24},{6,-24}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{59,60},{54,60},{54,36}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveDynamic.y, valveRH.in_w0) annotation (Line(
                points={{-31,210},{-40,210},{-40,254}},
                color={0,0,127},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false), graphics), Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false),
                  graphics));
          end OTSG_full_2ph_localControl;

          model test_OTSG "Test model of the OTSG"

            OTSG_full_localControl OTSG(
              Kp_T=20,
              Ti_T=20,
              Td_T=0,
              Nd_T=1,
              PVmin_T=600,
              PVmax_T=1000,
              CSmin_T=1,
              CSmax_T=300,
              PVstart_T=0.5,
              CSstart_T=0.8,
              actuatorGain_T=1,
              Ta_T=2,
              zl_sp=4,
              Kp_l=-250,
              Ti_l=20,
              Td_l=0,
              Nd_l=1,
              PVmin_l=0,
              PVmax_l=8,
              CSmin_l=0,
              CSmax_l=150,
              PVstart_l=0.5,
              CSstart_l=0.5,
              actuatorGain_l=1,
              Ta_l=5,
              T_RH_sp=826.05)
              annotation (Placement(transformation(extent={{-54,-40},{0,40}})));
            ThermoPower.Water.SourceMassFlow sourceSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1231860,
              w0=231.69,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{60,-50},{40,-30}})));
            ThermoPower.Water.SourceMassFlow sourceSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=82.57,
              h=3083198,
              p0=4698000,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{60,10},{40,30}})));
            ThermoPower.Water.SinkPressure sinkSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=4642887,
              use_in_p0=false)
              annotation (Placement(transformation(extent={{0,70},{20,90}})));
            ThermoPower.Water.SourceMassFlow sourceMS1(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              w0=610.5,
              h=520170,
              use_in_w0=false) annotation (Placement(transformation(extent={{-80,
                      70},{-60,90}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-60,-90},
                      {-80,-70}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            ThermoPower.Water.SinkPressure sinkSteam3(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17814720)
              annotation (Placement(transformation(extent={{40,-90},{60,-70}})));
            ThermoPower.Water.SinkPressure sinkSteam(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17611890,
              use_in_p0=false)
              annotation (Placement(transformation(extent={{40,50},{60,70}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=143.1,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{0,-70},{20,-90}})));
          equation
            connect(OTSG.FW_in, sourceSteam2.flange) annotation (Line(
                points={{1.5,-30.6667},{34,-30.6667},{34,-40},{40,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.RH_in, sourceSteam1.flange) annotation (Line(
                points={{1.5,29.3333},{32,29.3333},{32,20},{40,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS1.flange, OTSG.MS_in) annotation (Line(
                points={{-60,80},{-42,80},{-42,41.3333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-60,-80},{-42,-80},{-42,-41.3333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.MS_HPH_out, throughMassFlow.inlet) annotation (Line(
                points={{-24,-41.3333},{-24,-80},{0,-80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(throughMassFlow.outlet, sinkSteam3.flange) annotation (Line(
                points={{20,-80},{40,-80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.RH_out, sinkSteam1.flange) annotation (Line(
                points={{-24,41.3333},{-24,80},{0,80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SH_out, sinkSteam.flange) annotation (Line(
                points={{-12,41.3333},{-12,60},{40,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SEP_out, sourceSteam2.flange) annotation (Line(
                points={{1.5,-10.6667},{34,-10.6667},{34,-40},{40,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics), Icon(coordinateSystem(
                    extent={{-100,-100},{100,100}})));
          end test_OTSG;

          model test_OTSG_2ph "Test model of the OTSG"

            Old.OTSG_full_2ph_localControl OTSG(
              Kp_T=20,
              Ti_T=20,
              Td_T=0,
              Nd_T=1,
              PVmin_T=600,
              PVmax_T=1000,
              CSmin_T=1,
              CSmax_T=300,
              PVstart_T=0.5,
              CSstart_T=0.8,
              actuatorGain_T=1,
              Ta_T=2,
              zl_sp=4,
              Kp_l=-250,
              Ti_l=20,
              Td_l=0,
              Nd_l=1,
              PVmin_l=0,
              PVmax_l=8,
              CSmin_l=0,
              CSmax_l=150,
              PVstart_l=0.5,
              CSstart_l=0.5,
              actuatorGain_l=1,
              Ta_l=5,
              T_RH_sp=826.05)
              annotation (Placement(transformation(extent={{-54,-40},{0,40}})));
            ThermoPower.Water.SourceMassFlow sourceSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1231860,
              w0=231.69,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{60,-50},{40,-30}})));
            ThermoPower.Water.SourceMassFlow sourceSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=82.57,
              h=3083198,
              p0=4698000,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{60,10},{40,30}})));
            ThermoPower.Water.SinkPressure sinkSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=4642887,
              use_in_p0=false)
              annotation (Placement(transformation(extent={{0,70},{20,90}})));
            ThermoPower.Water.SourceMassFlow sourceMS1(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              w0=610.5,
              use_in_w0=false,
              h=518322) annotation (Placement(transformation(extent={{-80,70},{
                      -60,90}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-60,-90},
                      {-80,-70}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            ThermoPower.Water.SinkPressure sinkSteam3(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17814720)
              annotation (Placement(transformation(extent={{40,-90},{60,-70}})));
            ThermoPower.Water.SinkPressure sinkSteam(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17611890,
              use_in_p0=false)
              annotation (Placement(transformation(extent={{40,50},{60,70}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=143.1,
              use_in_w0=false)
              annotation (Placement(transformation(extent={{0,-70},{20,-90}})));
          equation
            connect(OTSG.FW_in, sourceSteam2.flange) annotation (Line(
                points={{1.5,-30.6667},{34,-30.6667},{34,-40},{40,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.RH_in, sourceSteam1.flange) annotation (Line(
                points={{1.5,29.3333},{32,29.3333},{32,20},{40,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS1.flange, OTSG.MS_in) annotation (Line(
                points={{-60,80},{-42,80},{-42,41.3333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-60,-80},{-42,-80},{-42,-41.3333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.MS_HPH_out, throughMassFlow.inlet) annotation (Line(
                points={{-24,-41.3333},{-24,-80},{0,-80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(throughMassFlow.outlet, sinkSteam3.flange) annotation (Line(
                points={{20,-80},{40,-80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.RH_out, sinkSteam1.flange) annotation (Line(
                points={{-24,41.3333},{-24,80},{0,80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SH_out, sinkSteam.flange) annotation (Line(
                points={{-12,41.3333},{-12,60},{40,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SEP_out, sourceSteam2.flange) annotation (Line(
                points={{1.5,-10.6667},{34,-10.6667},{34,-40},{40,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics), Icon(coordinateSystem(
                    extent={{-100,-100},{100,100}})));
          end test_OTSG_2ph;

          model OTSG_full_2ph_busControl_init100_5nodes
            "Complete dynamic model of the once through steam generator, with separate 2ph HTC"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    136706,129914,122014,112572,100947}),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={1.23186e+006,1.28146e+006,1.32175e+006,1.35546e+006,
                    1.38444e+006}),
              nominalHotFlow=610.6,
              Shot=2429.5,
              Scold=1913.2,
              Mm=29335,
              nominalColdFlow=143.1,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2000, alpha=0.447465),
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=5000, alpha=0.536143),
              tubeWalls(Tvolstart={560.978,569.126,575.7,581.167}),
              Vhot=33.634,
              Vcold=6.027,
              nominalColdPressure=17910000,
              nominalHotPressure=400000,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=581.85,
              nominalHotInletTemperature=586.85,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-254},{-44,-286}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    199579,192529,183185,168175,136603}),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                    1.66591e+006}),
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Shot=2394.2,
              Scold=1855.5,
              Mm=30395,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4400),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2200),
              tubeWalls(Tvolstart={582.675,605.885,616.62,623.137}),
              Vhot=45.011,
              Vcold=5.752,
              nominalColdPressure=17910000,
              nominalHotPressure=569600,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=623.79,
              nominalHotInletTemperature=628.75,
              nominalHotOutletTemperature=586.72)
              annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    289063,250302,228476,216201,209301,205481,203503,201573,199646,
                    197679}),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                    1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                    2.29575e+006}),
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              Mm=43100,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2300, alpha=0.447498),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=3875,
                  gamma_nom_2ph=25350,
                  gamma_nom_vap=3875,
                  alpha=1.6),
              nominalColdFlow=88.59,
              Shot=2251.9*0.94,
              Scold=1765.5*0.94,
              tubeWalls(Tvolstart={626.054,627.39,628.669,629.917,629.888,630.182,
                    630.842,632.016,634.097}),
              Vhot=26.587,
              Vcold=8.651,
              nominalColdPressure=17810000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=623.75,
              nominalColdOutletTemperature=629.32,
              nominalHotInletTemperature=688.04,
              nominalHotOutletTemperature=629.15) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    355877,349098,342248,335400,328621,320944,311763,303278,295435,
                    288187}),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                    2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                    2.69972e+006,2.74645e+006}),
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Mm=5182,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              Shot=429.2*0.88,
              Scold=338*0.88,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_2ph=6000,
                  gamma_nom_liq=2600,
                  gamma_nom_vap=2600),
              tubeWalls(Tvolstart={650.941,652.73,654.665,656.757,670.379,679.959,
                    684.074,688.573,693.427}),
              Vhot=3.905,
              Vcold=1.065,
              nominalColdPressure=17760000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=629.15,
              nominalColdOutletTemperature=648.65,
              nominalHotInletTemperature=732.05,
              nominalHotOutletTemperature=687.95) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_min=0,
              zl_max=7,
              zl_start=0,
              h_start=2.7e6,
              D=0.56,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              p_start=17710000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              use_in_w0=true,
              w0=10) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,4})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    518322,502443,472016,421345,355895}),
              redeclare package coldMedium = coldMedium,
              Mm=15353,
              nominalColdFlow=88.59,
              nominalHotFlow=371.8,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                    3.42731e+006}),
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2200, alpha=0.847436),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.28867),
              Nhex=Nhex_mono,
              Shot=1153.8*0.95,
              Scold=879.8*0.95,
              tubeWalls(Tvolstart={725.391,769.727,804.861,826.169}),
              Vhot=3.68,
              Vcold=2.683,
              nominalColdPressure=17710000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=648.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=732.02)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,120})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={
                    518322,503128,476511,430304,353343}),
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Mm=10081,
              nominalColdFlow=82.57,
              nominalHotFlow=238.7,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, Nt=1,
                hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                    3.56013e+006}),
              Shot=1339,
              Scold=1198,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=970),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2600, alpha=0.320782),
              tubeWalls(Tvolstart={734.495,783.217,812.321,829.047}),
              Vhot=1.522,
              Vcold=5.092,
              nominalColdPressure=4698000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=625.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=731.45)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              w0=238.7,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-46,270},{-26,250}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,230})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              dpnom=(0.05828)*10^5,
              rhonom=582.24,
              wnom=88.59)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.52492)*10^5,
              rhonom=768.15)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-176})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.11171)*10^5,
              rhonom=250)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = sensT_FW.T;
            Modelica.SIunits.Temperature T_outMS = sensT_MS.T;
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              dpnom=(177.1 - 176.1189)*10^5,
              rhonom=96.586,
              wnom=88.59)                    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,188})));
            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=82.57,
              dpnom=(0.55113)*10^5,
              rhonom=17.86)                  annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,190})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,10}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-276},{0,-256}})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{102,-246},{82,-226}})));
            ThermoPower.Water.SensP sensP_ECO(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-56,-140})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{190,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,260},{140,260},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(MS_in, valveRH.inlet) annotation (Line(
                points={{-100,310},{-100,260},{-46,260}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-270},{-100,-270},{-100,-210},{-76,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-286},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,236}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(MS_in, SH.inletHot) annotation (Line(
                points={{-100,310},{-100,120},{-16,120}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
                points={{-60,-194},{-60,-186}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,14},{1.77636e-015,14}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(SH.inletCold, separator.steam_out) annotation (Line(
                points={{0,104},{0,80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,120},{140,120},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-210},{-44,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-6},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
                points={{0,136},{0,178}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(SH_out, PDSteamSH.outlet) annotation (Line(
                points={{0,310},{0,198}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,224},{100,200}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,-20},{50,8},{6,8}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,246},{50,244},{-40,244},{-40,254}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
                points={{50,10},{50,10},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,10},{50,10},{50,244},{90,244},{90,238}},
                color={255,204,51},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-270},{-30,-270},{-16,-270}},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled},
                color={255,0,0}));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-270},{20,-270},{20,-310}},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled},
                color={255,0,0}));
            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{98,-240},{98,-240},{190,-240}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(sensT_FW.outlet, HPH.inletCold) annotation (Line(
                points={{86,-240},{86,-240},{-60,-240},{-60,-254}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_FW.outlet, ECO.inletCold) annotation (Line(
                points={{86,-240},{86,-240},{-60,-240},{-60,-226}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
                points={{50,10},{50,10},{50,-200},{50,-230},{84,-230}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_MS.T) annotation (Line(
                points={{50,10},{50,10},{50,-260},{-2,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, sensP_ECO.flange) annotation (Line(
                points={{-60,-116},{-60,-140}},
                color={0,0,255},
                thickness=0.5));
            connect(sensP_ECO.flange, PDSteamECO.outlet) annotation (Line(
                points={{-60,-140},{-60,-166}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, sensP_ECO.p) annotation (Line(
                points={{50,10},{50,10},{50,-158},{-50,-158},{-50,-148}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
          end OTSG_full_2ph_busControl_init100_5nodes;

          model OTSG_init100_5nodes_old
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              nominalHotFlow=610.6,
              Shot=2429.5,
              Scold=1913.2,
              Mm=29335,
              nominalColdFlow=143.1,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2000, alpha=0.447465),
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=5000, alpha=0.536143),
              Vhot=33.634,
              Vcold=6.027,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.23186e+006,1.28146e+006,1.32175e+006,1.35546e+006,
                    1.38444e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {136706,129914,122014,112572,100947}),
              tubeWalls(Tvolstart(displayUnit="K") = {560.978,569.126,575.7,581.167}),
              nominalColdPressure=17910000,
              nominalHotPressure=400000,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=581.85,
              nominalHotInletTemperature=586.85,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-254},{-44,-286}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Shot=2394.2,
              Scold=1855.5,
              Mm=30395,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4400),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2200),
              Vhot=45.011,
              Vcold=5.752,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                    1.66591e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                  623.137}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {199579,192529,183185,168175,136603}),
              nominalColdPressure=17910000,
              nominalHotPressure=569600,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=623.79,
              nominalHotInletTemperature=628.75,
              nominalHotOutletTemperature=586.72)
              annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              Mm=43100,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2300, alpha=0.447498),
              nominalColdFlow=88.59,
              Vhot=26.587,
              Vcold=8.651,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                    1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,2.02847e+006,
                    2.29575e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                  629.917,629.888,630.182,630.842,632.016,634.097}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {289063,250302,228476,216201,209301,205481,203503,201573,199646,
                    197679}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=3875,
                  gamma_nom_vap=3875,
                  alpha=1.6,
                  gamma_nom_2ph=10000),
              Shot=2251.9*0.81,
              Scold=1765.5*0.81,
              nominalColdPressure=17810000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=623.75,
              nominalColdOutletTemperature=629.32,
              nominalHotInletTemperature=688.04,
              nominalHotOutletTemperature=629.15) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Mm=5182,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              Vhot=3.905,
              Vcold=1.065,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                    2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                    2.69972e+006,2.74645e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                  656.757,670.379,679.959,684.074,688.573,693.427}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {355877,349098,342248,335400,328621,320944,311763,303278,295435,
                    288187}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000),
              Shot=429.2*0.88,
              Scold=338*0.88,
              nominalColdPressure=17760000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=629.15,
              nominalColdOutletTemperature=648.65,
              nominalHotInletTemperature=732.05,
              nominalHotOutletTemperature=687.95) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              h_start=2.7e6,
              D=0.56,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              zl_start=0,
              p_start=17710000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              use_in_w0=true,
              w0=10) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,6})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              Mm=15353,
              nominalColdFlow=88.59,
              nominalHotFlow=371.8,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2200, alpha=0.847436),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.28867),
              Nhex=Nhex_mono,
              Vhot=3.68,
              Vcold=2.683,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.74562e+006,3.02031e+006,3.23297e+006,3.36066e+006,
                    3.42731e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {725.391,769.727,804.861,
                  826.169}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {518322,502443,472016,421345,355895}),
              Shot=1153.8*0.95,
              Scold=879.8*0.95,
              nominalColdPressure=17710000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=648.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=732.02)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,120})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Mm=10081,
              nominalColdFlow=82.57,
              nominalHotFlow=238.7,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=970),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2600, alpha=0.320782),
              Vhot=1.522,
              Vcold=5.092,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={3.0832e+006,3.30568e+006,3.43926e+006,3.51621e+006,
                    3.56013e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {734.495,783.217,812.321,
                  829.047}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {518322,503128,476511,430304,353343}),
              Shot=1339,
              Scold=1198,
              nominalColdPressure=4698000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=625.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=731.45)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              w0=238.7,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,210})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              dpnom=(0.05828)*10^5,
              wnom=88.59,
              rhonom=168.8)        annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.52492)*10^5,
              rhonom=768.15)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-150})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.11171)*10^5,
              rhonom=97)           annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=82.57,
              dpnom=(0.55113)*10^5,
              rhonom=12.52)                  annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,10}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{102,-246},{82,-226}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-276},{0,-256}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              w0=610.6,
              use_in_w0=true,
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,200})));
            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=88.59,
              rhonom=51.9,
              dpnom=(177.1 - 176.1)*10^5)    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,170})));
            ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              Av=0.046406353,
              wnom=88.59,
              thetanom=0.8,
              Fxt_full=0.4542722663,
              pnom=17610000,
              dpnom=110000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{190,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,230},{140,230},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-270},{-100,-270},{-100,-210},{-76,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-286},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,216}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
                points={{-60,-194},{-60,-160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,16},{1.77636e-015,16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(SH.inletCold, separator.steam_out) annotation (Line(
                points={{0,104},{0,80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,120},{140,120},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-210},{-44,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,204},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{98,-240},{144,-240},{190,-240}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, ECO.inletCold) annotation (Line(
                points={{86,-240},{14,-240},{-60,-240},{-60,-226}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, HPH.inletCold) annotation (Line(
                points={{86,-240},{14,-240},{-60,-240},{-60,-254}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-270},{-16,-270}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-270},{20,-270},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,10},{30,10},{6,10}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
                points={{50,10},{50,10},{50,44},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
                points={{50,10},{50,10},{50,-152},{50,-230},{50,-230},{84,-230}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,218},{-40,218},{-40,224}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,10},{50,10},{50,218},{90,218}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,120},{-16,120}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,230},{-46,230}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,10},{50,10},{50,260},{50,192},{10,192}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                points={{-60,-116},{-60,-140}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
                points={{50,10},{50,10},{50,-230},{50,-260},{-2,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
                points={{0,200},{6.66134e-016,200},{6.66134e-016,180}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                points={{0,160},{0,136}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,10},{50,10},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{-4.44089e-016,270},{-4.44089e-016,236},{0,236},{0,200}},
                color={0,0,255},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,300},{0,290}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
          end OTSG_init100_5nodes_old;

          model OTSG_init50_5nodes_old
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              nominalHotFlow=610.6,
              Shot=2429.5,
              Scold=1913.2,
              Mm=29335,
              nominalColdFlow=143.1,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2000, alpha=0.447465),
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=5000, alpha=0.536143),
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25188e+006,1.26667e+006,1.25173e+006,1.26683e+006,
                    1.25157e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {93356,93346.5,93356.1,93346.6,93356.1}),
              tubeWalls(Tvolstart(displayUnit="K") = {557.843,557.837,557.843,
                  557.837}),
              Vhot=33.634,
              Vcold=6.027,
              nominalColdPressure=17910000,
              nominalHotPressure=400000,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=581.85,
              nominalHotInletTemperature=586.85,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-254},{-44,-286}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Shot=2394.2,
              Scold=1855.5,
              Mm=30395,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4400),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2200),
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                    1.3288e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {119114,110526,103784,98376.4,93969.4}),
              tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                  569.474}),
              Vhot=45.011,
              Vcold=5.752,
              nominalColdPressure=17910000,
              nominalHotPressure=569600,
              nominalColdInletTemperature=553.15,
              nominalColdOutletTemperature=623.79,
              nominalHotInletTemperature=628.75,
              nominalHotOutletTemperature=586.72)
              annotation (Placement(transformation(extent={{-44,-226},{-76,-194}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              Mm=43100,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2300, alpha=0.447498),
              nominalColdFlow=88.59,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                    1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                    1.45658e+006,1.56606e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {193708,157918,143681,138009,133137,128914,125226,121985,119121,
                    116578}),
              tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                  577.742,579.999,582.568,585.511,585.959,587.035}),
              Vhot=26.587,
              Vcold=8.651,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=3875,
                  gamma_nom_vap=3875,
                  alpha=1.6,
                  gamma_nom_2ph=10000),
              Shot=2251.9*0.81,
              Scold=1765.5*0.81,
              nominalColdPressure=17810000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=623.75,
              nominalColdOutletTemperature=629.32,
              nominalHotInletTemperature=688.04,
              nominalHotOutletTemperature=629.15) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              nominalHotFlow=610.6,
              nominalColdFlow=88.59,
              Mm=5182,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              Shot=429.2*0.88,
              Scold=338*0.88,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                    1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                    1.94272e+006,2.02642e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {344122,316769,292958,272234,254202,238514,224868,213001,202681,
                    193708}),
              tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                  602.087,604.627,607.543,610.89,614.73,619.134}),
              Vhot=3.905,
              Vcold=1.065,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000),
              nominalColdPressure=17760000,
              nominalHotPressure=730800,
              nominalColdInletTemperature=629.15,
              nominalColdOutletTemperature=648.65,
              nominalHotInletTemperature=732.05,
              nominalHotOutletTemperature=687.95) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=4,
              h_start=2016500,
              phase(start=2, fixed=true),
              D=0.56,
              p_start=10100000,
              initOpt=ThermoPower.Choices.Init.Options.steadyState,
              T(start=584.85))
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              use_in_w0=true,
              w0=10) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,6})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              Mm=15353,
              nominalColdFlow=88.59,
              nominalHotFlow=371.8,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2200, alpha=0.847436),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.28867),
              Nhex=Nhex_mono,
              Shot=1153.8*0.95,
              Scold=879.8*0.95,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.72364e+006,3.22113e+006,3.45073e+006,3.5168e+006,
                    3.53402e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {518322,514827,501414,454805,353814}),
              tubeWalls(Tvolstart={733.236,797.905,827.469,835.959}),
              Vhot=3.68,
              Vcold=2.683,
              nominalColdPressure=17710000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=648.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=732.02)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,120})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Mm=10081,
              nominalColdFlow=82.57,
              nominalHotFlow=238.7,
              Shot=1339,
              Scold=1198,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=970),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=2600, alpha=0.320782),
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={3.12533e+006,3.32376e+006,3.45094e+006,3.53171e+006,
                    3.58318e+006}),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart=
                   {518322,493431,454370,392870,296910}),
              tubeWalls(Tvolstart(displayUnit="K") = {712.396,768.496,804.215,
                  826.852}),
              Vhot=1.522,
              Vcold=5.092,
              nominalColdPressure=4698000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=625.65,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.15,
              nominalHotOutletTemperature=731.45)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              w0=238.7,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-46,240},{-26,220}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,210})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              dpnom=(0.05828)*10^5,
              wnom=88.59,
              rhonom=168.8,
              pin(start=10200000)) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.52492)*10^5,
              rhonom=768.15,
              pin(start=10300000))           annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-150})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=88.59,
              dpnom=(0.11171)*10^5,
              rhonom=97,
              pin(start=10150000)) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=88.59,
              dpnom=(177.1 - 176.1)*10^5,
              rhonom=51.9)                   annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,170})));
            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=82.57,
              dpnom=(0.55113)*10^5,
              rhonom=17.86)                  annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,10}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{102,-246},{82,-226}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-276},{0,-256}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              w0=610.6,
              use_in_w0=true,
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,200})));
            ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              Av=0.046406353,
              wnom=88.59,
              thetanom=0.8,
              Fxt_full=0.4542722663,
              pnom=17610000,
              dpnom=110000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{190,160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,230},{140,230},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-270},{-100,-270},{-100,-210},{-76,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-286},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,216}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO.inlet) annotation (Line(
                points={{-60,-194},{-60,-160}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,16},{1.77636e-015,16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(SH.inletCold, separator.steam_out) annotation (Line(
                points={{0,104},{0,80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                points={{-60,-116},{-60,-140}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,120},{140,120},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-210},{-44,-210}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletCold, PDSteamSH.inlet) annotation (Line(
                points={{0,136},{0,160},{-6.66134e-016,160}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,204},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{98,-240},{144,-240},{190,-240}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, sensT_FW.outlet) annotation (Line(
                points={{-60,-226},{-60,-240},{86,-240}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.inletCold, sensT_FW.outlet) annotation (Line(
                points={{-60,-254},{-60,-240},{86,-240}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_MS.inlet, HPH.outletHot) annotation (Line(
                points={{-16,-270},{-30,-270},{-44,-270}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-270},{10,-270},{20,-270},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,10},{6,10},{6,10}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, separator.level) annotation (Line(
                points={{50,10},{50,10},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_CS, valveRH.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,70},{50,218},{-40,218},{-40,224}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,10},{50,10},{50,218},{90,218}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, sensT_FW.T) annotation (Line(
                points={{50,10},{50,10},{50,-226},{50,-230},{84,-230}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,288},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,226},{-100,230},{-46,230}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,246},{-100,186},{-100,120},{-16,120}},
                color={255,0,0},
                thickness=0.5));
            connect(sensP.flange, PDSteamSH.outlet) annotation (Line(
                points={{0,200},{0,180}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
                points={{-42,48},{-50,48},{-60,48},{-60,-4}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, sensT_MS.T) annotation (Line(
                points={{50,10},{50,10},{50,-252},{50,-260},{-2,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,258},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,10},{50,10},{50,190},{50,192},{10,192}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,10},{50,10},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{0,270},{0,235},{0,200}},
                color={0,0,255},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)));
          end OTSG_init50_5nodes_old;

          model test_OTSG_4_optA_old "Test model of the OTSG at 4% of load"

            OTSG_init20_20nodes OTSG(
              separator(
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                h_start=1697500,
                p_start=8540000),
              PDSteamEVA1(pin(start=8620000)),
              PDSteamECO(pin(start=8660000)),
              PDSteamEVA2(pin(start=8580000)),
              PDSteamRH(pin(start=22.05e5)))
              annotation (Placement(transformation(extent={{-44,-36},{12,56}})));
            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=17.01,
              h=515800)
              annotation (Placement(transformation(extent={{110,-4},{90,-24}})));
            ThermoPower.Water.SourceMassFlow sourceMS(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322,
              w0=24.424,
              use_in_w0=true) annotation (Placement(transformation(extent={{-116,
                      100},{-96,80}})));
            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-20,-70},
                      {0,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-140,120},{-120,140}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{94,-70},{114,-50}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=false,
              w0=4.18,
              h=3092400)
              annotation (Placement(transformation(extent={{76,34},{56,54}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2200000)
              annotation (Placement(transformation(extent={{22,114},{42,134}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8500000)
              annotation (Placement(transformation(extent={{62,94},{82,114}})));
            IndustrialControlSystems.Controllers.PI pI(
              AntiWindup=true,
              CSmin=0,
              CSmax=620,
              CS_start=55,
              Kp=-0.3,
              Ti=1200)
                      annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=0,
                  origin={-90,-110})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=5)                                             annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-110,10})));
            Modelica.Blocks.Sources.Constant const(k=260 + 273.15) annotation (
                Placement(transformation(extent={{-40,-140},{-60,-120}})));
            ThermoPower.Water.SensT sensT
              annotation (Placement(transformation(extent={{42,-34},{22,-54}})));
            Control.plant_controller controllers(
              Kp_valveRH=1.77,
              Td_valveRH=0,
              Nd_valveRH=1,
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              useTS_valveRH=false,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              Td_pumpFW=0,
              Nd_pumpFW=1,
              Ta_pumpFW=5,
              Kp_valveBP=1,
              Ti_valveBP=1,
              Td_valveBP=0,
              Nd_valveBP=1,
              CSmin_valveBP=0,
              CSmax_valveBP=200,
              CSstart_valveBP=153.6,
              actuatorGain_valveBP=1,
              Ta_valveBP=2,
              useTS_valveBP=true,
              TS_valveBP=153.6,
              Kp_pumpHPH=1,
              Ti_pumpHPH=1,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              CSmin_pumpHPH=0,
              CSmax_pumpHPH=200,
              CSstart_pumpHPH=143.1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              useTS_pumpHPH=true,
              TS_pumpHPH=143.1,
              actuatorGain_pumpFW=1,
              l_sp=4,
              CSmin_pumpFW=1,
              CSmax_pumpFW=120,
              useTS_pumpFW=false,
              Kp_pumpFW=0.003,
              Ti_pumpFW=800,
              useTS_pumpSEP=false,
              CSstart_valveRH=6.08,
              TS_valveRH=6.08,
              CSstart_pumpSEP=10.45,
              TS_pumpSEP=10.45,
              p_SH_sp=13.99,
              CSstart_pumpFW=3.54,
              TS_pumpFW=3.54,
              f_load(k=10.45),
              load_start=4,
              load_end=4,
              t_ramp=1,
              Ti_valveRH=16,
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15)
              annotation (Placement(transformation(extent={{-80,-90},{-60,-70}})));
          equation
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-96,90},{-31.5556,90},{-31.5556,57.5333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                points={{13.5556,-2.26667},{44,-2.26667},{44,-14},{90,-14}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{104,-60},{104,-60},{104,-20}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%first",
                index=-1,
                extent={{-6,3},{-6,3}}));
            connect(OTSG.RH_in,sourceRH. flange) annotation (Line(
                points={{13.5556,43.7333},{54,43.7333},{54,44},{56,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SH_out,sinkSH. flange) annotation (Line(
                points={{-0.444444,57.5333},{-0.444444,104},{62,104}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{22,124},
                    {4,124},{-12.8889,124},{-12.8889,57.5333}},
                                                      color={0,0,255}));
            connect(pI.CS, firstOrder.u) annotation (Line(points={{-99,-110},{-110,
                    -110},{-110,-2}}, color={0,0,127}));
            connect(const.y, pI.SP) annotation (Line(points={{-61,-130},{-70,-130},
                    {-70,-116},{-82,-116}}, color={0,0,127}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -31.5556,-37.5333},{-31.5556,-60},{-20,-60}},
                                                           color={0,0,255}));
            connect(OTSG.FW_in, sensT.outlet) annotation (Line(points={{13.5556,
                    -25.2667},{20,-25.2667},{20,-40},{26,-40}}, color={0,0,255}));
            connect(sourceFW.flange, sensT.inlet) annotation (Line(points={{90,-14},
                    {68,-14},{44,-14},{44,-40},{38,-40}}, color={0,0,255}));
            connect(sensT.T, pI.PV) annotation (Line(points={{24,-50},{20,-50},{20,
                    -106},{20,-108},{-82,-108},{-82,-109}},               color={0,
                    0,127}));
            connect(sourceMS.in_w0, firstOrder.y) annotation (Line(points={{-110,84},
                    {-110,21}},           color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-59.75,-82.6286},{-52,-82.6286},{-52,10},{-46.1778,10}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, signalBus) annotation (Line(
                points={{-59.75,-82.6286},{104,-82.6286},{104,-60}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,
                      -140},{140,140}}), graphics={Text(
                    extent={{18,-100},{138,-140}},
                    lineColor={28,108,200},
                    textString="Simulare per 20000 s a 500 punti
per raggiungere regime")}),                                Icon(coordinateSystem(
                    extent={{-140,-140},{140,140}}, preserveAspectRatio=false)));
          end test_OTSG_4_optA_old;

          model test_OTSG_4_optB "Test model of the OTSG at 4% of load"

            OTSG_init4_5nodes_noDP OTSG(
              separator(
                zl_start=0,
                phase(fixed=true, start=1),
                h_start=3e6,
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                p_start=8510000,
                T(start=643.15)),
              SH(nominalColdPressure=8510000),
              EVA2(nominalColdPressure=8500000),
              EVA1(nominalColdPressure=8500000),
              ECO(nominalColdPressure=8500000))
              annotation (Placement(transformation(extent={{-64,-36},{-8,56}})));
            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=17.01,
              h=515800)
              annotation (Placement(transformation(extent={{162,-4},{142,-24}})));
            ThermoPower.Water.SourceMassFlow sourceMS(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322,
              w0=20,
              use_in_w0=false) annotation (Placement(transformation(extent={{-136,
                      100},{-116,80}})));
            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{20,-70},
                      {40,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-180,120},{-160,140}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{146,-70},{166,-50}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=false,
              w0=4.18,
              h=3092400)
              annotation (Placement(transformation(extent={{28,34},{8,54}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2200000)
              annotation (Placement(transformation(extent={{2,114},{22,134}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8500000)
              annotation (Placement(transformation(extent={{42,94},{62,114}})));
            IndustrialControlSystems.Controllers.PI pI(
              AntiWindup=true,
              CSmin=0,
              CSmax=620,
              Ti=650,
              CS_start=20,
              Kp=5)   annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=0,
                  origin={-110,-110})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              T=5,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-130,10})));
            Modelica.Blocks.Sources.Constant const(k=275 + 273.15) annotation (
                Placement(transformation(extent={{-60,-140},{-80,-120}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                  transformation(extent={{-32,-54},{-12,-74}})));
            Control.plant_controller controllers(
              Kp_valveRH=1.77,
              Ti_valveRH=160,
              Td_valveRH=0,
              Nd_valveRH=1,
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              useTS_valveRH=false,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              Td_pumpFW=0,
              Nd_pumpFW=1,
              Ta_pumpFW=5,
              Kp_valveBP=1,
              Ti_valveBP=1,
              Td_valveBP=0,
              Nd_valveBP=1,
              CSmin_valveBP=0,
              CSmax_valveBP=200,
              CSstart_valveBP=153.6,
              actuatorGain_valveBP=1,
              Ta_valveBP=2,
              useTS_valveBP=true,
              TS_valveBP=153.6,
              Kp_pumpHPH=1,
              Ti_pumpHPH=1,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              CSmin_pumpHPH=0,
              CSmax_pumpHPH=200,
              CSstart_pumpHPH=143.1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              useTS_pumpHPH=true,
              TS_pumpHPH=143.1,
              actuatorGain_pumpFW=1,
              CSmin_pumpFW=1,
              CSmax_pumpFW=120,
              Kp_pumpFW=0.003,
              Ti_pumpFW=800,
              CSstart_valveRH=6.08,
              TS_valveRH=6.08,
              CSstart_pumpFW=3.54,
              TS_pumpFW=3.54,
              l_sp=0,
              CSstart_pumpSEP=0,
              p_SH_sp=3.54,
              f_load(k=0),
              useTS_pumpFW=true,
              useTS_pumpSEP=true,
              TS_pumpSEP=0,
              load_start=4,
              load_end=4,
              t_ramp=1,
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15)
              annotation (Placement(transformation(extent={{-100,-90},{-80,-70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3583500,
              w0=1.4,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{140,10},{120,30}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=0,
              h=1e5)
              annotation (Placement(transformation(extent={{68,10},{88,30}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{120,-60},{140,-40}})));
            PreHeaters.Preheater_simplified
                                      HPH2(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_drainIN=true,
              Vhot=2.99,
              Vcold=0.53,
              Mm=10000,
              D=0.4,
              Shot=200,
              Scold=200,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2820),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2820),
              Kv=3.73e-5,
              nominalColdFlow=3.54,
              nominalHotFlow=3.73,
              Nhex=10,
              nominalColdPressure=8600000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=394.65,
              nominalColdOutletTemperature=533.15,
              nominalHotInletTemperature=821.15,
              nominalHotOutletTemperature=453.15)
              annotation (Placement(transformation(extent={{82,-34},{122,6}})));
            ThermoPower.Water.SensT sensT1(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{22,-30},{2,-10}})));
            IndustrialControlSystems.Controllers.PI pI1(
              AntiWindup=true,
              Kp=0.032,
              Ti=20,
              CSmax=3.73,
              CS_start=1.4,
              CSmin=0.5)
                      annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=0,
                  origin={186,52})));
            Modelica.Blocks.Sources.Constant const1(k=260 + 273.15)
                                                                   annotation (
                Placement(transformation(extent={{236,-4},{216,16}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder1(
              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=1)                                             annotation (
                Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=180,
                  origin={150,52})));
          equation
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-116,90},{-51.5556,90},{-51.5556,57.5333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{156,-60},{156,-50},{156,-40},{156,-20}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%first",
                index=-1,
                extent={{-6,3},{-6,3}}));
            connect(OTSG.SH_out,sinkSH. flange) annotation (Line(
                points={{-20.4444,57.5333},{-20.4444,104},{42,104}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{2,124},
                    {-16,124},{-32.8889,124},{-32.8889,57.5333}},
                                                      color={0,0,255}));
            connect(pI.CS, firstOrder.u) annotation (Line(points={{-119,-110},{-130,
                    -110},{-130,-2}}, color={0,0,127}));
            connect(const.y, pI.SP) annotation (Line(points={{-81,-130},{-90,-130},
                    {-90,-116},{-102,-116}},color={0,0,127}));
            connect(sensT.T, pI.PV) annotation (Line(points={{-14,-70},{-14,-70},{
                    -10,-70},{-8,-70},{-8,-110},{-102,-110},{-102,-109}}, color={0,
                    0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-79.75,-82.6286},{-72,-82.6286},{-72,10},{-66.1778,10}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, signalBus) annotation (Line(
                points={{-79.75,-82.6286},{156,-82.6286},{156,-60}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(sourceFW.flange, HPH2.FW_in)
              annotation (Line(points={{142,-14},{124,-14}}, color={0,0,255}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in)
              annotation (Line(points={{88,20},{88,6}}, color={0,0,255}));
            connect(sourceMassFlow_ST.flange, HPH2.ST_in) annotation (Line(points={
                    {120,20},{102,20},{102,6}}, color={0,0,255}));
            connect(HPH2.DR_out, sinkPressure_DR.flange) annotation (Line(points={{
                    102,-34},{102,-50},{120,-50}}, color={0,0,255}));
            connect(HPH2.FW_out, OTSG.SEP_out) annotation (Line(points={{82,-14},
                    {20,-14},{20,-2.26667},{-6.44444,-2.26667}},color={0,0,255}));
            connect(OTSG.MS_out, sensT.inlet) annotation (Line(points={{-51.5556,
                    -37.5333},{-51.5556,-60},{-28,-60}}, color={0,0,255}));
            connect(sensT.outlet, sinkMS.flange) annotation (Line(points={{-16,-60},
                    {10,-60},{20,-60}}, color={0,0,255}));
            connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{
                    -6.44444,43.7333},{0.77778,43.7333},{0.77778,44},{8,44}},
                                                                     color={0,0,255}));
            connect(OTSG.FW_in, sensT1.outlet) annotation (Line(points={{-6.44444,
                    -25.2667},{0,-25.2667},{0,-24},{6,-24}}, color={0,0,255}));
            connect(HPH2.FW_out, sensT1.inlet) annotation (Line(points={{82,-14},{
                    20,-14},{20,-24},{18,-24}}, color={0,0,255}));
            connect(pI1.CS, firstOrder1.u)
              annotation (Line(points={{177,52},{162,52}}, color={0,0,127}));
            connect(const1.y, pI1.SP) annotation (Line(points={{215,6},{206,6},{206,
                    46},{194,46}}, color={0,0,127}));
            connect(firstOrder1.y, sourceMassFlow_ST.in_w0) annotation (Line(points=
                   {{139,52},{134,52},{134,26}}, color={0,0,127}));
            connect(sensT1.T, pI1.PV) annotation (Line(points={{4,-14},{4,20},{60,
                    20},{60,82},{208,82},{208,53},{194,53}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -140},{180,140}})),                  Icon(coordinateSystem(
                    extent={{-180,-140},{180,140}}, preserveAspectRatio=false)));
          end test_OTSG_4_optB;

          model test_OTSG_4_optB_noHPH2 "Test model of the OTSG at 4% of load"

            OTSG_init4_5nodes_noDP OTSG(
              separator(
                zl_start=0,
                phase(fixed=true, start=1),
                h_start=3e6,
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                p_start=8510000,
                T(start=643.15)),
              SH(nominalColdPressure=8510000),
              EVA2(nominalColdPressure=8500000),
              EVA1(nominalColdPressure=8500000),
              ECO(nominalColdPressure=8500000),
              Nhex_mono=30,
              Nhex_bi=60)
              annotation (Placement(transformation(extent={{-44,-36},{12,56}})));
            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=3.54,
              h=1134280)
              annotation (Placement(transformation(extent={{120,-2},{100,-22}})));
            ThermoPower.Water.SourceMassFlow sourceMS(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322,
              use_in_w0=false,
              w0=24) annotation (Placement(transformation(extent={{-116,102},{-96,
                      82}})));
            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{40,-70},
                      {60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-140,120},{-120,140}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{104,-68},{124,-48}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=false,
              w0=4.18,
              h=3092400)
              annotation (Placement(transformation(extent={{48,34},{28,54}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2200000)
              annotation (Placement(transformation(extent={{22,114},{42,134}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8500000)
              annotation (Placement(transformation(extent={{62,94},{82,114}})));
            IndustrialControlSystems.Controllers.PI pI(
              AntiWindup=true,
              CSmin=0,
              CSmax=620,
              Ti=650,
              CS_start=20,
              Kp=5)   annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=0,
                  origin={-90,-110})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              T=5,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-110,10})));
            Modelica.Blocks.Sources.Constant const(k=275 + 273.15) annotation (
                Placement(transformation(extent={{-40,-140},{-60,-120}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                  transformation(extent={{-12,-54},{8,-74}})));
            Control.plant_controller controllers(
              Kp_valveRH=1.77,
              Td_valveRH=0,
              Nd_valveRH=1,
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              Td_pumpFW=0,
              Nd_pumpFW=1,
              Ta_pumpFW=5,
              Kp_valveBP=1,
              Ti_valveBP=1,
              Td_valveBP=0,
              Nd_valveBP=1,
              CSmin_valveBP=0,
              CSmax_valveBP=200,
              CSstart_valveBP=153.6,
              actuatorGain_valveBP=1,
              Ta_valveBP=2,
              useTS_valveBP=true,
              TS_valveBP=153.6,
              Kp_pumpHPH=1,
              Ti_pumpHPH=1,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              CSmin_pumpHPH=0,
              CSmax_pumpHPH=200,
              CSstart_pumpHPH=143.1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              useTS_pumpHPH=true,
              TS_pumpHPH=143.1,
              actuatorGain_pumpFW=1,
              CSmin_pumpFW=1,
              CSmax_pumpFW=120,
              Kp_pumpFW=0.003,
              Ti_pumpFW=800,
              CSstart_valveRH=6.08,
              TS_valveRH=6.08,
              CSstart_pumpFW=3.54,
              TS_pumpFW=3.54,
              l_sp=0,
              CSstart_pumpSEP=0,
              p_SH_sp=3.54,
              f_load(k=0),
              useTS_pumpFW=true,
              useTS_pumpSEP=true,
              TS_pumpSEP=0,
              load_start=4,
              load_end=4,
              t_ramp=1,
              useTS_valveRH=true,
              Ti_valveRH=16,
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15)
              annotation (Placement(transformation(extent={{-80,-90},{-60,-70}})));
          equation
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-96,92},{-31.5556,92},{-31.5556,57.5333}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{114,-58},{114,-48},{114,-38},{114,-18}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%first",
                index=-1,
                extent={{-6,3},{-6,3}}));
            connect(OTSG.SH_out,sinkSH. flange) annotation (Line(
                points={{-0.444444,57.5333},{-0.444444,104},{62,104}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{22,124},
                    {4,124},{-12.8889,124},{-12.8889,57.5333}},
                                                      color={0,0,255}));
            connect(pI.CS, firstOrder.u) annotation (Line(points={{-99,-110},{-110,
                    -110},{-110,-2}}, color={0,0,127}));
            connect(const.y, pI.SP) annotation (Line(points={{-61,-130},{-70,-130},
                    {-70,-116},{-82,-116}}, color={0,0,127}));
            connect(sensT.T, pI.PV) annotation (Line(points={{6,-70},{6,-70},{10,
                    -70},{12,-70},{12,-110},{-82,-110},{-82,-109}},       color={0,
                    0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-59.75,-82.6286},{-52,-82.6286},{-52,10},{-46.1778,10}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, signalBus) annotation (Line(
                points={{-59.75,-82.6286},{114,-82.6286},{114,-58}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(OTSG.MS_out, sensT.inlet) annotation (Line(points={{-31.5556,
                    -37.5333},{-31.5556,-60},{-8,-60}}, color={0,0,255}));
            connect(sensT.outlet, sinkMS.flange) annotation (Line(points={{4,-60},{
                    30,-60},{40,-60}}, color={0,0,255}));
            connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{13.5556,
                    43.7333},{20.7778,43.7333},{20.7778,44},{28,44}}, color={0,0,
                    255}));
            connect(sourceFW.flange, OTSG.FW_in) annotation (Line(points={{100,-12},
                    {62,-12},{62,-25.2667},{13.5556,-25.2667}}, color={0,0,255}));
            connect(OTSG.SEP_out, OTSG.FW_in) annotation (Line(points={{13.5556,
                    -2.26667},{62,-2.26667},{62,-25.2667},{13.5556,-25.2667}},
                  color={0,0,255}));
            connect(sourceMS.in_w0, firstOrder.y)
              annotation (Line(points={{-110,86},{-110,21}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,
                      -140},{140,140}}), graphics={Text(
                    extent={{20,-100},{140,-140}},
                    lineColor={28,108,200},
                    textString="Simulare per 60000 s a 500 punti
per raggiungere regime")}),                                Icon(coordinateSystem(
                    extent={{-140,-140},{140,140}}, preserveAspectRatio=false)));
          end test_OTSG_4_optB_noHPH2;

          model test_OTSG_4des "Test model of the OTSG at 4% of load"
            import PreFlexMS;

            OTSG_full_2ph_busControl_init20_5nodes OTSG(
              separator(
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                h_start=1697500,
                p_start=8540000),
              PDSteamEVA1(pin(start=8620000)),
              PDSteamECO(pin(start=8660000)),
              PDSteamEVA2(pin(start=8580000)),
              PDSteamRH(pin(start=22.05e5)))
              annotation (Placement(transformation(extent={{-164,-80},{-108,20}})));
            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=17.01,
              h=515800)
              annotation (Placement(transformation(extent={{8,-42},{-12,-62}})));
            ThermoPower.Water.SourceMassFlow sourceMS(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322,
              w0=34.424,
              use_in_w0=true) annotation (Placement(transformation(extent={{-236,
                      60},{-216,40}})));
            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-124},
                      {-120,-104}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-260,160},{-240,180}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-8,-108},{12,-88}})));
            IndustrialControlSystems.Controllers.PI pI(
              AntiWindup=true,
              CSmax=620,
              CSmin=20,
              Kp=0.6,
              Ti=650,
              CS_start=55)
                      annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=0,
                  origin={-210,-134})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              T=5,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-230,-30})));
            Modelica.Blocks.Sources.Constant const(k=260 + 273.15) annotation (
                Placement(transformation(extent={{-160,-180},{-180,-160}})));
            ThermoPower.Water.SensT sensT
              annotation (Placement(transformation(extent={{-78,-74},{-98,-94}})));
            PreFlexMS.Auxiliaries.desuperheatingStation_4
              desuperheatingStation_4(mixer_RH(noInitialPressure=false),
                mixer_SH(noInitialPressure=false))
              annotation (Placement(transformation(extent={{82,38},{136,86}})));
            Control.Schemes.desuperheating_controller desuperheating_controller(
              Kp_des_SH=-4.018e-3,
              Ti_des_SH=6.48,
              Td_des_SH=0,
              Nd_des_SH=1,
              CSmin_des_SH=0,
              CSmax_des_SH=3,
              CSstart_des_SH=0.6363,
              actuatorGain_des_SH=1,
              Ta_des_SH=2,
              Kp_des_RH=-2.67e-4,
              Ti_des_RH=6.22,
              Td_des_RH=0,
              Nd_des_RH=1,
              CSmin_des_RH=0,
              CSmax_des_RH=3,
              CSstart_des_RH=0.0524,
              actuatorGain_des_RH=1,
              Ta_des_RH=2,
              Td_p_SH=0,
              Nd_p_SH=1,
              CSmin_p_SH=0,
              CSstart_p_SH=0.6,
              actuatorGain_p_SH=1,
              Ta_p_SH=2,
              Td_p_RH=0,
              Nd_p_RH=1,
              CSmin_p_RH=0,
              CSstart_p_RH=0.6,
              actuatorGain_p_RH=1,
              Ta_p_RH=2,
              Kp_p_SH=-1.905e-7,
              Kp_p_RH=-1e6,
              Ti_p_SH=2,
              Ti_p_RH=2,
              CSmax_p_SH=1,
              CSmax_p_RH=1,
              useTS_des_SH=true,
              useTS_des_RH=true,
              useTS_p_SH=false,
              T_des_SH_sp=605.05,
              T_des_RH_sp=673.15,
              p_SH_sp=8500000,
              p_RH_sp=2200000,
              useTS_p_RH=true)
              annotation (Placement(transformation(extent={{60,100},{100,140}})));
            ThermoPower.Water.SourcePressure sourcePressure(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=515800,
              p0=8500000)
              annotation (Placement(transformation(extent={{176,52},{156,72}})));
            Control.OTSG_controller_partLoad
                                    controllers(
              zl_sp=4,
              Kp_l=-14.5,
              Ti_l=56.7,
              Td_l=0,
              Nd_l=1,
              CSmin_l=0,
              actuatorGain_l=1,
              Ti_T=160,
              Td_T=0,
              Nd_T=1,
              CSmin_T=1,
              CSmax_T=300,
              actuatorGain_T=1,
              Kp_T=1.77,
              Ta_l=5,
              Ta_T=2,
              Td_w=0,
              Nd_w=1,
              CSmin_w=0,
              CSmax_w=60,
              Ta_w=5,
              Kp_w=0.003,
              w_IN_sp=35.4,
              CSstart_w=3.54,
              Ti_w=800,
              CSstart_T=6.08,
              const(k=10.45),
              CSstart_l=10.45,
              CSmax_l=90,
              useTS_T=true,
              useTS_l=false,
              T_RH_sp=826.05,
              useTS_w=true)
              annotation (Placement(transformation(extent={{-200,-114},{-180,-82}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=false,
              w0=4.18,
              h=3092400)
              annotation (Placement(transformation(extent={{140,-120},{120,-100}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2190000)
              annotation (Placement(transformation(extent={{-20,78},{0,98}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8490000)
              annotation (Placement(transformation(extent={{26,-30},{46,-10}})));
            ThermoPower.Water.ValveLin valveLin2(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{100,-30},{80,-50}})));
            ThermoPower.Water.ValveLin valveLin1(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{100,-120},{80,-100}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=10000,
              height=0.99999,
              offset=0,
              duration=100)
              annotation (Placement(transformation(extent={{220,-70},{200,-50}})));
            Modelica.Blocks.Math.Add add(k1=-1)
              annotation (Placement(transformation(extent={{180,-90},{160,-70}})));
            Modelica.Blocks.Sources.Constant const1(k=1)
              annotation (Placement(transformation(extent={{220,-100},{200,-80}})));
            ThermoPower.Water.ValveLin valveLin3(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=3.54e-4)
              annotation (Placement(transformation(extent={{20,60},{40,40}})));
            Modelica.Blocks.Sources.Ramp ramp1(
              startTime=10000,
              height=0.99999,
              offset=0,
              duration=100)
              annotation (Placement(transformation(extent={{-56,20},{-36,40}})));
            Modelica.Blocks.Math.Add add1(k1=-1)
              annotation (Placement(transformation(extent={{-24,4},{-4,24}})));
            Modelica.Blocks.Sources.Constant const2(k=1)
              annotation (Placement(transformation(extent={{-56,-12},{-36,8}})));
            ThermoPower.Water.ValveLin valveLin4(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=3.54e-4)
              annotation (Placement(transformation(extent={{-6,-30},{14,-10}})));
            ThermoPower.Water.ValveLin valveLin5(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{-50,158},{-30,138}})));
            Modelica.Blocks.Sources.Ramp ramp2(
              startTime=10000,
              height=0.99999,
              offset=0,
              duration=100) annotation (Placement(transformation(extent={{-120,120},
                      {-100,140}})));
            Modelica.Blocks.Math.Add add2(k1=-1)
              annotation (Placement(transformation(extent={{-80,100},{-60,120}})));
            Modelica.Blocks.Sources.Constant const3(k=1)
              annotation (Placement(transformation(extent={{-120,94},{-100,114}})));
            ThermoPower.Water.ValveLin valveLin6(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{-50,78},{-30,98}})));
            ThermoPower.Water.SourcePressure sourceSH_p(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3583500,
              p0=8510000)
              annotation (Placement(transformation(extent={{48,-30},{68,-10}})));
            ThermoPower.Water.SourcePressure sourceRH_p(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3553400,
              p0=2210000)
              annotation (Placement(transformation(extent={{-40,56},{-20,76}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=2190000)
              annotation (Placement(transformation(extent={{180,-30},{200,-10}})));
            ThermoPower.Water.ValveLin valveLin(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{0,56},{20,76}})));
            ThermoPower.Water.ValveLin valveLin7(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=4.18e-4)
              annotation (Placement(transformation(extent={{140,-10},{160,-30}})));
            ThermoPower.Water.ValveLin valveLin8(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=3.54e-4) annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={72,14})));
          equation
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-216,50},{-151.556,50},{-151.556,21.6667}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                points={{-106.444,-43.3333},{-80,-43.3333},{-80,-52},{-12,-52}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS.in_w0, firstOrder.y)
              annotation (Line(points={{-230,44},{-230,-19}},color={0,0,127}));
            connect(pI.CS, firstOrder.u) annotation (Line(points={{-219,-134},{-230,
                    -134},{-230,-42}},color={0,0,127}));
            connect(const.y, pI.SP) annotation (Line(points={{-181,-170},{-190,-170},
                    {-190,-140},{-202,-140}},
                                            color={0,0,127}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{-151.556,
                    -81.6667},{-151.556,-114},{-140,-114}},color={0,0,255}));
            connect(OTSG.FW_in, sensT.outlet) annotation (Line(points={{-106.444,
                    -68.3333},{-100,-68.3333},{-100,-80},{-94,-80}},
                                                                color={0,0,255}));
            connect(sourceFW.flange, sensT.inlet) annotation (Line(points={{-12,-52},
                    {-12,-52},{-76,-52},{-80,-52},{-80,-80},{-82,-80}},
                                                                    color={0,0,255}));
            connect(sensT.T, pI.PV) annotation (Line(points={{-96,-90},{-100,-90},{
                    -100,-130},{-100,-134},{-202,-134},{-202,-133}},      color={0,
                    0,127}));
            connect(desuperheating_controller.signalBus, desuperheatingStation_4.signalBus)
              annotation (Line(
                points={{102,120},{109,120},{109,88}},
                color={255,204,51},
                thickness=0.5));
            connect(desuperheatingStation_4.FW_in, sourcePressure.flange)
              annotation (Line(points={{136,62},{146,62},{156,62}}, color={0,0,255}));
            connect(controllers.signalBus, signalBus) annotation (Line(
                points={{-179,-98},{-88,-98},{2,-98}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-179,-98},{-172,-98},{-172,-30},{-166.178,-30}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{2,-98},{2,-98},{2,-58}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%first",
                index=-1,
                extent={{-6,3},{-6,3}}));
            connect(valveLin1.inlet, sourceRH.flange)
              annotation (Line(points={{100,-110},{120,-110}}, color={0,0,255}));
            connect(ramp.y, add.u1) annotation (Line(points={{199,-60},{190,-60},{
                    190,-74},{182,-74}}, color={0,0,127}));
            connect(const1.y, add.u2) annotation (Line(points={{199,-90},{190,-90},
                    {190,-86},{182,-86}}, color={0,0,127}));
            connect(add.y, valveLin1.cmd) annotation (Line(points={{159,-80},{90,
                    -80},{90,-102}}, color={0,0,127}));
            connect(ramp.y, valveLin2.cmd) annotation (Line(points={{199,-60},{199,
                    -60},{90,-60},{90,-48}}, color={0,0,127}));
            connect(desuperheatingStation_4.SH_out, valveLin2.inlet) annotation (
                Line(points={{120.571,38},{120.571,-40},{100,-40}}, color={0,0,255}));
            connect(valveLin1.outlet, OTSG.RH_in) annotation (Line(points={{80,-110},
                    {60,-110},{60,-40},{42,-40},{-74,-40},{-74,6.66667},{-106.444,
                    6.66667}}, color={0,0,255}));
            connect(valveLin2.outlet, OTSG.RH_in) annotation (Line(points={{80,-40},
                    {-74,-40},{-74,6.66667},{-106.444,6.66667}}, color={0,0,255}));
            connect(ramp1.y, add1.u1) annotation (Line(points={{-35,30},{-32,30},{
                    -32,20},{-26,20}}, color={0,0,127}));
            connect(valveLin4.outlet, sinkSH.flange) annotation (Line(points={{14,
                    -20},{14,-20},{26,-20}}, color={0,0,255}));
            connect(OTSG.SH_out, valveLin3.inlet) annotation (Line(points={{
                    -120.444,21.6667},{-120.444,50},{20,50}}, color={0,0,255}));
            connect(valveLin3.outlet, desuperheatingStation_4.SH_in)
              annotation (Line(points={{40,50},{40,50},{82,50}}, color={0,0,255}));
            connect(OTSG.SH_out, valveLin4.inlet) annotation (Line(points={{
                    -120.444,21.6667},{-120.444,50},{-66,50},{-66,-20},{-6,-20}},
                  color={0,0,255}));
            connect(ramp2.y, add2.u1) annotation (Line(points={{-99,130},{-89,130},
                    {-89,116},{-82,116}}, color={0,0,127}));
            connect(const3.y, add2.u2)
              annotation (Line(points={{-99,104},{-82,104}}, color={0,0,127}));
            connect(add2.y, valveLin6.cmd) annotation (Line(points={{-59,110},{-40,
                    110},{-40,96}}, color={0,0,127}));
            connect(ramp2.y, valveLin5.cmd) annotation (Line(points={{-99,130},{-99,
                    130},{-40,130},{-40,140}}, color={0,0,127}));
            connect(valveLin6.outlet, sinkRH.flange) annotation (Line(points={{-30,
                    88},{-30,88},{-20,88}}, color={0,0,255}));
            connect(OTSG.RH_out, valveLin5.inlet) annotation (Line(points={{
                    -132.889,21.6667},{-132.889,148},{-50,148}}, color={0,0,255}));
            connect(OTSG.RH_out, valveLin6.inlet) annotation (Line(points={{
                    -132.889,21.6667},{-132.889,88},{-50,88}}, color={0,0,255}));
            connect(valveLin5.outlet, desuperheatingStation_4.RH_in) annotation (
                Line(points={{-30,148},{-30,148},{40,148},{40,74},{82,74}}, color={
                    0,0,255}));
            connect(sourceSH_p.flange, valveLin8.inlet) annotation (Line(points={{
                    68,-20},{68,-20},{72,-20},{72,-10},{72,4}}, color={0,0,255}));
            connect(valveLin7.outlet, sinkPressure.flange)
              annotation (Line(points={{160,-20},{180,-20}}, color={0,0,255}));
            connect(desuperheatingStation_4.SH_out, valveLin7.inlet) annotation (
                Line(points={{120.571,38},{120,38},{120,-16},{120,-20},{140,-20}},
                  color={0,0,255}));
            connect(valveLin8.outlet, desuperheatingStation_4.SH_in)
              annotation (Line(points={{72,24},{72,50},{82,50}}, color={0,0,255}));
            connect(valveLin.outlet, desuperheatingStation_4.RH_in) annotation (
                Line(points={{20,66},{40,66},{40,74},{82,74}}, color={0,0,255}));
            connect(sourceRH_p.flange, valveLin.inlet) annotation (Line(points={{
                    -20,66},{-10,66},{0,66}}, color={0,0,255}));
            connect(add1.y, valveLin8.cmd)
              annotation (Line(points={{-3,14},{64,14}}, color={0,0,127}));
            connect(const2.y, add1.u2) annotation (Line(points={{-35,-2},{-32,-2},{
                    -32,8},{-26,8}}, color={0,0,127}));
            connect(ramp1.y, valveLin3.cmd) annotation (Line(points={{-35,30},{30,
                    30},{30,42}}, color={0,0,127}));
            connect(add1.y, valveLin4.cmd)
              annotation (Line(points={{-3,14},{4,14},{4,-12}}, color={0,0,127}));
            connect(add.y, valveLin7.cmd) annotation (Line(points={{159,-80},{150,
                    -80},{150,-28}}, color={0,0,127}));
            connect(add2.y, valveLin.cmd) annotation (Line(points={{-59,110},{10,
                    110},{10,74}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-260,
                      -180},{260,180}})),                  Icon(coordinateSystem(
                    extent={{-260,-180},{260,180}}, preserveAspectRatio=false)));
          end test_OTSG_4des;
        end Old;
      end OTSG;

      package PreHeaters "Package containing all the pre-heaters train model"
        model Preheater_fixedLevel
          "Model of a feed water pre heater with ideal level control"
          extends BaseClasses.BaseFeedwaterHeater;

          //Desuperheating region parameters
          replaceable model HeatTransferCold_des =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          replaceable model HeatTransferHot_des =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          replaceable model HeatExchangerTopology_des =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          parameter Integer Nhex_des = 2
            "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Volume Vhot_des
            "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Volume Vcold_des
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Area Shot_des
            "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Area Scold_des
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
          final parameter Modelica.SIunits.Length L_des=1
            "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_des
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_des
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow_des
            "Nominal flow rate of hot fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_des
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_des
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalHotPressure_des
            "Nominal inlet pressure of hot fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalHotDeltaP_des
            "Nominal hot fluid pressure loss" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

          //Condensing region parameters
          parameter Integer Nhex_cond = 5
            "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Height H=Vhot_cond/A
            "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Height zl
            "Liquid level (ideally controlled)"                                    annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure" annotation (Dialog(tab="Condensing", group="Hot side"));
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction"
                                                                                 annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

          replaceable model HeatTransferCold_cond =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
          replaceable model HeatExchangerTopology_cond =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Volume Vcold_cond
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Area Scold_cond
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
          final parameter Modelica.SIunits.Length L_cond=1
            "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_cond
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_cond
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_cond
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_cond
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

          //Subcooling region parameters
          replaceable model HeatTransferCold_sub =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          replaceable model HeatTransferHot_sub =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          replaceable model HeatExchangerTopology_sub =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          parameter Integer Nhex_sub = 2
            "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Volume Vhot_sub
            "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Volume Vcold_sub
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Area Shot_sub
            "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Area Scold_sub
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
          final parameter Modelica.SIunits.Length L_sub=1
            "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_sub
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_sub
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow_sub
            "Nominal flow rate of hot fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_sub
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_sub
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalHotPressure_sub
            "Nominal inlet pressure of hot fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalHotDeltaP_sub
            "Nominal hot fluid pressure loss" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";

          //Controller parameters
          parameter Real Kv "Admittance of linear valve" annotation (Dialog(tab="Level controller"));
          parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
          parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
          //parameter Real PVmin "Minimum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          //parameter Real PVmax "Maximum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          //parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real CSstart=0.6 "Start value of CS" annotation (Dialog(tab="Level controller"));

          ThermoPower.Water.Flow1DFV des_FW(
            final N=Nhex_des,
            H=0,
            wnom=nominalColdFlow_des,
            pstart=nominalColdPressure_des,
            redeclare package Medium = Medium,
            L=L_des,
            dpnom=nominalColdDeltaP_des,
            rhonom=Medium.density_pT(nominalColdPressure_des,
                nominalColdInletTemperature_des),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_des,
                nominalColdInletTemperature_des),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_des -
                nominalColdDeltaP_des, nominalColdOutletTemperature_des),
            final A=Vcold_des/L_des,
            final omega=Scold_des/L_des,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_des,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,70})));
          ThermoPower.Water.Flow1DFV cond_FW(
            final N=Nhex_cond,
            H=0,
            wnom=nominalColdFlow_cond,
            pstart=nominalColdPressure_cond,
            redeclare package Medium = Medium,
            L=L_cond,
            dpnom=nominalColdDeltaP_cond,
            rhonom=Medium.density_pT(nominalColdPressure_cond,
                nominalColdInletTemperature_cond),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_cond,
                nominalColdInletTemperature_cond),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_cond -
                nominalColdDeltaP_cond, nominalColdOutletTemperature_cond),
            final A=Vcold_cond/L_cond,
            final omega=Scold_cond/L_cond,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_cond,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                               annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,20})));
          ThermoPower.Water.Flow1DFV sub_FW(
            final N=Nhex_sub,
            H=0,
            wnom=nominalColdFlow_sub,
            pstart=nominalColdPressure_sub,
            redeclare package Medium = Medium,
            L=L_sub,
            dpnom=nominalColdDeltaP_sub,
            rhonom=Medium.density_pT(nominalColdPressure_sub,
                nominalColdInletTemperature_sub),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_sub,
                nominalColdInletTemperature_sub),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_sub -
                nominalColdDeltaP_sub, nominalColdOutletTemperature_sub),
            final A=Vcold_sub/L_sub,
            final omega=Scold_sub/L_sub,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_sub,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,-30})));
          ThermoPower.Water.Flow1DFV2ph des_SP(
            N=Nhex_des,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure_des,
            redeclare package Medium = Medium,
            L=L_des,
            A=Vhot_des/L_des,
            omega=Shot_des/L_des,
            wnom=nominalHotFlow_des,
            dpnom=nominalHotDeltaP_des,
            rhonom=Medium.density_pT(nominalHotPressure_des,
                nominalHotInletTemperature_des),
            hstartin=Medium.specificEnthalpy_pT(nominalHotPressure_des,
                nominalHotInletTemperature_des),
            hstartout=Medium.specificEnthalpy_pT(nominalHotPressure_des -
                nominalHotDeltaP_des, nominalHotOutletTemperature_des),
            redeclare model HeatTransfer = HeatTransferHot_des,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-50,70})));
          ThermoPower.Water.Flow1DFV sub_SP(
            N=Nhex_sub,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure_sub,
            redeclare package Medium = Medium,
            L=L_sub,
            A=Vhot_sub/L_sub,
            omega=Shot_sub/L_sub,
            wnom=nominalHotFlow_sub,
            dpnom=nominalHotDeltaP_sub,
            rhonom=Medium.density_pT(nominalHotPressure_sub,
                nominalHotInletTemperature_sub),
            hstartin=Medium.specificEnthalpy_pT(nominalHotPressure_sub,
                nominalHotInletTemperature_sub),
            hstartout=Medium.specificEnthalpy_pT(nominalHotPressure_sub -
                nominalHotDeltaP_sub, nominalHotOutletTemperature_sub),
            redeclare model HeatTransfer = HeatTransferHot_sub,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-50,-30})));
          Components.NusseltCondenser_noLevel
                                       NusseltCondenser(
            V=Vhot_cond,
            A=A,
            S=Shot_cond,
            p_start=p_start,
            gamma=gamma,
            Nw=Nhex_cond - 1,
            zl=zl,
            allowFlowReversal=false)
            annotation (Placement(transformation(extent={{-82,-12},{-18,52}})));
          ThermoPower.Water.ValveLin        valveDrain(
            redeclare package Medium = Medium,
            Kv = Kv,
            allowFlowReversal=false)
                     annotation (
             Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={-50,-70})));

          ThermoPower.Thermal.MetalWallFV tubeWalls_des(
            final Nw=Nhex_des - 1,
            final M=Mm_des,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
            TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,70})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_des)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,70})));
          ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
            final Nw=Nhex_sub - 1,
            final M=Mm_sub,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
            TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,-30})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_sub)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,-30})));
          ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
            final Nw=Nhex_cond - 1,
            final M=Mm_cond,
            final cm=cm,
            TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
            Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
            initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,20})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_cond)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,20})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
            "Cold temperature vector (hot in the left side)";

          Modelica.Blocks.Sources.Constant const(k=1)
            annotation (Placement(transformation(extent={{-90,-80},{-70,-60}})));
        equation
          Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
          Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
          connect(des_SP.outfl, NusseltCondenser.steam_in) annotation (Line(
              points={{-50,60},{-50,47.4286}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sub_SP.infl, NusseltCondenser.drained_out) annotation (Line(
              points={{-50,-20},{-50,-0.571429}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(des_FW.infl, cond_FW.outfl) annotation (Line(
              points={{50,60},{50,30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
              points={{50,10},{50,-20}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
              points={{-50,-40},{-50,-60}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(ST_in, des_SP.infl) annotation (Line(
              points={{-50,100},{-50,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(FW_out, des_FW.outfl) annotation (Line(
              points={{50,100},{50,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
              points={{-100,0},{-100,29.1429},{-61.4286,29.1429}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sub_FW.infl, FW_in) annotation (Line(
              points={{50,-40},{50,-100}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valveDrain.outlet, DR_out) annotation (Line(
              points={{-50,-80},{-50,-100}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
              points={{-45,70},{-3.6,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
              points={{3.72,70},{21.59,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
              points={{28.3,70},{45,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
              points={{28.3,-30},{45,-30}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
              points={{-45,-30},{-3.6,-30}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
              points={{3.72,-30},{21.59,-30}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
              Line(
              points={{3.72,20},{21.59,20}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
              points={{45,20},{28.3,20}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                  -39.7143,20},{-39.7143,20},{-3.6,20}},
                                                color={255,127,0}));
          connect(valveDrain.cmd, const.y)
            annotation (Line(points={{-58,-70},{-64,-70},{-69,-70}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                    -100,-100},{100,100}})));
        end Preheater_fixedLevel;

        model Preheater_controlledLevel
          "Model of a feed water pre heater with level control"
          extends BaseClasses.BaseFeedwaterHeater;

          //Desuperheating region parameters
          replaceable model HeatTransferCold_des =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          replaceable model HeatTransferHot_des =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          replaceable model HeatExchangerTopology_des =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
          parameter Integer Nhex_des = 2
            "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Volume Vhot_des
            "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Volume Vcold_des
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Area Shot_des
            "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Area Scold_des
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
          final parameter Modelica.SIunits.Length L_des=1
            "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_des
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_des
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow_des
            "Nominal flow rate of hot fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_des
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_des
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalHotPressure_des
            "Nominal inlet pressure of hot fluid" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Pressure nominalHotDeltaP_des
            "Nominal hot fluid pressure loss" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

          //Condensing region parameters
          parameter Integer Nhex_cond = 5
            "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Height H=Vhot_cond/A
            "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure" annotation (Dialog(tab="Condensing", group="Hot side"));
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction"
                                                                                 annotation (Dialog(tab="Condensing", group="Hot side"));
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

          replaceable model HeatTransferCold_cond =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
          replaceable model HeatExchangerTopology_cond =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Volume Vcold_cond
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Area Scold_cond
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
          final parameter Modelica.SIunits.Length L_cond=1
            "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_cond
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_cond
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_cond
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_cond
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

          //Subcooling region parameters
          replaceable model HeatTransferCold_sub =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          replaceable model HeatTransferHot_sub =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          replaceable model HeatExchangerTopology_sub =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
          parameter Integer Nhex_sub = 2
            "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Volume Vhot_sub
            "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Volume Vcold_sub
            "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Area Shot_sub
            "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Area Scold_sub
            "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
          final parameter Modelica.SIunits.Length L_sub=1
            "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
          parameter Modelica.SIunits.Mass Mm_sub
            "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow_sub
            "Nominal flow rate of cold fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow_sub
            "Nominal flow rate of hot fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalColdPressure_sub
            "Nominal inlet pressure of cold fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalColdDeltaP_sub
            "Nominal cold fluid pressure loss" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalHotPressure_sub
            "Nominal inlet pressure of hot fluid" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Pressure nominalHotDeltaP_sub
            "Nominal hot fluid pressure loss" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
            "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
            "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";

          //Controller parameters
          parameter Real Kv "Admittance of linear valve" annotation (Dialog(tab="Level controller"));
          parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
          parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
          parameter Real PVmin "Minimum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVmax "Maximum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

          ThermoPower.Water.Flow1DFV des_FW(
            final N=Nhex_des,
            H=0,
            wnom=nominalColdFlow_des,
            pstart=nominalColdPressure_des,
            redeclare package Medium = Medium,
            L=L_des,
            dpnom=nominalColdDeltaP_des,
            rhonom=Medium.density_pT(nominalColdPressure_des,
                nominalColdInletTemperature_des),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_des,
                nominalColdInletTemperature_des),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_des -
                nominalColdDeltaP_des, nominalColdOutletTemperature_des),
            final A=Vcold_des/L_des,
            final omega=Scold_des/L_des,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_des,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,70})));
          ThermoPower.Water.Flow1DFV cond_FW(
            final N=Nhex_cond,
            H=0,
            wnom=nominalColdFlow_cond,
            pstart=nominalColdPressure_cond,
            redeclare package Medium = Medium,
            L=L_cond,
            dpnom=nominalColdDeltaP_cond,
            rhonom=Medium.density_pT(nominalColdPressure_cond,
                nominalColdInletTemperature_cond),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_cond,
                nominalColdInletTemperature_cond),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_cond -
                nominalColdDeltaP_cond, nominalColdOutletTemperature_cond),
            final A=Vcold_cond/L_cond,
            final omega=Scold_cond/L_cond,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_cond,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                               annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,20})));
          ThermoPower.Water.Flow1DFV sub_FW(
            final N=Nhex_sub,
            H=0,
            wnom=nominalColdFlow_sub,
            pstart=nominalColdPressure_sub,
            redeclare package Medium = Medium,
            L=L_sub,
            dpnom=nominalColdDeltaP_sub,
            rhonom=Medium.density_pT(nominalColdPressure_sub,
                nominalColdInletTemperature_sub),
            hstartin=Medium.specificEnthalpy_pT(nominalColdPressure_sub,
                nominalColdInletTemperature_sub),
            hstartout=Medium.specificEnthalpy_pT(nominalColdPressure_sub -
                nominalColdDeltaP_sub, nominalColdOutletTemperature_sub),
            final A=Vcold_sub/L_sub,
            final omega=Scold_sub/L_sub,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_sub,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={50,-40})));
          ThermoPower.Water.Flow1DFV2ph des_SP(
            N=Nhex_des,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure_des,
            redeclare package Medium = Medium,
            L=L_des,
            A=Vhot_des/L_des,
            omega=Shot_des/L_des,
            wnom=nominalHotFlow_des,
            dpnom=nominalHotDeltaP_des,
            rhonom=Medium.density_pT(nominalHotPressure_des,
                nominalHotInletTemperature_des),
            hstartin=Medium.specificEnthalpy_pT(nominalHotPressure_des,
                nominalHotInletTemperature_des),
            hstartout=Medium.specificEnthalpy_pT(nominalHotPressure_des -
                nominalHotDeltaP_des, nominalHotOutletTemperature_des),
            redeclare model HeatTransfer = HeatTransferHot_des,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-50,70})));
          ThermoPower.Water.Flow1DFV sub_SP(
            N=Nhex_sub,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure_sub,
            redeclare package Medium = Medium,
            L=L_sub,
            A=Vhot_sub/L_sub,
            omega=Shot_sub/L_sub,
            wnom=nominalHotFlow_sub,
            dpnom=nominalHotDeltaP_sub,
            rhonom=Medium.density_pT(nominalHotPressure_sub,
                nominalHotInletTemperature_sub),
            hstartin=Medium.specificEnthalpy_pT(nominalHotPressure_sub,
                nominalHotInletTemperature_sub),
            hstartout=Medium.specificEnthalpy_pT(nominalHotPressure_sub -
                nominalHotDeltaP_sub, nominalHotOutletTemperature_sub),
            redeclare model HeatTransfer = HeatTransferHot_sub,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true)                             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-50,-40})));
          Components.NusseltCondenser  NusseltCondenser(
            V=Vhot_cond,
            A=A,
            S=Shot_cond,
            zl_set=zl_set,
            zl_start=zl_start,
            p_start=p_start,
            gamma=gamma,
            Nw=Nhex_cond - 1,
            allowFlowReversal=false,
            noInitialPressure=true)
            annotation (Placement(transformation(extent={{-82,-12},{-18,52}})));
          ThermoPower.Water.ValveLin        valveDrain(
            redeclare package Medium = Medium,
            Kv = Kv,
            allowFlowReversal=false)
                     annotation (
             Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={-50,-70})));
          ThermoPower.PowerPlants.Control.PID PID_level(
          Kp=Kp,
          Ti=Ti,
          Td=Td,
          CSmin=CSmin,
          CSmax=CSmax,
            Nd=20,
            PVmax=PVmax,
            PVstart=PVstart,
            CSstart=CSstart,
            PVmin=PVmin,
            steadyStateInit=true,
            holdWhenSimplified=true)
                           annotation (Placement(
                transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={-76,-20})));

          Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
            initType=system.initOpt,
            y_start=CSstart)                                            annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-76,-50})));
          ThermoPower.Thermal.MetalWallFV tubeWalls_des(
            final Nw=Nhex_des - 1,
            final M=Mm_des,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
            TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,70})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_des)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,70})));
          ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
            final Nw=Nhex_sub - 1,
            final M=Mm_sub,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
            TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,-40})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_sub)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,-40})));
          ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
            final Nw=Nhex_cond - 1,
            final M=Mm_cond,
            final cm=cm,
            TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
            Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
            initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(
                extent={{-12,12},{12,-12}},
                rotation=-90,
                origin={0,20})));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology_cond)
            annotation (Placement(transformation(
                extent={{-12,-11},{12,11}},
                rotation=-90,
                origin={25,20})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
            "Cold temperature vector (hot in the left side)";

        equation
          Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
          Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
          connect(des_SP.outfl, NusseltCondenser.steam_in) annotation (Line(
              points={{-50,60},{-50,47.4286}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(des_FW.infl, cond_FW.outfl) annotation (Line(
              points={{50,60},{50,30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
              points={{50,10},{50,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
              points={{-50,-50},{-50,-60}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(ST_in, des_SP.infl) annotation (Line(
              points={{-50,100},{-50,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(FW_out, des_FW.outfl) annotation (Line(
              points={{50,100},{50,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
              points={{-100,0},{-100,29.1429},{-61.4286,29.1429}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sub_FW.infl, FW_in) annotation (Line(
              points={{50,-50},{50,-100}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valveDrain.outlet, DR_out) annotation (Line(
              points={{-50,-80},{-50,-100}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(NusseltCondenser.level, PID_level.PV) annotation (Line(
              points={{-61.4286,4},{-72,4},{-72,-10}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
              points={{-61.4286,17.7143},{-80,17.7143},{-80,-10}},
              color={0,0,127},
              smooth=Smooth.None));

          connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
              points={{-45,70},{-3.6,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
              points={{3.72,70},{21.59,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
              points={{28.3,70},{45,70}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
              points={{28.3,-40},{45,-40}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
              points={{-45,-40},{-3.6,-40}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
              points={{3.72,-40},{21.59,-40}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
              Line(
              points={{3.72,20},{21.59,20}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
              points={{45,20},{28.3,20}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(PID_level.CS, valveDynamic.u) annotation (Line(
              points={{-76,-30},{-76,-38}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(valveDynamic.y,   valveDrain.cmd)
            annotation (Line(points={{-76,-61},{-76,-70},{-58,-70}}, color={0,0,127}));
          connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                  -39.7143,20},{-39.7143,20},{-3.6,20}},
                                                color={255,127,0}));
          connect(NusseltCondenser.drained_out, sub_SP.infl) annotation (Line(
                points={{-50,-0.571429},{-50,-0.571429},{-50,-30}}, color={0,0,
                  255}));
          annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                    -100,-100},{100,100}})));
        end Preheater_controlledLevel;

        model Preheater_simplified
          "Simplified model of a feedwater pre-heater with \"fake\" level control"
          extends BaseClasses.BaseFeedwaterHeater;

          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Length D "Shell diameter";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";

          //Controller parameters
          parameter Real Kv "Valve coefficient" annotation (Dialog(tab="Level controller"));

          Components.HE HE(
            redeclare package coldMedium = Medium,
            redeclare package hotMedium = Medium,
            redeclare model HeatExchangerTopology = HeatExchangerTopology,
            Nhex=Nhex,
            Vhot=Vhot,
            Vcold=Vcold,
            Shot=Shot,
            Scold=Scold,
            Mm=Mm,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            nominalColdInletTemperature=nominalColdInletTemperature,
            nominalColdOutletTemperature=nominalColdOutletTemperature,
            nominalHotInletTemperature=nominalHotInletTemperature,
            nominalHotOutletTemperature=nominalHotOutletTemperature,
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot) annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={20,40})));

          ThermoPower.Water.FlowJoin flowJoin
            annotation (Placement(transformation(extent={{-54,70},{-34,90}})));

          ThermoPower.Water.ValveLin valveLin(
            redeclare package Medium=Medium,
            Kv=Kv) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={20,-40})));
          Modelica.Blocks.Sources.Constant cmd(k=1)
            annotation (Placement(transformation(extent={{-20,-50},{0,-30}})));
        equation

          connect(ST_in, flowJoin.in1) annotation (Line(
              points={{-50,100},{-50,84}},
              smooth=Smooth.None,
              thickness=0.5,
              color={255,0,0}));
          connect(DR_in, flowJoin.in2) annotation (Line(
              points={{-100,0},{-100,76},{-50,76}},
              smooth=Smooth.None,
              thickness=0.5,
              color={255,0,0}));
          connect(flowJoin.out, HE.inletHot) annotation (Line(
              points={{-38,80},{20,80},{20,60}},
              smooth=Smooth.None,
              thickness=0.5,
              color={255,0,0}));
          connect(HE.outletCold, FW_out) annotation (Line(
              points={{40,40},{50,40},{50,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(HE.inletCold, FW_in) annotation (Line(
              points={{3.55271e-015,40},{-20,40},{-20,0},{50,0},{50,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(valveLin.outlet, DR_out) annotation (Line(
              points={{20,-50},{20,-100},{-50,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(valveLin.inlet, HE.outletHot) annotation (Line(
              points={{20,-30},{20,20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(cmd.y, valveLin.cmd)
            annotation (Line(points={{1,-40},{6.5,-40},{12,-40}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})));
        end Preheater_simplified;

        model Preheater_quasiStatic
          extends BaseClasses.BaseFeedwaterHeater_noOpt;

          parameter Modelica.SIunits.Volume V_cold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area A "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer U
            "Overall heat transfer coefficient";

          Modelica.SIunits.Power Q_hot "Thermal power exchanged, hot side";
          Modelica.SIunits.Power Q_cold "Thermal power exchanged, cold side";
          Medium.ThermodynamicState FW_in_state
            "Thermodynamic state of the inlet feedwater";
          Medium.ThermodynamicState FW_out_state
            "Thermodynamic state of the outlet feedwater";
          Medium.ThermodynamicState DR_in_state
            "Thermodynamic state of the inlet drained flow";
          Medium.ThermodynamicState ST_in_state
            "Thermodynamic state of the inlet steam flow";
          Medium.ThermodynamicState MIX_in_state
            "Thermodynamic state of the inlet mix of drained flow and steam";
          Medium.ThermodynamicState DR_out_state
            "Thermodynamic state of the outlet drained flow";
          Medium.MassFlowRate w_FW_in "Feedwater inlet mass flow rate";
          Medium.MassFlowRate w_FW_out "Feedwater outet mass flow rate";
          Medium.MassFlowRate w_ST_in "Steam inlet mass flow rate";
          Medium.MassFlowRate w_DR_in "Drained inlet mass flow rate";
          Medium.MassFlowRate w_DR_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_MIX "Mixed inlet mass flow rate";
          Medium.Density rho_FW "Feedwater density";
          Medium.SpecificHeatCapacity cp_FW "Feedwater heat capacity";
          Real x_MIX "Vapour quality at steam inlet";
          Medium.AbsolutePressure p_SP "Steam pressure";
          Medium.AbsolutePressure p_FW "Feedwater pressure";
          Medium.Temperature T_MIX "Mix inlet temperature temperature";
          Medium.Temperature T_DR_out "Drained outlet temperature";
          Medium.Temperature T_DR_in "Drained inlet temperature";
          Medium.Temperature T_ST_in "Steam inlet temperature";
          Medium.Temperature T_FW_in "Feedwater inlet temperature";
          Medium.Temperature T_FW_out "Feedwater outlet temperature";
          Medium.SpecificEnthalpy h_ST_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy h_DR_in "Drained inlet specific enthalpy";
          Medium.SpecificEnthalpy h_DR_out "Drained outlet specific enthalpy";
          Medium.SpecificEnthalpy h_FW_in "Feedwater inlet specific enthalpy";
          Medium.SpecificEnthalpy h_FW_out "Feedwater outlet specific enthalpy";
          Medium.SpecificEnthalpy h_MIX "Mixed specific enthalpy";
          Medium.Temperature DT_m "Mean temperature difference";

        equation
          //Mixing inlet equation
          w_MIX = w_ST_in + w_DR_in;
          h_MIX = (w_DR_in*h_DR_in + w_ST_in*h_ST_in)/w_MIX;

          //Mass balances
          w_FW_in - w_FW_out = 0;
          w_MIX - w_DR_out = 0;

          //Energy balances
          Q_hot = w_MIX*(h_MIX - h_DR_out);
          Q_cold = w_FW_in*(h_FW_out - h_FW_in);
          V_cold*rho_FW*cp_FW*der(T_FW_out) = Q_hot - Q_cold;
          DT_m = (T_MIX + T_DR_out)/2 - (T_FW_out + T_FW_in)/2;
          Q_hot = U*A*DT_m;

          //Thermodynamic state definition
          FW_in_state = Medium.setState_ph(p_FW,h_FW_in);
          FW_out_state = Medium.setState_ph(p_FW,h_FW_out);
          MIX_in_state = Medium.setState_ph(p_SP,h_MIX);
          DR_out_state = Medium.setState_ph(p_SP,h_DR_out);
          DR_in_state = Medium.setState_ph(p_SP,h_DR_in);
          ST_in_state = Medium.setState_ph(p_SP,h_ST_in);
          x_MIX = Medium.vapourQuality(MIX_in_state);
          rho_FW = Medium.density(FW_out_state);
          cp_FW = Medium.specificHeatCapacityCp(FW_out_state);
          T_MIX = Medium.temperature(MIX_in_state);
          T_DR_out = Medium.temperature(DR_out_state);
          T_FW_in = Medium.temperature(FW_in_state);
          T_DR_in = Medium.temperature(DR_in_state);
          T_ST_in = Medium.temperature(ST_in_state);
          T_FW_out = Medium.temperature(FW_out_state);

          //Boundary conditions
          w_FW_in = FW_in.m_flow;
          w_FW_out = -FW_out.m_flow;
          w_DR_in = DR_in.m_flow;
          w_ST_in = ST_in.m_flow;
          w_DR_out = -DR_out.m_flow;

          FW_in.p = p_FW;
          FW_out.p = p_FW;
          ST_in.p = p_SP;
          DR_in.p = p_SP;
          DR_out.p = p_SP;

          h_FW_in = inStream(FW_in.h_outflow);
          h_DR_in = inStream(DR_in.h_outflow);
          h_ST_in = inStream(ST_in.h_outflow);
          DR_out.h_outflow = h_DR_out;
          FW_out.h_outflow = h_FW_out;
          FW_in.h_outflow = inStream(FW_out.h_outflow);
          ST_in.h_outflow = inStream(DR_out.h_outflow);
          DR_in.h_outflow = inStream(DR_out.h_outflow);

        end Preheater_quasiStatic;

        model HPH_train_fixedLevel "Model of the high pressure feedwater train"
          extends BaseClasses.BaseHPHTrain;
          ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium =
                Medium, w0=88.59,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{160,10},{140,-10}})));
          ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
            redeclare package Medium = Medium,
            w0=143.1,
            use_in_w0=true)  annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={40,-60})));
          ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{22,-14},{2,6}})));
          ThermoPower.Water.SensT sensT(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Medium,
            h=3218000,
            w0=0)
            annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
          ThermoPower.Water.ValveLin valve_bypass(redeclare package Medium =
                Medium, Kv=6.67826087e-4)
            annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          ThermoPower.Water.PressDrop DPSteamHPH1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=240000,
            rhonom=867.7)
            annotation (Placement(transformation(extent={{52,-10},{32,10}})));
          ThermoPower.Water.PressDrop DPSteamHPH2(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=78.07,
            dpnom=230000,
            rhonom=744.3)
            annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{90,-124},{130,-84}})));
          Preheater_fixedLevel      HPH2(
            redeclare model HeatTransferCold_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            redeclare model HeatTransferHot_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.8),
            Vhot_des=2.99*0.1,
            Vcold_des=0.53*0.1,
            Shot_des=210*0.1,
            Scold_des=210*0.1,
            Mm_des=10000*0.1,
            nominalColdFlow_des=78.07,
            nominalHotFlow_des=4.019,
            nominalColdDeltaP_des=0,
            nominalHotDeltaP_des=0,
            Vhot_cond=2.99*0.8,
            A=1,
            Shot_cond=210*0.8,
            gamma=7950,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            redeclare model HeatTransferCold_cond =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            Scold_cond=210*0.8,
            Mm_cond=10000*0.8,
            nominalColdFlow_cond=78.07,
            nominalColdDeltaP_cond=0,
            redeclare model HeatTransferCold_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            redeclare model HeatTransferHot_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.8),
            Vhot_sub=2.99*0.1,
            Vcold_sub=0.53*0.1,
            Shot_sub=210*0.1,
            Scold_sub=210*0.1,
            Mm_sub=10000*0.1,
            nominalColdFlow_sub=78.07,
            nominalHotFlow_sub=4.019,
            nominalColdDeltaP_sub=0,
            nominalHotDeltaP_sub=0,
            cm=500,
            Ti=10,
            Td=0,
            Ta=0.3,
            Nd=20,
            CSmin=0,
            CSmax=1,
            NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
            Vcold_cond=0.53*0.8,
            Kp=-171.12,
            CSstart=0.2,
            redeclare model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow,
            zl=0.1,
            Kv=6.575589005e-7,
            Nhex_cond=6,
            Nhex_des=4,
            Nhex_sub=4,
            nominalColdPressure_des=17910000,
            nominalHotPressure_des=8149000,
            nominalColdInletTemperature_des=561.15,
            nominalColdOutletTemperature_des=566.15,
            nominalHotInletTemperature_des=702.15,
            nominalHotOutletTemperature_des=569.65,
            p_start=8149000,
            nominalColdPressure_cond=17910000,
            nominalColdInletTemperature_cond=547.15,
            nominalColdOutletTemperature_cond=561.15,
            nominalColdPressure_sub=17910000,
            nominalHotPressure_sub=8149000,
            nominalColdInletTemperature_sub=546.15,
            nominalColdOutletTemperature_sub=547.15,
            nominalHotInletTemperature_sub=569.15,
            nominalHotOutletTemperature_sub=551.15)
            annotation (Placement(transformation(extent={{-70,-20},{-30,20}})));

          Preheater_fixedLevel      HPH1(
            Vcold_des=0.53*0.1,
            nominalColdDeltaP_des=0,
            nominalHotDeltaP_des=0,
            A=1,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            nominalColdDeltaP_cond=0,
            Vcold_sub=0.53*0.1,
            nominalColdDeltaP_sub=0,
            nominalHotDeltaP_sub=0,
            cm=500,
            Ti=10,
            Td=0,
            Ta=0.3,
            Nd=20,
            CSmin=0,
            CSmax=1,
            NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
            redeclare model HeatTransferCold_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            redeclare model HeatTransferHot_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.8),
            Vhot_des=2.01*0.1,
            Shot_des=205*0.067,
            Scold_des=205*0.067,
            Mm_des=7500*0.05,
            nominalColdFlow_des=88.59,
            nominalHotFlow_des=3.71,
            Vhot_cond=2.01*0.8,
            Shot_cond=205*0.8,
            gamma=8000,
            redeclare model HeatTransferCold_cond =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            Vcold_cond=0.53*0.8,
            Scold_cond=205*0.8,
            Mm_cond=7500*0.8,
            nominalColdFlow_cond=88.59,
            redeclare model HeatTransferCold_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            redeclare model HeatTransferHot_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4500),
            Vhot_sub=2.01*0.1,
            Shot_sub=205*0.15,
            Scold_sub=205*0.15,
            Mm_sub=7500*0.15,
            nominalColdFlow_sub=88.59,
            nominalHotFlow_sub=7.73,
            Kp=-103.9,
            CSstart=0.2,
            zl=0.1,
            Kv=6.798592788e-6,
            Nhex_cond=6,
            Nhex_des=4,
            Nhex_sub=10,
            nominalColdPressure_des=18380000,
            nominalHotPressure_des=2037000,
            nominalColdInletTemperature_des=476.25,
            nominalColdOutletTemperature_des=481.15,
            nominalHotInletTemperature_des=705.45,
            nominalHotOutletTemperature_des=486.55,
            p_start=2037000,
            nominalColdPressure_cond=18380000,
            nominalColdInletTemperature_cond=454.95,
            nominalColdOutletTemperature_cond=476.25,
            nominalColdPressure_sub=18380000,
            nominalHotPressure_sub=2037000,
            nominalColdInletTemperature_sub=452.35,
            nominalColdOutletTemperature_sub=454.95,
            nominalHotInletTemperature_sub=486.15,
            nominalHotOutletTemperature_sub=457.15)
            annotation (Placement(transformation(extent={{70,-20},{110,20}})));

        equation
          connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
              points={{40,-110},{40,-70}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
              points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(SEP_in, sensT.inlet) annotation (Line(
              points={{-120,110},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sensT.outlet, FW_out) annotation (Line(
              points={{-152,0},{-190,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_bypass.inlet, flowJoin.out) annotation (Line(
              points={{-40,-48},{0,-48},{0,-4},{6,-4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_bypass.outlet, sensT.inlet) annotation (Line(
              points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
              points={{18,0},{32,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
              points={{-100,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
              points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
              color={255,204,51},
              thickness=0.5));
          connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
          connect(HPH1.FW_in, pump_FW.outlet)
            annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
          connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
              points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
              color={255,204,51},
              thickness=0.5));
          connect(DPSteamHPH1.inlet, HPH1.FW_out)
            annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
          connect(flowJoin.out, HPH2.FW_in) annotation (Line(points={{6,-4},{0,-4},
                  {0,0},{-28,0}}, color={0,0,255}));
          connect(DPSteamHPH2.inlet, HPH2.FW_out)
            annotation (Line(points={{-80,0},{-70,0}}, color={0,0,255}));
          connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points={
                  {-80,40},{-64,40},{-64,20}}, color={0,127,0}));
          connect(SP1, HPH2.ST_in)
            annotation (Line(points={{-50,110},{-50,20}}, color={0,127,0}));
          connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                  -50,-30},{-12,-30},{-12,40},{76,40},{76,20}}, color={0,127,0}));
          connect(SP2, HPH1.ST_in)
            annotation (Line(points={{90,110},{90,20}}, color={0,127,0}));
          connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,-20},
                  {90,-60},{190,-60}}, color={0,127,0}));
          connect(signalBus.valveBP_CS, valve_bypass.cmd) annotation (Line(
              points={{110,-104},{110,-80},{-50,-80},{-50,-56}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -100},{180,100}})));
        end HPH_train_fixedLevel;

        model HPH_train_controlledLevel
          "Model of the high pressure feedwater train with level controllers"
          extends BaseClasses.BaseHPHTrain;
          ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium =
                Medium, w0=88.59,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{160,10},{140,-10}})));
          ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
            redeclare package Medium = Medium,
            w0=143.1,
            use_in_w0=true)  annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={40,-60})));
          ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{22,-14},{2,6}})));
          ThermoPower.Water.SensT sensT(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Medium,
            h=3218000,
            w0=0)
            annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
          ThermoPower.Water.ValveLin valve_bypass(redeclare package Medium =
                Medium, Kv=6.67826087e-4)
            annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          ThermoPower.Water.PressDrop DPSteamHPH1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=240000,
            rhonom=867.7)
            annotation (Placement(transformation(extent={{52,-10},{32,10}})));
          ThermoPower.Water.PressDrop DPSteamHPH2(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=78.07,
            dpnom=230000,
            rhonom=744.3)
            annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{90,-124},{130,-84}})));
          Preheater_controlledLevel HPH2(
            redeclare model HeatTransferCold_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            redeclare model HeatTransferHot_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.8),
            Vhot_des=2.99*0.1,
            Vcold_des=0.53*0.1,
            Shot_des=210*0.1,
            Scold_des=210*0.1,
            Mm_des=10000*0.1,
            nominalColdFlow_des=78.07,
            nominalHotFlow_des=4.019,
            nominalColdDeltaP_des=0,
            nominalHotDeltaP_des=0,
            Vhot_cond=2.99*0.8,
            A=1,
            Shot_cond=210*0.8,
            gamma=7950,
            zl_set=0.1,
            zl_start=0.1,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            redeclare model HeatTransferCold_cond =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            Scold_cond=210*0.8,
            Mm_cond=10000*0.8,
            nominalColdFlow_cond=78.07,
            nominalColdDeltaP_cond=0,
            redeclare model HeatTransferCold_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3600, alpha=0.8),
            redeclare model HeatTransferHot_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3000, alpha=0.8),
            Vhot_sub=2.99*0.1,
            Vcold_sub=0.53*0.1,
            Shot_sub=210*0.1,
            Scold_sub=210*0.1,
            Mm_sub=10000*0.1,
            nominalColdFlow_sub=78.07,
            nominalHotFlow_sub=4.019,
            nominalColdDeltaP_sub=0,
            cm=500,
            Ti=10,
            Td=0,
            Ta=0.3,
            Nd=20,
            CSmin=0,
            CSmax=1,
            Nhex_des=3,
            Nhex_cond=3,
            Vcold_cond=0.53*0.8,
            Nhex_sub=5,
            Kp=-171.12,
            Kv=6.575589005e-7/0.2,
            CSstart=0.2,
            redeclare model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow,
            PVmin=0,
            PVstart=0.1,
            PVmax=1,
            nominalColdPressure_des=17910000,
            nominalHotPressure_des=8149000,
            nominalColdInletTemperature_des=561.15,
            nominalColdOutletTemperature_des=566.15,
            nominalHotInletTemperature_des=702.15,
            nominalHotOutletTemperature_des=569.65,
            p_start=8149000,
            nominalColdPressure_cond=17910000,
            nominalColdInletTemperature_cond=547.15,
            nominalColdOutletTemperature_cond=561.15,
            nominalColdPressure_sub=17910000,
            nominalHotPressure_sub=8149000,
            nominalHotDeltaP_sub=100000,
            nominalColdInletTemperature_sub=546.15,
            nominalColdOutletTemperature_sub=547.15,
            nominalHotInletTemperature_sub=569.15,
            nominalHotOutletTemperature_sub=551.15)
            annotation (Placement(transformation(extent={{-70,-20},{-30,20}})));

          Preheater_controlledLevel HPH1(
            Vcold_des=0.53*0.1,
            nominalColdDeltaP_des=0,
            nominalHotDeltaP_des=0,
            A=1,
            zl_set=0.1,
            zl_start=0.1,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            nominalColdDeltaP_cond=0,
            Vcold_sub=0.53*0.1,
            nominalColdDeltaP_sub=0,
            cm=500,
            Ti=10,
            Td=0,
            Ta=0.3,
            Nd=20,
            CSmin=0,
            CSmax=1,
            Nhex_des=3,
            Nhex_cond=3,
            redeclare model HeatTransferCold_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            redeclare model HeatTransferHot_des =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.8),
            Vhot_des=2.01*0.1,
            Shot_des=205*0.067,
            Scold_des=205*0.067,
            Mm_des=7500*0.05,
            nominalColdFlow_des=88.59,
            nominalHotFlow_des=3.71,
            Vhot_cond=2.01*0.8,
            Shot_cond=205*0.8,
            gamma=8000,
            redeclare model HeatTransferCold_cond =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            Vcold_cond=0.53*0.8,
            Scold_cond=205*0.8,
            Mm_cond=7500*0.8,
            nominalColdFlow_cond=88.59,
            redeclare model HeatTransferCold_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4000),
            redeclare model HeatTransferHot_sub =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4500),
            Vhot_sub=2.01*0.1,
            Shot_sub=205*0.15,
            Scold_sub=205*0.15,
            Mm_sub=7500*0.15,
            nominalColdFlow_sub=88.59,
            nominalHotFlow_sub=7.73,
            Nhex_sub=5,
            Kp=-103.9,
            Kv=6.798592788e-6/0.2,
            CSstart=0.2,
            PVmin=0,
            PVmax=1,
            PVstart=0.1,
            nominalColdPressure_des=18380000,
            nominalHotPressure_des=2037000,
            nominalColdInletTemperature_des=476.25,
            nominalColdOutletTemperature_des=481.15,
            nominalHotInletTemperature_des=705.45,
            nominalHotOutletTemperature_des=486.55,
            p_start=2037000,
            nominalColdPressure_cond=18380000,
            nominalColdInletTemperature_cond=454.95,
            nominalColdOutletTemperature_cond=476.25,
            nominalColdPressure_sub=18380000,
            nominalHotPressure_sub=2037000,
            nominalHotDeltaP_sub=100000,
            nominalColdInletTemperature_sub=452.35,
            nominalColdOutletTemperature_sub=454.95,
            nominalHotInletTemperature_sub=486.15,
            nominalHotOutletTemperature_sub=457.15)
            annotation (Placement(transformation(extent={{70,-20},{110,20}})));

        equation
          connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
              points={{40,-110},{40,-70}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
              points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(SEP_in, sensT.inlet) annotation (Line(
              points={{-120,110},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sensT.outlet, FW_out) annotation (Line(
              points={{-152,0},{-190,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_bypass.inlet, flowJoin.out) annotation (Line(
              points={{-40,-48},{0,-48},{0,-4},{6,-4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_bypass.outlet, sensT.inlet) annotation (Line(
              points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
              points={{18,0},{32,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
              points={{-100,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
              points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
              color={255,204,51},
              thickness=0.5));
          connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
          connect(HPH1.FW_in, pump_FW.outlet)
            annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
          connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
              points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
              color={255,204,51},
              thickness=0.5));
          connect(DPSteamHPH1.inlet, HPH1.FW_out)
            annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
          connect(flowJoin.out, HPH2.FW_in) annotation (Line(points={{6,-4},{0,-4},
                  {0,0},{-28,0}}, color={0,0,255}));
          connect(DPSteamHPH2.inlet, HPH2.FW_out)
            annotation (Line(points={{-80,0},{-70,0}}, color={0,0,255}));
          connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points={
                  {-80,40},{-64,40},{-64,20}}, color={0,127,0}));
          connect(SP1, HPH2.ST_in)
            annotation (Line(points={{-50,110},{-50,20}}, color={0,127,0}));
          connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                  -50,-30},{-12,-30},{-12,40},{76,40},{76,20}}, color={0,127,0}));
          connect(SP2, HPH1.ST_in)
            annotation (Line(points={{90,110},{90,20}}, color={0,127,0}));
          connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,-20},
                  {90,-60},{190,-60}}, color={0,127,0}));
          connect(signalBus.valveBP_CS, valve_bypass.cmd) annotation (Line(
              points={{110,-104},{110,-80},{-50,-80},{-50,-56}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -100},{180,100}})));
        end HPH_train_controlledLevel;

        model HPH_train_simplified "Model of the high pressure feedwater train"
          extends BaseClasses.BaseHPHTrain;
          Preheater_simplified      HPH1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package Medium = Medium,
            use_drainIN=true,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            D=0.6,
            Vhot=2.01,
            Vcold=0.56,
            Mm=7500,
            nominalColdFlow=88.59,
            nominalHotFlow=7.728,
            Kv=6.796833773e-6,
            Shot=315,
            Scold=315,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4800),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=4800),
            Nhex=10,
            nominalColdPressure=18380000,
            nominalHotPressure=2037000,
            nominalColdInletTemperature=452.35,
            nominalColdOutletTemperature=481.15,
            nominalHotInletTemperature=487.15,
            nominalHotOutletTemperature=457.35,
            HE(
              tubeWalls(Tvolstart(displayUnit="K") = {463.187,472.824,475.497,
                  477.639,479.357,480.737,481.847,482.74,483.459}),
              coldFluid(hstart={768600,785513,811374,832165,848897,862371,873228,
                    881983,889043,894741}),
              hotFluid(noInitialPressure=false, hstart={2.22994e+006,2.16463e+006,
                    2.08368e+006,1.98333e+006,1.85886e+006,1.7044e+006,
                    1.5126e+006,1.27426e+006,977805,783922})))
            annotation (Placement(transformation(extent={{70,-20},{110,20}})));
          Preheater_simplified      HPH2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package Medium = Medium,
            use_drainIN=true,
            Vhot=2.99,
            Vcold=0.53,
            Mm=10000,
            nominalColdFlow=78.07,
            nominalHotFlow=4.019,
            Kv=6.575589005E-7,
            D=0.4,
            Shot=200,
            Scold=200,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=3680),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.8, gamma_nom=3680),
            Nhex=10,
            HE(
              hotFluid(hstart={3.218e+006,2.46938e+006,2.35638e+006,2.2311e+006,
                    2.09215e+006,1.93795e+006,1.76677e+006,1.57664e+006,
                    1.36534e+006,1.22703e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {553.669,559.073,560.109,
                  561.037,561.869,562.615,563.285,563.887,599.424}),
              coldFluid(hstart={1.197e+006,1.20412e+006,1.215e+006,1.22479e+006,
                    1.2336e+006,1.24154e+006,1.24869e+006,1.25514e+006,
                    1.26096e+006,1.29949e+006})),
            nominalColdPressure=18140000,
            nominalHotPressure=8149000,
            nominalColdInletTemperature=546.25,
            nominalColdOutletTemperature=566.45,
            nominalHotInletTemperature=702.25,
            nominalHotOutletTemperature=551.25)
            annotation (Placement(transformation(extent={{-70,-20},{-30,20}})));
          ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium =
                Medium, w0=88.59,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{160,10},{140,-10}})));
          ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
            redeclare package Medium = Medium,
            w0=143.1,
            use_in_w0=true)  annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={40,-60})));
          ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{22,-14},{2,6}})));
          ThermoPower.Water.SensT sensT(redeclare package Medium =
                       Medium)
            annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Medium,
            h=3218000,
            w0=0)
            annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
          ThermoPower.Water.ValveLin valve_bypass(redeclare package Medium =
                Medium, Kv=6.67826087e-4)
            annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          ThermoPower.Water.PressDrop DPSteamHPH1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=240000,
            rhonom=867.7)
            annotation (Placement(transformation(extent={{52,-10},{32,10}})));
          ThermoPower.Water.PressDrop DPSteamHPH2(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=78.07,
            dpnom=230000,
            rhonom=744.3)
            annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{90,-124},{130,-84}})));
          Modelica.Blocks.Sources.Constant const(k=1)
            annotation (Placement(transformation(extent={{-80,-80},{-60,-60}})));
        equation
          connect(SP1, HPH2.ST_in) annotation (Line(
              points={{-50,110},{-50,20}},
              color={0,127,0},
              smooth=Smooth.None));
          connect(SP2, HPH1.ST_in) annotation (Line(
              points={{90,110},{90,20}},
              color={0,127,0},
              smooth=Smooth.None));
          connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
              points={{40,-110},{40,-70}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
              points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flowJoin.out, HPH2.FW_in) annotation (Line(
              points={{6,-4},{0,-4},{0,0},{-28,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(SEP_in, sensT.inlet) annotation (Line(
              points={{-120,110},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sensT.outlet, FW_out) annotation (Line(
              points={{-152,0},{-190,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(
              points={{-80,40},{-64,40},{-64,20}},
              color={0,127,0},
              smooth=Smooth.None));
          connect(HPH1.DR_out, DR_out) annotation (Line(
              points={{90,-20},{90,-60},{190,-60}},
              color={0,127,0},
              smooth=Smooth.None));
          connect(valve_bypass.inlet, flowJoin.out) annotation (Line(
              points={{-40,-48},{0,-48},{0,-4},{6,-4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_bypass.outlet, sensT.inlet) annotation (Line(
              points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(
              points={{-50,-20},{-50,-30},{-10,-30},{-10,32},{76,32},{76,20}},
              color={0,127,0},
              smooth=Smooth.None));
          connect(HPH1.FW_out, DPSteamHPH1.inlet) annotation (Line(
              points={{70,0},{52,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
              points={{18,0},{32,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(HPH2.FW_out, DPSteamHPH2.inlet) annotation (Line(
              points={{-70,0},{-80,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
              points={{-100,0},{-140,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
              points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
              color={255,204,51},
              thickness=0.5));
          connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
          connect(HPH1.FW_in, pump_FW.outlet)  annotation (Line(points={{112,0},{126,0},{140,0}}, color={0,0,255}));
          connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
              points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
              color={255,204,51},
              thickness=0.5), Text(
              string="%first",
              index=-1,
              extent={{-6,3},{-6,3}}));
          connect(const.y, valve_bypass.cmd) annotation (Line(points={{-59,-70},{
                  -50,-70},{-50,-56}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -100},{180,100}})));
        end HPH_train_simplified;

        model LPH_train
          extends BaseClasses.BaseLPHTrain;
          ThermoPower.Water.SourceMassFlow sourceMassFlow(
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{130,-30},{110,-50}})));
          Modelica.Blocks.Sources.RealExpression w_pump(y=LPH1.w_DR_out)
            annotation (Placement(transformation(extent={{150,-70},{130,-50}})));
          Modelica.Blocks.Sources.RealExpression h_pump(y=LPH1.h_DR_out)
            annotation (Placement(transformation(extent={{150,-90},{130,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Medium, p0=38070)
            annotation (Placement(transformation(extent={{180,-50},{200,-30}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Medium,
            h=540000,
            w0=0)
            annotation (Placement(transformation(extent={{-220,30},{-200,50}})));
          ThermoPower.Water.PressDrop pressDrop(
            redeclare package Medium = Medium,
            wnom=64.26,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=150000,
            rhonom=990.1)
            annotation (Placement(transformation(extent={{130,-10},{110,10}})));
          ThermoPower.Water.PressDrop pressDrop1(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=77.31,
            dpnom=166000,
            rhonom=977.1)
            annotation (Placement(transformation(extent={{20,-10},{0,10}})));
          ThermoPower.Water.PressDrop pressDrop2(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=77.31,
            rhonom=960.6,
            dpnom=147000)
            annotation (Placement(transformation(extent={{-90,-10},{-110,10}})));
          ThermoPower.Water.PressDrop pressDrop3(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=77.31,
            dpnom=228000,
            rhonom=940.7)
            annotation (Placement(transformation(extent={{-200,-10},{-220,10}})));
          Preheater_quasiStatic LPH4(
            redeclare package Medium = Medium,
            V_cold=0.5,
            A=313,
            U=495,
            T_FW_out(start=422, fixed=true))
            annotation (Placement(transformation(extent={{-190,-20},{-150,20}})));
          Preheater_quasiStatic LPH2(
            redeclare package Medium = Medium,
            V_cold=0.75,
            A=405.4,
            U=2250,
            T_FW_out(start=370.75, fixed=true))
            annotation (Placement(transformation(extent={{30,-20},{70,20}})));
          Preheater_quasiStatic LPH3(
            redeclare package Medium = Medium,
            V_cold=0.7,
            A=320,
            U=6600,
            T_FW_out(start=396.65, fixed=true))
            annotation (Placement(transformation(extent={{-80,-20},{-40,20}})));
          Preheater_quasiStatic LPH1(
            redeclare package Medium = Medium,
            V_cold=0.7,
            U=1537,
            A=320,
            h_DR_out(start=3e5, fixed=false),
            T_DR_out(start=345.35, fixed=false),
            T_FW_out(start=345.35, fixed=true),
            DT_m(start=59, fixed=false))
            annotation (Placement(transformation(extent={{140,-20},{180,20}})));
          ThermoPower.Water.ValveLin valveLin43(
            redeclare package Medium = Medium,
            Kv=1.328818661e-5/cmd.k)
            annotation (Placement(transformation(extent={{-120,30},{-100,50}})));
          ThermoPower.Water.ValveLin valveLin32(
            redeclare package Medium = Medium,
            Kv=4.951971326e-5/cmd.k)
            annotation (Placement(transformation(extent={{-10,30},{10,50}})));

          ThermoPower.Water.ValveLin valveLin21(
            redeclare package Medium = Medium,
            Kv=1.542106068e-4/cmd.k)
            annotation (Placement(transformation(extent={{100,30},{120,50}})));
          Modelica.Blocks.Sources.Constant cmd(k=0.6)
            annotation (Placement(transformation(extent={{-150,60},{-130,80}})));
        equation
          connect(h_pump.y,sourceMassFlow. in_h) annotation (Line(
              points={{129,-80},{116,-80},{116,-46}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(w_pump.y,sourceMassFlow. in_w0) annotation (Line(
              points={{129,-60},{124,-60},{124,-46}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(FW_out, pressDrop3.outlet) annotation (Line(
              points={{-250,0},{-220,0}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(pressDrop3.inlet, LPH4.FW_out)
            annotation (Line(points={{-200,0},{-200,0},{-190,0}}, color={0,0,255}));
          connect(sourceMassFlow_DR.flange, LPH4.DR_in)
            annotation (Line(points={{-200,40},{-184,40},{-184,20}}, color={0,0,255}));
          connect(SP4, LPH4.ST_in) annotation (Line(points={{-170,110},{-170,110},{-170,
                  20}}, color={0,0,255}));
          connect(LPH4.FW_in, pressDrop2.outlet)
            annotation (Line(points={{-148,0},{-110,0}}, color={0,0,255}));
          connect(SP5, LPH3.ST_in)
            annotation (Line(points={{-60,110},{-60,110},{-60,20}}, color={0,0,255}));
          connect(LPH3.FW_out, pressDrop2.inlet)
            annotation (Line(points={{-80,0},{-90,0}}, color={0,0,255}));
          connect(LPH2.FW_out, pressDrop1.inlet)
            annotation (Line(points={{30,0},{26,0},{20,0}}, color={0,0,255}));
          connect(LPH3.FW_in, pressDrop1.outlet)
            annotation (Line(points={{-38,0},{0,0}},       color={0,0,255}));
          connect(SP6, LPH2.ST_in)
            annotation (Line(points={{50,110},{50,20}},         color={0,0,255}));
          connect(pressDrop.inlet, LPH1.FW_out)
            annotation (Line(points={{130,0},{136,0},{140,0}}, color={0,0,255}));
          connect(FW_in, LPH1.FW_in)
            annotation (Line(points={{250,0},{216,0},{182,0}}, color={0,0,255}));
          connect(SP7, LPH1.ST_in)
            annotation (Line(points={{160,110},{160,110},{160,20}}, color={0,0,255}));
          connect(LPH1.DR_out, sinkPressure_DR.flange)
            annotation (Line(points={{160,-20},{160,-40},{180,-40}}, color={0,0,255}));
          connect(sourceMassFlow.flange, LPH2.FW_in) annotation (Line(points={{110,-40},
                  {100,-40},{100,0},{72,0}}, color={0,0,255}));
          connect(pressDrop.outlet, LPH2.FW_in)
            annotation (Line(points={{110,0},{102,0},{72,0}}, color={0,0,255}));
          connect(cmd.y, valveLin21.cmd) annotation (Line(points={{-129,70},{-129,
                  70},{110,70},{110,48}},
                                     color={0,0,127}));
          connect(cmd.y, valveLin32.cmd) annotation (Line(points={{-129,70},{-129,
                  70},{0,70},{0,48}},
                                 color={0,0,127}));
          connect(cmd.y, valveLin43.cmd)
            annotation (Line(points={{-129,70},{-110,70},{-110,48}}, color={0,0,127}));
          connect(LPH4.DR_out, valveLin43.inlet) annotation (Line(points={{-170,-20},{-170,
                  -20},{-170,-40},{-130,-40},{-130,40},{-120,40}}, color={0,0,255}));
          connect(valveLin43.outlet, LPH3.DR_in) annotation (Line(points={{-100,40},{-88,
                  40},{-74,40},{-74,20}}, color={0,0,255}));
          connect(LPH3.DR_out, valveLin32.inlet) annotation (Line(points={{-60,-20},{-60,
                  -40},{-30,-40},{-30,40},{-10,40}}, color={0,0,255}));
          connect(valveLin32.outlet, LPH2.DR_in) annotation (Line(points={{10,40},{22,40},
                  {36,40},{36,20}}, color={0,0,255}));
          connect(LPH2.DR_out, valveLin21.inlet) annotation (Line(points={{50,-20},{50,-40},
                  {88,-40},{88,40},{100,40}}, color={0,0,255}));
          connect(valveLin21.outlet, LPH1.DR_in) annotation (Line(points={{120,40},{132,
                  40},{146,40},{146,20}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                    -100},{240,100}})));
        end LPH_train;

        package Test

          model test_LPH_train "Test model of the LPH train"

            LPH_train LPHs
              annotation (Placement(transformation(extent={{-46,-20},{46,20}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=64.26,
              h=197600)
              annotation (Placement(transformation(extent={{80,-10},{60,10}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=2.962,
              h=2525200)
              annotation (Placement(transformation(extent={{60,30},{40,50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.183,
              h=2673900)
              annotation (Placement(transformation(extent={{40,50},{20,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.375,
              h=2820500)
              annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST3(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=2971200,
              w0=3.532)
              annotation (Placement(transformation(extent={{-60,30},{-40,50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
          equation
            connect(LPHs.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{47.9167,0},{60,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPHs.FW_out, sinkPressure.flange) annotation (Line(
                points={{-47.9167,0},{-60,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, LPHs.SP7) annotation (Line(
                points={{40,40},{30.6667,40},{30.6667,22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPHs.SP6, sourceMassFlow_ST1.flange) annotation (Line(
                points={{9.58333,22},{9.58333,60},{20,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST2.flange, LPHs.SP5) annotation (Line(
                points={{-20,60},{-11.5,60},{-11.5,22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST3.flange, LPHs.SP4) annotation (Line(
                points={{-40,40},{-32.5833,40},{-32.5833,22}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})));
          end test_LPH_train;

          model test_HPH_train "Test model of the HPH_train"

            HPH_train_fixedLevel HPHs
              annotation (Placement(transformation(extent={{-34,-20},{38,20}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{60,30},{80,50}})));
            ThermoPower.Water.SourcePressure sourcePressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1384500,
              p0=18140000)
              annotation (Placement(transformation(extent={{-60,-38},{-40,-18}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17910000)
              annotation (Placement(transformation(extent={{-70,-10},{-90,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=0)
              annotation (Placement(transformation(extent={{-60,30},{-40,50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.709,
              h=3318000)
              annotation (Placement(transformation(extent={{-20,70},{0,90}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.019,
              h=3218000)
              annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000)
              annotation (Placement(transformation(extent={{80,-10},{60,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            Control.Old.plant_controller_HPpart_old1 controllers(
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              CSstart_valveRH=238.7,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              TS_valveRH=238.7,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              TS_pumpSEP=0,
              Ta_pumpFW=5,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              actuatorGain_pumpFW=1,
              P_mec_sp=79.7258e6,
              actuatorGain_pumpMS=1,
              Ta_pumpMS=5,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSmax_pumpFW=0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSmin_pumpMS=-0.9,
              CSmax_pumpMS=1,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              Nd_valveRH=10,
              Kp_valveRH=1.77,
              Ti_valveRH=16,
              Td_valveRH=0,
              l_sp=4,
              t_ramp=0,
              t_start=0,
              load_start=100,
              load_end=100,
              Kp_pumpFW=-1,
              Ti_pumpFW=28.59,
              Td_pumpFW=7.147,
              Nd_pumpFW=30,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Kp_pumpMS=1.2e-7,
              Ti_pumpMS=114.3,
              Td_pumpMS=28.57,
              Nd_pumpMS=20,
              Ti_valveTURB=95.23,
              Kp_valveTURB=-0.0000014,
              Ta_valveTURB=2,
              useTS_pumpFW=true,
              useTS_pumpHPH=true,
              useTS_pumpMS=true,
              useTS_valveTURB=true,
              T_RH_sp=826.05,
              useTS_valveRH=true,
              useTS_pumpSEP=true,
              T_MS_sp=563.15,
              T_FW_sp=553.15,
              p_sp=17610000)
              annotation (Placement(transformation(extent={{82,-68},{66,-52}})));
            Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                  transformation(extent={{-28,-44},{-20,-36}})));
            Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
                Placement(transformation(extent={{-28,-58},{-20,-50}})));
            Modelica.Blocks.Sources.Constant pumpMS_PV(k=0) annotation (Placement(
                  transformation(extent={{-28,-76},{-20,-68}})));
            Modelica.Blocks.Sources.Constant pumpSEP_PV(k=0) annotation (
                Placement(transformation(extent={{-28,-92},{-20,-84}})));
            Modelica.Blocks.Sources.Constant valveRH_PV(k=0)
              annotation (Placement(transformation(extent={{-10,-84},{-2,-76}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{8,-66},{20,-54}})));
            Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
              annotation (Placement(transformation(extent={{-10,-66},{-2,-58}})));
          equation
            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{40,12},{50,12},{50,40},{60,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
                points={{-40,-28},{10,-28},{10,-22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_out, sinkPressure.flange) annotation (Line(
                points={{-36,0},{-70,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(
                points={{-40,40},{-22,40},{-22,22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, HPHs.SP2) annotation (Line(
                points={{0,80},{18,80},{18,22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST1.flange, HPHs.SP1) annotation (Line(
                points={{-20,60},{-8,60},{-8,22}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{40,0},{60,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{24,-20.8},{24,-60},{65.6,-60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, pumpFW_PV.y) annotation (Line(
                points={{14,-60},{8,-60},{8,-40},{-19.6,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
                points={{14,-60},{8,-60},{8,-54},{-19.6,-54}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
                points={{14,-60},{12,-60},{8,-60},{8,-62},{-1.6,-62}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, valveRH_PV.y) annotation (Line(
                points={{14,-60},{8,-60},{8,-80},{-1.6,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, pumpMS_PV.y) annotation (Line(
                points={{14,-60},{8,-60},{8,-72},{-19.6,-72}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, pumpSEP_PV.y) annotation (Line(
                points={{14,-60},{8,-60},{8,-88},{-19.6,-88}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, controllers.signalBus) annotation (Line(
                points={{14,-60},{65.6,-60}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})));
          end test_HPH_train;

          model test_HPH_train_offDesign_fixedLevel
            "Test model of the HPH_train for offDesign checking, Nusselt condenser type, fixed subcooled level (no control)"
            import PreFlexMS;

            HPH_train_fixedLevel HPHs
              annotation (Placement(transformation(extent={{-60,-40},{80,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,30},{160,50}})));
            ThermoPower.Water.SourcePressure sourcePressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1384500,
              p0=18140000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-100,-110},{-80,-90}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=17910000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,-10},{-160,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=0,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{80,90},{60,110}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-240,160},{-220,180}})));
            Control.Old.plant_controller_HPpart_old2 controllers(
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              CSstart_valveRH=238.7,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              TS_valveRH=238.7,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              TS_pumpSEP=0,
              Ta_pumpFW=5,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              actuatorGain_pumpFW=1,
              P_mec_sp=79.7258e6,
              actuatorGain_pumpMS=1,
              Ta_pumpMS=5,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSmax_pumpFW=0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSmin_pumpMS=-0.9,
              CSmax_pumpMS=1,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              Nd_valveRH=10,
              Kp_valveRH=1.77,
              Ti_valveRH=16,
              Td_valveRH=0,
              l_sp=4,
              Kp_pumpFW=-1,
              Ti_pumpFW=28.59,
              Td_pumpFW=7.147,
              Nd_pumpFW=30,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Kp_pumpMS=1.2e-7,
              Ti_pumpMS=114.3,
              Td_pumpMS=28.57,
              Nd_pumpMS=20,
              Ti_valveTURB=95.23,
              Kp_valveTURB=-0.0000014,
              Ta_valveTURB=2,
              useTS_pumpFW=true,
              useTS_pumpHPH=true,
              useTS_pumpMS=true,
              useTS_valveTURB=true,
              useTS_valveRH=true,
              useTS_pumpSEP=true,
              load_start=loadCalc.load_start,
              load_end=loadCalc.load_end,
              t_ramp=loadCalc.t_ramp,
              t_start=loadCalc.t_start,
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15,
              p_sp=17610000) annotation (Placement(transformation(extent={{120,-160},
                      {80,-120}})));
            Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-124},{-40,-116}})));
            Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-138},{-40,-130}})));
            Modelica.Blocks.Sources.Constant pumpMS_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-156},{-40,-148}})));
            Modelica.Blocks.Sources.Constant pumpSEP_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-172},{-40,-164}})));
            Modelica.Blocks.Sources.Constant valveRH_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-164},{-22,-156}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-12,-146},{0,-134}})));
            Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-146},{-22,-138}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_ramp=8e5,
              t_start=5000,
              load_end=20) annotation (Placement(transformation(extent={{-220,-160},
                      {-180,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-40})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceH(table=[20,1258.5e3;
                  30,1260.6e3; 40,1258.9e3; 50,1251.9e3; 60,1111.4e3; 70,1293.8e3;
                  80,1318.1e3; 90,1359.2e3; 100,1384.5e3]) annotation (Placement(
                  transformation(extent={{-140,-50},{-120,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-70})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceP(table=[20,100.6e5; 30,
                  102e5; 40,103e5; 50,104.1e5; 60,115e5; 70,132.2e5; 80,149.1e5;
                  90,166.7e5; 100,181.4e5]) annotation (Placement(transformation(
                    extent={{-140,-80},{-120,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-210,30})));
            Modelica.Blocks.Tables.CombiTable1D FW_sinkP(table=[20,100.5e5; 30,
                  101.7e5; 40,102.5e5; 50,103.2e5; 60,113.8e5; 70,130.6e5; 80,
                  147.3e5; 90,164e5; 100,179.1e5]) annotation (Placement(
                  transformation(extent={{-180,20},{-160,40}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-70})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,524.5e3; 30,
                  586.9e3; 40,626.3e3; 50,656.8e3; 60,683.3e3; 70,705.5e3; 80,
                  728.4e3; 90,749.4e3; 100,768.6e3]) annotation (Placement(
                  transformation(extent={{180,-80},{160,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-40})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceP(table=[20,100.6e5; 30,
                  102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                  150.7e5; 90,168.6e5; 100,183.8e5]) annotation (Placement(
                  transformation(extent={{180,-50},{160,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,80})));
            Modelica.Blocks.Tables.CombiTable1D DR_sinkP(table=[20,1.587e5; 30,
                  2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306E5; 70,6.143E5; 80,
                  7.093e5; 90,8.046e5; 100,9e5])
              annotation (Placement(transformation(extent={{180,70},{160,90}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,140})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceH(table=[20,3287e3; 30,
                  3284e3; 40,3278e3; 50,3272e3; 60,3260e3; 70,3250e3; 80,3239e3;
                  90,3230e3; 100,3218e3]) annotation (Placement(transformation(
                    extent={{-60,130},{-40,150}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,110})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceP(table=[20,14.73e5; 30,
                  22.76e5; 40,30.83e5; 50,38.98e5; 60,47.09e5; 70,54.55e5; 80,
                  63.3e5; 90,72.25e5; 100,81.49e5])
                                     annotation (Placement(transformation(extent=
                      {{-60,100},{-40,120}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,130})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,160})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceP(table=[20,3.522e5; 30,
                  5.618e5; 40,7.694e5; 50,9.776e5; 60,11.86e5; 70,13.77e5; 80,
                  15.96e5; 90,18.18e5; 100,20.37e5])
              annotation (Placement(transformation(extent={{40,150},{60,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,120})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceH(table=[20,1409.2e3;
                  30,1410.2e3; 40,1411.6e3; 50,1413.3e3; 60,1461.9e3; 70,1529.2e3;
                  80,1594.2e3; 90,1658.6e3; 100,1722.1e3]) annotation (Placement(
                  transformation(extent={{-160,110},{-140,130}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,90})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceW(table=[20,47.18; 30,
                  57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-90,-6},{-110,14}})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceH(table=[20,3356e3; 30,
                  3352e3; 40,3347e3; 50,3343e3; 60,3338e3; 70,3334e3; 80,3329e3;
                  90,3324e3; 100,3318e3])
              annotation (Placement(transformation(extent={{40,120},{60,140}})));
          equation
            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{83.8889,24},{110,24},{110,40},{140,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
                points={{-80,-100},{25.5556,-100},{25.5556,-44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(
                points={{-120,60},{-36,60},{-36,44},{-36.6667,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, HPHs.SP2) annotation (Line(
                points={{60,100},{41.1111,100},{41.1111,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST1.flange, HPHs.SP1) annotation (Line(
                points={{-20,80},{-9.44444,80},{-9.44444,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{83.8889,0},{140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{52.7778,-41.6},{52.7778,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, pumpFW_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-120},{-39.6,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-134},{-39.6,-134}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
                points={{-6,-140},{-8,-140},{-12,-140},{-12,-142},{-21.6,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, valveRH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-160},{-21.6,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, pumpMS_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-152},{-39.6,-152}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, pumpSEP_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-168},{-39.6,-168}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, controllers.signalBus) annotation (Line(
                points={{-6,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(HPH_sourceH.y[1], sourcePressure.in_h) annotation (Line(
                  points={{-119,-40},{-104,-40},{-86,-40},{-86,-91}}, color={0,0,
                    127}));
            connect(LOAD1.y, HPH_sourceH.u[1]) annotation (Line(points={{-159,-40},
                    {-150,-40},{-142,-40}}, color={0,0,127}));
            connect(LOAD2.y, HPH_sourceP.u[1]) annotation (Line(points={{-159,-70},
                    {-150,-70},{-142,-70}}, color={0,0,127}));
            connect(HPH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
                  points={{-119,-70},{-106,-70},{-94,-70},{-94,-90.8}}, color={0,
                    0,127}));
            connect(LOAD3.y, FW_sinkP.u[1]) annotation (Line(points={{-199,30},{
                    -190,30},{-182,30}}, color={0,0,127}));
            connect(FW_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{
                    -159,30},{-152,30},{-146,30},{-146,8.8}}, color={0,0,127}));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{199,-70},
                    {199,-70},{182,-70}}, color={0,0,127}));
            connect(LOAD5.y, FW_sourceP.u[1]) annotation (Line(points={{199,-40},
                    {199,-40},{182,-40}}, color={0,0,127}));
            connect(FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                  points={{159,-40},{154,-40},{154,-9.2}}, color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{159,-70},{146,-70},{146,-9}}, color={0,0,127}));
            connect(DR_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points=
                   {{159,80},{146,80},{146,48.8}}, color={0,0,127}));
            connect(LOAD8.y,SP7_sourceP. u[1]) annotation (Line(points={{-79,110},
                    {-70,110},{-62,110}}, color={0,0,127}));
            connect(LOAD10.y,SP6_sourceP. u[1]) annotation (Line(points={{21,160},
                    {30,160},{38,160}}, color={0,0,127}));
            connect(LOAD11.y, sep_sourceH.u[1]) annotation (Line(points={{-179,
                    120},{-170,120},{-162,120}}, color={0,0,127}));
            connect(LOAD12.y, sep_sourceW.u[1]) annotation (Line(points={{-179,90},
                    {-170,90},{-162,90}}, color={0,0,127}));
            connect(sep_sourceW.y[1], sourceMassFlow.in_w0) annotation (Line(
                  points={{-139,90},{-134,90},{-134,66}}, color={0,0,127}));
            connect(sep_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-139,120},{-126,120},{-126,66}}, color={0,0,127}));
            connect(DR_sinkP.u[1], LOAD6.y) annotation (Line(points={{182,80},{
                    199,80},{199,80}}, color={0,0,127}));
            connect(sensT.inlet, HPHs.FW_out)
              annotation (Line(points={{-94,0},{-63.8889,0}}, color={0,0,255}));
            connect(sinkPressure.flange, sensT.outlet)
              annotation (Line(points={{-140,0},{-106,0}}, color={0,0,255}));
            connect(SP7_sourceP.y[1], sourceMassFlow_ST1.in_p0) annotation (Line(
                  points={{-39,110},{-39,110},{-34,110},{-34,89.2}}, color={0,0,
                    127}));
            connect(SP6_sourceP.y[1], sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{61,160},{74,160},{74,109.2}}, color={0,0,127}));
            connect(LOAD9.y, SP6_sourceH.u[1]) annotation (Line(points={{21,130},{38,130}},
                                        color={0,0,127}));
            connect(LOAD7.y, SP7_sourceH.u[1]) annotation (Line(points={{-79,140},{-70.5,140},
                    {-62,140}}, color={0,0,127}));
            connect(SP7_sourceH.y[1], sourceMassFlow_ST1.in_h)
              annotation (Line(points={{-39,140},{-26,140},{-26,89}}, color={0,0,127}));
            connect(SP6_sourceH.y[1], sourceMassFlow_ST.in_h)
              annotation (Line(points={{61,130},{66,130},{66,109}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -180},{240,180}}), graphics={Text(
                    extent={{90,172},{230,100}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    textStyle={TextStyle.Bold,TextStyle.Italic},
                    textString="Con le condizioni al contorno corrette la
temperatura di uscita dell'acqua di alimento 
� coerente con i PDF, cos� come le pressioni di
spillamento in quanto imposte. Ci� � dovuto al
differente modello di scambio termico.")}),
              Icon(coordinateSystem(extent={{-240,-180},{240,180}})),
              experiment(StopTime=805000),
              __Dymola_experimentSetupOutput);
          end test_HPH_train_offDesign_fixedLevel;

          model test_HPH_train_offDesign_controlledLevel
            "Test model of the HPH_train for offDesign checking, Nusselt condense type"
            import PreFlexMS;

            HPH_train_controlledLevel HPHs(HPH2(Kv=6.575589005e-7/0.2), HPH1(Kv=
                    6.798592788e-6/0.2))
              annotation (Placement(transformation(extent={{-60,-40},{80,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,30},{160,50}})));
            ThermoPower.Water.SourcePressure sourcePressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1384500,
              p0=18140000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-100,-110},{-80,-90}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=17910000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,-10},{-160,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=0,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{80,90},{60,110}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-240,160},{-220,180}})));
            Control.Old.plant_controller_HPpart_old controllers(
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              CSstart_valveRH=238.7,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              TS_valveRH=238.7,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              TS_pumpSEP=0,
              Ta_pumpFW=5,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              actuatorGain_pumpFW=1,
              P_mec_sp=79.7258e6,
              actuatorGain_pumpMS=1,
              Ta_pumpMS=5,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSmax_pumpFW=0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSmin_pumpMS=-0.9,
              CSmax_pumpMS=1,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              Nd_valveRH=10,
              Kp_valveRH=1.77,
              Ti_valveRH=16,
              Td_valveRH=0,
              l_sp=4,
              Kp_pumpFW=-1,
              Ti_pumpFW=28.59,
              Td_pumpFW=7.147,
              Nd_pumpFW=30,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Kp_pumpMS=1.2e-7,
              Ti_pumpMS=114.3,
              Td_pumpMS=28.57,
              Nd_pumpMS=20,
              Ti_valveTURB=95.23,
              Kp_valveTURB=-0.0000014,
              Ta_valveTURB=2,
              useTS_pumpFW=true,
              useTS_pumpHPH=true,
              useTS_pumpMS=true,
              useTS_valveTURB=true,
              useTS_valveRH=true,
              useTS_pumpSEP=true,
              load_start=loadCalc.load_start,
              load_end=loadCalc.load_end,
              t_ramp=loadCalc.t_ramp,
              t_start=loadCalc.t_start,
              gain(k=0),
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15,
              p_sp=17610000) annotation (Placement(transformation(extent={{120,-160},
                      {80,-120}})));
            Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-124},{-40,-116}})));
            Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-138},{-40,-130}})));
            Modelica.Blocks.Sources.Constant pumpMS_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-156},{-40,-148}})));
            Modelica.Blocks.Sources.Constant pumpSEP_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-172},{-40,-164}})));
            Modelica.Blocks.Sources.Constant valveRH_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-164},{-22,-156}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-12,-146},{0,-134}})));
            Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-146},{-22,-138}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_ramp=8e5,
              t_start=5000,
              load_end=50) annotation (Placement(transformation(extent={{-220,-160},
                      {-180,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-40})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceH(table=[20,1258.5e3;
                  30,1260.6e3; 40,1258.9e3; 50,1251.9e3; 60,1111.4e3; 70,1293.8e3;
                  80,1318.1e3; 90,1359.2e3; 100,1384.5e3]) annotation (Placement(
                  transformation(extent={{-140,-50},{-120,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-70})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceP(table=[20,100.6e5; 30,
                  102e5; 40,103e5; 50,104.1e5; 60,115e5; 70,132.2e5; 80,149.1e5;
                  90,166.7e5; 100,181.4e5]) annotation (Placement(transformation(
                    extent={{-140,-80},{-120,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-210,30})));
            Modelica.Blocks.Tables.CombiTable1D FW_sinkP(table=[20,100.5e5; 30,
                  101.7e5; 40,102.5e5; 50,103.2e5; 60,113.8e5; 70,130.6e5; 80,
                  147.3e5; 90,164e5; 100,179.1e5]) annotation (Placement(
                  transformation(extent={{-180,20},{-160,40}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-70})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,524.5e3; 30,
                  586.9e3; 40,626.3e3; 50,656.8e3; 60,683.3e3; 70,705.5e3; 80,
                  728.4e3; 90,749.4e3; 100,768.6e3]) annotation (Placement(
                  transformation(extent={{180,-80},{160,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-40})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceP(table=[20,100.6e5; 30,
                  102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                  150.7e5; 90,168.6e5; 100,183.8e5]) annotation (Placement(
                  transformation(extent={{180,-50},{160,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,80})));
            Modelica.Blocks.Tables.CombiTable1D DR_sinkP(table=[20,1.587e5; 30,
                  2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306E5; 70,6.143E5; 80,
                  7.093e5; 90,8.046e5; 100,9e5])
              annotation (Placement(transformation(extent={{180,70},{160,90}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,140})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceH(table=[20,3287e3; 30,
                  3284e3; 40,3278e3; 50,3272e3; 60,3260e3; 70,3250e3; 80,3239e3;
                  90,3230e3; 100,3218e3]) annotation (Placement(transformation(
                    extent={{-60,130},{-40,150}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,110})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceP(table=[20,14.73e5; 30,
                  22.76e5; 40,30.83e5; 50,38.98e5; 60,47.09e5; 70,54.55e5; 80,
                  63.3e5; 90,72.25e5; 100,81.49e5])
                                     annotation (Placement(transformation(extent=
                      {{-60,100},{-40,120}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,130})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,160})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceP(table=[20,3.522e5; 30,
                  5.618e5; 40,7.694e5; 50,9.776e5; 60,11.86e5; 70,13.77e5; 80,
                  15.96e5; 90,18.18e5; 100,20.37e5])
              annotation (Placement(transformation(extent={{40,150},{60,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,120})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceH(table=[20,1409.2e3;
                  30,1410.2e3; 40,1411.6e3; 50,1413.3e3; 60,1461.9e3; 70,1529.2e3;
                  80,1594.2e3; 90,1658.6e3; 100,1722.1e3]) annotation (Placement(
                  transformation(extent={{-160,110},{-140,130}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,90})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceW(table=[20,47.18; 30,
                  57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-90,-6},{-110,14}})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceH(table=[20,3356e3; 30,
                  3352e3; 40,3347e3; 50,3343e3; 60,3338e3; 70,3334e3; 80,3329e3;
                  90,3324e3; 100,3318e3])
              annotation (Placement(transformation(extent={{40,120},{60,140}})));
          equation
            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{83.8889,24},{110,24},{110,40},{140,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
                points={{-80,-100},{25.5556,-100},{25.5556,-44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(
                points={{-120,60},{-36,60},{-36,44},{-36.6667,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, HPHs.SP2) annotation (Line(
                points={{60,100},{41.1111,100},{41.1111,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST1.flange, HPHs.SP1) annotation (Line(
                points={{-20,80},{-9.44444,80},{-9.44444,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{83.8889,0},{140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{52.7778,-41.6},{52.7778,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, pumpFW_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-120},{-39.6,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-134},{-39.6,-134}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
                points={{-6,-140},{-8,-140},{-12,-140},{-12,-142},{-21.6,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, valveRH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-160},{-21.6,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, pumpMS_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-152},{-39.6,-152}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, pumpSEP_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-168},{-39.6,-168}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, controllers.signalBus) annotation (Line(
                points={{-6,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(HPH_sourceH.y[1], sourcePressure.in_h) annotation (Line(
                  points={{-119,-40},{-104,-40},{-86,-40},{-86,-91}}, color={0,0,
                    127}));
            connect(LOAD1.y, HPH_sourceH.u[1]) annotation (Line(points={{-159,-40},
                    {-150,-40},{-142,-40}}, color={0,0,127}));
            connect(LOAD2.y, HPH_sourceP.u[1]) annotation (Line(points={{-159,-70},
                    {-150,-70},{-142,-70}}, color={0,0,127}));
            connect(HPH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
                  points={{-119,-70},{-106,-70},{-94,-70},{-94,-90.8}}, color={0,
                    0,127}));
            connect(LOAD3.y, FW_sinkP.u[1]) annotation (Line(points={{-199,30},{
                    -190,30},{-182,30}}, color={0,0,127}));
            connect(FW_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{
                    -159,30},{-152,30},{-146,30},{-146,8.8}}, color={0,0,127}));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{199,-70},
                    {199,-70},{182,-70}}, color={0,0,127}));
            connect(LOAD5.y, FW_sourceP.u[1]) annotation (Line(points={{199,-40},
                    {199,-40},{182,-40}}, color={0,0,127}));
            connect(FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                  points={{159,-40},{154,-40},{154,-9.2}}, color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{159,-70},{146,-70},{146,-9}}, color={0,0,127}));
            connect(DR_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points=
                   {{159,80},{146,80},{146,48.8}}, color={0,0,127}));
            connect(LOAD7.y, SP7_sourceH.u[1]) annotation (Line(points={{-79,140},
                    {-70,140},{-62,140}}, color={0,0,127}));
            connect(LOAD8.y,SP7_sourceP. u[1]) annotation (Line(points={{-79,110},
                    {-70,110},{-62,110}}, color={0,0,127}));
            connect(LOAD10.y,SP6_sourceP. u[1]) annotation (Line(points={{21,160},
                    {30,160},{38,160}}, color={0,0,127}));
            connect(SP7_sourceH.y[1], sourceMassFlow_ST1.in_h) annotation (Line(
                  points={{-39,140},{-34,140},{-26,140},{-26,89}}, color={0,0,127}));
            connect(LOAD11.y, sep_sourceH.u[1]) annotation (Line(points={{-179,
                    120},{-170,120},{-162,120}}, color={0,0,127}));
            connect(LOAD12.y, sep_sourceW.u[1]) annotation (Line(points={{-179,90},
                    {-170,90},{-162,90}}, color={0,0,127}));
            connect(sep_sourceW.y[1], sourceMassFlow.in_w0) annotation (Line(
                  points={{-139,90},{-134,90},{-134,66}}, color={0,0,127}));
            connect(sep_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-139,120},{-126,120},{-126,66}}, color={0,0,127}));
            connect(DR_sinkP.u[1], LOAD6.y) annotation (Line(points={{182,80},{
                    199,80},{199,80}}, color={0,0,127}));
            connect(sensT.inlet, HPHs.FW_out)
              annotation (Line(points={{-94,0},{-63.8889,0}}, color={0,0,255}));
            connect(sinkPressure.flange, sensT.outlet)
              annotation (Line(points={{-140,0},{-106,0}}, color={0,0,255}));
            connect(SP7_sourceP.y[1], sourceMassFlow_ST1.in_p0) annotation (Line(
                  points={{-39,110},{-39,110},{-34,110},{-34,89.2}}, color={0,0,
                    127}));
            connect(SP6_sourceP.y[1], sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{61,160},{74,160},{74,109.2}}, color={0,0,127}));
            connect(LOAD9.y, SP6_sourceH.u[1]) annotation (Line(points={{21,130},
                    {38,130},{38,130}}, color={0,0,127}));
            connect(SP6_sourceH.y[1], sourceMassFlow_ST.in_h) annotation (Line(
                  points={{61,130},{66,130},{66,109}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -180},{240,180}}), graphics={Text(
                    extent={{90,172},{230,100}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    textStyle={TextStyle.Bold,TextStyle.Italic},
                    textString="Con le condizioni al contorno corrette la
temperatura di uscita dell'acqua di alimento 
� coerente con i PDF, cos� come le pressioni di
spillamento in quanto imposte. Ci� � dovuto al
differente modello di scambio termico.")}),
              Icon(coordinateSystem(extent={{-240,-180},{240,180}})),
              experiment(StopTime=805000),
              __Dymola_experimentSetupOutput);
          end test_HPH_train_offDesign_controlledLevel;

          model test_HPH_train_offDesign_simplified
            "Test model of the HPH_train for offDesign checking, convective heat exchanger model"
            import PreFlexMS;

            HPH_train_simplified HPHs(HPH2(HE(generateInitCode=true)), HPH1(HE(
                    generateInitCode=true)))
              annotation (Placement(transformation(extent={{-60,-40},{80,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,30},{160,50}})));
            ThermoPower.Water.SourcePressure sourcePressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1384500,
              p0=18140000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-100,-110},{-80,-90}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=17910000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,-10},{-160,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=0,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.709,
              h=3318000,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{80,90},{60,110}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.019,
              h=3218000,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-240,160},{-220,180}})));
            Control.Old.plant_controller_HPpart_old1 controllers(
              CSmin_valveRH=1,
              CSmax_valveRH=300,
              CSstart_valveRH=238.7,
              actuatorGain_valveRH=1,
              Ta_valveRH=2,
              TS_valveRH=238.7,
              Kp_pumpSEP=-14.5,
              Ti_pumpSEP=56.7,
              Td_pumpSEP=0,
              Nd_pumpSEP=1,
              CSmin_pumpSEP=0,
              CSmax_pumpSEP=70,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=5,
              TS_pumpSEP=0,
              Ta_pumpFW=5,
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              actuatorGain_pumpFW=1,
              P_mec_sp=79.7258e6,
              actuatorGain_pumpMS=1,
              Ta_pumpMS=5,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSmax_pumpFW=0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSmin_pumpMS=-0.9,
              CSmax_pumpMS=1,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              Nd_valveRH=10,
              Kp_valveRH=1.77,
              Ti_valveRH=16,
              Td_valveRH=0,
              l_sp=4,
              Kp_pumpFW=-1,
              Ti_pumpFW=28.59,
              Td_pumpFW=7.147,
              Nd_pumpFW=30,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Kp_pumpMS=1.2e-7,
              Ti_pumpMS=114.3,
              Td_pumpMS=28.57,
              Nd_pumpMS=20,
              Ti_valveTURB=95.23,
              Kp_valveTURB=-0.0000014,
              Ta_valveTURB=2,
              useTS_pumpFW=true,
              useTS_pumpHPH=true,
              useTS_pumpMS=true,
              useTS_valveTURB=true,
              useTS_valveRH=true,
              useTS_pumpSEP=true,
              load_start=loadCalc.load_start,
              load_end=loadCalc.load_end,
              t_ramp=loadCalc.t_ramp,
              t_start=loadCalc.t_start,
              T_RH_sp=826.05,
              T_MS_sp=563.15,
              T_FW_sp=553.15,
              p_sp=17610000) annotation (Placement(transformation(extent={{120,-160},
                      {80,-120}})));
            Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-124},{-40,-116}})));
            Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-138},{-40,-130}})));
            Modelica.Blocks.Sources.Constant pumpMS_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-156},{-40,-148}})));
            Modelica.Blocks.Sources.Constant pumpSEP_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-172},{-40,-164}})));
            Modelica.Blocks.Sources.Constant valveRH_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-164},{-22,-156}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-12,-146},{0,-134}})));
            Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
              annotation (Placement(transformation(extent={{-30,-146},{-22,-138}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_start=0,
              load_end=20,
              t_ramp=8e5) annotation (Placement(transformation(extent={{-220,-160},
                      {-180,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-40})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceH(table=[20,1258.5e3;
                  30,1260.6e3; 40,1258.9e3; 50,1251.9e3; 60,1111.4e3; 70,1293.8e3;
                  80,1318.1e3; 90,1359.2e3; 100,1384.5e3]) annotation (Placement(
                  transformation(extent={{-140,-50},{-120,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-70})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceP(table=[20,100.6e5; 30,
                  102e5; 40,103e5; 50,104.1e5; 60,115e5; 70,132.2e5; 80,149.1e5;
                  90,166.7e5; 100,181.4e5]) annotation (Placement(transformation(
                    extent={{-140,-80},{-120,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-210,30})));
            Modelica.Blocks.Tables.CombiTable1D FW_sinkP(table=[20,100.5e5; 30,
                  101.7e5; 40,102.5e5; 50,103.2e5; 60,113.8e5; 70,130.6e5; 80,
                  147.3e5; 90,164e5; 100,179.1e5]) annotation (Placement(
                  transformation(extent={{-180,20},{-160,40}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-70})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,524.5e3; 30,
                  586.9e3; 40,626.3e3; 50,656.8e3; 60,683.3e3; 70,705.5e3; 80,
                  728.4e3; 90,749.4e3; 100,768.6e3]) annotation (Placement(
                  transformation(extent={{180,-80},{160,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-40})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceP(table=[20,100.6e5; 30,
                  102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                  150.7e5; 90,168.6e5; 100,183.8e5]) annotation (Placement(
                  transformation(extent={{180,-50},{160,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,80})));
            Modelica.Blocks.Tables.CombiTable1D DR_sinkP(table=[20,1.587e5; 30,
                  2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306E5; 70,6.143E5; 80,
                  7.093e5; 90,8.046e5; 100,9e5])
              annotation (Placement(transformation(extent={{180,70},{160,90}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,140})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceH(table=[20,3287e3; 30,
                  3284e3; 40,3278e3; 50,3272e3; 60,3260e3; 70,3250e3; 80,3239e3;
                  90,3230e3; 100,3218e3]) annotation (Placement(transformation(
                    extent={{-60,130},{-40,150}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,110})));
            Modelica.Blocks.Tables.CombiTable1D SP7_sourceW(table=[20,1.607; 30,
                  2.806; 40,4.245; 50,5.921; 60,7.809; 70,8.488; 80,7.588; 90,
                  6.322; 100,4.019]) annotation (Placement(transformation(extent=
                      {{-60,100},{-40,120}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,130})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceH(table=[20,3356e3; 30,
                  3352e3; 40,3347e3; 50,3343e3; 60,3338e3; 70,3334e3; 80,3329e3;
                  90,3324e3; 100,3318e3])
              annotation (Placement(transformation(extent={{40,120},{60,140}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,160})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceW(table=[20,0.33; 30,
                  0.5678; 40,0.8797; 50,1.227; 60,1.582; 70,1.928; 80,2.415; 90,
                  2.961; 100,3.709])
              annotation (Placement(transformation(extent={{40,150},{60,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,120})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceH(table=[20,1409.2e3;
                  30,1410.2e3; 40,1411.6e3; 50,1413.3e3; 60,1461.9e3; 70,1529.2e3;
                  80,1594.2e3; 90,1658.6e3; 100,1722.1e3]) annotation (Placement(
                  transformation(extent={{-160,110},{-140,130}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,90})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceW(table=[20,47.18; 30,
                  57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-90,-6},{-110,14}})));
          equation
            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{83.8889,24},{110,24},{110,40},{140,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
                points={{-80,-100},{25.5556,-100},{25.5556,-44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(
                points={{-120,60},{-36,60},{-36,44},{-36.6667,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, HPHs.SP2) annotation (Line(
                points={{60,100},{41.1111,100},{41.1111,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST1.flange, HPHs.SP1) annotation (Line(
                points={{-20,80},{-9.44444,80},{-9.44444,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{83.8889,0},{140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{52.7778,-41.6},{52.7778,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV, pumpFW_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-120},{-39.6,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-134},{-39.6,-134}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
                points={{-6,-140},{-8,-140},{-12,-140},{-12,-142},{-21.6,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, valveRH_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-160},{-21.6,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, pumpMS_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-152},{-39.6,-152}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, pumpSEP_PV.y) annotation (Line(
                points={{-6,-140},{-12,-140},{-12,-168},{-39.6,-168}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, controllers.signalBus) annotation (Line(
                points={{-6,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(HPH_sourceH.y[1], sourcePressure.in_h) annotation (Line(
                  points={{-119,-40},{-104,-40},{-86,-40},{-86,-91}}, color={0,0,
                    127}));
            connect(LOAD1.y, HPH_sourceH.u[1]) annotation (Line(points={{-159,-40},
                    {-150,-40},{-142,-40}}, color={0,0,127}));
            connect(LOAD2.y, HPH_sourceP.u[1]) annotation (Line(points={{-159,-70},
                    {-150,-70},{-142,-70}}, color={0,0,127}));
            connect(HPH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
                  points={{-119,-70},{-106,-70},{-94,-70},{-94,-90.8}}, color={0,
                    0,127}));
            connect(LOAD3.y, FW_sinkP.u[1]) annotation (Line(points={{-199,30},{
                    -190,30},{-182,30}}, color={0,0,127}));
            connect(FW_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{
                    -159,30},{-152,30},{-146,30},{-146,8.8}}, color={0,0,127}));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{199,-70},
                    {199,-70},{182,-70}}, color={0,0,127}));
            connect(LOAD5.y, FW_sourceP.u[1]) annotation (Line(points={{199,-40},
                    {199,-40},{182,-40}}, color={0,0,127}));
            connect(FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                  points={{159,-40},{154,-40},{154,-9.2}}, color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{159,-70},{146,-70},{146,-9}}, color={0,0,127}));
            connect(DR_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points=
                   {{159,80},{146,80},{146,48.8}}, color={0,0,127}));
            connect(LOAD7.y, SP7_sourceH.u[1]) annotation (Line(points={{-79,140},
                    {-70,140},{-62,140}}, color={0,0,127}));
            connect(LOAD8.y, SP7_sourceW.u[1]) annotation (Line(points={{-79,110},
                    {-70,110},{-62,110}}, color={0,0,127}));
            connect(LOAD9.y, SP6_sourceH.u[1]) annotation (Line(points={{21,130},
                    {30,130},{38,130}}, color={0,0,127}));
            connect(LOAD10.y, SP6_sourceW.u[1]) annotation (Line(points={{21,160},
                    {30,160},{38,160}}, color={0,0,127}));
            connect(SP6_sourceH.y[1], sourceMassFlow_ST.in_h) annotation (Line(
                  points={{61,130},{66,130},{66,106}}, color={0,0,127}));
            connect(SP6_sourceW.y[1], sourceMassFlow_ST.in_w0) annotation (Line(
                  points={{61,160},{74,160},{74,106}}, color={0,0,127}));
            connect(SP7_sourceW.y[1], sourceMassFlow_ST1.in_w0) annotation (Line(
                  points={{-39,110},{-34,110},{-34,86}}, color={0,0,127}));
            connect(SP7_sourceH.y[1], sourceMassFlow_ST1.in_h) annotation (Line(
                  points={{-39,140},{-34,140},{-26,140},{-26,86}}, color={0,0,127}));
            connect(LOAD11.y, sep_sourceH.u[1]) annotation (Line(points={{-179,
                    120},{-170,120},{-162,120}}, color={0,0,127}));
            connect(LOAD12.y, sep_sourceW.u[1]) annotation (Line(points={{-179,90},
                    {-170,90},{-162,90}}, color={0,0,127}));
            connect(sep_sourceW.y[1], sourceMassFlow.in_w0) annotation (Line(
                  points={{-139,90},{-134,90},{-134,66}}, color={0,0,127}));
            connect(sep_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-139,120},{-126,120},{-126,66}}, color={0,0,127}));
            connect(DR_sinkP.u[1], LOAD6.y) annotation (Line(points={{182,80},{
                    199,80},{199,80}}, color={0,0,127}));
            connect(sensT.inlet, HPHs.FW_out)
              annotation (Line(points={{-94,0},{-63.8889,0}}, color={0,0,255}));
            connect(sinkPressure.flange, sensT.outlet)
              annotation (Line(points={{-140,0},{-106,0}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -180},{240,180}}), graphics={Text(
                    extent={{92,176},{232,104}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    textString="Con le condizioni al contorno corrette la
temperatura di uscita dell'acqua di alimento 
� coerente con i PDF, ma le pressioni di
spillamento sono completamente sbagliate,
soprattutto quella sull'HPH2",
                    textStyle={TextStyle.Bold,TextStyle.Italic})}),
              Icon(coordinateSystem(extent={{-240,-180},{240,180}})),
              experiment(StopTime=800000),
              __Dymola_experimentSetupOutput);
          end test_HPH_train_offDesign_simplified;

          model test_HPH1_simp "Test model of HPH1"

            Preheater_simplified      HPH1(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_drainIN=true,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              D=0.6,
              Vhot=2.01,
              Vcold=0.56,
              Mm=7500,
              nominalColdFlow=88.59,
              nominalHotFlow=7.728,
              Kv=6.796833773e-6,
              Shot=315,
              Scold=315,
              HE(generateInitCode=true),
              Nhex=10,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4800),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4800),
              nominalColdPressure=18380000,
              nominalHotPressure=2037000,
              nominalColdInletTemperature=396.65,
              nominalColdOutletTemperature=422.65,
              nominalHotInletTemperature=528.15,
              nominalHotOutletTemperature=401.15)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=18380000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.709,
              h=3318000)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              w0=88.59)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.019,
              h=1225800)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
          equation
            connect(HPH1.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,HPH1. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,HPH1. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPH1.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,HPH1. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics));
          end test_HPH1_simp;

          model test_HPH2_simp "Test model of HPH2"

            Preheater_simplified      HPH2(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_drainIN=true,
              Vhot=2.99,
              Vcold=0.53,
              Mm=10000,
              nominalColdFlow=78.07,
              nominalHotFlow=4.019,
              Kv=6.575589005E-7,
              D=0.4,
              Shot=200,
              Scold=200,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              Nhex=10,
              HE(generateInitCode=true),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3680),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3680),
              nominalColdPressure=18140000,
              nominalHotPressure=8149000,
              nominalColdInletTemperature=396.65,
              nominalColdOutletTemperature=422.65,
              nominalHotInletTemperature=528.15,
              nominalHotOutletTemperature=401.15)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=18140000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.019,
              h=3218000)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=78.07,
              h=1197000)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=2037000)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
          equation
            connect(HPH2.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,HPH2. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,HPH2. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPH2.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,HPH2. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics));
          end test_HPH2_simp;

          model test_HPH2_simp_optB "Test model of HPH2"

            Preheater_simplified      HPH2(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_drainIN=true,
              Vhot=2.99,
              Vcold=0.53,
              Mm=10000,
              D=0.4,
              Shot=200,
              Scold=200,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2820),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2820),
              Kv=3.73e-5,
              nominalColdFlow=3.54,
              nominalHotFlow=3.73,
              Nhex=20,
              nominalColdPressure=8600000,
              nominalHotPressure=1000000,
              nominalColdInletTemperature=394.65,
              nominalColdOutletTemperature=573.15,
              nominalHotInletTemperature=821.15,
              nominalHotOutletTemperature=473.15)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=8600000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3583500,
              w0=1.4)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.54,
              h=515800)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
          equation
            connect(HPH2.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,HPH2. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,HPH2. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPH2.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,HPH2. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics));
          end test_HPH2_simp_optB;

          model test_LPH1_ultrasimp "Test model of LPH1"

            Preheater_quasiStatic LPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              V_cold=0.7,
              U=1537,
              A=320,
              T_DR_out(start=345.35, fixed=false),
              T_FW_out(start=345.35, fixed=false),
              h_DR_out(start=3e5, fixed=false),
              DT_m(start=59, fixed=false))
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1591000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=10.091,
              h=323400)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=2.962,
              h=2525200)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=64.26,
              h=197600)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-24,-6},{-44,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-46,-6},{-66,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=38070)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              use_in_w0=true,
              use_in_h=true,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-40,-90},{-20,-70}})));
            Modelica.Blocks.Sources.RealExpression w_pump(y=LPH1.w_DR_out)
              annotation (Placement(transformation(extent={{-80,-70},{-60,-50}})));
            Modelica.Blocks.Sources.RealExpression h_pump(y=LPH1.h_DR_out)
              annotation (Placement(transformation(extent={{-80,-50},{-60,-30}})));
          equation
            connect(LPH1.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,LPH1. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,LPH1. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-62,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-50,0},{-40,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,LPH1. FW_out) annotation (Line(
                points={{-28,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPH1.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(h_pump.y, sourceMassFlow.in_h) annotation (Line(
                points={{-59,-40},{-26,-40},{-26,-74}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(w_pump.y, sourceMassFlow.in_w0) annotation (Line(
                points={{-59,-60},{-34,-60},{-34,-74}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, sensT.inlet) annotation (Line(
                points={{-20,-80},{-10,-80},{-10,0},{-28,0}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics));
          end test_LPH1_ultrasimp;

          model test_LPH2_ultrasimp "Test model of LPH2"

            Preheater_quasiStatic LPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              V_cold=0.75,
              A=405.4,
              U=2250)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1441000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=6.908,
              h=430100)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.183,
              h=2673900)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=77.31,
              h=303500)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=103500)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
          equation
            connect(LPH2.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,LPH2. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,LPH2. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,LPH2. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPH2.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent=
                      {{-100,-100},{100,100}}), graphics));
          end test_LPH2_ultrasimp;

          model test_LPH3_ultrasimp "Test model of LPH3"

            Preheater_quasiStatic LPH3(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              V_cold=0.7,
              A=320,
              U=6600)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1275000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.532,
              h=540000)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=3.375,
              h=2820500)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=77.31,
              h=409800)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=243000)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
          equation
            connect(LPH2.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,LPH2. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,LPH2. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,LPH2. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPH2.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent=
                      {{-100,-100},{100,100}}), graphics));
          end test_LPH3_ultrasimp;

          model test_LPH4_ultrasimp "Test model of LPH4"

            Preheater_quasiStatic LPH4(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              V_cold=0.5,
              A=313,
              U=495)
              annotation (Placement(transformation(extent={{0,-20},{40,20}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1128000)
              annotation (Placement(transformation(extent={{-72,-10},{-92,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=2971200,
              w0=3.532)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=77.31,
              h=519200)
              annotation (Placement(transformation(extent={{84,-10},{64,10}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));
            ThermoPower.Water.SensW sensW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-42,-6},{-62,14}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=243000)
              annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-20,50},{0,70}})));
          equation
            connect(LPH2.FW_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{42,0},{64,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange,LPH2. ST_in) annotation (Line(
                points={{40,60},{20,60},{20,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure.flange, sensW.outlet) annotation (Line(
                points={{-72,0},{-58,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensW.inlet, sensT.outlet) annotation (Line(
                points={{-46,0},{-32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.inlet,LPH2. FW_out) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LPH2.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{20,-20},{20,-60},{40,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_DR.flange,LPH2. DR_in) annotation (Line(
                points={{0,60},{6,60},{6,20}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics));
          end test_LPH4_ultrasimp;
        end Test;

        package Preheaters_NusseltCondenser_tuning
          "Package containing test model for the Nusselt condenser type - for model tuning"

          package HPH2 "Test model of the HPH2"

            model test_condensingSection_FW
              "Test of the preheater condensing section"

              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final M=8000,
                final cm=500,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final Nw=5)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={10,18})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                  Nw=5)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={35,18})));

              ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=78.07,
                h=1202.5e3)
                annotation (Placement(transformation(extent={{30,-30},{50,-10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=18340000)
                annotation (Placement(transformation(extent={{70,50},{90,70}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Liquid,
                noInitialPressure=true,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                A=0.53,
                omega=210*0.8,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                N=6)                                                  annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={60,18})));
              ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={-12,18})));
              Modelica.Blocks.Sources.Constant T_in(k=563.15) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,40})));
              Modelica.Blocks.Sources.Constant T_out(k=567.15) annotation (
                  Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,0})));
            equation

              connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                  Line(
                  points={{13.72,18},{31.59,18}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV.wall)
                annotation (Line(points={{38.3,18},{55,18}}, color={255,127,0}));
              connect(flow1DFV.infl, sourceMassFlow2.flange)
                annotation (Line(points={{60,8},{60,-20},{50,-20}}, color={0,0,255}));
              connect(flow1DFV.outfl, sinkPressure1.flange) annotation (Line(points={{60,28},
                      {60,28},{60,60},{70,60}}, color={0,0,255}));
              connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                    points={{-15,22},{-48,22},{-48,40},{-59,40}}, color={0,0,127}));
              connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                    points={{-14.8,14},{-48.2,14},{-48.2,0},{-59,0}}, color={0,0,
                      127}));
              connect(tempSource1DlinFV.wall, tubeWalls_cond.int)
                annotation (Line(points={{-9,18},{6.4,18}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_condensingSection_FW;

            model test_condensingSection_ST
              "Test of the condensing section of the last high pressure preheater"

              Components.NusseltCondenser baseNusseltCondenser(
                zl_set=0.1,
                zl_start=0.1,
                V=2.99*0.8,
                A=1,
                S=210*0.8,
                noInitialPressure=true,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                gamma=8000,
                Nw=5,
                p_start=8150000)
                annotation (Placement(transformation(extent={{-28,12},{28,68}})));
              inner ThermoPower.System system
                annotation (Placement(transformation(extent={{80,80},{100,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=540000,
                w0=0)
                annotation (Placement(transformation(extent={{-62,36},{-42,56}})));
              ThermoPower.Water.SourcePressure sourceMassFlow1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=8150000,
                h=2760e3)
                annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
              ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph, Kv=1.095752222e-6)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={0,-38})));
              ThermoPower.PowerPlants.Control.PID PID_level(
                PVmin=0,
                CSmin=0,
                Ti=15,
                Kp=-20,
                steadyStateInit=true,
                PVmax=1,
                CSmax=1,
                PVstart=0.1,
                CSstart=0.6) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-40,-10})));
              ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=2037000)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={34,40})));
              Modelica.Blocks.Sources.Constant T_in(k=563.15) annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={70,60})));
              Modelica.Blocks.Sources.Constant T_out(k=567.15) annotation (
                  Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={70,20})));
            equation
              connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
                annotation (Line(
                  points={{-20,80},{0,80},{0,64}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
                annotation (Line(
                  points={{-42,46},{-26,46},{-26,48},{-10,48}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                  points={{-10,26},{-44,26},{-44,0}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                  points={{-10,38},{-36,38},{-36,0}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(PID_level.CS, valveDrain.cmd) annotation (Line(points={{-40,
                      -20},{-40,-20},{-40,-38},{-8,-38}}, color={0,0,127}));
              connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                    points={{0,-48},{0,-60},{20,-60}}, color={0,0,255}));
              connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
                annotation (Line(points={{0,22},{0,22},{0,-28}}, color={0,0,255}));
              connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
                 Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
              connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                    points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
              connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                    points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})));
            end test_condensingSection_ST;

            model test_condensingSection
              "Test of the preheater condensing section"

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final M=8000,
                final cm=500,
                final Nw=5,
                Tstart1=563.15,
                TstartN=567.15,
                initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={10,20})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={35,20})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=78.07,
                h=1202.5e3)
                annotation (Placement(transformation(extent={{30,-28},{50,-8}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=18340000)
                annotation (Placement(transformation(extent={{70,50},{90,70}})));
              ThermoPower.Water.Flow1DFV flow1DFV(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                omega=210*0.8,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                N=6,
                hstartin=1202.5e3,
                hstartout=1262.5e3,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                A=0.53*0.8)                                           annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={60,20})));
              Components.NusseltCondenser baseNusseltCondenser(
                zl_set=0.1,
                zl_start=0.1,
                V=2.99*0.8,
                A=1,
                S=210*0.8,
                noInitialPressure=true,
                gamma=7952.348,
                Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                p_start=8150000)
                annotation (Placement(transformation(extent={{-48,-8},{8,48}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=540000,
                w0=0)
                annotation (Placement(transformation(extent={{-88,18},{-68,38}})));
              ThermoPower.Water.SourcePressure sourceMassFlow1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=2760e3,
                p0=8150000)
                annotation (Placement(transformation(extent={{-66,50},{-46,70}})));
              ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph, Kv=6.575589005e-7/0.6)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={-20,-50})));
              ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=2037000)
                annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
              IndustrialControlSystems.Controllers.PI PI_valve(
                CSmin=0,
                CS_start=0.6,
                AntiWindup=true,
                useTS=false,
                Ti=10,
                Kp=-100,
                CSmax=1)
                        annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={-60,-20})));
              Modelica.Blocks.Sources.Constant const(k=0.3) annotation (Placement(
                    transformation(extent={{-100,-20},{-80,0}})));
              Modelica.Blocks.Sources.BooleanConstant booleanConstant annotation (
                 Placement(transformation(extent={{-100,-50},{-80,-30}})));
            equation

              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{13.72,20},{31.59,20}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1,flow1DFV. wall)
                annotation (Line(points={{38.3,20},{55,20}}, color={255,127,0}));
              connect(flow1DFV.infl,sourceMassFlow2. flange)
                annotation (Line(points={{60,10},{60,-18},{50,-18}},color={0,0,255}));
              connect(flow1DFV.outfl,sinkPressure1. flange) annotation (Line(points={{60,30},
                      {60,30},{60,60},{70,60}}, color={0,0,255}));
              connect(sourceMassFlow1.flange,baseNusseltCondenser. steam_in)
                annotation (Line(
                  points={{-46,60},{-20,60},{-20,44}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMassFlow.flange,baseNusseltCondenser. drained_in)
                annotation (Line(
                  points={{-68,28},{-30,28}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(valveDrain.outlet,sinkPressure. flange) annotation (Line(
                    points={{-20,-60},{-20,-80},{0,-80}},
                                                       color={0,0,255}));
              connect(baseNusseltCondenser.drained_out,valveDrain. inlet)
                annotation (Line(points={{-20,2},{-20,-40}},     color={0,0,255}));
              connect(baseNusseltCondenser.level, PI_valve.PV) annotation (Line(
                    points={{-30,6},{-59,6},{-59,-12}}, color={0,0,127}));
              connect(baseNusseltCondenser.zl_SP, PI_valve.SP) annotation (Line(
                    points={{-30,18},{-30,18},{-66,18},{-66,-12}}, color={0,0,127}));
              connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-60,-29},
                      {-60,-29},{-60,-50},{-28,-50}},      color={0,0,127}));
              connect(baseNusseltCondenser.DHT, tubeWalls_cond.int)
                annotation (Line(points={{-11,20},{6.4,20}}, color={255,127,0}));
              connect(PI_valve.TR, const.y) annotation (Line(points={{-68,-20},{
                      -72,-20},{-72,-10},{-79,-10}}, color={0,0,127}));
              connect(booleanConstant.y, PI_valve.TS) annotation (Line(points={{
                      -79,-40},{-72,-40},{-72,-24},{-68,-24}}, color={255,0,255}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput);
            end test_condensingSection;

            model test_subcoolingSection
              "Test model of the subcooling section (HPH2)"

              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=78.07,
                h=1197.4e3) annotation (Placement(transformation(extent={{20,-50},
                        {40,-30}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=4.019,
                h=1.3242e6)
                annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=17910000)
                annotation (Placement(transformation(extent={{60,30},{80,50}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=8149000)
                annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV_FW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                omega=210*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                hstartin=1197.5e3,
                hstartout=1202.5e3,
                A=0.53*0.1) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,0})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final M=1000,
                Tstart1=548.15,
                TstartN=563.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,0})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,0})));
              ThermoPower.Water.Flow1DFV flow1DFV_SP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                omega=210*0.1,
                hstartin=1.3e6,
                hstartout=1.2e6,
                wnom=4.019,
                A=2.99*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3000)) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,0})));
            equation

              connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                    points={{60,40},{50,40},{50,10}}, color={0,0,255}));
              connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                    points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{-8.28,0},{9.59,0}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
              connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                    points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
              connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                    points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
              connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_subcoolingSection;

            model test_desuperheatingSection
              "Test model of the subcooling section (HPH2)"

              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=78.07,
                h=1275.5e3) annotation (Placement(transformation(extent={{20,-50},
                        {40,-30}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=4.019,
                h=3216000)
                annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=17910000)
                annotation (Placement(transformation(extent={{60,30},{80,50}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=8149000)
                annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV_FW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                omega=210*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                A=0.53*0.1,
                hstartin=1275.5e3,
                hstartout=1320e3) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,0})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final M=1000,
                Tstart1=548.15,
                TstartN=563.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,0})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,0})));
              ThermoPower.Water.Flow1DFV flow1DFV_SP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                omega=210*0.1,
                wnom=4.019,
                A=2.99*0.1,
                hstartin=3.216e6,
                hstartout=2760e3,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4500)) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,0})));
            equation

              connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                    points={{60,40},{50,40},{50,10}}, color={0,0,255}));
              connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                    points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{-8.28,0},{9.59,0}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
              connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                    points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
              connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                    points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
              connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_desuperheatingSection;

            model test_HPH2 "Test model of the complete HPH2"

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=3216000,
                p0=8150000)
                annotation (Placement(transformation(extent={{-80,80},{-60,100}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=17910000)
                annotation (Placement(transformation(extent={{60,80},{80,100}})));
              ThermoPower.Water.Flow1DFV FW_des(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                omega=210*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                A=0.53*0.1,
                hstartin=1275.5e3,
                hstartout=1320e3,
                initOpt=ThermoPower.Choices.Init.Options.fixedState) annotation (
                  Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,50})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                final M=1000,
                Tstart1=548.15,
                TstartN=563.15,
                initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,50})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,50})));
              ThermoPower.Water.Flow1DFV SP_des(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                omega=210*0.1,
                wnom=4.019,
                A=2.99*0.1,
                hstartin=3.216e6,
                hstartout=2760e3,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4500),
                initOpt=ThermoPower.Choices.Init.Options.fixedState) annotation (
                  Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,50})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond1(
                final M=8000,
                final cm=500,
                final Nw=5,
                Tstart1=563.15,
                TstartN=567.15,
                initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,6})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond1(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,6})));
              ThermoPower.Water.Flow1DFV FW_cond(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                omega=210*0.8,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                N=6,
                hstartin=1202.5e3,
                hstartout=1262.5e3,
                A=0.53*0.8,
                initOpt=ThermoPower.Choices.Init.Options.fixedState) annotation (
                  Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,6})));
              Components.NusseltCondenser SP_cond(
                zl_set=0.1,
                zl_start=0.1,
                V=2.99*0.8,
                A=1,
                S=210*0.8,
                gamma=7952.348,
                Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                noInitialPressure=true,
                p_start=8150000) annotation (Placement(transformation(extent={{
                        -78,-22},{-22,34}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=540000,
                w0=0)
                annotation (Placement(transformation(extent={{-90,4},{-70,24}})));
              IndustrialControlSystems.Controllers.PI PI_valve(
                CSmin=0,
                CS_start=0.6,
                AntiWindup=true,
                useTS=false,
                Ti=10,
                Kp=-100,
                CSmax=1)
                        annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={-80,-34})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=78.07,
                h=1197.4e3) annotation (Placement(transformation(extent={{30,-88},
                        {50,-68}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=2037000)
                annotation (Placement(transformation(extent={{-30,-88},{-10,-68}})));
              ThermoPower.Water.Flow1DFV sub_FW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                wnom=78.07,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                omega=210*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                hstartin=1197.5e3,
                hstartout=1202.5e3,
                A=0.53*0.1,
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                N=6) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,-34})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond2(
                final cm=500,
                final M=1000,
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                final Nw=5,
                Tstart1=548.15,
                TstartN=563.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,-34})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond2(
                  redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                  Nw=5)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,-34})));
              ThermoPower.Water.Flow1DFV SP_sub(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                omega=210*0.1,
                hstartin=1.3e6,
                hstartout=1.2e6,
                wnom=4.019,
                A=2.99*0.1,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3000),
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                N=6) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,-34})));
              ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph, Kv=6.575589005e-7/0.6)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={-50,-60})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-100,-100},{-80,-80}})));
            equation
              connect(sinkPressureFW.flange, FW_des.outfl) annotation (Line(
                    points={{60,90},{50,90},{50,60}}, color={0,0,255}));
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{-8.28,50},{9.59,50}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, FW_des.wall)
                annotation (Line(points={{16.3,50},{45,50}}, color={255,127,0}));
              connect(sourceMassFlowSP.flange, SP_des.infl) annotation (Line(
                    points={{-60,90},{-50,90},{-50,60}}, color={0,0,255}));
              connect(SP_des.wall, tubeWalls_cond.int) annotation (Line(points={{
                      -45,50},{-15.6,50}}, color={255,127,0}));
              connect(tubeWalls_cond1.ext, heatExchangerTopology_cond1.side2)
                annotation (Line(
                  points={{-8.28,6},{9.59,6}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond1.side1, FW_cond.wall)
                annotation (Line(points={{16.3,6},{45,6}}, color={255,127,0}));
              connect(sourceMassFlow.flange, SP_cond.drained_in) annotation (Line(
                  points={{-70,14},{-60,14}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SP_cond.level, PI_valve.PV) annotation (Line(points={{-60,
                      -8},{-79,-8},{-79,-26}}, color={0,0,127}));
              connect(SP_cond.zl_SP, PI_valve.SP) annotation (Line(points={{-60,4},
                      {-60,4},{-86,4},{-86,-26}}, color={0,0,127}));
              connect(SP_cond.DHT, tubeWalls_cond1.int) annotation (Line(points={
                      {-41,6},{-28,6},{-15.6,6}}, color={255,127,0}));
              connect(SP_des.outfl, SP_cond.steam_in)
                annotation (Line(points={{-50,40},{-50,30}}, color={0,0,255}));
              connect(FW_des.infl, FW_cond.outfl) annotation (Line(points={{50,40},
                      {50,40},{50,16}}, color={0,0,255}));
              connect(sourceMassFlowFW.flange, sub_FW.infl) annotation (Line(
                    points={{50,-78},{50,-78},{50,-44}}, color={0,0,255}));
              connect(tubeWalls_cond2.ext, heatExchangerTopology_cond2.side2)
                annotation (Line(
                  points={{-8.28,-34},{9.59,-34}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond2.side1, sub_FW.wall) annotation (
                 Line(points={{16.3,-34},{45,-34}}, color={255,127,0}));
              connect(SP_sub.wall, tubeWalls_cond2.int) annotation (Line(points={
                      {-45,-34},{-15.6,-34}}, color={255,127,0}));
              connect(SP_cond.drained_out, SP_sub.infl) annotation (Line(points={
                      {-50,-12},{-50,-12},{-50,-24}}, color={0,0,255}));
              connect(FW_cond.infl, sub_FW.outfl) annotation (Line(points={{50,-4},
                      {50,-4},{50,-24}}, color={0,0,255}));
              connect(SP_sub.outfl, valveDrain.inlet) annotation (Line(points={{
                      -50,-44},{-50,-44},{-50,-50}}, color={0,0,255}));
              connect(valveDrain.outlet, sinkPressure1.flange) annotation (Line(
                    points={{-50,-70},{-50,-78},{-30,-78}}, color={0,0,255}));
              connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-80,
                      -43},{-80,-60},{-58,-60}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false,
                      extent={{-100,-100},{100,100}})));
            end test_HPH2;
          end HPH2;

          package HPH1 "Test models of the HPH1"

            model test_condensingSection_FW
              "Test of the preheater condensing section"

              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final Nw=5,
                final M=7500*0.8)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={10,18})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                  Nw=5)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={35,18})));

              ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=780.2e3)
                annotation (Placement(transformation(extent={{30,-30},{50,-10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=18380000)
                annotation (Placement(transformation(extent={{70,50},{90,70}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Liquid,
                noInitialPressure=true,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                A=0.53,
                N=6,
                omega=172*0.8,
                wnom=88.59,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000))                      annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={60,18})));
              ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={-12,18})));
              Modelica.Blocks.Sources.Constant T_in(k=473.15) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,40})));
              Modelica.Blocks.Sources.Constant T_out(k=482.15) annotation (
                  Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,0})));
            equation

              connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                  Line(
                  points={{13.72,18},{31.59,18}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV.wall)
                annotation (Line(points={{38.3,18},{55,18}}, color={255,127,0}));
              connect(flow1DFV.infl, sourceMassFlow2.flange)
                annotation (Line(points={{60,8},{60,-20},{50,-20}}, color={0,0,255}));
              connect(flow1DFV.outfl, sinkPressure1.flange) annotation (Line(points={{60,28},
                      {60,28},{60,60},{70,60}}, color={0,0,255}));
              connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                    points={{-15,22},{-48,22},{-48,40},{-59,40}}, color={0,0,127}));
              connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                    points={{-14.8,14},{-48.2,14},{-48.2,0},{-59,0}}, color={0,0,
                      127}));
              connect(tempSource1DlinFV.wall, tubeWalls_cond.int)
                annotation (Line(points={{-9,18},{6.4,18}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_condensingSection_FW;

            model test_condensingSection_ST
              "Test of the condensing section of the last high pressure preheater"

              Components.NusseltCondenser baseNusseltCondenser(
                zl_set=0.1,
                zl_start=0.1,
                A=1,
                noInitialPressure=true,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                Nw=5,
                V=2.01*0.8,
                S=172*0.8,
                gamma=6800,
                p_start=2037000)
                annotation (Placement(transformation(extent={{-28,12},{28,68}})));
              inner ThermoPower.System system
                annotation (Placement(transformation(extent={{80,80},{100,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=4.02,
                h=1225.81e3)
                annotation (Placement(transformation(extent={{-62,36},{-42,56}})));
              ThermoPower.Water.SourcePressure sourceMassFlow1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=2037000,
                h=2799e3)
                annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
              ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph, Kv=6.798592788e-6/0.6)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={0,-38})));
              ThermoPower.PowerPlants.Control.PID PID_level(
                PVmin=0,
                CSmin=0,
                Ti=15,
                Kp=-20,
                steadyStateInit=true,
                PVmax=1,
                CSmax=1,
                PVstart=0.1,
                CSstart=0.6) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-40,-10})));
              ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=900000)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={34,40})));
              Modelica.Blocks.Sources.Constant T_in(k=473.15) annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={70,60})));
              Modelica.Blocks.Sources.Constant T_out(k=482.15) annotation (
                  Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={70,20})));
            equation
              connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
                annotation (Line(
                  points={{-20,80},{0,80},{0,64}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
                annotation (Line(
                  points={{-42,46},{-26,46},{-26,48},{-10,48}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                  points={{-10,26},{-44,26},{-44,0}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                  points={{-10,38},{-36,38},{-36,0}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(PID_level.CS, valveDrain.cmd) annotation (Line(points={{-40,
                      -20},{-40,-20},{-40,-38},{-8,-38}}, color={0,0,127}));
              connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                    points={{0,-48},{0,-60},{20,-60}}, color={0,0,255}));
              connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
                annotation (Line(points={{0,22},{0,22},{0,-28}}, color={0,0,255}));
              connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
                 Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
              connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                    points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
              connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                    points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})));
            end test_condensingSection_ST;

            model test_condensingSection
              "Test of the preheater condensing section"

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final M=7500*0.8,
                Tstart1=563.15,
                TstartN=567.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={10,20})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={35,20})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=780.2e3)
                annotation (Placement(transformation(extent={{30,-28},{50,-8}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=18340000)
                annotation (Placement(transformation(extent={{70,50},{90,70}})));
              ThermoPower.Water.Flow1DFV flow1DFV(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                A=0.53*0.8,
                wnom=88.59,
                hstartin=780.2e3,
                hstartout=873.2e3,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                omega=205*0.8)                                        annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={60,20})));
              Components.NusseltCondenser baseNusseltCondenser(
                zl_set=0.1,
                zl_start=0.1,
                A=1,
                noInitialPressure=true,
                Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                V=2.01*0.8,
                gamma=8000,
                S=205*0.80,
                p_start=2037000)
                annotation (Placement(transformation(extent={{-48,-8},{8,48}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=4.02,
                h=1225.81e3)
                annotation (Placement(transformation(extent={{-88,18},{-68,38}})));
              ThermoPower.Water.SourcePressure sourceMassFlow1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=2037000,
                h=2799e3)
                annotation (Placement(transformation(extent={{-66,50},{-46,70}})));
              ThermoPower.Water.ValveLin valveDrain(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph, Kv=6.798592788e-6/0.6)
                annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=-90,
                    origin={-20,-50})));
              ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=900000)
                annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
              IndustrialControlSystems.Controllers.PI PI_valve(
                CSmin=0,
                CS_start=0.6,
                AntiWindup=true,
                useTS=false,
                Ti=10,
                Kp=-100,
                CSmax=1)
                        annotation (Placement(transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={-60,-20})));

            Real DT = baseNusseltCondenser.T_sat - baseNusseltCondenser.Tw[3];
            Real UA = baseNusseltCondenser.gamma*baseNusseltCondenser.S;

            equation
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{13.72,20},{31.59,20}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1,flow1DFV. wall)
                annotation (Line(points={{38.3,20},{55,20}}, color={255,127,0}));
              connect(flow1DFV.infl,sourceMassFlow2. flange)
                annotation (Line(points={{60,10},{60,-18},{50,-18}},color={0,0,255}));
              connect(flow1DFV.outfl,sinkPressure1. flange) annotation (Line(points={{60,30},
                      {60,30},{60,60},{70,60}}, color={0,0,255}));
              connect(sourceMassFlow1.flange,baseNusseltCondenser. steam_in)
                annotation (Line(
                  points={{-46,60},{-20,60},{-20,44}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMassFlow.flange,baseNusseltCondenser. drained_in)
                annotation (Line(
                  points={{-68,28},{-30,28}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(valveDrain.outlet,sinkPressure. flange) annotation (Line(
                    points={{-20,-60},{-20,-80},{0,-80}},
                                                       color={0,0,255}));
              connect(baseNusseltCondenser.drained_out,valveDrain. inlet)
                annotation (Line(points={{-20,2},{-20,-40}},     color={0,0,255}));
              connect(baseNusseltCondenser.level, PI_valve.PV) annotation (Line(
                    points={{-30,6},{-59,6},{-59,-12}}, color={0,0,127}));
              connect(baseNusseltCondenser.zl_SP, PI_valve.SP) annotation (Line(
                    points={{-30,18},{-30,18},{-66,18},{-66,-12}}, color={0,0,127}));
              connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-60,-29},{-60,-29},
                      {-60,-50},{-28,-50}},                color={0,0,127}));
              connect(baseNusseltCondenser.DHT, tubeWalls_cond.int)
                annotation (Line(points={{-11,20},{6.4,20}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput);
            end test_condensingSection;

            model test_subcoolingSection
              "Test model of the subcooling section (HPH2)"

              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=768.8e3) annotation (Placement(transformation(extent={{20,-50},
                        {40,-30}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=7.73,
                h=912.5e3)
                annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=18380000)
                annotation (Placement(transformation(extent={{60,30},{80,50}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=2037000)
                annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV_FW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                hstartin=1197.5e3,
                hstartout=1202.5e3,
                A=0.53*0.1,
                wnom=88.59,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                omega=205*0.15) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,0})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final M=7500*0.1,
                Tstart1=548.15,
                TstartN=563.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,0})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,0})));
              ThermoPower.Water.Flow1DFV flow1DFV_SP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                hstartin=1.3e6,
                hstartout=1.2e6,
                A=2.01*0.1,
                wnom=7.73,
                omega=205*0.15,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4500)) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,0})));
            equation

              connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                    points={{60,40},{50,40},{50,10}}, color={0,0,255}));
              connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                    points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{-8.28,0},{9.59,0}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
              connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                    points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
              connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                    points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
              connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_subcoolingSection;

            model test_desuperheatingSection
              "Test model of the subcooling section (HPH2)"

              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=88.59,
                h=873.2e3) annotation (Placement(transformation(extent={{20,-50},
                        {40,-30}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=3.71,
                h=3318.6e3)
                annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=18340000)
                annotation (Placement(transformation(extent={{60,30},{80,50}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=2037000)
                annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
              inner ThermoPower.System system annotation (Placement(
                    transformation(extent={{-100,80},{-80,100}})));
              ThermoPower.Water.Flow1DFV flow1DFV_FW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                A=0.53*0.1,
                hstartin=1275.5e3,
                hstartout=1320e3,
                wnom=88.59,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                omega=205*0.067) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={50,0})));
              ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                final cm=500,
                final Nw=5,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                final M=1000,
                Tstart1=548.15,
                TstartN=563.15)
                annotation (Placement(transformation(
                    extent={{-12,12},{12,-12}},
                    rotation=-90,
                    origin={-12,0})));
              ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                  Nw=5, redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                annotation (Placement(transformation(
                    extent={{-12,-11},{12,11}},
                    rotation=-90,
                    origin={13,0})));
              ThermoPower.Water.Flow1DFV flow1DFV_SP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                L=1,
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                N=6,
                initOpt=ThermoPower.Choices.Init.Options.steadyState,
                hstartin=3.216e6,
                hstartout=2760e3,
                A=2.01*0.1,
                wnom=3.71,
                redeclare model HeatTransfer =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4500),
                omega=205*0.067) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={-50,0})));
            equation

              connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                    points={{60,40},{50,40},{50,10}}, color={0,0,255}));
              connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                    points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
              connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                  Line(
                  points={{-8.28,0},{9.59,0}},
                  color={255,127,0},
                  smooth=Smooth.None));
              connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
              connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                    points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
              connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                    points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
              connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
              annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                        -100,-100},{100,100}})));
            end test_desuperheatingSection;
          end HPH1;

          model test_HPH2 "Test model of the HPH2"

            Preheater_controlledLevel HPH2(
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3600, alpha=0.8),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=4500, alpha=0.8),
              Vhot_des=2.99*0.1,
              Vcold_des=0.53*0.1,
              Shot_des=210*0.1,
              Scold_des=210*0.1,
              Mm_des=10000*0.1,
              nominalColdFlow_des=78.07,
              nominalHotFlow_des=4.019,
              nominalColdDeltaP_des=0,
              nominalHotDeltaP_des=0,
              Vhot_cond=2.99*0.8,
              A=1,
              Shot_cond=210*0.8,
              gamma=7950,
              zl_set=0.1,
              zl_start=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3600, alpha=0.8),
              Scold_cond=210*0.8,
              Mm_cond=10000*0.8,
              nominalColdFlow_cond=78.07,
              nominalColdDeltaP_cond=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3600, alpha=0.8),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              Vhot_sub=2.99*0.1,
              Vcold_sub=0.53*0.1,
              Shot_sub=210*0.1,
              Scold_sub=210*0.1,
              Mm_sub=10000*0.1,
              nominalColdFlow_sub=78.07,
              nominalHotFlow_sub=4.019,
              nominalColdDeltaP_sub=0,
              nominalHotDeltaP_sub=0,
              cm=500,
              Kp=-100,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              Kv=6.575589005e-7/0.6,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_des=3,
              Nhex_cond=3,
              Vcold_cond=0.53*0.8,
              Nhex_sub=5,
              nominalColdPressure_des=17910000,
              nominalHotPressure_des=8149000,
              nominalColdInletTemperature_des=561.15,
              nominalColdOutletTemperature_des=566.15,
              nominalHotInletTemperature_des=702.15,
              nominalHotOutletTemperature_des=569.65,
              p_start=8149000,
              nominalColdPressure_cond=17910000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdPressure_sub=17910000,
              nominalHotPressure_sub=8149000,
              nominalColdInletTemperature_sub=546.15,
              nominalColdOutletTemperature_sub=547.15,
              nominalHotInletTemperature_sub=569.15,
              nominalHotOutletTemperature_sub=551.15)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));

            ThermoPower.Water.SourcePressure sourceMassFlowSP(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3216000,
              p0=8150000)
              annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
            ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, p0=17910000)
              annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
            inner ThermoPower.System system annotation (Placement(transformation(
                    extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=78.07,
              h=1197.4e3,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{80,-10},{60,10}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=2037000)
              annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-60,22},{-40,42}})));
            Modelica.Blocks.Sources.Step step(
              height=5,
              offset=78.07,
              startTime=500)
              annotation (Placement(transformation(extent={{40,20},{60,40}})));
          equation
            connect(sourceMassFlowSP.flange, HPH2.ST_in) annotation (Line(points=
                    {{-20,60},{0,60},{0,20}}, color={0,0,255}));
            connect(sinkPressureFW.flange, HPH2.FW_out) annotation (Line(points={
                    {-60,0},{-40,0},{-20,0}}, color={0,0,255}));
            connect(HPH2.FW_in, sourceMassFlowFW.flange)
              annotation (Line(points={{22,0},{60,0}}, color={0,0,255}));
            connect(HPH2.DR_out, sinkPressure1.flange) annotation (Line(points={{
                    0,-20},{0,-20},{0,-60},{20,-60}}, color={0,0,255}));
            connect(sourceMassFlow.flange, HPH2.DR_in) annotation (Line(points={{
                    -40,32},{-14,32},{-14,20}}, color={0,0,255}));
            connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                    30},{74,30},{74,6}}, color={0,0,127}));
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=1000),
              __Dymola_experimentSetupOutput,
              Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
          end test_HPH2;

          model test_HPH1 "Test model of the HPH1"

            Preheater_controlledLevel HPH1(
              Vcold_des=0.53*0.1,
              nominalColdDeltaP_des=0,
              nominalHotDeltaP_des=0,
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              nominalColdDeltaP_cond=0,
              Vcold_sub=0.53*0.1,
              nominalColdDeltaP_sub=0,
              nominalHotDeltaP_sub=0,
              cm=500,
              Kp=-100,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              Nhex_des=3,
              Nhex_cond=3,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=4500, alpha=0.8),
              Vhot_des=2.01*0.1,
              Shot_des=205*0.067,
              Scold_des=205*0.067,
              Mm_des=7500*0.05,
              nominalColdFlow_des=88.59,
              nominalHotFlow_des=3.71,
              Vhot_cond=2.01*0.8,
              Shot_cond=205*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Scold_cond=205*0.8,
              Mm_cond=7500*0.8,
              nominalColdFlow_cond=88.59,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4500),
              Vhot_sub=2.01*0.1,
              Shot_sub=205*0.15,
              Scold_sub=205*0.15,
              Mm_sub=7500*0.15,
              nominalColdFlow_sub=88.59,
              nominalHotFlow_sub=7.73,
              Nhex_sub=5,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              CSstart=0.2,
              Kv=6.798592788e-6/0.2,
              nominalColdPressure_des=18380000,
              nominalHotPressure_des=2037000,
              nominalColdInletTemperature_des=476.25,
              nominalColdOutletTemperature_des=481.15,
              nominalHotInletTemperature_des=705.45,
              nominalHotOutletTemperature_des=486.55,
              p_start=2037000,
              nominalColdPressure_cond=18380000,
              nominalColdInletTemperature_cond=454.95,
              nominalColdOutletTemperature_cond=476.25,
              nominalColdPressure_sub=18380000,
              nominalHotPressure_sub=2037000,
              nominalColdInletTemperature_sub=452.35,
              nominalColdOutletTemperature_sub=454.95,
              nominalHotInletTemperature_sub=486.15,
              nominalHotOutletTemperature_sub=457.15)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));

            ThermoPower.Water.SourcePressure sourceMassFlowSP(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318.6e3,
              p0=2037000)
              annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
            ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, p0=18380000)
              annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                            annotation (Placement(transformation(
                    extent={{-100,80},{-80,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=88.59,
              h=768.8e3)
              annotation (Placement(transformation(extent={{80,-10},{60,10}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000)
              annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.02,
              h=1225.81e3)
              annotation (Placement(transformation(extent={{-60,22},{-40,42}})));
            Modelica.Blocks.Sources.Step step(
              height=5,
              startTime=500,
              offset=88.59)
              annotation (Placement(transformation(extent={{40,20},{60,40}})));
          equation
            connect(sourceMassFlowSP.flange, HPH1.ST_in) annotation (Line(points=
                    {{-20,60},{0,60},{0,20}}, color={0,0,255}));
            connect(sinkPressureFW.flange, HPH1.FW_out) annotation (Line(points={
                    {-60,0},{-40,0},{-20,0}}, color={0,0,255}));
            connect(HPH1.FW_in, sourceMassFlowFW.flange)
              annotation (Line(points={{22,0},{60,0}}, color={0,0,255}));
            connect(HPH1.DR_out, sinkPressure1.flange) annotation (Line(points={{
                    0,-20},{0,-20},{0,-60},{20,-60}}, color={0,0,255}));
            connect(sourceMassFlow.flange, HPH1.DR_in) annotation (Line(points={{
                    -40,32},{-14,32},{-14,20}}, color={0,0,255}));
            connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                    30},{74,30},{74,6}}, color={0,0,127}));
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=1000),
              __Dymola_experimentSetupOutput,
              Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
          end test_HPH1;
        end Preheaters_NusseltCondenser_tuning;

      end PreHeaters;
    end HeatExchangers;

    package SteamTurbine "Package containing all the steam turbines models"
      model HPT "Model of the high pressure turbine"

        replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
          constrainedby Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        outer ThermoPower.System system "System wide properties";

        Modelica.SIunits.Power Pm "Mechanical power";

        ThermoPower.Water.SteamTurbineStodola HPT1(
          redeclare package Medium = Medium,
          wnom=88.59,
          eta_mech=1,
          eta_iso_nom=0.9034,
          partialArc_nom=1,
          PRstart=2.15,
          Kt=0.003333977,
          pnom=17500000)
          annotation (Placement(transformation(extent={{-26,-10},{-6,10}})));
        ThermoPower.Water.SteamTurbineStodola HPT2(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=84.57,
          eta_iso_nom=0.8760,
          pnom=8149000,
          Kt=0.00686821)
          annotation (Placement(transformation(extent={{28,-10},{48,10}})));

        Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_HP_in annotation (
            Placement(transformation(extent={{-114,-10},{-94,10}}),
              iconTransformation(extent={{-120,-10},{-100,10}})));
        Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_HP_out
          annotation (Placement(transformation(extent={{94,-10},{114,10}}),
              iconTransformation(extent={{100,-10},{120,10}})));
        ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={
                  {-86,14},{-74,26}}), iconTransformation(extent={{-120,50},{-100,70}})));
        ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{74,14},{86,26}}),
              iconTransformation(extent={{-120,-90},{-100,-70}})));
        ThermoPower.Water.PressDrop pressDrop_HPT1_HPH2(
          redeclare package Medium = Medium,
          wnom=4.019,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          rhonom=27.8679,
          allowFlowReversal=false,
          dpnom=100000)   annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={8,-40})));

        ThermoPower.Water.FlangeB SP7(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{2,-86},{14,-74}}), iconTransformation(
                extent={{-10,-120},{10,-100}})));
        ThermoPower.Water.SinkMassFlow sinkMassFlow(redeclare package Medium =
             Medium, w0=2)
          annotation (Placement(transformation(extent={{60,50},{80,70}})));

      equation
        Pm = HPT1.omega*HPT1.tau + HPT2.omega*HPT2.tau;
        connect(HPT1.shaft_b, HPT2.shaft_a) annotation (Line(
            points={{-9.6,0},{31.4,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(HPT2.shaft_b, flange_HP_out) annotation (Line(
            points={{44.4,0},{104,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(HPT1.outlet, pressDrop_HPT1_HPH2.inlet) annotation (Line(
            points={{-8,8},{8,8},{8,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(HPT1.outlet, HPT2.inlet) annotation (Line(
            points={{-8,8},{30,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(HPT2.outlet, vap_out) annotation (Line(
            points={{46,8},{46,20},{80,20}},
            color={0,0,255},
            smooth=Smooth.None));

        connect(pressDrop_HPT1_HPH2.outlet, SP7) annotation (Line(
            points={{8,-50},{8,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(HPT2.outlet, sinkMassFlow.flange) annotation (Line(
            points={{46,8},{46,60},{60,60}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(flange_HP_in, HPT1.shaft_a) annotation (Line(
            points={{-104,0},{-22.6,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(vap_in, HPT1.inlet)
          annotation (Line(points={{-80,20},{-24,20},{-24,8}}, color={0,0,255}));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}})),           Icon(coordinateSystem(
                preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
              Polygon(
                points={{40,20},{40,-20},{68,-46},{68,48},{40,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-94,60},{-100,60},{-60,60},{-60,20}},
                color={0,0,0},
                thickness=0.5),
              Rectangle(
                extent={{-100,8},{-60,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{-34,8},{40,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{68,8},{100,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Line(
                points={{68,-46},{68,-60},{68,-80},{10,-80}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-34,-44},{-34,-60},{0,-60},{0,-100}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{18,-60},{0,-60},{40,-60},{40,-20}},
                color={0,0,0},
                thickness=0.5),
                         Text(extent={{-106,96},{110,66}},
                textString="%name",
                lineColor={0,0,0}),
              Line(
                points={{-100,-80},{-10,-80}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{-10,-80},{-10,-78},{-8,-74},{-6,-72},{-2,-70},{2,-70},{6,-72},
                    {8,-74},{10,-78},{10,-80}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None)}));
      end HPT;

      model IPT "Model of the intermediate  pressure turbine"

        replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
          constrainedby Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        outer ThermoPower.System system "System wide properties";

        Modelica.SIunits.Power Pm "Mechanical power";

        ThermoPower.Water.SteamTurbineStodola IPT1(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=82.57,
          eta_iso_nom=0.9163,
          Kt=0.01248715,
          pnom=4540000)
          annotation (Placement(transformation(extent={{-56,-10},{-36,10}})));
        ThermoPower.Water.SteamTurbineStodola IPT2(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=78.86,
          eta_iso_nom=0.9109,
          Kt=0.02361412,
          pnom=2100000)
          annotation (Placement(transformation(extent={{-16,-10},{4,10}})));

        ThermoPower.Water.SteamTurbineStodola IPT3(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=75.31,
          pnom=927900,
          eta_iso_nom=0.9081,
          Kt=0.05110007)
          annotation (Placement(transformation(extent={{24,-10},{44,10}})));

        ThermoPower.Water.SteamTurbineStodola IPT4(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=71.78,
          pnom=524600,
          eta_iso_nom=0.9053,
          Kt=0.13030101)
          annotation (Placement(transformation(extent={{60,-10},{80,10}})));

        Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_IP_in annotation (
            Placement(transformation(extent={{-114,-10},{-94,10}}),
              iconTransformation(extent={{-120,-10},{-100,10}})));
        Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_IP_out
          annotation (Placement(transformation(extent={{94,-10},{114,10}}),
              iconTransformation(extent={{100,-10},{120,10}})));
        ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={{-98,14},
                  {-86,26}}),          iconTransformation(extent={{-120,50},{-100,70}})));
        ThermoPower.Water.PressDrop pressDrop_OTSG_IPT(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=82.57,
          rhonom=12.5147,
          dpnom=100000)
          annotation (Placement(transformation(extent={{-80,10},{-60,30}})));
        ThermoPower.Water.PressDrop pressDrop_IPT1_HPH1(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=3.709,
          rhonom=6.59908,
          dpnom=63000)    annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={-28,-40})));
        ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{86,14},{98,26}}),
              iconTransformation(extent={{100,50},{120,70}})));

        ThermoPower.Water.FlangeB SP6(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{-34,-86},{-22,-74}}),
              iconTransformation(extent={{-64,-120},{-44,-100}})));

        ThermoPower.Water.PressDrop pressDrop_IPT2_DEA(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=3.551,
          rhonom=3.44048,
          dpnom=27900) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={12,-40})));
        ThermoPower.Water.FlangeB SP5(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{6,-86},{18,-74}}), iconTransformation(
                extent={{-20,-120},{0,-100}})));

        ThermoPower.Water.PressDrop pressDrop_IPT3_LPH4(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=3.532,
          rhonom=2.18965,
          dpnom=15800)    annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={52,-40})));
        ThermoPower.Water.FlangeB SP4(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{46,-86},{58,-74}}), iconTransformation(
                extent={{26,-120},{46,-100}})));

      equation
        Pm = IPT1.omega*IPT1.tau + IPT2.omega*IPT2.tau + IPT3.omega*IPT3.tau + IPT4.omega*IPT4.tau;
        connect(IPT1.shaft_b,IPT2. shaft_a) annotation (Line(
            points={{-39.6,0},{-12.6,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(IPT1.outlet,pressDrop_IPT1_HPH1. inlet) annotation (Line(
            points={{-38,8},{-28,8},{-28,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT1.outlet,IPT2. inlet) annotation (Line(
            points={{-38,8},{-14,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(SP6, SP6) annotation (Line(
            points={{-28,-80},{-28,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_IPT1_HPH1.outlet, SP6) annotation (Line(
            points={{-28,-50},{-28,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(flange_IP_in,IPT1. shaft_a) annotation (Line(
            points={{-104,0},{-52.6,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(SP5, SP5) annotation (Line(
            points={{12,-80},{12,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_IPT2_DEA.outlet, SP5) annotation (Line(
            points={{12,-50},{12,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT2.outlet, pressDrop_IPT2_DEA.inlet) annotation (Line(
            points={{2,8},{12,8},{12,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(SP4, SP4) annotation (Line(
            points={{52,-80},{52,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_IPT3_LPH4.outlet, SP4) annotation (Line(
            points={{52,-50},{52,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT3.outlet, pressDrop_IPT3_LPH4.inlet) annotation (Line(
            points={{42,8},{52,8},{52,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT2.outlet, IPT3.inlet) annotation (Line(
            points={{2,8},{26,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT3.outlet, IPT4.inlet) annotation (Line(
            points={{42,8},{62,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT4.outlet, vap_out) annotation (Line(
            points={{78,8},{92,8},{92,20}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(IPT2.shaft_b, IPT3.shaft_a) annotation (Line(
            points={{0.4,0},{27.4,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(IPT3.shaft_b, IPT4.shaft_a) annotation (Line(
            points={{40.4,0},{63.4,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(IPT4.shaft_b, flange_IP_out) annotation (Line(
            points={{76.4,0},{104,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(vap_in, pressDrop_OTSG_IPT.inlet) annotation (Line(
            points={{-92,20},{-80,20}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_OTSG_IPT.outlet, IPT1.inlet) annotation (Line(
            points={{-60,20},{-54,20},{-54,8}},
            color={0,0,255},
            smooth=Smooth.None));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}), graphics), Icon(coordinateSystem(
                preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
              Polygon(
                points={{-38,18},{-38,-22},{-10,-48},{-10,46},{-38,18}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-80,20},{-80,-20},{-54,-44},{-54,48},{-80,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-100,60},{-100,60},{-80,60},{-80,20}},
                color={0,0,0},
                thickness=0.5),
              Rectangle(
                extent={{-100,8},{-80,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{-54,8},{-38,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{80,8},{100,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
                         Text(extent={{-106,96},{110,66}},
                textString="%name",
                lineColor={0,0,0}),
              Polygon(
                points={{52,20},{52,-20},{80,-46},{80,48},{52,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{8,20},{8,-20},{36,-46},{36,48},{8,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-10,8},{8,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{36,8},{52,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Line(
                points={{-54,-44},{-54,-60},{-54,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{-38,-22},{-38,-60},{-54,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{-10,-48},{-10,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{8,-20},{8,-60},{-10,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{36,-46},{36,-74},{36,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{52,-20},{52,-42},{52,-60},{36,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{80,48},{80,60},{100,60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None)}));
      end IPT;

      model LPT "Model of the low  pressure turbine"

        replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
          constrainedby Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        outer ThermoPower.System system "System wide properties";

        Modelica.SIunits.Power Pm "Mechanical power";

        ThermoPower.Water.SteamTurbineStodola LPT1(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=71.78,
          eta_iso_nom=0.9261,
          Kt=0.09249649,
          pnom=450000)
          annotation (Placement(transformation(extent={{-68,-10},{-48,10}})));
        ThermoPower.Water.SteamTurbineStodola LPT2(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=68.4,
          eta_iso_nom=0.9318,
          Kt=0.1363584,
          pnom=250600)
          annotation (Placement(transformation(extent={{-28,-10},{-8,10}})));

        ThermoPower.Water.SteamTurbineStodola LPT3(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=65.22,
          eta_iso_nom=0.9281,
          Kt=0.27114629,
          pnom=106700)
          annotation (Placement(transformation(extent={{12,-10},{32,10}})));

        ThermoPower.Water.SteamTurbineStodola LPT4(
          redeclare package Medium = Medium,
          eta_mech=1,
          partialArc_nom=1,
          PRstart=2.15,
          wnom=62.26,
          eta_iso_nom=0.8449,
          Kt=0.6600986,
          pnom=39250)
          annotation (Placement(transformation(extent={{48,-10},{68,10}})));

        Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_LP_in annotation (
            Placement(transformation(extent={{-114,-10},{-94,10}}),
              iconTransformation(extent={{-120,-10},{-100,10}})));
        Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_LP_out
          annotation (Placement(transformation(extent={{94,-10},{114,10}}),
              iconTransformation(extent={{100,-10},{120,10}})));
        ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={{-98,14},
                  {-86,26}}),          iconTransformation(extent={{-120,50},{-100,70}})));
        ThermoPower.Water.PressDrop pressDrop_LPT1_LPH3(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=3.375,
          rhonom=1.22641,
          dpnom=7600)     annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={-40,-40})));
        ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{86,14},{98,26}}),
              iconTransformation(extent={{100,50},{120,70}})));

        ThermoPower.Water.FlangeB SP3(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{-46,-86},{-34,-74}}),
              iconTransformation(extent={{-64,-120},{-44,-100}})));

        ThermoPower.Water.PressDrop pressDrop_LPT2_LPH2(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=3.183,
          rhonom=0.627094,
          dpnom=3200)      annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={0,-40})));
        ThermoPower.Water.FlangeB SP2(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{-6,-86},{6,-74}}), iconTransformation(
                extent={{-20,-120},{0,-100}})));

        ThermoPower.Water.PressDrop pressDrop_LPT3_LPH1(
          redeclare package Medium = Medium,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          allowFlowReversal=false,
          wnom=2.962,
          rhonom=0.2460102,
          dpnom=1180)     annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={40,-40})));
        ThermoPower.Water.FlangeB SP1(redeclare package Medium = Medium) annotation (
            Placement(transformation(extent={{34,-86},{46,-74}}), iconTransformation(
                extent={{26,-120},{46,-100}})));

      equation
        Pm = LPT1.omega*LPT1.tau + LPT2.omega*LPT2.tau + LPT3.omega*LPT3.tau + LPT4.omega*LPT4.tau;
        connect(LPT1.shaft_b,LPT2. shaft_a) annotation (Line(
            points={{-51.6,0},{-24.6,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(LPT1.outlet,pressDrop_LPT1_LPH3. inlet) annotation (Line(
            points={{-50,8},{-40,8},{-40,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT1.outlet,LPT2. inlet) annotation (Line(
            points={{-50,8},{-26,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(SP3,SP3)  annotation (Line(
            points={{-40,-80},{-40,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_LPT1_LPH3.outlet,SP3)  annotation (Line(
            points={{-40,-50},{-40,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(flange_LP_in,LPT1. shaft_a) annotation (Line(
            points={{-104,0},{-64.6,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(SP2,SP2)  annotation (Line(
            points={{0,-80},{0,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_LPT2_LPH2.outlet, SP2) annotation (Line(
            points={{-1.77636e-015,-50},{-1.77636e-015,-64},{0,-64},{0,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT2.outlet, pressDrop_LPT2_LPH2.inlet) annotation (Line(
            points={{-10,8},{1.77636e-015,8},{1.77636e-015,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(SP1,SP1)  annotation (Line(
            points={{40,-80},{40,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(pressDrop_LPT3_LPH1.outlet,SP1)  annotation (Line(
            points={{40,-50},{40,-80}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT3.outlet,pressDrop_LPT3_LPH1. inlet) annotation (Line(
            points={{30,8},{40,8},{40,-30}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT2.outlet,LPT3. inlet) annotation (Line(
            points={{-10,8},{14,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT3.outlet,LPT4. inlet) annotation (Line(
            points={{30,8},{50,8}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT4.outlet, vap_out) annotation (Line(
            points={{66,8},{92,8},{92,20}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(LPT2.shaft_b,LPT3. shaft_a) annotation (Line(
            points={{-11.6,0},{15.4,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(LPT3.shaft_b,LPT4. shaft_a) annotation (Line(
            points={{28.4,0},{51.4,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(LPT4.shaft_b,flange_LP_out)  annotation (Line(
            points={{64.4,0},{104,0}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(vap_in, LPT1.inlet) annotation (Line(
            points={{-92,20},{-66,20},{-66,8}},
            color={0,0,255},
            smooth=Smooth.None));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                  -100},{100,100}}), graphics), Icon(coordinateSystem(
                preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
              Polygon(
                points={{-38,18},{-38,-22},{-10,-48},{-10,46},{-38,18}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-80,20},{-80,-20},{-54,-44},{-54,48},{-80,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-100,60},{-100,60},{-80,60},{-80,20}},
                color={0,0,0},
                thickness=0.5),
              Rectangle(
                extent={{-100,8},{-80,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{-54,8},{-38,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{80,8},{100,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
                         Text(extent={{-106,96},{110,66}},
                textString="%name",
                lineColor={0,0,0}),
              Polygon(
                points={{52,20},{52,-20},{80,-46},{80,48},{52,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{8,20},{8,-20},{36,-46},{36,48},{8,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-10,8},{8,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{36,8},{52,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Line(
                points={{-54,-44},{-54,-60},{-54,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{-38,-22},{-38,-60},{-54,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{-10,-48},{-10,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{8,-20},{8,-60},{-10,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{36,-46},{36,-74},{36,-100}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{52,-20},{52,-42},{52,-60},{36,-60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None),
              Line(
                points={{80,48},{80,60},{100,60}},
                color={0,0,0},
                thickness=0.5,
                smooth=Smooth.None)}));
      end LPT;

      package Test

        model test_HP1 "Test model of first high pressure body"

          ThermoPower.Water.SteamTurbineStodola steamTurbineStodola(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            wnom=88.59,
            eta_mech=1,
            eta_iso_nom=0.9034,
            partialArc_nom=1,
            PRstart=2.15,
            pnom=17500000,
            Kt=0.003333977)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=8150000)
            annotation (Placement(transformation(extent={{40,10},{60,30}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=17500000,
            h=3431893)
            annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=
               314.1592654)
            annotation (Placement(transformation(extent={{-60,-28},{-40,-8}})));
        equation
          connect(sourcePressure.flange, steamTurbineStodola.inlet) annotation (
              Line(
              points={{-40,20},{-8,20},{-8,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure.flange, steamTurbineStodola.outlet) annotation (Line(
              points={{40,20},{8,20},{8,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(constantSpeed.flange, steamTurbineStodola.shaft_a) annotation (
              Line(
              points={{-40,-18},{-28,-18},{-28,0},{-6.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                    -100,-100},{100,100}}), graphics));
        end test_HP1;

        model test_HPT "Test model of the high pressure turbine"

          HPT HPTurbine
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{72,-10},{52,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3431893,
            p0=17610000)
            annotation (Placement(transformation(extent={{-78,30},{-58,50}})));
          ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=8050000)
            annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=4700000)
            annotation (Placement(transformation(extent={{-60,-70},{-80,-50}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
        equation

          connect(HPTurbine.flange_HP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{52,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, HPTurbine.vap_in) annotation (Line(
              points={{-58,40},{-22,40},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, HPTurbine.vap_out) annotation (Line(
              points={{-60,-60},{-22,-60},{-22,-16}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkMassFlow.flange, HPTurbine.SP7) annotation (Line(
              points={{20,-60},{0,-60},{0,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}), graphics));
        end test_HPT;

        model test_IPT "Test model of the intermediate pressure turbine"

          IPT IPTurbine
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{80,-10},{60,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3559700,
            p0=4640000)
            annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=450000)
            annotation (Placement(transformation(extent={{40,10},{60,30}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800)
            annotation (Placement(transformation(extent={{20,-50},{40,-30}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000)
            annotation (Placement(transformation(extent={{0,-70},{20,-50}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=2037000)
            annotation (Placement(transformation(extent={{-20,-50},{-40,-30}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
        equation
          connect(IPTurbine.flange_IP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{60,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, IPTurbine.vap_in) annotation (Line(
              points={{-40,20},{-22,20},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure.flange, IPTurbine.vap_out) annotation (Line(
              points={{40,20},{22,20},{22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, IPTurbine.SP6) annotation (Line(
              points={{-20,-40},{-10.8,-40},{-10.8,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure2.flange, IPTurbine.SP5) annotation (Line(
              points={{0,-60},{-2,-60},{-2,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPTurbine.SP4, sinkPressure1.flange) annotation (Line(
              points={{7.2,-22},{7.2,-40},{20,-40}},
              color={0,0,255},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                    -100,-100},{100,100}}), graphics));
        end test_IPT;

        model test_LPT "Test model of the low pressure turbine"

          LPT LPTurbine
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{80,-10},{60,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=2938300,
            p0=450000)
            annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=11010)
            annotation (Placement(transformation(extent={{40,10},{60,30}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=38070)
            annotation (Placement(transformation(extent={{20,-50},{40,-30}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=103500)
            annotation (Placement(transformation(extent={{20,-90},{40,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=243000)
            annotation (Placement(transformation(extent={{-20,-70},{-40,-50}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
        equation
          connect(LPTurbine.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{60,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, LPTurbine.vap_in) annotation (Line(
              points={{-40,20},{-22,20},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.vap_out, sinkPressure.flange) annotation (Line(
              points={{22,12},{22,20},{40,20}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, LPTurbine.SP3) annotation (Line(
              points={{-20,-60},{-10.8,-60},{-10.8,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, LPTurbine.SP1) annotation (Line(
              points={{20,-40},{7.2,-40},{7.2,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.SP2, sinkPressure2.flange) annotation (Line(
              points={{-2,-22},{-2,-80},{20,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                    -100,-100},{100,100}}), graphics));
        end test_LPT;

        model test_turbine "Global turbine model"

          HPT HPTurbine
            annotation (Placement(transformation(extent={{-102,0},{-62,40}})));
          IPT IPTurbine
            annotation (Placement(transformation(extent={{-30,0},{10,40}})));
          LPT LPTurbine
            annotation (Placement(transformation(extent={{38,0},{78,40}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{140,10},{120,30}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=103500)
            annotation (Placement(transformation(extent={{58,-70},{78,-50}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=38070)
            annotation (Placement(transformation(extent={{68,-30},{88,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=243000)
            annotation (Placement(transformation(extent={{46,-30},{26,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=11010)
            annotation (Placement(transformation(extent={{120,70},{140,90}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3559700,
            p0=4640000)
            annotation (Placement(transformation(extent={{-54,48},{-34,68}})));
          ThermoPower.Water.SinkPressure sinkPressure4(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=2037000)
            annotation (Placement(transformation(extent={{-22,-62},{-42,-42}})));
          ThermoPower.Water.SinkPressure sinkPressure5(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000)
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure6(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800)
            annotation (Placement(transformation(extent={{0,-60},{20,-40}})));
          ThermoPower.Water.SourcePressure sourcePressure1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3431893,
            p0=17610000)
            annotation (Placement(transformation(extent={{-170,22},{-150,42}})));
          ThermoPower.Water.SinkPressure sinkPressure7(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=4700000)
            annotation (Placement(transformation(extent={{-152,-6},{-172,14}})));
          ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=8050000)
            annotation (Placement(transformation(extent={{-80,-84},{-60,-64}})));
        equation
          connect(HPTurbine.flange_HP_out, IPTurbine.flange_IP_in) annotation (Line(
              points={{-60,20},{-32,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.flange_IP_out, LPTurbine.flange_LP_in) annotation (Line(
              points={{12,20},{36,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(LPTurbine.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{80,20},{120,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.vap_out, LPTurbine.vap_in) annotation (Line(
              points={{12,32},{36,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.vap_out, sinkPressure.flange) annotation (Line(
              points={{80,32},{80,80},{120,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, LPTurbine.SP1) annotation (Line(
              points={{68,-20},{66,-20},{66,-2},{65.2,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure2.flange, LPTurbine.SP2) annotation (Line(
              points={{58,-60},{56,-60},{56,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, LPTurbine.SP3) annotation (Line(
              points={{46,-20},{48,-20},{48,-2},{47.2,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure.flange, IPTurbine.vap_in) annotation (Line(
              points={{-34,58},{-32,58},{-32,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure4.flange, IPTurbine.SP6) annotation (Line(
              points={{-22,-52},{-20,-52},{-20,-2},{-20.8,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure5.flange, IPTurbine.SP5) annotation (Line(
              points={{-10,-80},{-12,-80},{-12,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure6.flange, IPTurbine.SP4) annotation (Line(
              points={{0,-50},{-2,-50},{-2,-2},{-2.8,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure1.flange, HPTurbine.vap_in) annotation (Line(
              points={{-150,32},{-104,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure7.flange, HPTurbine.vap_out) annotation (Line(
              points={{-152,4},{-104,4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkMassFlow.flange, HPTurbine.SP7) annotation (Line(
              points={{-80,-74},{-82,-74},{-82,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                    -180,-100},{140,100}}), graphics), Icon(coordinateSystem(extent=
                   {{-180,-100},{140,100}})));
        end test_turbine;

        model test_turbine_offDesign
          "Global turbine model, check of the off design operation points"
          import PreFlexMS;
          HPT HPTurbine
            annotation (Placement(transformation(extent={{-102,0},{-62,40}})));
          IPT IPTurbine
            annotation (Placement(transformation(extent={{-30,0},{10,40}})));
          LPT LPTurbine
            annotation (Placement(transformation(extent={{38,0},{78,40}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{140,10},{120,30}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=103500)
            annotation (Placement(transformation(extent={{58,-70},{78,-50}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=38070)
            annotation (Placement(transformation(extent={{68,-30},{88,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=243000)
            annotation (Placement(transformation(extent={{46,-30},{26,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=11010,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{100,40},{120,60}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3559700,
            p0=4640000,
            use_in_p0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-60,40},{-40,60}})));
          ThermoPower.Water.SinkPressure sinkPressure4(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=2037000)
            annotation (Placement(transformation(extent={{-22,-62},{-42,-42}})));
          ThermoPower.Water.SinkPressure sinkPressure5(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000)
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure6(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800)
            annotation (Placement(transformation(extent={{0,-60},{20,-40}})));
          ThermoPower.Water.SourcePressure sourcePressure1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3431893,
            p0=17610000,
            use_in_p0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-140,40},{-120,60}})));
          ThermoPower.Water.SinkPressure sinkPressure7(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=4700000)
            annotation (Placement(transformation(extent={{-152,-6},{-172,14}})));
          ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=8050000)
            annotation (Placement(transformation(extent={{-80,-84},{-60,-64}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=loadCalculator.load_end - loadCalculator.load_start,
            duration=loadCalculator.t_ramp,
            offset=loadCalculator.load_start,
            startTime=loadCalculator.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={162,80})));
          Modelica.Blocks.Tables.CombiTable1D LPTurb_sink(table=[20,0.0479e5; 30,
                0.0537e5; 40,0.0599e5; 50,0.0666e5; 60,0.0738e5; 70,0.0809e5; 80,
                0.0897e5; 90,0.0994e5; 100,0.1101e5])
            annotation (Placement(transformation(extent={{140,70},{120,90}})));
          PreFlexMS.Auxiliaries.Components.loadCalculator loadCalculator(
            load_start=100,
            load_end=100,
            t_ramp=0,
            t_start=0) annotation (Placement(transformation(extent={{-200,-120},
                    {-180,-100}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=loadCalculator.load_end - loadCalculator.load_start,
            duration=loadCalculator.t_ramp,
            offset=loadCalculator.load_start,
            startTime=loadCalculator.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-100,80})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_source(table=[20,0.0479e5;
                30,0.0537e5; 40,0.0599e5; 50,0.0666e5; 60,0.0738e5; 70,0.0809e5;
                80,0.0897e5; 90,0.0994e5; 100,0.1101e5])
            annotation (Placement(transformation(extent={{-80,70},{-60,90}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=loadCalculator.load_end - loadCalculator.load_start,
            duration=loadCalculator.t_ramp,
            offset=loadCalculator.load_start,
            startTime=loadCalculator.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-180,80})));
          Modelica.Blocks.Tables.CombiTable1D HPTurb_source(table=[20,100e5; 30,
                100e5; 40,100e5; 50,100e5; 60,111.4e5; 70,127.7e5; 80,144e5; 90,
                160.1e5; 100,175e5])
            annotation (Placement(transformation(extent={{-160,70},{-140,90}})));
        equation
          connect(HPTurbine.flange_HP_out, IPTurbine.flange_IP_in) annotation (Line(
              points={{-60,20},{-32,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.flange_IP_out, LPTurbine.flange_LP_in) annotation (Line(
              points={{12,20},{36,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(LPTurbine.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{80,20},{120,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.vap_out, LPTurbine.vap_in) annotation (Line(
              points={{12,32},{36,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.vap_out, sinkPressure.flange) annotation (Line(
              points={{80,32},{80,50},{100,50}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, LPTurbine.SP1) annotation (Line(
              points={{68,-20},{66,-20},{66,-2},{65.2,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure2.flange, LPTurbine.SP2) annotation (Line(
              points={{58,-60},{56,-60},{56,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, LPTurbine.SP3) annotation (Line(
              points={{46,-20},{48,-20},{48,-2},{47.2,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure.flange, IPTurbine.vap_in) annotation (Line(
              points={{-40,50},{-32,50},{-32,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure4.flange, IPTurbine.SP6) annotation (Line(
              points={{-22,-52},{-20,-52},{-20,-2},{-20.8,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure5.flange, IPTurbine.SP5) annotation (Line(
              points={{-10,-80},{-12,-80},{-12,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure6.flange, IPTurbine.SP4) annotation (Line(
              points={{0,-50},{-2,-50},{-2,-2},{-2.8,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure1.flange, HPTurbine.vap_in) annotation (Line(
              points={{-120,50},{-104,50},{-104,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure7.flange, HPTurbine.vap_out) annotation (Line(
              points={{-152,4},{-104,4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkMassFlow.flange, HPTurbine.SP7) annotation (Line(
              points={{-80,-74},{-82,-74},{-82,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LOAD1.y,LPTurb_sink. u[1]) annotation (Line(points={{151,80},{
                  151,80},{142,80}},   color={0,0,127}));
          connect(LPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={
                  {119,80},{112,80},{106,80},{106,58.8}}, color={0,0,127}));
          connect(LOAD2.y, IPTurb_source.u[1]) annotation (Line(points={{-89,80},
                  {-89,80},{-82,80}}, color={0,0,127}));
          connect(HPTurb_source.y[1], sourcePressure1.in_p0) annotation (Line(
                points={{-139,80},{-134,80},{-134,59.2}}, color={0,0,127}));
          connect(IPTurb_source.y[1], sourcePressure.in_p0) annotation (Line(
                points={{-59,80},{-54,80},{-54,59.2}}, color={0,0,127}));
          connect(LOAD3.y, HPTurb_source.u[1]) annotation (Line(points={{-169,80},
                  {-165.5,80},{-162,80}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-220,
                    -140},{180,140}})),                Icon(coordinateSystem(extent={{-220,
                    -140},{180,140}})));
        end test_turbine_offDesign;
      end Test;

    end SteamTurbine;

    package Plants
      "Package containing partial/complete models of the power plant"
      model plant_nom

        SteamTurbine.HPT HPTurb
          annotation (Placement(transformation(extent={{-86,102},{-10,178}})));
        SteamTurbine.IPT IPTurb(vap_in(p(start=46.4e5)), vap_out(p(start=4.5e5)))
          annotation (Placement(transformation(extent={{82,102},{164,178}})));
        SteamTurbine.LPT LPTurb
          annotation (Placement(transformation(extent={{256,102},{338,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
          annotation (Placement(transformation(extent={{-440,220},{-420,240}})));
        ThermoPower.Water.SourcePressure sourceMS1(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-280,150},{-260,
                  170}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-260,-190},{
                  -280,-170}})));
        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{388,130},{368,150}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=11010)
          annotation (Placement(transformation(extent={{362,190},{382,210}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          w0=64.26,
          h=197600)
          annotation (Placement(transformation(extent={{402,-94},{382,-74}})));
        HeatExchangers.Components.Deaerator deaerator(
          zl_min=0,
          h_start=750000,
          L=12,
          H=2.677,
          zl_max=2.6,
          zl_start=2,
          initOpt=ThermoPower.Choices.Init.Options.noInit,
          T(fixed=true, start=448.15),
          p(start=900000, fixed=true))
          annotation (Placement(transformation(extent={{108,-128},{162,-72}})));
        HeatExchangers.OTSG.Old.OTSG_init100_5nodes_old OTSG(PDSteamSH(pout(
                start=176.1e5)), EVA1(Scold=1765.5*0.9, Shot=2251*0.9))
          annotation (Placement(transformation(extent={{-280,-160},{-140,80}})));
        HeatExchangers.PreHeaters.HPH_train_simplified HPHs(FW_out(p(start=
                  179.1e5)), SP1(p(start=8149000)))
          annotation (Placement(transformation(extent={{-84,-162},{16,-102}})));
        HeatExchangers.PreHeaters.LPH_train LPHs(
          pressDrop(pin(start=15.91e5)),
          pressDrop1(pin(start=1441000, fixed=true)),
          pressDrop2(pin(start=1275000, fixed=true)),
          SP4(p(start=5.088e5)),
          SP5(p(start=2.43e5)),
          SP6(p(start=1.035e5)),
          SP7(p(start=0.3807e5)),
          LPH4(T_FW_out(fixed=false)),
          LPH2(T_FW_out(fixed=false)),
          pressDrop3(pin(start=1128000, fixed=true)))
          annotation (Placement(transformation(extent={{220,-114},{340,-54}})));
        Control.Old.plant_controller_full_old controllers(
          Kp_valveRH=1.77,
          Td_valveRH=0,
          CSmin_valveRH=1,
          CSmax_valveRH=300,
          CSstart_valveRH=238.7,
          actuatorGain_valveRH=1,
          Ta_valveRH=2,
          useTS_valveRH=false,
          TS_valveRH=238.7,
          l_sp=0,
          Kp_pumpSEP=-14.5,
          Ti_pumpSEP=56.7,
          Td_pumpSEP=0,
          Nd_pumpSEP=1,
          CSmin_pumpSEP=0,
          CSmax_pumpSEP=70,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=5,
          TS_pumpSEP=0,
          Ta_pumpFW=5,
          Td_pumpHPH=0,
          Nd_pumpHPH=1,
          actuatorGain_pumpHPH=1,
          Ta_pumpHPH=5,
          actuatorGain_pumpFW=1,
          useTS_pumpHPH=false,
          load_start=100,
          load_end=100,
          t_ramp=0,
          t_start=0,
          Ti_valveRH=16,
          Nd_valveRH=10,
          Kp_pumpFW=-1,
          Ti_pumpFW=28.59,
          Td_pumpFW=7.147,
          Nd_pumpFW=30,
          CSmin_pumpFW=-0.3,
          CSmax_pumpFW=0.3,
          CSstart_pumpFW=0,
          TS_pumpFW=0,
          Kp_pumpHPH=0.6461,
          Ti_pumpHPH=19.05,
          CSmin_pumpHPH=-0.5,
          CSmax_pumpHPH=0.5,
          CSstart_pumpHPH=0,
          TS_pumpHPH=0,
          P_mec_sp=117227e3,
          Kp_pumpMS=1.2e-7,
          Ti_pumpMS=114.3,
          Td_pumpMS=28.57,
          Nd_pumpMS=20,
          CSmin_pumpMS=-0.9,
          CSmax_pumpMS=1,
          CSstart_pumpMS=0,
          actuatorGain_pumpMS=1,
          Ta_pumpMS=5,
          useTS_pumpMS=false,
          TS_pumpMS=0,
          Ti_valveTURB=95.23,
          Td_valveTURB=0,
          Nd_valveTURB=1,
          CSmin_valveTURB=-0.9,
          CSmax_valveTURB=0.65,
          CSstart_valveTURB=0,
          actuatorGain_valveTURB=1,
          TS_valveTURB=0,
          Kp_valveTURB=-0.000014,
          Ta_valveTURB=2,
          useTS_pumpFW=true,
          useTS_valveTURB=true,
          T_RH_sp=826.05,
          useTS_pumpSEP=true,
          T_MS_sp=563.15,
          T_FW_sp=553.15,
          p_sp=17611000)
          annotation (Placement(transformation(extent={{-400,-80},{-340,0}})));
        Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
              IPTurb.Pm + LPTurb.Pm))
          annotation (Placement(transformation(extent={{-426,50},{-346,70}})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-20,-20},{20,20}},
              rotation=-90,
              origin={-320,60})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{-6.2,140},{77.9,140}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
            points={{168.1,140},{251.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(LPTurb.flange_LP_out, constantSpeed.flange) annotation (Line(
            points={{342.1,140},{368,140}},
            color={0,0,0},
            smooth=Smooth.None));
        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-260,-180},{-248.889,-180},{-248.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS1.flange, OTSG.MS_in) annotation (Line(
            points={{-260,160},{-248.889,160},{-248.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(LPTurb.vap_out, sinkPressure.flange) annotation (Line(
            points={{342.1,162.8},{342.1,200},{362,200}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-136.111,48},{-89.8,48},{-89.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-171.111,84},{-171.111,162.8},{-89.8,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(IPTurb.SP5, deaerator.steam_in) annotation (Line(
            points={{118.9,98.2},{118.9,-96},{127.671,-96}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{168.1,162.8},{251.9,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-136.111,-132},{-136.111,-132},{-86.7778,-132}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.FW_in, deaerator.drained_out) annotation (Line(
            points={{18.7778,-132},{135,-132},{135,-122}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-136.111,-72},{-136.111,-72},{-67.3333,-72},{-67.3333,-99}},
            color={0,0,255},
            thickness=0.5));

        connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
            points={{-48,98.2},{-48,98.2},{-48,-99},{-47.8889,-99}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
            points={{-202.222,-164},{-202,-164},{-202,-172},{-202,-180},{-22.8889,
                -180},{-22.8889,-165}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{141.943,-84},{141.943,-84},{217.5,-84}},
            color={0,0,255},
            thickness=0.5));
        connect(LPHs.FW_in, sourceMassFlow_FW.flange) annotation (Line(
            points={{342.5,-84},{392,-84},{382,-84}},
            color={0,0,255},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP7) annotation (Line(
            points={{311.76,98.2},{311.76,71.1},{320,71.1},{320,-51}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP6) annotation (Line(
            points={{292.9,98.2},{292.9,60},{292.5,60},{292.5,-51}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP3, LPHs.SP5) annotation (Line(
            points={{274.86,98.2},{274.86,72},{265,72},{265,-51}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, LPHs.SP4) annotation (Line(
            points={{137.76,98.2},{137.76,70},{237.5,70},{237.5,-51}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
            points={{100.86,98.2},{100.86,70},{-11.7778,70},{-11.7778,-99}},
            color={0,127,0},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{18.7778,-114},{18.7778,-114},{109.929,-114}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.signalBus, controllers.signalBus) annotation (Line(
            points={{-285.444,-40},{-285.444,-40},{-338.5,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-202.222,84},{-202,84},{-202,168},{-202,200},{77.9,200},{
                77.9,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-338.5,-40},{-320,-40},{-320,-220},{-3.44444,-220},{-3.44444,
                -163.2}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus,signalBus)  annotation (Line(
            points={{-338.5,-40},{-320,-40},{-320,60}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpMS_PV,Power_sensor. y) annotation (Line(
            points={{-320,60},{-342,60}},
            color={255,204,51},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-440,-240},{480,240}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -240},{480,240}})));
      end plant_nom;

      model plant_HP_100_chechValveBP

        SteamTurbine.HPT HPTurb(pressDrop_HPT1_HPH2(dpnom=1000))
          annotation (Placement(transformation(extent={{16,102},{92,178}})));
        SteamTurbine.IPT IPTurb(vap_in(p(start=46.4e5)), vap_out(p(start=4.5e5)))
          annotation (Placement(transformation(extent={{124,102},{206,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
          annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-158,150},{-138,
                  170}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-140,-190},{
                  -160,-170}})));
        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{262,130},{242,150}})));
        HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(initOpt=
                ThermoPower.Choices.Init.Options.fixedState))
          annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
        HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(
          FW_out(p(start=179.1e5)),
          SP1(p(start=8149000)),
          SP2(p(start=20.37e5)),
          HPH2(
            Nhex_cond=5,
            Nhex_sub=2,
            CSstart=0.2,
            Nhex_des=4,
            CSmin=0.05),
          HPH1(
            Nhex_cond=5,
            CSstart=0.2,
            Nhex_sub=2,
            Nhex_des=4,
            Kp=-207.8,
            Ti=5,
            CSmin=0.2,
            CSmax=0.2))
          annotation (Placement(transformation(extent={{18,-160},{118,-104}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{214,170},{234,190}})));

        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,30},{220,50}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
        Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
              IPTurb.Pm))
          annotation (Placement(transformation(extent={{-280,44},{-228,76}})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-20,-20},{20,20}},
              rotation=-90,
              origin={-200,60})));
        Modelica.Blocks.Sources.Ramp LOAD1(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,210})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
              1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
              3.527e5; 90,4.011e5; 100,4.5e5])
          annotation (Placement(transformation(extent={{248,200},{228,220}})));
        Modelica.Blocks.Sources.Ramp LOAD2(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,60})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
              1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
              4.002e5; 90,4.543e5; 100,5.088e5])
          annotation (Placement(transformation(extent={{248,50},{228,70}})));
        Modelica.Blocks.Sources.Ramp LOAD3(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={272,0})));
        Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
              2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{250,-10},{230,10}})));
        Modelica.Blocks.Sources.Ramp LOAD4(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-80})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
              30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
        Modelica.Blocks.Sources.Ramp LOAD5(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-120})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
              586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
              749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                  -130},{180,-110}})));
        Control.Schemes.plant_controller_HPpart_checkValveBP controllers(
          actuatorGain_valveRH=1,
          Ta_valveRH=2,
          Kp_pumpSEP=-14.5,
          Ti_pumpSEP=56.7,
          Td_pumpSEP=0,
          Nd_pumpSEP=1,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=5,
          TS_pumpSEP=0,
          Ta_pumpFW=5,
          Td_pumpHPH=0,
          Nd_pumpHPH=1,
          actuatorGain_pumpHPH=1,
          Ta_pumpHPH=5,
          actuatorGain_pumpFW=1,
          P_mec_sp=79.7258e6,
          actuatorGain_pumpMS=1,
          Ta_pumpMS=5,
          Td_valveTURB=0,
          Nd_valveTURB=1,
          actuatorGain_valveTURB=1,
          CSmin_pumpFW=-0.3,
          CSmax_pumpFW=0.3,
          CSstart_pumpFW=0,
          TS_pumpFW=0,
          CSmin_pumpHPH=-0.5,
          CSmax_pumpHPH=0.5,
          CSstart_pumpHPH=0,
          TS_pumpHPH=0,
          CSmin_pumpMS=-0.9,
          CSmax_pumpMS=1,
          CSstart_pumpMS=0,
          TS_pumpMS=0,
          CSmin_valveTURB=-0.9,
          CSmax_valveTURB=0.65,
          CSstart_valveTURB=0,
          TS_valveTURB=0,
          Nd_valveRH=10,
          Ti_valveRH=16,
          Td_valveRH=0,
          load_start=100,
          Kp_pumpFW=-1,
          Ti_pumpFW=28.59,
          Td_pumpFW=7.147,
          Nd_pumpFW=30,
          Kp_pumpHPH=0.6461,
          Ti_pumpHPH=19.05,
          Kp_pumpMS=1.2e-7,
          Ti_pumpMS=114.3,
          Td_pumpMS=28.57,
          Nd_pumpMS=20,
          Ti_valveTURB=95.23,
          Kp_valveTURB=-0.0000014,
          Ta_valveTURB=2,
          Kp_valveRH=0.177,
          CSmin_valveRH=-0.9,
          CSmax_valveRH=1,
          CSstart_valveRH=0,
          TS_valveRH=0,
          CSmin_pumpSEP=-0.9,
          CSmax_pumpSEP=1,
          load_end=100,
          t_ramp=0,
          t_start=0,
          useTS_valveRH=true,
          useTS_pumpFW=true,
          useTS_pumpHPH=true,
          useTS_pumpMS=true,
          useTS_valveTURB=true,
          useTS_pumpSEP=false,
          table_T_MS1(table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.25; 80,0.5;
                90,0.75; 100,1]),
          T_RH_sp=826.05,
          l_sp=0,
          T_MS_sp=563.15,
          T_FW_sp=553.15,
          p_sp=17611000)
          annotation (Placement(transformation(extent={{-280,-80},{-220,0}})));
        Modelica.Blocks.Sources.Step step1(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,50},{-300,70}})));
        Modelica.Blocks.Sources.Step step2(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,10},{-300,30}})));
        Modelica.Blocks.Sources.Step step3(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-30},{-300,-10}})));
        Modelica.Blocks.Sources.Step step4(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-70},{-300,-50}})));
        Modelica.Blocks.Sources.Step step5(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
        Modelica.Blocks.Sources.Step step6(
          height=0,
          offset=0,
          startTime=0) annotation (Placement(transformation(extent={{-320,-150},{
                  -300,-130}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{95.8,140},{119.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-140,-180},{-128.889,-180},{-128.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-138,160},{-128.889,160},{-128.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-16.1111,48},{12.2,48},{12.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
            color={0,0,255},
            thickness=0.5));

        connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
            points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
            points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                -180},{79.1111,-162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
            points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{119.9,
                162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                140},{210.1,140},{242,140}},       color={0,0,0}));
        connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
        connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                        color={0,0,255}));
        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                {210.1,180},{210.1,162.8}}, color={0,0,255}));
        connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                98.2},{179.76,40},{200,40}},        color={0,127,0},
            thickness=0.5));
        connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
            points={{-200,60},{-225.4,60}},
            color={255,204,51},
            thickness=0.5));
        connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
            points={{160.9,98.2},{160.9,-20},{200,-20}},
            color={0,127,0},
            thickness=0.5));
        connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                259,210},{250,210}}, color={0,0,127}));
        connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                227,210},{220,210},{220,188.8}}, color={0,0,127}));
        connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                {250,60}},     color={0,0,127}));
        connect(LOAD3.y,SP5_sink. u[1])
          annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
        connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                {211,-80},{202,-80}},      color={0,0,127}));
        connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                {211,-120},{202,-120}},       color={0,0,127}));
        connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                60},{206,60},{206,48.8}}, color={0,0,127}));
        connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                0},{206,0},{206,-11.2}}, color={0,0,127}));
        connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
              points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
        connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
              points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-218.5,-40},{-165.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, signalBus) annotation (Line(
            points={{-218.5,-40},{-200,-40},{-200,60}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-218.5,-40},{-210,-40},{-200,-40},{-200,-220},{98.5556,-220},
                {98.5556,-161.12}},
            color={255,204,51},
            thickness=0.5));
        connect(step1.y, controllers.du_w_MS) annotation (Line(points={{-299,60},
                {-286,60},{-286,0},{-281.5,0}}, color={0,0,127}));
        connect(step2.y, controllers.du_Y_t) annotation (Line(points={{-299,20},{
                -290,20},{-290,-16.5333},{-281.5,-16.5333}}, color={0,0,127}));
        connect(step3.y, controllers.du_w_FW) annotation (Line(points={{-299,-20},
                {-294,-20},{-294,-32},{-281.5,-32}}, color={0,0,127}));
        connect(step4.y, controllers.du_w_HPH) annotation (Line(points={{-299,-60},
                {-294,-60},{-294,-48},{-281.5,-48}}, color={0,0,127}));
        connect(step5.y, controllers.du_w_RH) annotation (Line(points={{-299,-100},
                {-299,-90},{-290,-90},{-290,-64},{-281.5,-64}}, color={0,0,127}));
        connect(step6.y, controllers.du_w_SEP) annotation (Line(points={{-299,
                -140},{-286,-140},{-286,-80},{-281.5,-80}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                  -240},{320,240}}, preserveAspectRatio=false)),
          experiment(StopTime=20000),
          __Dymola_experimentSetupOutput);
      end plant_HP_100_chechValveBP;

      model plant_HP_100_chechValveBP_noLevel

        SteamTurbine.HPT HPTurb(pressDrop_HPT1_HPH2(dpnom=1000))
          annotation (Placement(transformation(extent={{16,102},{92,178}})));
        SteamTurbine.IPT IPTurb(vap_in(p(start=46.4e5)), vap_out(p(start=4.5e5)))
          annotation (Placement(transformation(extent={{124,102},{206,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
          annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-158,150},{-138,
                  170}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-140,-190},{
                  -160,-170}})));
        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{262,130},{242,150}})));
        HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(initOpt=
                ThermoPower.Choices.Init.Options.fixedState))
          annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
        HeatExchangers.PreHeaters.HPH_train_fixedLevel HPHs(
          FW_out(p(start=179.1e5)),
          SP1(p(start=8149000)),
          SP2(p(start=20.37e5)),
          HPH2(
            Nhex_cond=5,
            Nhex_sub=2,
            CSstart=0.2,
            Nhex_des=4,
            CSmin=0.05),
          HPH1(
            Nhex_cond=5,
            CSstart=0.2,
            Nhex_sub=2,
            Nhex_des=4,
            Kp=-207.8,
            Ti=5,
            CSmin=0.2,
            CSmax=0.2))
          annotation (Placement(transformation(extent={{18,-160},{118,-104}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{214,170},{234,190}})));

        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,30},{220,50}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
        Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
              IPTurb.Pm))
          annotation (Placement(transformation(extent={{-280,44},{-228,76}})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-20,-20},{20,20}},
              rotation=-90,
              origin={-200,60})));
        Modelica.Blocks.Sources.Ramp LOAD1(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,210})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
              1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
              3.527e5; 90,4.011e5; 100,4.5e5])
          annotation (Placement(transformation(extent={{248,200},{228,220}})));
        Modelica.Blocks.Sources.Ramp LOAD2(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,60})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
              1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
              4.002e5; 90,4.543e5; 100,5.088e5])
          annotation (Placement(transformation(extent={{248,50},{228,70}})));
        Modelica.Blocks.Sources.Ramp LOAD3(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={272,0})));
        Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
              2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{250,-10},{230,10}})));
        Modelica.Blocks.Sources.Ramp LOAD4(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-80})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
              30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
        Modelica.Blocks.Sources.Ramp LOAD5(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-120})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
              586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
              749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                  -130},{180,-110}})));
        Control.Schemes.plant_controller_HPpart_checkValveBP controllers(
          actuatorGain_valveRH=1,
          Ta_valveRH=2,
          Kp_pumpSEP=-14.5,
          Ti_pumpSEP=56.7,
          Td_pumpSEP=0,
          Nd_pumpSEP=1,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=5,
          TS_pumpSEP=0,
          Ta_pumpFW=5,
          Td_pumpHPH=0,
          Nd_pumpHPH=1,
          actuatorGain_pumpHPH=1,
          Ta_pumpHPH=5,
          actuatorGain_pumpFW=1,
          P_mec_sp=79.7258e6,
          actuatorGain_pumpMS=1,
          Ta_pumpMS=5,
          Td_valveTURB=0,
          Nd_valveTURB=1,
          actuatorGain_valveTURB=1,
          CSmin_pumpFW=-0.3,
          CSmax_pumpFW=0.3,
          CSstart_pumpFW=0,
          TS_pumpFW=0,
          CSmin_pumpHPH=-0.5,
          CSmax_pumpHPH=0.5,
          CSstart_pumpHPH=0,
          TS_pumpHPH=0,
          CSmin_pumpMS=-0.9,
          CSmax_pumpMS=1,
          CSstart_pumpMS=0,
          TS_pumpMS=0,
          CSmin_valveTURB=-0.9,
          CSmax_valveTURB=0.65,
          CSstart_valveTURB=0,
          TS_valveTURB=0,
          Nd_valveRH=10,
          Ti_valveRH=16,
          Td_valveRH=0,
          load_start=100,
          Kp_pumpFW=-1,
          Ti_pumpFW=28.59,
          Td_pumpFW=7.147,
          Nd_pumpFW=30,
          Kp_pumpHPH=0.6461,
          Ti_pumpHPH=19.05,
          Kp_pumpMS=1.2e-7,
          Ti_pumpMS=114.3,
          Td_pumpMS=28.57,
          Nd_pumpMS=20,
          Ti_valveTURB=95.23,
          Kp_valveTURB=-0.0000014,
          Ta_valveTURB=2,
          Kp_valveRH=0.177,
          CSmin_valveRH=-0.9,
          CSmax_valveRH=1,
          CSstart_valveRH=0,
          TS_valveRH=0,
          CSmin_pumpSEP=-0.9,
          CSmax_pumpSEP=1,
          load_end=100,
          t_ramp=0,
          t_start=0,
          useTS_valveRH=true,
          useTS_pumpFW=true,
          useTS_pumpHPH=true,
          useTS_pumpMS=true,
          useTS_valveTURB=true,
          useTS_pumpSEP=false,
          table_T_MS1(table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.25; 80,0.5;
                90,0.75; 100,1]),
          T_RH_sp=826.05,
          l_sp=0,
          T_MS_sp=563.15,
          T_FW_sp=553.15,
          p_sp=17611000)
          annotation (Placement(transformation(extent={{-280,-80},{-220,0}})));
        Modelica.Blocks.Sources.Step step1(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,50},{-300,70}})));
        Modelica.Blocks.Sources.Step step2(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,10},{-300,30}})));
        Modelica.Blocks.Sources.Step step3(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-30},{-300,-10}})));
        Modelica.Blocks.Sources.Step step4(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-70},{-300,-50}})));
        Modelica.Blocks.Sources.Step step5(
          height=0,
          offset=0,
          startTime=0)
          annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
        Modelica.Blocks.Sources.Step step6(
          height=0,
          offset=0,
          startTime=0) annotation (Placement(transformation(extent={{-320,-150},{
                  -300,-130}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{95.8,140},{119.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-140,-180},{-128.889,-180},{-128.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-138,160},{-128.889,160},{-128.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-16.1111,48},{12.2,48},{12.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
            color={0,0,255},
            thickness=0.5));

        connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
            points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
            points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                -180},{79.1111,-162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
            points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{119.9,
                162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                140},{210.1,140},{242,140}},       color={0,0,0}));
        connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
        connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                        color={0,0,255}));
        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                {210.1,180},{210.1,162.8}}, color={0,0,255}));
        connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                98.2},{179.76,40},{200,40}},        color={0,127,0},
            thickness=0.5));
        connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
            points={{-200,60},{-225.4,60}},
            color={255,204,51},
            thickness=0.5));
        connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
            points={{160.9,98.2},{160.9,-20},{200,-20}},
            color={0,127,0},
            thickness=0.5));
        connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                259,210},{250,210}}, color={0,0,127}));
        connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                227,210},{220,210},{220,188.8}}, color={0,0,127}));
        connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                {250,60}},     color={0,0,127}));
        connect(LOAD3.y,SP5_sink. u[1])
          annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
        connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                {211,-80},{202,-80}},      color={0,0,127}));
        connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                {211,-120},{202,-120}},       color={0,0,127}));
        connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                60},{206,60},{206,48.8}}, color={0,0,127}));
        connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                0},{206,0},{206,-11.2}}, color={0,0,127}));
        connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
              points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
        connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
              points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-218.5,-40},{-165.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, signalBus) annotation (Line(
            points={{-218.5,-40},{-200,-40},{-200,60}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-218.5,-40},{-210,-40},{-200,-40},{-200,-220},{98.5556,-220},
                {98.5556,-161.12}},
            color={255,204,51},
            thickness=0.5));
        connect(step1.y, controllers.du_w_MS) annotation (Line(points={{-299,60},
                {-286,60},{-286,0},{-281.5,0}}, color={0,0,127}));
        connect(step2.y, controllers.du_Y_t) annotation (Line(points={{-299,20},{
                -290,20},{-290,-16.5333},{-281.5,-16.5333}}, color={0,0,127}));
        connect(step3.y, controllers.du_w_FW) annotation (Line(points={{-299,-20},
                {-294,-20},{-294,-32},{-281.5,-32}}, color={0,0,127}));
        connect(step4.y, controllers.du_w_HPH) annotation (Line(points={{-299,-60},
                {-294,-60},{-294,-48},{-281.5,-48}}, color={0,0,127}));
        connect(step5.y, controllers.du_w_RH) annotation (Line(points={{-299,-100},
                {-299,-90},{-290,-90},{-290,-64},{-281.5,-64}}, color={0,0,127}));
        connect(step6.y, controllers.du_w_SEP) annotation (Line(points={{-299,
                -140},{-286,-140},{-286,-80},{-281.5,-80}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                  -240},{320,240}}, preserveAspectRatio=false)),
          experiment(StopTime=20000),
          __Dymola_experimentSetupOutput);
      end plant_HP_100_chechValveBP_noLevel;

      model plant_HP_100
        "Model of the high pressure parto of the OTSG for linearization at 100% load"

        SteamTurbine.HPT HPTurb
          annotation (Placement(transformation(extent={{16,102},{92,178}})));
        SteamTurbine.IPT IPTurb(SP6(p(start=2100000)))
          annotation (Placement(transformation(extent={{124,102},{206,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-158,150},{-138,
                  170}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-140,-190},{
                  -160,-170}})));
        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{262,130},{242,150}})));
        HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG
          annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
        HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
              NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
              NusseltCondenser(w_cond(start=4.019, fixed=true))))
          annotation (Placement(transformation(extent={{18,-160},{118,-104}})));
        Control.Schemes.plant_controller_HPpart controllers(
          actuatorGain_valveRH=1,
          Td_pumpHPH=0,
          Nd_pumpHPH=1,
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          CSstart_pumpFW=0,
          TS_pumpFW=0,
          CSmin_pumpHPH=-0.5,
          CSmax_pumpHPH=0.5,
          CSstart_pumpHPH=0,
          TS_pumpHPH=0,
          TS_pumpMS=0,
          CSstart_valveTURB=0,
          TS_valveTURB=0,
          Nd_valveRH=10,
          Ti_valveRH=16,
          Td_valveRH=0,
          load_start=100,
          Nd_pumpFW=30,
          Kp_pumpHPH=0.6461,
          Ti_pumpHPH=19.05,
          Nd_pumpMS=20,
          CSmin_valveRH=-0.9,
          CSmax_valveRH=1,
          CSstart_valveRH=0,
          TS_valveRH=0,
          useTS_pumpHPH=true,
          CSmin_valveTURB=-5.03e-6,
          CSmax_valveTURB=0.04e-6,
          t_start_ramp=0,
          Ta_valveRH=0.3,
          Kp_valveBP=0.1,
          Ti_valveBP=10,
          Td_valveBP=0,
          Nd_valveBP=20,
          CSmin_valveBP=0,
          CSmax_valveBP=1.2,
          CSstart_valveBP=1,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          useTS_valveBP=true,
          TS_valveBP=0,
          CSmax_pumpFW=0.15,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          DT_SH_sp=20,
          Kp_valveRH=0.17,
          CSmin_pumpFW=-0.9,
          useTS_valveRH=false,
          useTS_pumpFW=false,
          useTS_pumpMS=false,
          Kp_pumpMS=0.000035,
          Ti_pumpMS=100,
          Td_pumpMS=67,
          Kp_valveTURB=-0.55e-12,
          Ti_valveTURB=125,
          Td_valveTURB=67,
          Nd_valveTURB=20,
          load_end=70,
          t_ramp=300,
          CSstart_pumpMS=0,
          useTS_valveTURB=false,
          CSmin_pumpMS=-10,
          CSmax_pumpMS=10,
          Kp_pumpFW=-0.04,
          Td_pumpFW=0,
          T_RH_sp=826.05,
          T_FW_sp=553.15,
          Ti_pumpFW=100,
          T_MS_sp=563.15,
          P_mec_sp=79725800,
          p_sp=17611000)
          annotation (Placement(transformation(extent={{-254,-60},{-206,-20}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{214,170},{234,190}})));

        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,30},{220,50}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
        Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
              IPTurb.Pm))
          annotation (Placement(transformation(extent={{-262,6},{-240,34}})));
        Modelica.Blocks.Sources.Ramp LOAD1(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start_ramp)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,210})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
              1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
              3.527e5; 90,4.011e5; 100,4.5e5])
          annotation (Placement(transformation(extent={{248,200},{228,220}})));
        Modelica.Blocks.Sources.Ramp LOAD2(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start_ramp)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={270,60})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
              1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
              4.002e5; 90,4.543e5; 100,5.088e5])
          annotation (Placement(transformation(extent={{248,50},{228,70}})));
        Modelica.Blocks.Sources.Ramp LOAD3(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start_ramp)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={272,0})));
        Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
              2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{250,-10},{230,10}})));
        Modelica.Blocks.Sources.Ramp LOAD4(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start_ramp)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-80})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
              30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
              7.093e5; 90,8.046e5; 100,9e5])
          annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
        Modelica.Blocks.Sources.Ramp LOAD5(
          height=controllers.load_end - controllers.load_start,
          duration=controllers.t_ramp,
          offset=controllers.load_start,
          startTime=controllers.t_start_ramp)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={222,-120})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
              586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
              749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                  -130},{180,-110}})));

      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{95.8,140},{119.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-140,-180},{-128.889,-180},{-128.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-138,160},{-128.889,160},{-128.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-16.1111,48},{12.2,48},{12.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
            color={0,0,255},
            thickness=0.5));

        connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
            points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
            points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                -180},{79.1111,-162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
            points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
            color={0,127,0},
            thickness=0.5));
        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{119.9,
                162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                140},{210.1,140},{242,140}},       color={0,0,0}));
        connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
        connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                        color={0,0,255}));
        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                {210.1,180},{210.1,162.8}}, color={0,0,255}));
        connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                98.2},{179.76,40},{200,40}},        color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
            points={{160.9,98.2},{160.9,-20},{200,-20}},
            color={0,127,0},
            thickness=0.5));
        connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                259,210},{250,210}}, color={0,0,127}));
        connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                227,210},{220,210},{220,188.8}}, color={0,0,127}));
        connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                {250,60}},     color={0,0,127}));
        connect(LOAD3.y,SP5_sink. u[1])
          annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
        connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                {211,-80},{202,-80}},      color={0,0,127}));
        connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                {211,-120},{202,-120}},       color={0,0,127}));
        connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                60},{206,60},{206,48.8}}, color={0,0,127}));
        connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                0},{206,0},{206,-11.2}}, color={0,0,127}));
        connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
              points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
        connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
              points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
        connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-238.9,
                20},{-230,20},{-230,-18.6667}},
                                            color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-204.8,-40},{-165.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                -161.12}},
            color={255,204,51},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                  -240},{320,240}}, preserveAspectRatio=false)),
          experiment(
            StartTime=-2000,
            StopTime=1000,
            __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput,
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
      end plant_HP_100;
    end Plants;

    package Control "Package containing control schemes of the power plant"
      package Schemes
        "Package containing the control models for the OTSG and power plant"
        package SingleControllers
          "Package containing the models of the single controllers"

          model control_wMS_Yt "Model of the power-pressure section controller"

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={-100,100})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{100,80},{60,120}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{120,130},{100,150}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{-80,-120},{-120,-80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=true,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{100,-120},{60,-80}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{120,-70},{100,-50}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,14.887e6; 30,23.2105e6; 40,31.6337e6; 50,40.1936e6; 60,
                  48.842e6; 70,56.4144e6; 80,63.9324e6; 90,71.7506e6; 100,
                  79.2104e6])
              annotation (Placement(transformation(extent={{160,100},{140,120}})));
            Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                  40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                  161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
              annotation (Placement(transformation(extent={{160,-100},{140,-80}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{-40,-110},{-60,-90}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                  488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
              annotation (Placement(transformation(extent={{80,40},{60,60}})));
            Modelica.Blocks.Math.Add add2
              annotation (Placement(transformation(extent={{-40,90},{-60,110}})));
            Modelica.Blocks.Math.Add add1
              annotation (Placement(transformation(extent={{0,-110},{-20,-90}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1.76067e-6; 30,2.60116e-6; 40,3.48908e-6; 50,4.49771e-6; 60,
                  5.03874e-6; 70,5.00728e-6; 80,5.03831e-6; 90,4.98553e-6; 100,
                  5.00938e-6])
              annotation (Placement(transformation(extent={{80,-160},{60,-140}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{240,-20},{200,20}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{20,120},{60,160}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,140})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveTURB_bool annotation (Placement(
                  transformation(extent={{20,-80},{60,-40}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,-120})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-160,0}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-210,0})));
          equation
            connect(pumpMS_TS.y,PID_pumpMS. TR) annotation (Line(points={{99,140},{99,140},
                    {80,140},{80,116}},   color={0,0,127}));
            connect(valveTURB_TS.y,PID_valveTURB. TR) annotation (Line(points={{99,-60},{99,
                    -60},{80,-60},{80,-84}},       color={0,0,127}));
            connect(PID_pumpMS.SP,table_P_MEC. y[1])
              annotation (Line(points={{96,112},{96,110},{139,110}},   color={0,0,127}));
            connect(PID_valveTURB.SP,table_P. y[1])
              annotation (Line(points={{96,-88},{96,-90},{139,-90}},
                                                           color={0,0,127}));
            connect(table_w_MS.y[1],add2. u2) annotation (Line(points={{59,50},{-21,50},{-21,
                    94},{-38,94}},             color={0,0,127}));
            connect(pumpMS_dynamic.u,add2. y) annotation (Line(points={{-76,100},{-61,100}},
                                    color={0,0,127}));
            connect(valveTURB_dynamic.u,table_Y_tTOtheta. y[1])
              annotation (Line(points={{-76,-100},{-66,-100},{-61,-100}},
                                                          color={0,0,127}));
            connect(table_Y_tTOtheta.u[1],add1. y)
              annotation (Line(points={{-38,-100},{-21,-100}},
                                                           color={0,0,127}));
            connect(add1.u2,table_Yt. y[1]) annotation (Line(points={{2,-106},{10,-106},{10,
                    -150},{59,-150}},   color={0,0,127}));
            connect(load, table_P_MEC.u[1]) annotation (Line(points={{220,0},{180,0},{180,
                    110},{162,110}}, color={0,0,127}));
            connect(load, table_P.u[1]) annotation (Line(points={{220,0},{180,0},{180,-90},
                    {162,-90}}, color={0,0,127}));
            connect(add2.u1, PID_pumpMS.CS) annotation (Line(points={{-38,106},{0,106},{0,
                    100},{62,100}}, color={0,0,127}));
            connect(add1.u1, PID_valveTURB.CS) annotation (Line(points={{2,-94},{12,-94},{
                    20,-94},{20,-100},{62,-100}}, color={0,0,127}));
            connect(load, table_w_MS.u[1]) annotation (Line(points={{220,0},{200,0},{180,0},
                    {180,50},{82,50}}, color={0,0,127}));
            connect(load, table_Yt.u[1]) annotation (Line(points={{220,0},{220,0},{180,0},
                    {180,-150},{82,-150}}, color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{-160,0},{-160,0},{-160,100},{-122,100}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{-160,0},{-160,0},{-160,-100},{-122,-100}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
                points={{-160,0},{-16,0},{130,0},{130,98},{96,98}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{-160,0},{-16,0},{130,0},{130,-102},{96,-102}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, PID_pumpMS.TS) annotation (Line(points={{40,
                    140},{58,140},{72,140},{72,116}}, color={255,0,255}));
            connect(TS_valveTURB_bool, PID_valveTURB.TS) annotation (Line(points=
                    {{40,-60},{56,-60},{72,-60},{72,-84}}, color={255,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    fontSize=14,
                    textString="Power/
pressure
controller")}));
          end control_wMS_Yt;

          model control_wHPH "Model of the w_HPH controller"

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{240,-20},{200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-160,0}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-210,0})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{20,-20},{-20,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(                                                            table=[
                  20,0.01; 30,0.01; 40,0.01; 50,0.01; 60,0.01; 70,5.257; 80,24.44;
                  90,67.83; 100,143.1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
          equation
            connect(signalBus.pumpHPH_CS,pumpHPH_dynamic. y) annotation (Line(
                points={{-160,0},{-160,0},{-22,0}},
                color={255,204,51},
                thickness=0.5));
            connect(table_w_HPH.u[1], load) annotation (Line(points={{102,0},{160,
                    0},{220,0}}, color={0,0,127}));
            connect(pumpHPH_dynamic.u, table_w_HPH.y[1])
              annotation (Line(points={{24,0},{79,0}},        color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    fontSize=14,
                    textString="w_HPH

controller")}));
          end control_wHPH;

          model control_wRH "Model of the w_RH controller"

            //-- valveRH --
            parameter Modelica.SIunits.Temperature T_RH_sp
              "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
            parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Ti_valveRH
              "Controller integral time"                                          annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Td_valveRH
              "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
            parameter Real Nd_valveRH
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
            parameter Real CSmin_valveRH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
            parameter Real CSmax_valveRH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
            parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
            parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant"
                                                                                annotation (Dialog(tab="valveRH"));
            parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{240,-20},{200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-160,0}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
              k=actuatorGain_valveRH,
              T=Ta_valveRH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{-80,20},{-120,60}})));
            IndustrialControlSystems.Controllers.PI PID_valveRH(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveRH,
              CSmax=CSmax_valveRH,
              CS_start=CSstart_valveRH,
              Kp=Kp_valveRH,
              Ti=Ti_valveRH)
              annotation (Placement(transformation(extent={{100,20},{60,60}})));
            Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
              annotation (Placement(transformation(extent={{120,70},{100,90}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.4; 70,
                  127.897; 80,158.7; 90,197.125; 100,240.532])
              annotation (Placement(transformation(extent={{80,-20},{60,0}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{12,36},{-8,56}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-40,30},{-60,50}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveRH_bool annotation (Placement(
                  transformation(extent={{20,60},{60,100}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,140})));
            Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
              annotation (Placement(transformation(extent={{160,40},{140,60}})));
          equation
            connect(valveRH_TS.y,PID_valveRH. TR) annotation (Line(points={{99,80},{99,80},
                    {80,80},{80,56}},            color={0,0,127}));
            connect(table_w_RH.y[1], product.u2) annotation (Line(points={{59,-10},
                    {31,-10},{31,40},{14,40}}, color={0,0,127}));
            connect(product.y, add.u1) annotation (Line(points={{-9,46},{-9,46},{
                    -38,46}}, color={0,0,127}));
            connect(add.y, valveRH_dynamic.u) annotation (Line(points={{-61,40},{
                    -61,40},{-76,40}}, color={0,0,127}));
            connect(add.u2, table_w_RH.y[1]) annotation (Line(points={{-38,34},{-30,
                    34},{-20,34},{-20,-10},{59,-10}}, color={0,0,127}));
            connect(product.u1, PID_valveRH.CS) annotation (Line(points={{14,52},
                    {28,52},{40,52},{40,40},{62,40}}, color={0,0,127}));
            connect(PID_valveRH.TS, TS_valveRH_bool)
              annotation (Line(points={{72,56},{72,80},{40,80}}, color={255,0,255}));
            connect(load, table_w_RH.u[1]) annotation (Line(points={{220,0},{180,0},{160,0},
                    {160,-10},{82,-10}}, color={0,0,127}));
            connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{139,50},{130,50},
                    {130,52},{96,52}}, color={0,0,127}));
            connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
                points={{-160,0},{-160,0},{-160,40},{-122,40}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
                points={{-160,0},{-160,-60},{120,-60},{120,38},{96,38}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    fontSize=14,
                    textString="w_RH

controller")}));
          end control_wRH;

          model control_wBP "Model of the w_BP controller"

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater steam temperature set point" annotation (Dialog(tab="valveRH"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveRH"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveRH"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveRH"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveRH"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{240,-20},{200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-160,0}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              k=actuatorGain_valveBP,
              T=Ta_valveBP,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{-80,20},{-120,60}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{100,20},{60,60}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{120,70},{100,90}})));
            Modelica.Blocks.Tables.CombiTable1D table_theta_BP(
                                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.05; 80,0.2; 90,0.55; 100,
                  1])
              annotation (Placement(transformation(extent={{80,-20},{60,0}})));
            Modelica.Blocks.Math.Product product5
                                                 annotation (Placement(transformation(
                    extent={{12,36},{-8,56}})));
            Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-40,30},
                      {-60,50}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveBP_bool annotation (Placement(
                  transformation(extent={{20,60},{60,100}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,140})));
            Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
              annotation (Placement(transformation(extent={{160,40},{140,60}})));
          equation
            connect(add6.u1, product5.y) annotation (Line(points={{-38,46},{-9,46},
                    {-9,46}}, color={0,0,127}));
            connect(product5.u2, table_theta_BP.y[1]) annotation (Line(points={{
                    14,40},{30,40},{30,-10},{59,-10}}, color={0,0,127}));
            connect(add6.u2, table_theta_BP.y[1]) annotation (Line(points={{-38,
                    34},{-30,34},{-20,34},{-20,-10},{59,-10}}, color={0,0,127}));
            connect(product5.u1, PID_valveBP.CS) annotation (Line(points={{14,52},
                    {40,52},{40,40},{62,40}}, color={0,0,127}));
            connect(TS_valveBP_bool, PID_valveBP.TS) annotation (Line(points={{40,
                    80},{72,80},{72,56}}, color={255,0,255}));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{99,80},
                    {80,80},{80,56}}, color={0,0,127}));
            connect(PID_valveBP.SP, T_FW_SP.y) annotation (Line(points={{96,52},{
                    120,52},{120,50},{139,50}}, color={0,0,127}));
            connect(table_theta_BP.u[1], load) annotation (Line(points={{82,-10},
                    {122,-10},{160,-10},{160,0},{220,0}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{-160,0},{-160,40},{-122,40}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{-160,0},{-160,0},{-160,-60},{120,-60},{120,38},{96,38}},
                color={255,204,51},
                thickness=0.5));

            connect(valveBP_dynamic.u, add6.y) annotation (Line(points={{-76,40},
                    {-61,40},{-61,40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    fontSize=14,
                    textString="w_BP

controller")}));
          end control_wBP;

          model control_wFW_w_SEP "Model of the w_FW and w_SEP controller"

            parameter Real load_switch_FW
              "Plant load limit for switching from dry to wet separator configuration";
            parameter Real load_sep_ON
              "Plant load limit for separator pump activation";
            parameter Real level_sep_ON
              "Separator level limit for separator pump activation";

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"
                                   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{240,-20},{200,20}}),
                  iconTransformation(extent={{240,-20},{200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-160,0}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-210,0})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{160,-140},{140,-120}})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={80,140})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={-120,140})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{120,170},{100,190}})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_high,
              CSmax=CSmax_pumpFW_high,
              CS_start=CSstart_pumpFW_high,
              Kp=Kp_pumpFW_high,
              Ti=Ti_pumpFW_high,
              Td=Td_pumpFW_high,
              N=Nd_pumpFW_high)
              annotation (Placement(transformation(extent={{100,-30},{60,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={-120,-60})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{120,20},{100,40}})));
            Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
              annotation (Placement(transformation(extent={{160,140},{140,160}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                  10.62; 20,47.18; 30,55.8443; 40,60.7113; 50,59.9704; 60,59.9704;
                  70,59.9704; 80,0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{80,80},{60,100}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                  3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.7; 70,64.0423;
                  80,72.1907; 90,80.1795; 100,88.2715])
                                              annotation (Placement(transformation(
                    extent={{80,-70},{60,-50}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{-20,136},{-40,156}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-60,130},{-80,150}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{20,-14},{0,6}})));
            Modelica.Blocks.Math.Add add1
              annotation (Placement(transformation(extent={{-20,-20},{-40,0}})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{-60,-70},{-80,-50}})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_low,
              CSmax=CSmax_pumpFW_low,
              CS_start=CSstart_pumpFW_low,
              Kp=Kp_pumpFW_low,
              Ti=Ti_pumpFW_low,
              Td=Td_pumpFW_low,
              N=Nd_pumpFW_low)
              annotation (Placement(transformation(extent={{100,-160},{60,-120}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                       k=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{120,-110},{100,-90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpSEP_bool annotation (Placement(
                  transformation(extent={{20,160},{60,200}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,140})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{20,10},{60,50}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={220,-140})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch_FW)
              annotation (Placement(transformation(extent={{160,-90},{140,-70}})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{160,-10},{140,10}})));
            Modelica.Blocks.Logical.And and1
              annotation (Placement(transformation(extent={{220,98},{200,118}})));
            Modelica.Blocks.Logical.Switch switch_SEP
              annotation (Placement(transformation(extent={{120,100},{100,80}})));
            Modelica.Blocks.Sources.Constant const(k=100)
              annotation (Placement(transformation(extent={{170,100},{150,120}})));
            Modelica.Blocks.Logical.Greater greater
              annotation (Placement(transformation(extent={{260,130},{240,110}})));
            Modelica.Blocks.Logical.Less less
              annotation (Placement(transformation(extent={{260,92},{240,72}})));
            Modelica.Blocks.Sources.Constant level_SEP_on(k=level_sep_ON) annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,150})));
            Modelica.Blocks.Sources.Constant load_SEP_on(k=load_sep_ON) annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,90})));
            Modelica.Blocks.Math.Division division
              annotation (Placement(transformation(extent={{-40,80},{-20,100}})));
            Modelica.Blocks.Sources.Constant l_SP1(
                                                  k=l_sp)
              annotation (Placement(transformation(extent={{-80,68},{-60,88}})));
            Modelica.Blocks.Math.Product product2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={10,110})));
          equation
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{-160,0},{-160,140},{-142,140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{-160,0},{-160,0},{-160,-60},{-142,-60}},
                color={255,204,51},
                thickness=0.5));
            connect(product.y, add.u1)
              annotation (Line(points={{-41,146},{-41,146},{-58,146}},
                                                                     color={0,0,127}));
            connect(pumpSEP_dynamic.u, add.y)
              annotation (Line(points={{-96,140},{-81,140}}, color={0,0,127}));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{-160,0},{-160,60},{128,60},{128,138},{96,138}},
                color={255,204,51},
                thickness=0.5));
            connect(product1.y, add1.u1)
              annotation (Line(points={{-1,-4},{-1,-4},{-18,-4}}, color={0,0,127}));
            connect(add1.u2, table_w_FW.y[1]) annotation (Line(points={{-18,-16},{0,-16},{
                    0,-60},{59,-60}}, color={0,0,127}));
            connect(product1.u2, table_w_FW.y[1]) annotation (Line(points={{22,-10},
                    {32,-10},{32,-60},{59,-60}},
                                        color={0,0,127}));
            connect(pumpFW_dynamic.u, switch_FW.y)
              annotation (Line(points={{-96,-60},{-81,-60}}, color={0,0,127}));
            connect(load, table_w_FW.u[1]) annotation (Line(points={{220,0},{220,0},{180,0},
                    {180,-60},{82,-60}}, color={0,0,127}));
            connect(add1.y, switch_FW.u1) annotation (Line(points={{-41,-10},{-48,-10},{-48,
                    -52},{-58,-52}}, color={0,0,127}));
            connect(product1.u1, PID_pumpFW_high.CS) annotation (Line(points={{22,2},{
                    40,2},{40,-10},{62,-10}},
                                        color={0,0,127}));
            connect(switch_FW.u3, PID_pumpFW_low.CS) annotation (Line(points={{-58,-68},{-48,
                    -68},{-48,-140},{62,-140}}, color={0,0,127}));
            connect(pumpFW_TS_low.y, PID_pumpFW_low.TR)
              annotation (Line(points={{99,-100},{80,-100},{80,-124}}, color={0,0,127}));
            connect(l_SP.y, PID_pumpFW_low.SP) annotation (Line(points={{139,-130},{96,-130},
                    {96,-128}}, color={0,0,127}));
            connect(T_MS_SP.y, PID_pumpSEP.SP)
              annotation (Line(points={{139,150},{96,150},{96,152}}, color={0,0,127}));
            connect(pumpSEP_TS.y, PID_pumpSEP.TR)
              annotation (Line(points={{99,180},{80,180},{80,156}}, color={0,0,127}));
            connect(product.u1, PID_pumpSEP.CS) annotation (Line(points={{-18,152},
                    {-18,152},{40,152},{40,140},{62,140}},
                                                 color={0,0,127}));
            connect(pumpFW_TS_high.y, PID_pumpFW_high.TR) annotation (Line(points={{99,30},
                    {90,30},{80,30},{80,6}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW_high.PV) annotation (Line(
                points={{-160,0},{-160,0},{-160,60},{128,60},{128,-12},{96,-12}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
                points={{-160,0},{-160,0},{-160,60},{128,60},{128,-142},{96,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpSEP_bool, PID_pumpSEP.TS)
              annotation (Line(points={{40,180},{72,180},{72,156}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, PID_pumpFW_high.TS)
              annotation (Line(points={{40,30},{72,30},{72,6}}, color={255,0,255}));
            connect(switch_FW.u2, greaterEqualThreshold.y)
              annotation (Line(points={{-58,-60},{-20,-60},{-20,-80},{139,-80}},
                                                             color={255,0,255}));
            connect(DT_sh_SP.y, PID_pumpFW_high.SP)
              annotation (Line(points={{139,0},{96,0},{96,2}}, color={0,0,127}));
            connect(table_w_SEP.u[1], switch_SEP.y)
              annotation (Line(points={{82,90},{99,90}}, color={0,0,127}));
            connect(and1.u1, greater.y) annotation (Line(points={{222,108},{232,
                    108},{232,120},{239,120}},
                                color={255,0,255}));
            connect(and1.u2, less.y)
              annotation (Line(points={{222,100},{222,100},{233,100},{233,82},{
                    239,82}},                                       color={255,0,255}));
            connect(load, less.u1) annotation (Line(points={{220,0},{220,0},{180,0},{180,30},
                    {270,30},{270,82},{262,82}}, color={0,0,127}));
            connect(load_SEP_on.y, less.u2)
              annotation (Line(points={{279,90},{270,90},{262,90}}, color={0,0,127}));
            connect(load, switch_SEP.u1) annotation (Line(points={{220,0},{200,0},{180,0},
                    {180,82},{122,82}}, color={0,0,127}));
            connect(switch_SEP.u3, const.y) annotation (Line(points={{122,98},{130,98},{140,
                    98},{140,110},{149,110}}, color={0,0,127}));
            connect(level_SEP_on.y, greater.u2) annotation (Line(points={{279,150},
                    {274,150},{270,150},{270,128},{262,128}},
                                                    color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, greater.u1) annotation (Line(
                points={{-160,0},{-160,0},{-160,60},{128,60},{320,60},{320,120},{
                    262,120}},
                color={255,204,51},
                thickness=0.5));

            connect(load, greaterEqualThreshold.u) annotation (Line(points={{220,
                    0},{200,0},{180,0},{180,-80},{162,-80}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, PID_pumpFW_low.TS) annotation (Line(
                  points={{139,-80},{110,-80},{72,-80},{72,-124}}, color={255,0,
                    255}));
            connect(division.y, product2.u1) annotation (Line(points={{-19,90},{4,
                    90},{4,98}}, color={0,0,127}));
            connect(table_w_SEP.y[1], product2.u2) annotation (Line(points={{59,
                    90},{16,90},{16,98}}, color={0,0,127}));
            connect(product2.y, add.u2) annotation (Line(points={{10,121},{10,128},
                    {-48,128},{-48,134},{-58,134}}, color={0,0,127}));
            connect(product2.y, product.u2) annotation (Line(points={{10,121},{10,
                    121},{10,140},{-18,140}}, color={0,0,127}));
            connect(l_SP1.y, division.u2) annotation (Line(points={{-59,78},{-50,
                    78},{-50,84},{-42,84}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, division.u1) annotation (Line(
                points={{-160,0},{-160,0},{-160,60},{-100,60},{-100,96},{-42,96}},
                color={255,204,51},
                thickness=0.5));

            connect(switch_SEP.u2, less.y) annotation (Line(points={{122,90},{220,
                    90},{220,82},{239,82}}, color={255,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{340,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{340,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    fontSize=14,
                    textString="w_SEP
w_FW
control")}));
          end control_wFW_w_SEP;
        end SingleControllers;

        model plant_controller_HPpart "Model of the HP plant control system "

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.673; 70,64.0423;
                80,72.1907; 90,80.1795; 100,88.2715])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(                                              table=[
                20,1; 30,1; 40,1; 50,1; 60,1; 70,5.257; 80,24.44; 90,67.83; 100,
                143.1], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.7; 70,127.897;
                80,158.7; 90,197.125; 100,240.532])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,
                1.76067e-6; 30,2.60116e-6; 40,3.48908e-6; 50,4.49771e-6; 60,5.03874e-6;
                70,5.00728e-6; 80,5.03831e-6; 90,4.98553e-6; 100,5.00938e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(table=[4,0; 20,0; 30,0; 40,0;
                50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={360,160}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-390,72})));
        equation
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                  -100},{272,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                  -100},{280,-100},{280,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                  {-152,-190},{-152,-146},{-142,-146}},color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                  10},{-262,10}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                  339,-128},{339,-128}}, color={0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                  {379,-128}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                  10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(table_T_FW.y[1], PID_valveBP.SP)
            annotation (Line(points={{-339,72},{-296,72},{-296,72}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},{-290,
                  280},{-280,280},{-280,256}}, color={0,0,127}));
          connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                  -100},{-280,-124}}, color={0,0,127}));
          connect(valveTURB_TS.y, PID_valveTURB.TR)
            annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{122,246},{172,
                  246},{220,246},{220,240},{262,240}}, color={0,0,127}));
          connect(PID_valveRH.CS, product5.u1) annotation (Line(points={{-262,240},
                  {-232,240},{-200,240},{-200,252},{-182,252}}, color={0,0,127}));
          connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},{
                  -210,60},{-158,60},{-158,66},{-142,66}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,-140},
                  {-224,-140},{-224,-128},{-182,-128}}, color={0,0,127}));
          connect(product1.u1, PID_pumpHPH.CS) annotation (Line(points={{162,-128},
                  {214,-128},{214,-140},{262,-140}}, color={0,0,127}));
          connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{172,66},{
                  216,66},{216,60},{262,60}}, color={0,0,127}));
          connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                  238},{324,160},{360,160}}, color={0,0,127}));
          connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},{
                  -370.5,72},{-362,72}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart;

        model plant_controller_HPpart_checkValveBP
          "Model of the HP plant control system for by-pass valve on HPH2 testing "

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(table=[20,1.76067e-6; 30,
                2.65048e-6; 40,3.52138e-6; 50,4.55279e-6; 60,5.03874e-6; 70,
                5.03871e-6; 80,5.03821e-6; 90,5.03773e-6; 100,5.03668e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Gain    product2(k=0)
                                               annotation (Placement(transformation(
                  extent={{-190,70},{-170,90}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-170,-270})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS1(
                                                         smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.25; 80,0.5; 90,0.75; 100,1])
            annotation (Placement(transformation(extent={{-140,-280},{-120,-260}})));
          Modelica.Blocks.Sources.Ramp ramp_pos(
            offset=0,
            duration=5000,
            startTime=5000,
            height=0.4) annotation (Placement(transformation(extent={{-140,-200},{
                    -120,-180}})));
          Modelica.Blocks.Sources.Ramp ramp_neg(
            offset=0,
            duration=5000,
            height=-1.2,
            startTime=15000) annotation (Placement(transformation(extent={{-140,
                    -230},{-120,-210}})));
          Modelica.Blocks.Math.MultiSum multiSum(nu=3)
            annotation (Placement(transformation(extent={{-66,-266},{-54,-254}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},
                  {-272,100},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{-240,
                  60},{-240,54},{-218,54},{-218,54},{-142,54},{-142,54}},
                                            color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -53},{-104,-132},{-104,-132}}, color={0,0,127}));
          connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,100},
                  {-280,100},{-280,76}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,110},{120,110},{
                  220,110},{220,72},{212,72}}, color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(product2.y, add8.u1) annotation (Line(points={{-169,80},{-160,80},
                  {-160,66},{-142,66}}, color={0,0,127}));
          connect(du_w_SEP, product2.u) annotation (Line(points={{-140,100},{-170,
                  100},{-200,100},{-200,80},{-192,80}}, color={0,0,127}));
          connect(add8.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -84,60},{-84,60}}, color={0,0,127}));
          connect(add8.y, add.u2) annotation (Line(points={{-119,60},{-108,60},{-98,
                  60},{-98,2}}, color={0,0,127}));
          connect(LOAD10.y,table_T_MS1. u[1]) annotation (Line(points={{-159,-270},
                  {-150.5,-270},{-142,-270}}, color={0,0,127}));
          connect(table_T_MS1.y, multiSum.u[1:1]) annotation (Line(points={{-119,
                  -270},{-80,-270},{-80,-257.2},{-66,-257.2}}, color={0,0,127}));
          connect(ramp_pos.y, multiSum.u[2]) annotation (Line(points={{-119,-190},{
                  -80,-190},{-80,-260},{-66,-260}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, multiSum.y) annotation (Line(
              points={{0,60},{0,60},{0,-260},{-52.98,-260}},
              color={255,204,51},
              thickness=0.5), Text(
              string="%first",
              index=-1,
              extent={{-6,3},{-6,3}}));
          connect(ramp_neg.y, multiSum.u[3]) annotation (Line(points={{-119,-220},{
                  -119,-220},{-80,-220},{-80,-262.8},{-66,-262.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_checkValveBP;

        model plant_controller_HPpart_lin_highLoad
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp_TS
            "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
          parameter Boolean TS_start = true
            "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanStep booleanStep1(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep2(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep6(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.7; 70,
                64.0423; 80,72.1907; 90,80.1795; 100,88.2715])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(                                                            table=[
                20,0.01; 30,0.01; 40,0.01; 50,0.01; 60,0.01; 70,5.257; 80,24.44;
                90,67.83; 100,143.1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-120},{140,-80}}),  iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(table=[20,1.76067e-6; 30,
                2.65048e-6; 40,3.52138e-6; 50,4.55279e-6; 60,5.03874e-6; 70,
                5.03871e-6; 80,5.03821e-6; 90,5.03773e-6; 100,5.03668e-6],
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(table=[4,0; 20,0; 30,0; 40,0;
                50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{-220,56},{-200,76}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
        equation
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                  -100},{272,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                  -100},{280,-100},{280,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,-100},{-230,
                  -100},{-230,-122},{-222,-122}},      color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-100},{168,-100},{214,
                  -100},{214,-122},{202,-122}},     color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{212,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                  10},{-262,10}}, color={0,0,127}));
          connect(PID_valveRH.CS, PID_valveRH.TR) annotation (Line(points={{-262,
                  240},{-254,240},{-254,264},{-280,264},{-280,256}}, color={0,0,
                  127}));
          connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-262,-140},{-254,
                  -140},{-254,-116},{-280,-116},{-280,-124}},             color={
                  0,0,127}));
          connect(PID_valveTURB.CS, PID_valveTURB.TR) annotation (Line(points={{
                  262,60},{252,60},{252,84},{280,84},{280,76}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                  339,-128},{339,-128}}, color={0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                  {379,-128}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{-230,100},{
                  -230,72},{-222,72}}, color={0,0,127}));
          connect(add11.y, add8.u1) annotation (Line(points={{-199,66},{-170.5,66},{-142,
                  66}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                  10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
          connect(T_FW_SP.y, table_T_FW.u[1])
            annotation (Line(points={{-379,72},{-370,72},{-362,72}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_valveBP.CS, add11.u2)
            annotation (Line(points={{-262,60},{-242,60},{-222,60}}, color={0,0,127}));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(table_T_FW.y[1], PID_valveBP.SP)
            annotation (Line(points={{-339,72},{-296,72},{-296,72}}, color={0,0,127}));
          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad;

        model plant_controller_HPpart_lin_highLoad_FF
          "Model of the HP plant control system for linearization purpose, only feedforward"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.673; 70,
                64.0423; 80,72.24; 90,80.1795; 100,88.2715])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                                      smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,1; 30,1; 40,1; 50,1; 60,1; 70,5.257; 80,24.44; 90,67.83; 100,
                143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.7; 70,127.897;
                80,158.7; 90,197.125; 100,240.532])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-120},{140,-80}}),  iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,
                1.76067e-6; 30,2.60116e-6; 40,3.48908e-6; 50,4.49771e-6; 60,5.03874e-6;
                70,5.00728e-6; 80,5.03831e-6; 90,4.98553e-6; 100,5.00938e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(table=[4,0; 20,0; 30,0; 40,0;
                50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{-220,56},{-200,76}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
        equation
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                  -100},{272,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                  -100},{280,-100},{280,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,-100},{-230,
                  -100},{-230,-122},{-222,-122}},      color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-100},{168,-100},{214,
                  -100},{214,-122},{202,-122}},     color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{212,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                  10},{-262,10}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                  339,-128},{339,-128}}, color={0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                  {379,-128}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{-230,100},{
                  -230,72},{-222,72}}, color={0,0,127}));
          connect(add11.y, add8.u1) annotation (Line(points={{-199,66},{-170.5,66},{-142,
                  66}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                  10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
          connect(T_FW_SP.y, table_T_FW.u[1])
            annotation (Line(points={{-379,72},{-370,72},{-362,72}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_valveBP.CS, add11.u2)
            annotation (Line(points={{-262,60},{-242,60},{-222,60}}, color={0,0,127}));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(table_T_FW.y[1], PID_valveBP.SP)
            annotation (Line(points={{-339,72},{-296,72},{-296,72}}, color={0,0,127}));
          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},{-290,
                  280},{-280,280},{-280,256}}, color={0,0,127}));
          connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                  -100},{-280,-124}}, color={0,0,127}));
          connect(valveTURB_TS.y, PID_valveTURB.TR)
            annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad_FF;

        model plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
          "Model of the HP plant control system for linearization purpose, only feedforward"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,55.673; 70,
                64.0423; 80,72.24; 90,80.1795; 100,88.2715])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                                      smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,1; 30,1; 40,1; 50,1; 60,1; 70,5.257; 80,24.44; 90,67.83; 100,
                143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(
                                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,102.7; 70,127.897;
                80,158.7; 90,197.125; 100,240.532])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-120},{140,-80}}),  iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent={{-220,
                    -144},{-200,-124}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,
                1.76067e-6; 30,2.60116e-6; 40,3.48908e-6; 50,4.49771e-6; 60,5.03874e-6;
                70,5.00728e-6; 80,5.03831e-6; 90,4.98553e-6; 100,5.00938e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(table=[4,0; 20,0; 30,0; 40,0;
                50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{-220,56},{-200,76}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
        equation
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                  -100},{272,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                  -100},{280,-100},{280,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-222,-140}},             color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,
                  -100},{-230,-100},{-230,-128},{-222,-128}},
                                                       color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-100},{168,-100},{214,
                  -100},{214,-122},{202,-122}},     color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{212,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                  10},{-262,10}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                  339,-128},{339,-128}}, color={0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                  {379,-128}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{-230,100},{
                  -230,72},{-222,72}}, color={0,0,127}));
          connect(add11.y, add8.u1) annotation (Line(points={{-199,66},{-170.5,66},{-142,
                  66}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                  10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
          connect(T_FW_SP.y, table_T_FW.u[1])
            annotation (Line(points={{-379,72},{-370,72},{-362,72}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_valveBP.CS, add11.u2)
            annotation (Line(points={{-262,60},{-242,60},{-222,60}}, color={0,0,127}));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(table_T_FW.y[1], PID_valveBP.SP)
            annotation (Line(points={{-339,72},{-296,72},{-296,72}}, color={0,0,127}));
          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},{-290,
                  280},{-280,280},{-280,256}}, color={0,0,127}));
          connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                  -100},{-280,-124}}, color={0,0,127}));
          connect(valveTURB_TS.y, PID_valveTURB.TR)
            annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(add9.y, add1.u1) annotation (Line(points={{-199,-134},{-170.5,
                  -134},{-142,-134}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim;

        model plant_controller_HPpart_lin_lowLoad
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_TS
            "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
          parameter Boolean TS_start = true
            "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"   annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-360,242},{-340,262}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanStep booleanStep1(
              startTime=t_start_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep2(
              startTime=t_start_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-400,22},{-380,42}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep6(
              startTime=t_start_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent={{-200,
                    -150},{-180,-130}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep3(startTime=t_start_TS,
              startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_CS(k=0)
            annotation (Placement(transformation(extent={{100,-150},{80,-130}})));
          Modelica.Blocks.Sources.Constant pump_HPH_CS(k=0.01)
            annotation (Placement(transformation(extent={{100,-192},{80,-172}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[4,6.08; 20,22.7; 30,39.3155; 40,57.8195; 50,78.6059; 60,
                102.7; 70,127.897; 80,158.7; 90,197.125; 100,240.532])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(table=[4,10.62; 20,
                47.18; 30,55.8443; 40,60.7113; 50,59.9704; 60,0; 70,0; 80,0; 90,0;
                100,0], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[4,3.54; 20,17.04; 30,26.1634; 40,35.5869; 50,45.2777; 60,
                55.673; 70,64.0423; 80,72.1907; 90,80.1795; 100,88.2715])
            annotation (Placement(transformation(extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt1(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,1.76067e-6; 30,2.60116e-6; 40,3.48908e-6; 50,4.49771e-6; 60,
                5.03874e-6; 70,5.00728e-6; 80,5.03831e-6; 90,4.98553e-6; 100,
                5.00938e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS1(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
        equation
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-339,252},{-339,252},
                  {-296,252}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{-220,-140},
                  {-220,-146},{-218,-146},{-202,-146}},color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-140,-100},{-220,
                  -100},{-220,-134},{-202,-134}},      color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{212,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(PID_valveRH.CS, PID_valveRH.TR) annotation (Line(points={{-262,
                  240},{-254,240},{-254,264},{-280,264},{-280,256}}, color={0,0,
                  127}));
          connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-262,-140},{-254,
                  -140},{-254,-116},{-280,-116},{-280,-124}},             color={
                  0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{-362,72},{
                  -379,72}},   color={0,0,127}));
          connect(l_SP.y, PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));

          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(product4.y,add2. u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add2.y,pumpSEP_dynamic. u) annotation (Line(points={{-119,60},{-101.5,
                  60},{-84,60}},        color={0,0,127}));
          connect(add8.y,product4. u1) annotation (Line(points={{-199,72},{-192,72},{-182,
                  72}},       color={0,0,127}));
          connect(du_w_SEP,add8. u1) annotation (Line(points={{-140,100},{-184,100},{-230,
                  100},{-230,78},{-222,78}},       color={0,0,127}));
          connect(PID_pumpSEP.CS,add8. u2) annotation (Line(points={{-262,60},{-230,60},
                  {-230,66},{-222,66}},     color={0,0,127}));
          connect(PID_pumpSEP.CS,PID_pumpSEP. TR) annotation (Line(points={{-262,60},{-256,
                  60},{-252,60},{-252,84},{-280,84},{-280,76}},       color={0,0,
                  127}));
          connect(table_T_MS.y[1], PID_pumpSEP.SP)
            annotation (Line(points={{-339,72},{-296,72}},           color={0,0,127}));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep3.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},{-272,
                  100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_CS, valveBP_CS.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{79,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pump_HPH_CS.y) annotation (Line(
              points={{0,60},{0,60},{0,-182},{79,-182}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-222},{0,-220},{-320,-220},{-320,-142},{
                  -296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(add9.y, pumpFW_dynamic.u) annotation (Line(points={{-179,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_valveTURB.CS, PID_valveTURB.TR) annotation (Line(points={{
                  262,60},{258,60},{254,60},{254,82},{280,82},{280,76}}, color={0,
                  0,127}));
          connect(LOAD9.y, table_w_RH.u[1]) annotation (Line(points={{-279,190},{
                  -262,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -196,190},{-150,190},{-150,234},{-142,234}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,
                  190},{-214,190},{-190,190},{-190,240},{-182,240}}, color={0,0,
                  127}));
          connect(LOAD8.y, table_w_SEP.u[1]) annotation (Line(points={{-279,10},{
                  -270,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add2.u2) annotation (Line(points={{-239,10},{
                  -196,10},{-150,10},{-150,54},{-142,54}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-239,
                  10},{-216,10},{-190,10},{-190,60},{-182,60}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-279,-190},
                  {-268,-190},{-268,-190},{-262,-190}}, color={0,0,127}));
          connect(table_w_MS1.u[1], LOAD7.y) annotation (Line(points={{242,190},{
                  259,190},{259,190}}, color={0,0,127}));
          connect(table_w_MS1.y[1], add4.u2) annotation (Line(points={{219,190},{
                  180,190},{140,190},{140,234},{122,234}}, color={0,0,127}));
          connect(LOAD6.y, table_Yt1.u[1]) annotation (Line(points={{259,10},{242,
                  10},{242,10}}, color={0,0,127}));
          connect(table_Yt1.y[1], add5.u2) annotation (Line(points={{219,10},{200,
                  10},{180,10},{180,54},{172,54}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_lowLoad;

        model desuperheating_controller "Model of the OTSG control system"

          //Controllers parameter
          //--SH DESUPERHEATING CONTROL--
          parameter Modelica.SIunits.Temperature T_des_SH_sp
            "SH desuperheating temperature set point"                                                  annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real Kp_des_SH "Controller proportional gain" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Ti_des_SH "Controller integral time" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Td_des_SH
            "Controller derivative time"                                         annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real Nd_des_SH
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSmin_des_SH
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSmax_des_SH
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSstart_des_SH "Start value of CS" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real actuatorGain_des_SH "Actuator gain" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Ta_des_SH "Actuator time constant" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Boolean useTS_des_SH "Tracking reference mode" annotation (Dialog(tab="SH desuperheating controller"));

          //--RH DESUPERHEATING CONTROL--
          parameter Modelica.SIunits.Temperature T_des_RH_sp
            "RH desuperheating temperature set point"                                              annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real Kp_des_RH "Controller proportional gain" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Ti_des_RH "Controller integral time" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Td_des_RH
            "Controller derivative time"                                         annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real Nd_des_RH
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSmin_des_RH
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSmax_des_RH
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSstart_des_RH "Start value of CS" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real actuatorGain_des_RH "Actuator gain" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Ta_des_RH "Actuator time constant" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Boolean useTS_des_RH "Tracking reference mode" annotation (Dialog(tab="RH desuperheating controller"));

          //--SH LAMINATING CONTROL--
          parameter Modelica.SIunits.AbsolutePressure p_SH_sp
            "SH pressure set point"     annotation (Dialog(tab="SH pressure controller"));
          parameter Real Kp_p_SH "Controller proportional gain" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Ti_p_SH "Controller integral time" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Td_p_SH "Controller derivative time" annotation (Dialog(tab="SH pressure controller"));
          parameter Real Nd_p_SH
            "Controller derivative action up to Nd/Td rad/s"                      annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSmin_p_SH
            "Minimum value of control signal for scaling"                         annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSmax_p_SH
            "Maximum value of control signal for scaling"                         annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSstart_p_SH "Start value of CS" annotation (Dialog(tab="SH pressure controller"));
          parameter Real actuatorGain_p_SH "Actuator gain" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Ta_p_SH "Actuator time constant" annotation (Dialog(tab="SH pressure controller"));
          parameter Boolean useTS_p_SH "Tracking reference mode" annotation (Dialog(tab="SH pressure controller"));

          //--RH LAMINATING CONTROL--
          parameter Modelica.SIunits.AbsolutePressure p_RH_sp
            "RH pressure set point"     annotation (Dialog(tab="RH pressure controller"));
          parameter Real Kp_p_RH "Controller proportional gain" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Ti_p_RH "Controller integral time" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Td_p_RH "Controller derivative time" annotation (Dialog(tab="RH pressure controller"));
          parameter Real Nd_p_RH
            "Controller derivative action up to Nd/Td rad/s"                      annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSmin_p_RH
            "Minimum value of control signal for scaling"                         annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSmax_p_RH
            "Maximum value of control signal for scaling"                         annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSstart_p_RH "Start value of CS" annotation (Dialog(tab="RH pressure controller"));
          parameter Real actuatorGain_p_RH "Actuator gain" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Ta_p_RH "Actuator time constant" annotation (Dialog(tab="RH pressure controller"));
          parameter Boolean useTS_p_RH "Tracking reference mode" annotation (Dialog(tab="RH pressure controller"));

          Modelica.Blocks.Continuous.FirstOrder valveDynamic_desSH(
            k=actuatorGain_des_SH,
            T=Ta_des_SH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{40,40},{60,60}})));
          IndustrialControlSystems.Controllers.PI PID_desSH(
            Ti=Ti_des_SH,
            CSmin=CSmin_des_SH,
            CSmax=CSmax_des_SH,
            CS_start=CSstart_des_SH,
            Kp=Kp_des_SH,
            AntiWindup=true,
            useTS=useTS_des_SH)
            annotation (Placement(transformation(extent={{-10,40},{10,60}})));
          Modelica.Blocks.Sources.Constant T_desSH_SP(k=T_des_SH_sp)
            annotation (Placement(transformation(extent={{-90,46},{-70,66}})));
          Modelica.Blocks.Sources.Constant p_RH_SP(k=p_RH_sp)
            annotation (Placement(transformation(extent={{-88,-74},{-68,-54}})));
          IndustrialControlSystems.Controllers.PI PID_p_RH(
            Kp=Kp_p_RH,
            Ti=Ti_p_RH,
            CSmin=CSmin_p_RH,
            CSmax=CSmax_p_RH,
            CS_start=CSstart_p_RH,
            AntiWindup=true,
            useTS=useTS_p_RH) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={0,-70})));
         Modelica.Blocks.Continuous.FirstOrder valveDynamic_p_RH(
            k=actuatorGain_p_RH,
            T=Ta_p_RH,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={50,-70})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={110,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{40,-40},{20,-20}})));
          IndustrialControlSystems.Controllers.PI PID_p_SH(
            CSmin=CSmin_p_SH,
            CSmax=CSmax_p_SH,
            CS_start=CSstart_p_SH,
            Kp=Kp_p_SH,
            Ti=Ti_p_SH,
            AntiWindup=true,
            useTS=useTS_p_SH)
            annotation (Placement(transformation(extent={{-10,-160},{10,-140}})));
          Modelica.Blocks.Sources.Constant p_SH_SP(k=p_SH_sp)
            annotation (Placement(transformation(extent={{-86,-154},{-66,-134}})));
         Modelica.Blocks.Continuous.FirstOrder valveDynamic_p_SH(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_p_SH,
            T=Ta_p_SH) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={50,-150})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{40,70},{20,90}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{40,-130},{20,-110}})));
          Modelica.Blocks.Continuous.FirstOrder valveDynamic_desRH(
            k=actuatorGain_des_RH,
            T=Ta_des_RH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{40,120},{60,140}})));
          IndustrialControlSystems.Controllers.PI
                                              PID_desRH(
            Ti=Ti_des_RH,
            CSmin=CSmin_des_RH,
            CSmax=CSmax_des_RH,
            CS_start=CSstart_des_RH,
            Kp=Kp_des_RH,
            AntiWindup=true,
            useTS=useTS_des_RH)
            annotation (Placement(transformation(extent={{-12,120},{8,140}})));
          Modelica.Blocks.Sources.Constant T_desRH_SP(k=T_des_RH_sp)
            annotation (Placement(transformation(extent={{-90,126},{-70,146}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{40,150},{20,170}})));
          Modelica.Blocks.Sources.Constant const(k=0.0522)
            annotation (Placement(transformation(extent={{-30,150},{-10,170}})));
          Modelica.Blocks.Sources.Constant const1(k=0.6341)
            annotation (Placement(transformation(extent={{-30,70},{-10,90}})));
          Modelica.Blocks.Sources.Constant const2(k=0.6)
            annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
          Modelica.Blocks.Sources.Constant const3(k=0.6)
            annotation (Placement(transformation(extent={{-30,-130},{-10,-110}})));
        equation
          connect(T_desSH_SP.y, PID_desSH.SP) annotation (Line(
              points={{-69,56},{-8,56}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_desSH.CS, valveDynamic_desSH.u) annotation (Line(
              points={{9,50},{38,50}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_p_RH.SP, p_RH_SP.y) annotation (Line(
              points={{-8,-64},{-67,-64}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep.y, PID_p_RH.TS) annotation (Line(points={{19,-30},{4,-30},
                  {4,-62}},                 color={255,0,255}));
          connect(PID_p_RH.CS, valveDynamic_p_RH.u)
            annotation (Line(points={{9,-70},{24,-70},{38,-70}},
                                                        color={0,0,127}));
          connect(booleanStep1.y, PID_desSH.TS)
            annotation (Line(points={{19,80},{4,80},{4,58}}, color={255,0,255}));
          connect(PID_p_SH.TS, booleanStep2.y) annotation (Line(points={{4,-142},{4,-142},
                  {4,-122},{4,-120},{19,-120}}, color={255,0,255}));
          connect(p_SH_SP.y, PID_p_SH.SP) annotation (Line(points={{-65,-144},{-60,-144},
                  {-8,-144}}, color={0,0,127}));
          connect(T_desRH_SP.y, PID_desRH.SP) annotation (Line(
              points={{-69,136},{-10,136}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_desRH.CS, valveDynamic_desRH.u) annotation (Line(
              points={{7,130},{38,130}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep3.y, PID_desRH.TS)
            annotation (Line(points={{19,160},{2,160},{2,138}}, color={255,0,255}));
          connect(PID_p_SH.CS, valveDynamic_p_SH.u)
            annotation (Line(points={{9,-150},{24,-150},{38,-150}}, color={0,0,127}));
          connect(signalBus.sensT_des_RH, PID_desRH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,129},{-10,129}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensT_des_SH, PID_desSH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,49},{-8,49}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDes_RH_CS, valveDynamic_desRH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,130},{61,130}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDes_SH_CS, valveDynamic_desSH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,50},{61,50}},
              color={255,204,51},
              thickness=0.5));
          connect(const.y, PID_desRH.TR) annotation (Line(points={{-9,160},{-2,160},
                  {-2,138}}, color={0,0,127}));
          connect(const1.y, PID_desSH.TR)
            annotation (Line(points={{-9,80},{0,80},{0,58}}, color={0,0,127}));
          connect(const2.y, PID_p_RH.TR)
            annotation (Line(points={{-9,-30},{0,-30},{0,-62}}, color={0,0,127}));
          connect(const3.y, PID_p_SH.TR) annotation (Line(points={{-9,-120},{0,-120},
                  {0,-142}}, color={0,0,127}));
          connect(signalBus.valveLam_RH_CS, valveDynamic_p_RH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,-70},{61,-70}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveLam_SH_CS, valveDynamic_p_SH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,-150},{61,-150}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensP_RH, PID_p_RH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,-71},{-8,-71}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensP_SH, PID_p_SH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,-151},{-8,-151}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -180},{100,180}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-180},{100,180}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-94,98},{94,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="Desuperheating/
laminating
station
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-100,180},{100,-180}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end desuperheating_controller;

      end Schemes;

      package Linearization "Test for process linearization and PID tuning"

        model Plant_HP_IO_100
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            load_end=100,
            t_ramp=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            t_start_ramp=0,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            P_mec_sp=79725800,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,
                  120},{-280,120},{-280,-28.2667},{-255.2,-28.2667}},
                                                                 color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{
                  98.5556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_100;

        model Plant_HP_IO_90
          "Model of the high pressure parto of the OTSG for linearization at 90% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            load_end=90,
            t_ramp=10000,
            t_start_ramp=5000,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            P_mec_sp=79725800,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -200},{-270,-200},{-270,-60},{-255.2,-60}},
                                                            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -40},{-290,-40},{-290,-44},{-255.2,-44}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 90&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 90&percnt; load begin. At 20000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_90;

        model Plant_HP_IO_80
          "Model of the high pressure parto of the OTSG for linearization at 80% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_new
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=80,
            t_ramp=20000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 80&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 80&percnt; load begin. At 30000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_80;

        model Plant_HP_IO_70
          "Model of the high pressure parto of the OTSG for linearization at 70% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_new
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            t_ramp=30000,
            load_end=70,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=90000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 70&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 70&percnt; load begin. At 40000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_70;

        model Plant_HP_IO_60
          "Model of the high pressure parto of the OTSG for linearization at 60% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_new
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=60,
            t_ramp=100000,
            P_mec_sp=79725800,
            Kp_valveTURB=-0.01e-11,
            Ti_valveTURB=500,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)    annotation (Placement(transformation(extent={{-254,
                    -60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=250000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 60&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 60&percnt; load begin. At 50000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_60;

        model Plant_HP_IO_50_wet
          "Model of the high pressure parto of the OTSG for linearization at 50% load with wet separator"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.IPT IPTurb annotation (Placement(transformation(extent={
                    {124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin OTSG(
            PDSteamEVA2(pin(fixed=true)),
            EVA2(coldFluid(noInitialPressure=true)),
            separator(H=12)) annotation (Placement(transformation(extent={{-160,
                    -160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH2(
              CSstart=0.4,
              des_FW(hstart={1.01649e6,1.03008e6,1.07408e6}),
              des_SP(hstart={3.272e6,2.93121e6,2.82604e6}),
              cond_FW(hstart={794236,946281,1.01649e6}),
              sub_FW(hstart={766705,771261,777127,784650,794236}),
              sub_SP(hstart={1.08001e6,1.00576e6,947499,902067,866791}),
              NusseltCondenser(h(start=2.82592e6))), HPH1(
              CSmin=0.05,
              des_SP(hstart={3.343e6,2.65755e6,2.63474e6}),
              des_FW(hstart={743882,744614,766600}),
              cond_FW(hstart={669974,721085,744942}),
              sub_FW(hstart={656800,658717,661326,664874,669688}),
              sub_SP(hstart={758347,728486,706860,690303,678413}),
              NusseltCondenser(h(start=2.77624e6)))) annotation (Placement(
                transformation(extent={{20,-158},{120,-102}})));
          Schemes.plant_controller_HPpart_lin_lowLoad controllers(
            actuatorGain_valveRH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_valveRH=true,
            useTS_valveTURB=true,
            load_start=50,
            load_end=50,
            t_ramp=0,
            t_start_ramp=0,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-1,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            TS_pumpSEP=0,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Ti_pumpFW=50,
            CSmax_pumpFW=80,
            CSstart_pumpFW=53.92,
            Kp_pumpFW=5,
            Kp_pumpSEP=0.08,
            Ti_pumpSEP=400,
            t_start_TS=10000,
            TS_start=false,
            CSmin_pumpFW=-30,
            useTS_pumpFW=true,
            useTS_pumpSEP=true,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            P_mec_sp=79725800,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-254,-60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{162,-190},{142,-170}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceH(table=[20,524500;
                30,586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400;
                90,749400; 100,768600]) annotation (Placement(transformation(
                  extent={{200,-130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}}),        iconTransformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));

          Modelica.Blocks.Sources.Ramp LOAD6(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-152})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceP(table=[20,100.6e5;
                30,102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                150.7e5; 90,168.6e5; 100,183.8e5])
                                     annotation (Placement(transformation(extent={{200,
                    -162},{180,-142}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-130},{17.2222,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -99.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-99.2},{56.1111,-99.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-160.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{92.2222,70},{92.2222,-99.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -130},{122.778,-130},{136,-130},{136,-180},{142,-180}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -113.2},{122.778,-113.2},{136,-113.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y, HPH1_FW_sourceH.u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}}, color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-171}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,
                  120},{-280,120},{-280,-28.2667},{-255.2,-28.2667}},
                                                                 color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));

          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},                       color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,
                  -40},{-300,-40},{-300,-60},{-255.2,-60}},
                                                 color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-188,-40},{-188,-200},{100.556,-200},{
                  100.556,-159.12}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD6.y, HPH1_FW_sourceP.u[1]) annotation (Line(points={{211,
                  -152},{211,-152},{202,-152}}, color={0,0,127}));
          connect(HPH1_FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                points={{179,-152},{156,-152},{156,-170.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 50&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the operational point at 50&percnt; load with wet separator. At 10000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_50_wet;

        model Plant_HP_IO_40
          "Model of the high pressure parto of the OTSG for linearization at 40% load"

          SteamTurbine.HPT HPTurb(HPT1(pnom=7150000), HPT2(pnom=3100000))
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.IPT IPTurb(
            IPT1(pnom=2200000),
            IPT2(pnom=990000),
            IPT3(pnom=444700),
            IPT4(pnom=253000)) annotation (Placement(transformation(extent={{
                    124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin OTSG(
            PDSteamEVA2(pin(fixed=true)),
            EVA2(coldFluid(noInitialPressure=true)),
            separator(H=12)) annotation (Placement(transformation(extent={{-160,
                    -160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH2(
              CSstart=0.4,
              des_FW(hstart={1.01649e6,1.03008e6,1.07408e6}),
              des_SP(hstart={3.272e6,2.93121e6,2.82604e6}),
              cond_FW(hstart={794236,946281,1.01649e6}),
              sub_FW(hstart={766705,771261,777127,784650,794236}),
              sub_SP(hstart={1.08001e6,1.00576e6,947499,902067,866791}),
              NusseltCondenser(h(start=2.82592e6))), HPH1(
              CSmin=0.05,
              des_SP(hstart={3.343e6,2.65755e6,2.63474e6}),
              des_FW(hstart={743882,744614,766600}),
              cond_FW(hstart={669974,721085,744942}),
              sub_FW(hstart={656800,658717,661326,664874,669688}),
              sub_SP(hstart={758347,728486,706860,690303,678413}),
              NusseltCondenser(h(start=2.77624e6)))) annotation (Placement(
                transformation(extent={{20,-160},{120,-104}})));
          Schemes.plant_controller_HPpart_lin_lowLoad controllers(
            actuatorGain_valveRH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_valveRH=true,
            useTS_valveTURB=true,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-1,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Ti_pumpFW=50,
            CSmax_pumpFW=80,
            CSstart_pumpFW=53.92,
            Kp_pumpFW=5,
            TS_start=false,
            useTS_pumpFW=true,
            Kp_pumpSEP=0.08,
            t_ramp=10000,
            t_start_ramp=10000,
            t_start_TS=30000,
            CSmin_pumpFW=-30,
            load_start=50,
            Ti_pumpSEP=400,
            P_mec_sp=79725800,
            load_end=42,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-254,-60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{162,-190},{142,-170}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceH(table=[20,524500;
                30,586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400;
                90,749400; 100,768600]) annotation (Placement(transformation(
                  extent={{200,-130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}}),        iconTransformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));

          Modelica.Blocks.Sources.Ramp LOAD6(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-152})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceP(table=[20,100.6e5;
                30,102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                150.7e5; 90,168.6e5; 100,183.8e5])
                                     annotation (Placement(transformation(extent={{200,
                    -162},{180,-142}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{92.2222,70},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-180},{142,-180}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y, HPH1_FW_sourceH.u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}}, color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-171}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));

          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},                       color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,
                  -40},{-300,-40},{-300,-60},{-255.2,-60}},
                                                 color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-188,-40},{-188,-200},{100.556,-200},{100.556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD6.y, HPH1_FW_sourceP.u[1]) annotation (Line(points={{211,
                  -152},{211,-152},{202,-152}}, color={0,0,127}));
          connect(HPH1_FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                points={{179,-152},{156,-152},{156,-170.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 50&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the operational point at 50&percnt; load with wet separator. <span style=\"font-family: MS Shell Dlg 2;\">At 10000s a quasi-static load ramp from 50&percnt; to 40&percnt; load begin. </span>At 30000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_40;

        model Plant_HP_IO_30
          "Model of the high pressure parto of the OTSG for linearization at 30% load"

          SteamTurbine.HPT HPTurb(HPT1(pnom=7150000), HPT2(pnom=3090000))
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.IPT IPTurb(
            IPT1(pnom=2100000),
            IPT2(pnom=990000),
            IPT3(pnom=444700),
            IPT4(pnom=253000)) annotation (Placement(transformation(extent={{
                    124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin OTSG(PDSteamEVA2(pin(fixed=
                   true)), EVA2(coldFluid(noInitialPressure=true))) annotation (
             Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH2(
              CSstart=0.4,
              des_FW(hstart={1.01649e6,1.03008e6,1.07408e6}),
              des_SP(hstart={3.272e6,2.93121e6,2.82604e6}),
              cond_FW(hstart={794236,946281,1.01649e6}),
              sub_FW(hstart={766705,771261,777127,784650,794236}),
              sub_SP(hstart={1.08001e6,1.00576e6,947499,902067,866791}),
              NusseltCondenser(h(start=2.82592e6))), HPH1(
              CSmin=0.05,
              des_SP(hstart={3.343e6,2.65755e6,2.63474e6}),
              des_FW(hstart={743882,744614,766600}),
              cond_FW(hstart={669974,721085,744942}),
              sub_FW(hstart={656800,658717,661326,664874,669688}),
              sub_SP(hstart={758347,728486,706860,690303,678413}),
              NusseltCondenser(h(start=2.77624e6)))) annotation (Placement(
                transformation(extent={{20,-160},{120,-104}})));
          Schemes.plant_controller_HPpart_lin_lowLoad controllers(
            actuatorGain_valveRH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_valveRH=true,
            useTS_valveTURB=true,
            load_start=50,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-1,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Ti_pumpFW=50,
            CSmin_pumpFW=1,
            CSmax_pumpFW=80,
            CSstart_pumpFW=53.92,
            Kp_pumpFW=5,
            TS_start=false,
            useTS_pumpFW=true,
            Kp_pumpSEP=0.08,
            Ti_pumpSEP=400,
            t_start_ramp=10000,
            load_end=30,
            t_ramp=20000,
            t_start_TS=40000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-254,-60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{162,-190},{142,-170}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceH(table=[20,524500;
                30,586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400;
                90,749400; 100,768600]) annotation (Placement(transformation(
                  extent={{200,-130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}}),        iconTransformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));

          Modelica.Blocks.Sources.Ramp LOAD6(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-152})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceP(table=[20,100.6e5;
                30,102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                150.7e5; 90,168.6e5; 100,183.8e5])
                                     annotation (Placement(transformation(extent={{200,
                    -162},{180,-142}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{92.2222,70},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-180},{142,-180}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y, HPH1_FW_sourceH.u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}}, color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-171}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));

          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},                       color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,
                  -40},{-300,-40},{-300,-60},{-255.2,-60}},
                                                 color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-188,-40},{-188,-200},{100.556,-200},{100.556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD6.y, HPH1_FW_sourceP.u[1]) annotation (Line(points={{211,
                  -152},{211,-152},{202,-152}}, color={0,0,127}));
          connect(HPH1_FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                points={{179,-152},{156,-152},{156,-170.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 50&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the operational point at 50&percnt; load with wet separator. <span style=\"font-family: MS Shell Dlg 2;\">At 10000s a quasi-static load ramp from 50&percnt; to 30&percnt; load begin. </span>At 40000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_30;

        model Plant_HP_IO_20_fail
          "Model of the high pressure parto of the OTSG for linearization at 20% load"

          SteamTurbine.HPT HPTurb(HPT1(pnom=7150000), HPT2(pnom=3090000))
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.IPT IPTurb(
            IPT1(pnom=2100000),
            IPT2(pnom=990000),
            IPT3(pnom=444700),
            IPT4(pnom=253000)) annotation (Placement(transformation(extent={{
                    124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin OTSG(PDSteamEVA2(pin(fixed=
                   true)), EVA2(coldFluid(noInitialPressure=true))) annotation (
             Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH2(
              CSstart=0.4,
              des_FW(hstart={1.01649e6,1.03008e6,1.07408e6}),
              des_SP(hstart={3.272e6,2.93121e6,2.82604e6}),
              cond_FW(hstart={794236,946281,1.01649e6}),
              sub_FW(hstart={766705,771261,777127,784650,794236}),
              sub_SP(hstart={1.08001e6,1.00576e6,947499,902067,866791}),
              NusseltCondenser(h(start=2.82592e6))), HPH1(
              CSmin=0.05,
              des_SP(hstart={3.343e6,2.65755e6,2.63474e6}),
              des_FW(hstart={743882,744614,766600}),
              cond_FW(hstart={669974,721085,744942}),
              sub_FW(hstart={656800,658717,661326,664874,669688}),
              sub_SP(hstart={758347,728486,706860,690303,678413}),
              NusseltCondenser(h(start=2.77624e6)),
              Kp=-40)) annotation (Placement(transformation(extent={{20,-160},{
                    120,-104}})));
          Schemes.plant_controller_HPpart_lin_lowLoad controllers(
            actuatorGain_valveRH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_valveRH=true,
            useTS_valveTURB=true,
            load_start=50,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-1,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Ti_pumpFW=50,
            CSmin_pumpFW=1,
            CSmax_pumpFW=80,
            CSstart_pumpFW=53.92,
            Kp_pumpFW=5,
            TS_start=false,
            useTS_pumpFW=true,
            Ti_pumpSEP=400,
            t_start_ramp=10000,
            Kp_pumpSEP=0.06,
            load_end=25,
            P_mec_sp=79725800,
            t_ramp=60000,
            t_start_TS=80000,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000,
            pump_HPH_CS(k=0.1))
            annotation (Placement(transformation(extent={{-254,-60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{162,-190},{142,-170}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceH(table=[20,524500;
                30,586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400;
                90,749400; 100,768600]) annotation (Placement(transformation(
                  extent={{200,-130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}}),        iconTransformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));

          Modelica.Blocks.Sources.Ramp LOAD6(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-152})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_sourceP(table=[20,100.6e5;
                30,102.2e5; 40,103.4e5; 50,104.7e5; 60,115.9e5; 70,133.4e5; 80,
                150.7e5; 90,168.6e5; 100,183.8e5])
                                     annotation (Placement(transformation(extent={{200,
                    -162},{180,-142}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{92.2222,70},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-180},{142,-180}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y, HPH1_FW_sourceH.u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}}, color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-171}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));

          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},                       color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,
                  -40},{-300,-40},{-300,-60},{-255.2,-60}},
                                                 color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-188,-40},{-188,-200},{100.556,-200},{100.556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD6.y, HPH1_FW_sourceP.u[1]) annotation (Line(points={{211,
                  -152},{211,-152},{202,-152}}, color={0,0,127}));
          connect(HPH1_FW_sourceP.y[1], sourcePressure1.in_p0) annotation (Line(
                points={{179,-152},{156,-152},{156,-170.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=90000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 50&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the operational point at 50&percnt; load with wet separator. <span style=\"font-family: MS Shell Dlg 2;\">At 10000s a quasi-static load ramp from 50&percnt; to 20&percnt; load begin. </span>At 50000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_20_fail;

        model Plant_HP_IO_100_DTsh_sensitivity
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Old.plant_controller_HPpart_lin_highLoad controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Kp_pumpSEP=-14.5,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=5,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSmax_pumpFW=0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ta_valveTURB=2,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            load_end=100,
            t_ramp=0,
            t_start=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_pumpSEP=0,
            CSmax_pumpSEP=100,
            l_sp=0,
            useTS_pumpSEP=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_pumpFW=-0.1,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Sources.Ramp ramp(
            offset=0,
            startTime=10000,
            height=-3*7.111412123e-3,
            duration=10000)
            annotation (Placement(transformation(extent={{-340,30},{-320,50}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,0},{-261.5,0}}, color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -40},{-268,-40},{-268,-48},{-261.5,-48}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-64},{-261.5,-64}}, color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,
                  -200},{-304,-200},{-270,-200},{-270,-80},{-261.5,-80}}, color={
                  0,0,127}));
          connect(ramp.y, controllers.du_w_FW) annotation (Line(points={{-319,40},
                  {-290,40},{-290,-32},{-261.5,-32}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=5000),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_100_DTsh_sensitivity;

        model Plant_HP_IO_100_Q
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            load_end=100,
            t_ramp=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            t_start_ramp=0,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_Q_eva = OTSG.ECO.Q_Hot + OTSG.EVA1.Q_Hot + OTSG.EVA2.Q_Hot annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_100_Q;

        model Plant_HP_IO_90_Q
          "Model of the high pressure parto of the OTSG for linearization at 90% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            load_end=90,
            t_ramp=10000,
            t_start_ramp=5000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_Q_eva = OTSG.ECO.Q_Hot + OTSG.EVA1.Q_Hot + OTSG.EVA2.Q_Hot  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -200},{-270,-200},{-270,-60},{-255.2,-60}},
                                                            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -40},{-290,-40},{-290,-44},{-255.2,-44}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 90&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 90&percnt; load begin. At 20000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_90_Q;

        model Plant_HP_IO_80_Q
          "Model of the high pressure parto of the OTSG for linearization at 80% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=80,
            t_ramp=20000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_Q_eva = OTSG.ECO.Q_Hot + OTSG.EVA1.Q_Hot + OTSG.EVA2.Q_Hot  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 80&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 80&percnt; load begin. At 30000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_80_Q;

        model Plant_HP_IO_70_Q
          "Model of the high pressure parto of the OTSG for linearization at 70% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            t_ramp=30000,
            load_end=70,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_Q_eva = OTSG.ECO.Q_Hot + OTSG.EVA1.Q_Hot + OTSG.EVA2.Q_Hot annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=90000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 70&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 70&percnt; load begin. At 40000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_70_Q;

        model Plant_HP_IO_60_Q
          "Model of the high pressure parto of the OTSG for linearization at 60% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF_wFWnotAdim
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=60,
            t_ramp=100000,
            P_mec_sp=79725800,
            Kp_valveTURB=-0.01e-11,
            Ti_valveTURB=500,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)    annotation (Placement(transformation(extent={{-254,
                    -60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_Q_eva = OTSG.ECO.Q_Hot + OTSG.EVA1.Q_Hot + OTSG.EVA2.Q_Hot  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=250000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 60&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 60&percnt; load begin. At 50000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_60_Q;

        model Plant_HP_IO_100_Tms
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            load_end=100,
            t_ramp=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            t_start_ramp=0,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_EVA = OTSG.EVA1.hotFluid.T[1] annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_100_Tms;

        model Plant_HP_IO_90_Tms
          "Model of the high pressure parto of the OTSG for linearization at 90% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            load_end=90,
            t_ramp=10000,
            t_start_ramp=5000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_EVA = OTSG.EVA1.hotFluid.T[1]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -200},{-270,-200},{-270,-60},{-255.2,-60}},
                                                            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -40},{-290,-40},{-290,-44},{-255.2,-44}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 90&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 90&percnt; load begin. At 20000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_90_Tms;

        model Plant_HP_IO_80_Tms
          "Model of the high pressure parto of the OTSG for linearization at 80% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=80,
            t_ramp=20000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_EVA = OTSG.EVA1.hotFluid.T[1]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 80&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 80&percnt; load begin. At 30000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_80_Tms;

        model Plant_HP_IO_70_Tms
          "Model of the high pressure parto of the OTSG for linearization at 70% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            t_ramp=30000,
            load_end=70,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_EVA = OTSG.EVA1.hotFluid.T[1] annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=90000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 70&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 70&percnt; load begin. At 40000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_70_Tms;

        model Plant_HP_IO_60_Tms
          "Model of the high pressure parto of the OTSG for linearization at 60% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=60,
            t_ramp=100000,
            P_mec_sp=79725800,
            Kp_valveTURB=-0.01e-11,
            Ti_valveTURB=500,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)    annotation (Placement(transformation(extent={{-254,
                    -60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_EVA = OTSG.EVA1.hotFluid.T[1]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=250000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 60&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 60&percnt; load begin. At 50000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_60_Tms;

        model Plant_HP_IO_100_DT_ms
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            load_end=100,
            t_ramp=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            t_start_ramp=0,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            P_mec_sp=79725800,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_ms = OTSG.SH.hotFluid.T[end] - OTSG.RH.hotFluid.T[end] annotation (Placement(
                transformation(extent={{320,30},{340,50}}), iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_100_DT_ms;

        model Plant_HP_IO_90_DT_ms
          "Model of the high pressure parto of the OTSG for linearization at 90% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            load_end=90,
            t_ramp=10000,
            t_start_ramp=5000,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            P_mec_sp=79725800,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_ms = OTSG.SH.hotFluid.T[end] - OTSG.RH.hotFluid.T[end]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,
                  200},{-270,200},{-270,-20},{-255.2,-20}},
                                                        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},
                  {-314,40},{-290,40},{-290,-36},{-255.2,-36}}, color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -200},{-270,-200},{-270,-60},{-255.2,-60}},
                                                            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,
                  -120},{-280,-120},{-280,-52},{-255.2,-52}}, color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -40},{-290,-40},{-290,-44},{-255.2,-44}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 90&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 90&percnt; load begin. At 20000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_90_DT_ms;

        model Plant_HP_IO_80_DT_ms
          "Model of the high pressure parto of the OTSG for linearization at 80% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=80,
            t_ramp=20000,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_ms = OTSG.SH.hotFluid.T[end] - OTSG.RH.hotFluid.T[end]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 80&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 80&percnt; load begin. At 30000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_80_DT_ms;

        model Plant_HP_IO_70_DT_ms
          "Model of the high pressure parto of the OTSG for linearization at 70% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Kp_valveTURB=-0.1e-11,
            Ti_valveTURB=5,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            t_ramp=30000,
            load_end=70,
            P_mec_sp=79725800,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000) annotation (Placement(transformation(extent={{-254,-60},
                    {-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_ms = OTSG.SH.hotFluid.T[end] - OTSG.RH.hotFluid.T[end]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=90000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 70&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 70&percnt; load begin. At 40000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_70_DT_ms;

        model Plant_HP_IO_60_DT_ms
          "Model of the high pressure parto of the OTSG for linearization at 60% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(SP6(p(start=2100000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin OTSG annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_controlledLevel HPHs(HPH1(
                NusseltCondenser(h(start=2.80e6, fixed=true))), HPH2(
                NusseltCondenser(w_cond(start=4.019, fixed=true)))) annotation (
             Placement(transformation(extent={{18,-160},{118,-104}})));
          Schemes.plant_controller_HPpart_lin_highLoad_FF
                                                       controllers(
            actuatorGain_valveRH=1,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Ta_valveRH=0.3,
            Kp_valveBP=0.1,
            Ti_valveBP=10,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=0,
            CSmax_valveBP=1.2,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=100,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            t_start_ramp=5000,
            load_end=60,
            t_ramp=100000,
            P_mec_sp=79725800,
            Kp_valveTURB=-0.01e-11,
            Ti_valveTURB=500,
            T_RH_sp=826.05,
            T_FW_sp=553.15,
            T_MS_sp=563.15,
            p_sp=17611000)    annotation (Placement(transformation(extent={{-254,
                    -60},{-206,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_ms = OTSG.SH.hotFluid.T[end] - OTSG.RH.hotFluid.T[end]  annotation (Placement(transformation(extent={{320,30},
                    {340,50}}), iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}}), iconTransformation(extent={{320,30},{340,50}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,-20},{-255.2,-20}},        color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-28.2667},{-255.2,-28.2667}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-36},{-255.2,-36}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-200},{
                  -270,-200},{-270,-60},{-255.2,-60}},      color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-52},{-255.2,-52}},             color={0,0,127}));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,-40},
                  {-290,-40},{-290,-44},{-255.2,-44}}, color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-204.8,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-204.8,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=250000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 60&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000s a quasi-static load ramp from 100&percnt; to 60&percnt; load begin. At 50000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_60_DT_ms;
      end Linearization;

      package Test "Package containing control tests"
        model test_dryWetTransition
          "Test model to check the control switch between dry and wet mode of the separator"

          HeatExchangers.Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                  1.66591e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                623.137}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={199579,192529,183185,168175,136603},
              noInitialPressure=true),
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=5,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72) annotation (Placement(
                transformation(extent={{-134,-180},{-166,-148}})));

          HeatExchangers.Components.HE_2ph EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                  1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,
                  2.02847e+006,2.29575e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                629.917,629.888,630.182,630.842,632.016,634.097}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                  199646,197679},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                gamma_nom_2ph=10000,
                alpha=1.6),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalHotPressure=730800) annotation (Placement(transformation(
                  extent={{-166,-100},{-134,-68}})));

          HeatExchangers.Components.HE_2ph EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                  2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                  2.69972e+006,2.74645e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                656.757,670.379,679.959,684.074,688.573,693.427}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                  295435,288187},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalHotPressure=730800) annotation (Placement(transformation(
                  extent={{-134,-20},{-166,12}})));

          HeatExchangers.Components.Equilibrium2phVessel separator(
            zl_start=0,
            D=0.56,
            noInitialPressure=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h_start=4e6,
            H=9,
            p_start=17710000)
            annotation (Placement(transformation(extent={{-8,118},{48,174}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={20,76})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-44})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            rhonom=582.8,
            dpnom=(0.52492/2)*10^5,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-124})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-120,138})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{-80,-228},{-100,-208}})));
          ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                transformation(extent={{-180,-158},{-200,-178}})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-198})));
          ThermoPower.Water.SourceMassFlow sourceMS5(
            allowFlowReversal=false,
            G=0,
            w0=610.6,
            h=355877,
            p0=730800,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-90,-14},{-110,6}})));
          ThermoPower.Water.SinkPressure sinkSteam5(
            allowFlowReversal=false,
            use_in_p0=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=17748830)
            annotation (Placement(transformation(extent={{26,180},{46,200}})));
          ThermoPower.Water.SinkPressure sinkMS2(
            allowFlowReversal=false,
            p0=404671,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-210,-174},{-230,-154}})));
          ThermoPower.Water.SourceMassFlow sourceSteam2(
            allowFlowReversal=false,
            h=1231860,
            w0=88.59,
            p0=17910000,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{86,-232},{66,-212}})));
          Modelica.Blocks.Tables.CombiTable1D P_sink_separator(
            tableOnFile=false,
            table=[20,100.1e5; 30,100.3e5; 40,100.6e5; 50,101e5; 60,112.7e5; 70,129.3e5;
                80,145.7e5; 90,162e5; 100,177.1e5],
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={10,230})));
          Modelica.Blocks.Tables.CombiTable1D H_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,356.5e3; 30,351.2e3; 40,347.3e3; 50,344.1e3; 60,357.8e3; 70,373.4e3;
                80,374.4e3; 90,382.9e3; 100,356.849e3]) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,70})));
          Modelica.Blocks.Tables.CombiTable1D W_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,122.1; 30,183.2; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,488.4;
                90,549.4; 100,610.6]) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,30})));
          Modelica.Blocks.Tables.CombiTable1D H_source_FW(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,840.6e3; 30,933.8e3; 40,1004.5e3; 50,1062.5e3; 60,1111.4e3; 70,1126.7e3;
                80,1133.9e3; 90,1182.5e3; 100,1231.9e3]) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={50,-182})));
          Modelica.Blocks.Sources.Trapezoid LOAD(
            amplitude=-20,
            rising=100,
            width=500,
            falling=100,
            period=5000,
            nperiod=1,
            offset=70,
            startTime=0)
            annotation (Placement(transformation(extent={{-76,-56},{-44,-24}})));
          Schemes.SingleControllers.control_wFW_w_SEP control_wFW_w_SEP(
            Ti_pumpFW_high=100,
            Td_pumpFW_high=0,
            Nd_pumpFW_high=20,
            CSmax_pumpFW_high=0.2,
            CSstart_pumpFW_high=0,
            TS_pumpFW_high=0,
            l_sp=4,
            Td_pumpFW_low=0,
            Nd_pumpFW_low=20,
            CSmin_pumpFW_low=1,
            CSmax_pumpFW_low=100,
            CSstart_pumpFW_low=60,
            TS_pumpFW_low=0,
            load_switch_FW=55,
            load_sep_ON=55,
            actuatorGain_pumpFW=1,
            Ta_pumpFW=2,
            Td_pumpSEP=0,
            Nd_pumpSEP=20,
            CSmin_pumpSEP=-0.9,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            TS_pumpSEP=0,
            DT_sh_sp=20,
            Kp_pumpSEP=1,
            Ti_pumpSEP=50,
            Ti_pumpFW_low=50,
            Kp_pumpFW_low=12,
            CSmin_pumpFW_high=-0.95,
            level_sep_ON=3,
            T_MS_sp=558.15,
            Kp_pumpFW_high=-0.01)
            annotation (Placement(transformation(extent={{200,-80},{94,0}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={238,-40})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{-260,240},{-240,260}})));
          Modelica.Blocks.Sources.BooleanConstant TS_sep(k=true)
            annotation (Placement(transformation(extent={{60,-22},{80,-2}})));
          Modelica.Blocks.Sources.BooleanConstant TS_DTsh(k=false)
            annotation (Placement(transformation(extent={{60,-78},{80,-58}})));
        equation
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-150,-148},{-150,-134}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{20,128},{20,86}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-110,138},{10,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-150,-34},{-150,-20}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-150,-68},{-150,-54}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-150,12},{-150,138},{-130,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-166,-4},{-190,-4},{-190,-84},{-166,-84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-134,-84},{-110,-84},{-110,-164},{-134,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-150,-100},{-150,-114}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-150,-180},{-150,-188}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{-96,-222},{-96,-222},{-150,-222},{-150,-208}},
              color={0,0,255},
              thickness=0.5));
          connect(sinkSteam5.flange, separator.steam_out) annotation (Line(
              points={{26,190},{20,190},{20,170}},
              color={0,0,255},
              thickness=0.5));
          connect(H_source_EVA2.y[1], sourceMS5.in_h) annotation (Line(points={{-81,70},
                  {-81,70},{-104,70},{-104,2}}, color={0,0,127}));
          connect(W_source_EVA2.y[1], sourceMS5.in_w0)
            annotation (Line(points={{-81,30},{-96,30},{-96,2}}, color={0,0,127}));
          connect(sinkMS2.flange, sensT_MS.outlet) annotation (Line(
              points={{-210,-164},{-204,-164},{-196,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.inlet, ECO.outletHot) annotation (Line(
              points={{-184,-164},{-184,-164},{-166,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(H_source_FW.y[1], sourceSteam2.in_h)
            annotation (Line(points={{61,-182},{72,-182},{72,-216}}, color={0,0,127}));
          connect(sensT_FW.inlet, sourceSteam2.flange) annotation (Line(
              points={{-84,-222},{-84,-222},{66,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA2.inletHot, sourceMS5.flange) annotation (Line(
              points={{-134,-4},{-110,-4}},
              color={255,0,0},
              thickness=0.5));
          connect(LOAD.y, H_source_FW.u[1]) annotation (Line(points={{-42.4,-40},{-30,-40},
                  {-30,-182},{38,-182}}, color={0,0,127}));
          connect(LOAD.y, P_sink_separator.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,230},{-2,230}}, color={0,0,127}));
          connect(LOAD.y, W_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-42.4,
                  -39},{-30,-39},{-30,30},{-58,30}}, color={0,0,127}));
          connect(LOAD.y, H_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,70},{-58,70}}, color={0,0,127}));
          connect(sensT_FW.inlet, waterPump.outlet) annotation (Line(
              points={{-84,-222},{20,-222},{20,66}},
              color={0,0,255},
              thickness=0.5));
          connect(LOAD.y, control_wFW_w_SEP.load) annotation (Line(points={{-42.4,
                  -40},{-42.4,-40},{117.556,-40}},
                                         color={0,0,127}));
          connect(control_wFW_w_SEP.signalBus, signalBus) annotation (Line(
              points={{201.963,-40},{201.963,-40},{238,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{238,-40},{240,-40},{240,80},{26,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{238,-40},{240,-40},{240,70},{240,132},{30,132}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
              points={{238,-40},{240,-40},{240,156},{30,156}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_MS.T) annotation (Line(
              points={{238,-40},{238,-40},{238,-210},{238,-242},{-198,-242},{-198,-174}},
              color={255,204,51},
              thickness=0.5));

          connect(TS_sep.y, control_wFW_w_SEP.TS_pumpSEP_bool)
            annotation (Line(points={{81,-12},{117.556,-12}},
                                                          color={255,0,255}));
          connect(TS_DTsh.y, control_wFW_w_SEP.TS_pumpFWhigh_bool) annotation (Line(
                points={{81,-68},{117.556,-68}},        color={255,0,255}));
          connect(P_sink_separator.y[1], sinkSteam5.in_p0)
            annotation (Line(points={{21,230},{32,230},{32,198.8}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, sourceSteam2.in_w0) annotation (Line(
              points={{238,-40},{238,-40},{238,-200},{80,-200},{80,-216}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-260,-260},{260,260}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-260,-260},{260,260}}, preserveAspectRatio=false)),
            experiment(
              StartTime=-5000,
              StopTime=5000,
              __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>Test model to check the procedure of the filling and draining of the separator, as function of the plant load. The system is initialized at 70&percnt; load, at 0 s a negative ramp begins in order to reach the 50&percnt; load. At 55&percnt; the separator filling procedure starts, and the FW pump control is switched from degree of superheating to level control. </p>
<p>After 10 min a positive load ramp starts, and the separator is drained in order to get the 70&percnt; load.</p>
<p>OPEN POINTS:</p>
<p>- separator control optimization;</p>
<p>- pump ramp limits (from 0 a 100&percnt; mass flow in ~10-15s).</p>
</html>"));
        end test_dryWetTransition;

        model plant_LP_checkPrimaryLoad
          "Test model to check the extra-power available if the condenser extraction pump is switched off"
          import PreFlexMS;
          PreFlexMS.FullScale_280degC.SteamTurbine.IPT IPTurb(vap_in(p(start=
                    46.4e5)), vap_out(p(start=4.5e5))) annotation (Placement(
                transformation(extent={{-156,72},{-74,148}})));
          PreFlexMS.FullScale_280degC.SteamTurbine.LPT LPTurb
            annotation (Placement(transformation(extent={{18,72},{100,148}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-300,220},{-280,240}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{150,100},{130,120}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            use_in_p0=true,
            p0=11010,
            use_in_h=false)
            annotation (Placement(transformation(extent={{120,150},{140,170}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=64.26,
            h=197600,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-130},{140,-110}})));
          PreFlexMS.FullScale_280degC.HeatExchangers.Components.Deaerator deaerator(
            h_start=750000,
            L=12,
            H=2.677,
            zl_start=2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true,
            p_start=900000,
            T(start=448.15),
            p(start=900000)) annotation (Placement(transformation(extent={{-128,
                    -164},{-72,-108}})));
          PreFlexMS.FullScale_280degC.HeatExchangers.PreHeaters.LPH_train LPHs(
            pressDrop(pin(start=15.91e5)),
            pressDrop1(pin(start=1441000, fixed=true)),
            pressDrop2(pin(start=1275000, fixed=true)),
            SP4(p(start=5.088e5)),
            SP5(p(start=2.43e5)),
            SP6(p(start=1.035e5)),
            SP7(p(start=0.3807e5)),
            LPH4(T_FW_out(fixed=false)),
            LPH2(T_FW_out(fixed=false)),
            pressDrop3(pin(start=1128000, fixed=true)),
            sinkPressure_DR(p0=36650)) annotation (Placement(transformation(
                  extent={{-60,-160},{120,-80}})));
          PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
            load_start=100,
            load_end=100,
            t_ramp=0,
            t_start=0) annotation (Placement(transformation(extent={{-280,-220},
                    {-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,210})));
          Modelica.Blocks.Tables.CombiTable1D IPT_sourceH(table=[20,3594e3; 30,
                3590e3; 40,3586e3; 50,3581e3; 60,3577e3; 70,3573e3; 80,3568e3; 90,
                3563e3; 100,3558e3])                     annotation (Placement(
                transformation(extent={{-220,200},{-200,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,180})));
          Modelica.Blocks.Tables.CombiTable1D IPT_sourceP(table=[20,7.507e5; 30,
                12.02e5; 40,16.56e5; 50,21.15e5; 60,25.75e5; 70,30.01e5; 80,35e5;
                90,40.1e5; 100,45.4e5])   annotation (Placement(transformation(
                  extent={{-220,170},{-200,190}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3559700,
            p0=4640000,
            use_in_p0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-200,150},{-180,170}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=2037000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{-160,30},{-180,50}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,70})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sinkP(table=[20,3.522e5; 30,
                5.618e5; 40,7.694e5; 50,9.776e5; 60,11.86e5; 70,13.77e5; 80,15.96e5;
                90,18.18e5; 100,20.37e5])
            annotation (Placement(transformation(extent={{-220,60},{-200,80}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={50,180})));
          Modelica.Blocks.Tables.CombiTable1D LPT_sinkP(table=[20,0.0479e5; 30,
                0.0537e5; 40,0.0599e5; 50,0.0666e5; 60,0.0738e5; 70,0.0809e5; 80,
                0.0897e5; 90,0.0994e5; 100,0.1101e5])
            annotation (Placement(transformation(extent={{80,170},{100,190}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=7.727,
            h=782000,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-180,-160},{-160,-140}})));
          ThermoPower.Water.SinkMassFlow    waterPump(
            allowFlowReversal=false,
            use_in_w0=true,
            w0=88.59,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-100,-194})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-90})));
          Modelica.Blocks.Tables.CombiTable1D DR_sourceH(table=[20,522.3e3; 30,
                590.3e3; 40,637.4e3; 50,676.7e3; 60,711.5e3; 70,736.5e3; 80,756.1e3;
                90,772.2e3; 100,782e3])
            annotation (Placement(transformation(extent={{-220,-100},{-200,-80}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-120})));
          Modelica.Blocks.Tables.CombiTable1D DR_sourceW(table=[20,1.937; 30,3.374;
                40,5.125; 50,7.147; 60,9.391; 70,10.42; 80,10; 90,9.282; 100,7.727])
            annotation (Placement(transformation(extent={{-220,-130},{-200,-110}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-190,-190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={250,-10})));
          Modelica.Blocks.Tables.CombiTable1D cond_sourceH(table=[20,127.8e3; 30,
                139.1e3; 40,148.1e3; 50,156.6e3; 60,164.8e3; 70,172.2e3; 80,180.7e3;
                90,189.1e3; 100,197.6e3])
            annotation (Placement(transformation(extent={{220,-20},{200,0}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-100})));
          Modelica.Blocks.Tables.CombiTable1D cond_sourceW(table=[20,13.21; 30,
                19.64; 40,25.96; 50,32.26; 60,38.52; 70,44.24; 80,50.82; 90,57.47;
                100,64.26])
            annotation (Placement(transformation(extent={{240,-110},{220,-90}})));
          Modelica.Blocks.Sources.Ramp step(
            offset=0,
            startTime=2000,
            height=-0.8,
            duration=2)
            annotation (Placement(transformation(extent={{260,-78},{240,-58}})));
          Modelica.Blocks.Tables.CombiTable1D FW_sinkW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,
                64.64; 80,72.9; 90,81.03; 100,88.59]) annotation (Placement(
                transformation(extent={{-160,-200},{-140,-180}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{180,-90},{160,-70}})));
          IndustrialControlSystems.Controllers.PI
                                              PID_level(
            CSmin=0,
            CSmax=100,
            Ti=10000,
            Kp=-500,
            AntiWindup=true,
            CS_start=88.59,
            useTS=true)    annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-40,-190})));
          Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=5)
                  annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-62,-220})));
          Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
            annotation (Placement(transformation(extent={{20,-186},{0,-166}})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{208,-84},{188,-64}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(startValue=false,
              startTime=2000)
            annotation (Placement(transformation(extent={{20,-220},{0,-200}})));
        equation
          connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
              points={{-69.9,110},{13.9,110}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(LPTurb.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{104.1,110},{130,110}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(LPTurb.vap_out, sinkPressure.flange) annotation (Line(
              points={{104.1,132.8},{104.1,160},{120,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(IPTurb.SP5, deaerator.steam_in) annotation (Line(
              points={{-119.1,68.2},{-119.1,-132},{-107.6,-132}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
              points={{-69.9,132.8},{13.9,132.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
              points={{-92.8,-120},{-92.8,-120},{-63.75,-120}},
              color={0,0,255},
              thickness=0.5));
          connect(LPHs.FW_in, sourceMassFlow_FW.flange) annotation (Line(
              points={{123.75,-120},{123.75,-120},{140,-120}},
              color={0,0,255},
              thickness=0.5));
          connect(LPTurb.SP1, LPHs.SP7) annotation (Line(
              points={{73.76,68.2},{73.76,39.1},{90,39.1},{90,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LPTurb.SP2, LPHs.SP6) annotation (Line(
              points={{54.9,68.2},{54.9,40},{48.75,40},{48.75,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LPTurb.SP3, LPHs.SP5) annotation (Line(
              points={{36.86,68.2},{36.86,40},{7.5,40},{7.5,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP4, LPHs.SP4) annotation (Line(
              points={{-100.24,68.2},{-100.24,40},{-33.75,40},{-33.75,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPT_sourceH. u[1]) annotation (Line(points={{-239,210},{
                  -230,210},{-222,210}},  color={0,0,127}));
          connect(LOAD2.y,IPT_sourceP. u[1]) annotation (Line(points={{-239,180},{
                  -230,180},{-222,180}},  color={0,0,127}));
          connect(sourcePressure.flange, IPTurb.vap_in) annotation (Line(
              points={{-180,160},{-172,160},{-160.1,160},{-160.1,132.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, sinkPressure3.flange) annotation (Line(
              points={{-137.14,68.2},{-137.14,40},{-160,40}},
              color={0,127,0},
              thickness=0.5));
          connect(IPT_sourceP.y[1], sourcePressure.in_p0) annotation (Line(points={
                  {-199,180},{-194,180},{-194,169.2}}, color={0,0,127}));
          connect(IPT_sourceH.y[1], sourcePressure.in_h) annotation (Line(points={{
                  -199,210},{-186,210},{-186,169}}, color={0,0,127}));
          connect(LOAD3.y, SP5_sinkP.u[1]) annotation (Line(points={{-239,70},{-230,
                  70},{-222,70}}, color={0,0,127}));
          connect(SP5_sinkP.y[1], sinkPressure3.in_p0) annotation (Line(points={{
                  -199,70},{-174,70},{-166,70},{-166,48.8}}, color={0,0,127}));
          connect(LPT_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{101,
                  180},{114,180},{126,180},{126,168.8}}, color={0,0,127}));
          connect(deaerator.drained_out, waterPump.flange) annotation (Line(
              points={{-100,-158},{-100,-184}},
              color={0,0,255},
              thickness=0.5));
          connect(sourceMassFlow_DR.flange, deaerator.drained_in) annotation (Line(
              points={{-160,-150},{-126,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(LOAD4.y, DR_sourceH.u[1]) annotation (Line(points={{-239,-90},{
                  -230,-90},{-222,-90}}, color={0,0,127}));
          connect(LOAD6.y, DR_sourceW.u[1]) annotation (Line(points={{-239,-120},{
                  -239,-120},{-222,-120}}, color={0,0,127}));
          connect(DR_sourceH.y[1], sourceMassFlow_DR.in_h) annotation (Line(points=
                  {{-199,-90},{-166,-90},{-166,-144}}, color={0,0,127}));
          connect(DR_sourceW.y[1], sourceMassFlow_DR.in_w0) annotation (Line(points=
                 {{-199,-120},{-199,-118},{-174,-118},{-174,-144}}, color={0,0,127}));
          connect(LOAD8.y, cond_sourceH.u[1]) annotation (Line(points={{239,-10},
                  {239,-10},{222,-10}},color={0,0,127}));
          connect(LOAD9.y, cond_sourceW.u[1]) annotation (Line(points={{259,-100},
                  {259,-100},{242,-100}},color={0,0,127}));
          connect(cond_sourceH.y[1], sourceMassFlow_FW.in_h) annotation (Line(
                points={{199,-10},{146,-10},{146,-114}}, color={0,0,127}));
          connect(LOAD7.y, FW_sinkW.u[1])
            annotation (Line(points={{-179,-190},{-162,-190}}, color={0,0,127}));
          connect(add.y, sourceMassFlow_FW.in_w0) annotation (Line(points={{159,-80},
                  {154,-80},{154,-114}}, color={0,0,127}));
          connect(cond_sourceW.y[1], add.u2) annotation (Line(points={{219,-100},
                  {194,-100},{194,-86},{182,-86}},color={0,0,127}));
          connect(LOAD5.y, LPT_sinkP.u[1]) annotation (Line(points={{61,180},{70,
                  180},{78,180}}, color={0,0,127}));
          connect(PID_level.CS,pumpDynamic. u) annotation (Line(
              points={{-40,-199},{-40,-220},{-50,-220}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(zl_SP.y,PID_level. SP) annotation (Line(
              points={{-1,-176},{-34,-176},{-34,-182}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(deaerator.level,PID_level. PV) annotation (Line(
              points={{-74,-152},{-66,-152},{-66,-176},{-41,-176},{-41,-182}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(pumpDynamic.y, waterPump.in_w0) annotation (Line(points={{-73,
                  -220},{-80,-220},{-80,-190},{-94,-190}}, color={0,0,127}));
          connect(add.u1, product.y) annotation (Line(points={{182,-74},{187,-74}},
                             color={0,0,127}));
          connect(product.u2, cond_sourceW.y[1]) annotation (Line(points={{210,-80},
                  {214,-80},{214,-100},{219,-100}}, color={0,0,127}));
          connect(product.u1, step.y)
            annotation (Line(points={{210,-68},{239,-68}}, color={0,0,127}));
          connect(PID_level.CS, PID_level.TR) annotation (Line(points={{-40,-199},{
                  -40,-208},{-24,-208},{-24,-190},{-32,-190}}, color={0,0,127}));
          connect(booleanStep.y, PID_level.TS) annotation (Line(points={{-1,-210},{
                  -14,-210},{-14,-194},{-32,-194}}, color={255,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-300,-240},{300,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-300,
                    -240},{300,240}})),
            experiment(StopTime=2500, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput);
        end plant_LP_checkPrimaryLoad;
      end Test;

      package Old "Package containing old control schemes and FF tables"
        model plant_controller_HPpart_old1
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-260,220},{-220,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-360,242},{-340,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-240,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-200,90},{-220,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-280,90},{-260,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-260,-160},{-220,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{380,200},{360,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-200,270},{-220,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-200,-100},{-220,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-280,270},{-260,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-280,-100},{-260,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{260,-160},{220,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{380,-180},{360,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{260,220},{220,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-380,-182},{-360,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{200,270},{220,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{280,270},{260,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{260,40},{220,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{380,20},{360,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{200,90},{220,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{280,90},{260,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,242},{360,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{340,242},{320,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-340,-138},{-320,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-370,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,62},{360,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{340,62},{320,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,-138},{360,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{340,-138},{320,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-220,-200},{-200,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{200,-202},{180,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0.6; 30,0.6; 40,0.6; 50,0.6; 60,0.6; 70,0.6; 80,0.6; 90,0.6;
                100,0.6])
            annotation (Placement(transformation(extent={{200,0},{180,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{200,180},{180,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0;
                80,0; 90,0; 100,0])
            annotation (Placement(transformation(extent={{-220,0},{-200,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-220,180},{-200,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-221,100},{-232,
                  100},{-232,76}},color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-221,280},{-232,
                  280},{-232,256}}, color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-232,-124},{-232,
                  -124},{-232,-102},{-232,-90},{-221,-90}},   color={255,0,255}));
          connect(PID_pumpSEP.TR, pumpSEP_TS.y) annotation (Line(points={{-240,76},{-240,
                  76},{-240,100},{-259,100}},
                                            color={0,0,127}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-259,280},{-272,
                  280},{-240,280},{-240,256}}, color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-240,-124},{-240,
                  -124},{-240,-92},{-240,-90},{-259,-90}},    color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{221,-100},{232,
                  -100},{232,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{259,-100},{259,
                  -100},{240,-100},{240,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-300,130},{-300,238},{-256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,-142},{256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{0,-60},{-300,-60},{-300,58},{-256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-300,-60},{-300,-142},{-256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{221,280},
                  {232,280},{232,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{259,280},{
                  259,280},{240,280},{240,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{300,130},{300,238},{256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{221,100},
                  {232,100},{232,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{259,100},
                  {259,100},{240,100},{240,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,58},{256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-359,-128},{-352,-128},
                  {-342,-128}}, color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-319,-128},{-256,-128}}, color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-339,252},{
                  -256,252}},  color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-339,72},{-256,72}},           color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{256,252},{256,252},{319,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{342,252},{359,252}}, color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{342,72},{359,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{256,72},{288,72},{319,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{342,-128},{350,-128},{359,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{256,-128},{288,-128},{319,-128}},
                                                             color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-239,-190},{-222,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-199,-190},{
                  -150,-190},{-150,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{219,-192},{
                  210,-192},{202,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{179,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(PID_pumpHPH.CS, product1.u1) annotation (Line(points={{222,-140},
                  {202,-140},{180,-140},{180,-128},{162,-128}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140}},           color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{219,10},{202,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{179,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60}},         color={0,0,127}));
          connect(product2.u1, PID_valveTURB.CS) annotation (Line(points={{162,72},
                  {180,72},{180,60},{222,60}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{219,190},{210,
                  190},{202,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{179,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(product3.u1, PID_pumpMS.CS) annotation (Line(points={{162,252},{
                  180,252},{180,240},{222,240}}, color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-199,-190},
                  {-199,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{179,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{179,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{179,190},
                  {176,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-222,-140},{
                  -216,-140},{-200,-140},{-200,-128},{-182,-128}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -92.5},{-104,-132}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-239,10},{-222,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-199,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-199,10},{-170,
                  10},{-170,54},{-142,54}}, color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, product4.u1) annotation (Line(points={{-222,60},{
                  -212,60},{-200,60},{-200,72},{-182,72}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-199,10},{-110,
                  10},{-110,2}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-239,190},{-222,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-199,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-199,190},{
                  -174,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240}},           color={0,0,127}));
          connect(PID_valveRH.CS, product5.u1) annotation (Line(points={{-222,240},
                  {-200,240},{-200,252},{-182,252}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_old1;

        model plant_controller_HPpart_old2
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-260,220},{-220,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-360,242},{-340,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-240,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-200,90},{-220,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-280,90},{-260,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-260,-160},{-220,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{380,200},{360,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-200,270},{-220,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-200,-100},{-220,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-280,270},{-260,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-280,-100},{-260,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{260,-160},{220,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{380,-180},{360,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{260,220},{220,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-380,-182},{-360,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{200,270},{220,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{280,270},{260,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{260,40},{220,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{380,20},{360,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{200,90},{220,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{280,90},{260,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,242},{360,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{340,242},{320,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-340,-138},{-320,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-370,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,62},{360,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{340,62},{320,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,-138},{360,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{340,-138},{320,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-220,-200},{-200,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{200,-202},{180,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0.6; 30,0.6; 40,0.6; 50,0.6; 60,0.6; 70,0.6; 80,0.6; 90,0.6;
                100,0.6])
            annotation (Placement(transformation(extent={{200,0},{180,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{200,180},{180,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0;
                80,0; 90,0; 100,0])
            annotation (Placement(transformation(extent={{-220,0},{-200,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-220,180},{-200,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-130,-250})));
          Modelica.Blocks.Tables.CombiTable1D table_valveBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.25; 80,0.5; 90,0.75;
                100,1]) annotation (Placement(transformation(extent={{-100,-260},
                    {-80,-240}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-221,100},{-232,
                  100},{-232,76}},color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-221,280},{-232,
                  280},{-232,256}}, color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-232,-124},{-232,
                  -124},{-232,-102},{-232,-90},{-221,-90}},   color={255,0,255}));
          connect(PID_pumpSEP.TR, pumpSEP_TS.y) annotation (Line(points={{-240,76},{-240,
                  76},{-240,100},{-259,100}},
                                            color={0,0,127}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-259,280},{-272,
                  280},{-240,280},{-240,256}}, color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-240,-124},{-240,
                  -124},{-240,-92},{-240,-90},{-259,-90}},    color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{221,-100},{232,
                  -100},{232,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{259,-100},{259,
                  -100},{240,-100},{240,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-300,130},{-300,238},{-256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,-142},{256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{0,-60},{-300,-60},{-300,58},{-256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-300,-60},{-300,-142},{-256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{221,280},
                  {232,280},{232,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{259,280},{
                  259,280},{240,280},{240,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{300,130},{300,238},{256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{221,100},
                  {232,100},{232,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{259,100},
                  {259,100},{240,100},{240,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,58},{256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-359,-128},{-352,-128},
                  {-342,-128}}, color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-319,-128},{-256,-128}}, color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-339,252},{
                  -256,252}},  color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-339,72},{-256,72}},           color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{256,252},{256,252},{319,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{342,252},{359,252}}, color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{342,72},{359,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{256,72},{288,72},{319,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{342,-128},{350,-128},{359,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{256,-128},{288,-128},{319,-128}},
                                                             color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-239,-190},{-222,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-199,-190},{
                  -150,-190},{-150,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{219,-192},{
                  210,-192},{202,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{179,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(PID_pumpHPH.CS, product1.u1) annotation (Line(points={{222,-140},
                  {202,-140},{180,-140},{180,-128},{162,-128}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{219,10},{202,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{179,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60},{99,60}}, color={0,0,127}));
          connect(product2.u1, PID_valveTURB.CS) annotation (Line(points={{162,72},
                  {180,72},{180,60},{222,60}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{219,190},{210,
                  190},{202,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{179,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240},{99,240}}, color={0,0,127}));
          connect(product3.u1, PID_pumpMS.CS) annotation (Line(points={{162,252},{
                  180,252},{180,240},{222,240}}, color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-199,-190},
                  {-199,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{179,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{179,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{179,190},
                  {176,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-222,-140},{
                  -216,-140},{-200,-140},{-200,-128},{-182,-128}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -92.5},{-104,-132}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-239,10},{-222,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-199,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-199,10},{-170,
                  10},{-170,54},{-142,54}}, color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, product4.u1) annotation (Line(points={{-222,60},{
                  -212,60},{-200,60},{-200,72},{-182,72}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-199,10},{-110,
                  10},{-110,2}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-239,190},{-222,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-199,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-199,190},{
                  -174,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(PID_valveRH.CS, product5.u1) annotation (Line(points={{-222,240},
                  {-200,240},{-200,252},{-182,252}}, color={0,0,127}));
          connect(LOAD10.y, table_valveBP.u[1]) annotation (Line(points={{-119,-250},
                  {-110.5,-250},{-102,-250}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, table_valveBP.y[1]) annotation (Line(
              points={{0,60},{0,60},{0,-246},{0,-250},{-79,-250}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_old2;

        model plant_controller_lin
          "Model of the plant control system for linearization"

          //Controllers parameter

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point"  annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,340},{-40,380}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-180,340},{-140,380}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-260,362},{-240,382}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-260,162},{-240,182}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-160,160})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-56,160})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={410,90})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-116,190},{-136,210}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-340,190},{-320,210}})));
          IndustrialControlSystems.Controllers.PI PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW)
            annotation (Placement(transformation(extent={{-180,-220},{-140,-180}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp)
            annotation (Placement(transformation(extent={{-260,-198},{-240,-178}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-200})));
          Modelica.Blocks.Sources.Constant f_load(k=0)
            annotation (Placement(transformation(extent={{-150,-60},{-130,-40}})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-100,-70})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-106,-194},{-94,-206}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-120,390},{-140,410}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-120,-160},{-140,-140}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-340,390},{-320,410}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-340,-160},{-320,-140}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-220},{40,-180}})));
          IndustrialControlSystems.Controllers.PI PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{180,-220},{140,-180}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{260,-198},{240,-178}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{120,-170},{140,-150}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{340,-170},{320,-150}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-206},{-8,-194}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-192},{-28,-186}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-100,-102})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,160})));
          IndustrialControlSystems.Controllers.PI PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS)
            annotation (Placement(transformation(extent={{180,140},{140,180}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{260,162},{240,182}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{120,190},{140,210}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{340,190},{320,210}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,340},{40,380}})));
          IndustrialControlSystems.Controllers.PI PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{180,340},{140,380}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{260,362},{240,382}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{120,390},{140,410}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{340,390},{320,410}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{360,260},{320,300}}), iconTransformation(
                  extent={{-440,244},{-400,284}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-440,-232},{-400,-192}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{360,60},{320,100}}), iconTransformation(
                  extent={{-440,368},{-400,408}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{360,-270},{320,-230}}), iconTransformation(
                  extent={{-440,8},{-400,48}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-270},{-320,-230}}),
                iconTransformation(extent={{-440,128},{-400,168}})));
          Modelica.Blocks.Math.Add add1
            annotation (Placement(transformation(extent={{-120,150},{-100,170}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{-130,-210},{-110,-190}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=180,
                origin={108,160})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=180,
                origin={110,-200})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=180,
                origin={110,360})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{-280,100},{-260,120}})));
          Modelica.Blocks.Math.Product product1 annotation (Placement(
                transformation(extent={{-280,-250},{-260,-230}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{280,100},{260,120}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{280,300},{260,320}})));
          Modelica.Blocks.Math.Product product4
            annotation (Placement(transformation(extent={{280,-250},{260,-230}})));
          Modelica.Blocks.Math.Product product5
            annotation (Placement(transformation(extent={{-280,300},{-260,320}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,260},{-320,300}}), iconTransformation(
                  extent={{-440,-112},{-400,-72}})));
          Modelica.Blocks.Math.Add add6
            annotation (Placement(transformation(extent={{-120,350},{-100,370}})));
        equation
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(
              points={{-239,372},{-176,372}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_pumpSEP.SP, l_SP.y) annotation (Line(
              points={{-176,172},{-239,172}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-137,200},
                  {-152,200},{-152,176}},
                                  color={255,0,255}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-200},{-84,
                  -200},{-94.6,-200}},color={0,0,127}));
          connect(f_load.y, add.u1) annotation (Line(points={{-129,-50},{-106,-50},{-106,
                  -58}}, color={0,0,127}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-141,400},{-152,
                  400},{-152,376}}, color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-152,-184},{-152,
                  -184},{-152,-162},{-152,-150},{-141,-150}}, color={255,0,255}));
          connect(PID_pumpSEP.TR, pumpSEP_TS.y) annotation (Line(points={{-160,176},
                  {-160,176},{-160,200},{-319,200}},
                                            color={0,0,127}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-319,400},
                  {-319,400},{-160,400},{-160,376}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-160,-184},
                  {-160,-184},{-160,-152},{-160,-150},{-319,-150}},
                                                              color={0,0,127}));
          connect(T_FW_SP.y, PID_pumpHPH.SP) annotation (Line(
              points={{239,-188},{176,-188}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{141,-160},{152,
                  -160},{152,-184}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{319,-160},
                  {319,-160},{160,-160},{160,-184}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,0},{0,0},{0,360},{-38,360}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,0},{0,0},{0,160},{-34,160}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,0},{0,0},{0,-202},{0,-200},{38,-200}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,0},{0,0},{0,280},{-200,280},{-200,358},{-176,358}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,0},{0,0},{-4,0},{220,0},{220,-202},{176,-202}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,0},{0,0},{0,80},{-200,80},{-200,158},{-176,158}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,
                  -200},{-32,-200},{-32,-203.6},{-21.2,-203.6}}, color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-189},{
                  -24,-189},{-24,-196.4},{-21.2,-196.4}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,0},{0,0},{0,-200},{-7.4,-200}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-100,-81},{-100,-90}},  color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-100,-113},{-100,-113},
                  {-100,-144},{-100,-192},{-100,-195.2}},
                                      color={0,0,127}));
          connect(T_MS_SP.y, PID_pumpMS.SP) annotation (Line(
              points={{239,172},{176,172}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{141,200},
                  {152,200},{152,176}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{319,200},{
                  319,200},{160,200},{160,176}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,0},{0,0},{0,162},{0,160},{38,160}},
              color={255,204,51},
              thickness=0.5));
          connect(p_SP.y, PID_valveTURB.SP) annotation (Line(
              points={{239,372},{176,372}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{141,400},{
                  152,400},{152,376}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{319,400},
                  {319,400},{160,400},{160,376}},color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,0},{0,0},{0,360},{38,360}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,0},{0,0},{0,282},{0,280},{220,280},{220,358},{176,358}},
              color={255,204,51},
              thickness=0.5));
          connect(add1.y, pumpSEP_dynamic.u)
            annotation (Line(points={{-99,160},{-80,160}},           color={0,0,127}));
          connect(PID_pumpSEP.CS, add1.u1) annotation (Line(points={{-142,160},{
                  -132,160},{-132,166},{-122,166}},
                                          color={0,0,127}));
          connect(add.u2, pumpSEP_dynamic.u)
            annotation (Line(points={{-94,-58},{-94,160},{-80,160}}, color={0,0,127}));
          connect(feedback.u1, add2.y) annotation (Line(points={{-104.8,-200},{-104.8,-200},
                  {-109,-200}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add2.u1) annotation (Line(points={{-142,-200},{-138,-200},
                  {-138,-194},{-132,-194}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add5.y) annotation (Line(points={{84,360},{92,360},
                  {92,360},{99,360}}, color={0,0,127}));
          connect(PID_valveTURB.CS, add5.u2) annotation (Line(points={{142,360},{134,360},
                  {134,366},{122,366}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add3.y)
            annotation (Line(points={{84,160},{97,160}},          color={0,0,127}));
          connect(add3.u2, PID_pumpMS.CS) annotation (Line(points={{120,166},{130,
                  166},{130,160},{142,160}},
                                       color={0,0,127}));
          connect(pumpHPH_dynamic.u, add4.y)
            annotation (Line(points={{84,-200},{99,-200},{99,-200}}, color={0,0,127}));
          connect(add4.u2, PID_pumpHPH.CS) annotation (Line(points={{122,-194},{130,-194},
                  {130,-200},{142,-200}}, color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,0},{0,0},{0,82},{0,80},{220,80},{220,158},{176,158}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, product.u2) annotation (Line(points={{-340,80},{-320,80},
                  {-300,80},{-300,104},{-282,104}},       color={0,0,127}));
          connect(pumpSEP_TS.y, product.u1) annotation (Line(points={{-319,200},{
                  -319,200},{-300,200},{-300,116},{-282,116}}, color={0,0,127}));
          connect(product.y, add1.u2) annotation (Line(points={{-259,110},{-194,110},
                  {-132,110},{-132,154},{-122,154}}, color={0,0,127}));
          connect(du_w_FW, product1.u2) annotation (Line(points={{-340,-250},{-320,
                  -250},{-300,-250},{-300,-246},{-282,-246}}, color={0,0,127}));
          connect(product1.y, add2.u2) annotation (Line(points={{-259,-240},{-198,
                  -240},{-138,-240},{-138,-206},{-132,-206}}, color={0,0,127}));
          connect(product2.u1, pumpMS_TS.y) annotation (Line(points={{282,116},{292,
                  116},{300,116},{300,200},{319,200}}, color={0,0,127}));
          connect(product2.u2, du_w_MS) annotation (Line(points={{282,104},{300,104},
                  {300,80},{340,80}},   color={0,0,127}));
          connect(add3.u1, product2.y) annotation (Line(points={{120,154},{130,154},
                  {130,110},{259,110}}, color={0,0,127}));
          connect(product3.u2, du_Y_t) annotation (Line(points={{282,304},{292,304},
                  {300,304},{300,280},{340,280}}, color={0,0,127}));
          connect(add5.u1, product3.y) annotation (Line(points={{122,354},{128,354},
                  {134,354},{134,310},{259,310}}, color={0,0,127}));
          connect(product4.u2, du_w_HPH) annotation (Line(points={{282,-246},{300,-246},
                  {300,-250},{340,-250}}, color={0,0,127}));
          connect(add4.u1, product4.y) annotation (Line(points={{122,-206},{126,
                  -206},{130,-206},{130,-240},{259,-240}}, color={0,0,127}));
          connect(pumpHPH_TS.y, product4.u1) annotation (Line(points={{319,-160},{
                  310,-160},{300,-160},{300,-234},{282,-234}}, color={0,0,127}));
          connect(valveTURB_TS.y, product3.u1) annotation (Line(points={{319,400},{
                  300,400},{300,316},{282,316}}, color={0,0,127}));
          connect(P_MEC_SP.y, PID_pumpFW.SP)
            annotation (Line(points={{-239,-188},{-176,-188}}, color={0,0,127}));
          connect(pumpFW_TS.y, product1.u1) annotation (Line(points={{-319,-150},{
                  -312,-150},{-298,-150},{-298,-234},{-282,-234}}, color={0,0,127}));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,0},{-100,0},{-200,0},{-200,-202},{-176,-202}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_RH, product5.u2) annotation (Line(points={{-340,280},{-320,
                  280},{-300,280},{-300,304},{-282,304}}, color={0,0,127}));
          connect(product5.y, add6.u2) annotation (Line(points={{-259,310},{-194,
                  310},{-132,310},{-132,354},{-122,354}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-99,360},{
                  -84,360},{-84,360}}, color={0,0,127}));
          connect(PID_valveRH.CS, add6.u1) annotation (Line(points={{-142,360},{
                  -132,360},{-132,366},{-122,366}}, color={0,0,127}));
          connect(valveRH_TS.y, product5.u1) annotation (Line(points={{-319,400},{
                  -300,400},{-300,316},{-282,316}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -260},{400,440}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-260},{400,440}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,340},{360,-140}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,440},{400,-260}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_lin;

        model plant_controller_HPpart_lin_highLoad_old
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.6; 30,0.6; 40,0.6; 50,0.6; 60,0.6; 70,0.6; 80,0.6; 90,0.6; 100,
                0.6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{200,242},{180,262}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{200,62},{180,82}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},
                  {-272,100},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{259,10},{242,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{219,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60},{99,60}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{219,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{219,190},
                  {219,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-239,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-239,10},{
                  -170,10},{-170,54},{-142,54}},
                                            color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(add8.y, product4.u1) annotation (Line(points={{-199,72},{-192,72},
                  {-182,72}}, color={0,0,127}));
          connect(du_w_SEP, add8.u1) annotation (Line(points={{-140,100},{-184,100},
                  {-230,100},{-230,78},{-222,78}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{-230,
                  60},{-230,66},{-222,66}}, color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(product3.u1, add10.y)
            annotation (Line(points={{162,252},{179,252}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{212,280},{
                  212,258},{202,258}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{212,246},{202,246}}, color={0,0,127}));
          connect(product2.u1, add11.y)
            annotation (Line(points={{162,72},{179,72}}, color={0,0,127}));
          connect(add11.u2, PID_valveTURB.CS) annotation (Line(points={{202,66},{
                  208,66},{214,66},{214,60},{262,60}}, color={0,0,127}));
          connect(du_Y_t, add11.u1) annotation (Line(points={{120,110},{120,110},{
                  214,110},{214,78},{202,78}}, color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -53},{-104,-132},{-104,-132}}, color={0,0,127}));
          connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,100},
                  {-280,100},{-280,76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad_old;

        model plant_controller_HPpart_lin_lowLoad_old
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=3000,
              startValue=false)
            annotation (Placement(transformation(extent={{-240,100},{-260,120}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.01; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.0491592; 30,0.2; 40,0.2; 50,0.06; 60,0.6; 70,0.6; 80,0.6; 90,
                0.6; 100,0.6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{200,242},{180,262}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{200,62},{180,82}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Sources.Constant const1(k=0)
            annotation (Placement(transformation(extent={{-40,-90},{-60,-70}})));
          Modelica.Blocks.Logical.Switch switch1 annotation (Placement(
                transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={-104,-90})));
          Modelica.Blocks.Sources.BooleanStep booleanStep3(startValue=true,
              startTime=6000)
            annotation (Placement(transformation(extent={{-40,-50},{-60,-30}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,110},
                  {-272,110},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{259,10},{242,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{219,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60},{99,60}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{219,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{219,190},
                  {219,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-239,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-239,10},{
                  -170,10},{-170,54},{-142,54}},
                                            color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(add8.y, product4.u1) annotation (Line(points={{-199,72},{-192,72},
                  {-182,72}}, color={0,0,127}));
          connect(du_w_SEP, add8.u1) annotation (Line(points={{-140,100},{-184,100},
                  {-230,100},{-230,78},{-222,78}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{-230,
                  60},{-230,66},{-222,66}}, color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(product3.u1, add10.y)
            annotation (Line(points={{162,252},{179,252}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{212,280},{
                  212,258},{202,258}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{212,246},{202,246}}, color={0,0,127}));
          connect(product2.u1, add11.y)
            annotation (Line(points={{162,72},{179,72}}, color={0,0,127}));
          connect(add11.u2, PID_valveTURB.CS) annotation (Line(points={{202,66},{
                  208,66},{214,66},{214,60},{262,60}}, color={0,0,127}));
          connect(du_Y_t, add11.u1) annotation (Line(points={{120,110},{120,110},{
                  214,110},{214,78},{202,78}}, color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, PID_pumpSEP.TR) annotation (Line(points={{-262,60},
                  {-256,60},{-252,60},{-252,88},{-280,88},{-280,76}}, color={0,0,
                  127}));
          connect(switch1.y, feedback.u2) annotation (Line(points={{-104,-101},{
                  -104,-101},{-104,-132},{-104,-132}}, color={0,0,127}));
          connect(gain.y, switch1.u1) annotation (Line(points={{-104,-53},{-104,-56},
                  {-112,-56},{-112,-78}}, color={0,0,127}));
          connect(const1.y, switch1.u3) annotation (Line(points={{-61,-80},{-80,-80},
                  {-80,-72},{-96,-72},{-96,-78}}, color={0,0,127}));
          connect(booleanStep3.y, switch1.u2) annotation (Line(points={{-61,-40},{
                  -70,-40},{-80,-40},{-80,-66},{-104,-66},{-104,-78}}, color={255,0,
                  255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_lowLoad_old;

        model plant_controller_HPpart_lin_lowLoad_vapValve_old
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=3000,
              startValue=false)
            annotation (Placement(transformation(extent={{-240,100},{-260,120}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.01; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.0491592; 30,0.074174; 40,0.112522; 50,0.215186; 60,0.8; 70,0.8;
                80,0.8; 90,0.8; 100,0.8])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{200,242},{180,262}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{200,62},{180,82}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Sources.Constant const1(k=0)
            annotation (Placement(transformation(extent={{-40,-90},{-60,-70}})));
          Modelica.Blocks.Logical.Switch switch1 annotation (Placement(
                transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={-104,-90})));
          Modelica.Blocks.Sources.BooleanStep booleanStep3(startValue=true,
              startTime=6000)
            annotation (Placement(transformation(extent={{-40,-50},{-60,-30}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,110},
                  {-272,110},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{259,10},{242,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{219,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60}},         color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{219,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{219,190},
                  {219,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-239,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-239,10},{
                  -170,10},{-170,54},{-142,54}},
                                            color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(add8.y, product4.u1) annotation (Line(points={{-199,72},{-192,72},
                  {-182,72}}, color={0,0,127}));
          connect(du_w_SEP, add8.u1) annotation (Line(points={{-140,100},{-184,100},
                  {-230,100},{-230,78},{-222,78}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{-230,
                  60},{-230,66},{-222,66}}, color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(product3.u1, add10.y)
            annotation (Line(points={{162,252},{179,252}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{212,280},{
                  212,258},{202,258}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{212,246},{202,246}}, color={0,0,127}));
          connect(product2.u1, add11.y)
            annotation (Line(points={{162,72},{179,72}}, color={0,0,127}));
          connect(add11.u2, PID_valveTURB.CS) annotation (Line(points={{202,66},{
                  208,66},{214,66},{214,60},{262,60}}, color={0,0,127}));
          connect(du_Y_t, add11.u1) annotation (Line(points={{120,110},{120,110},{
                  214,110},{214,78},{202,78}}, color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, PID_pumpSEP.TR) annotation (Line(points={{-262,60},
                  {-256,60},{-252,60},{-252,88},{-280,88},{-280,76}}, color={0,0,
                  127}));
          connect(switch1.y, feedback.u2) annotation (Line(points={{-104,-101},{
                  -104,-101},{-104,-132},{-104,-132}}, color={0,0,127}));
          connect(gain.y, switch1.u1) annotation (Line(points={{-104,-53},{-104,-56},
                  {-112,-56},{-112,-78}}, color={0,0,127}));
          connect(const1.y, switch1.u3) annotation (Line(points={{-61,-80},{-80,-80},
                  {-80,-72},{-96,-72},{-96,-78}}, color={0,0,127}));
          connect(booleanStep3.y, switch1.u2) annotation (Line(points={{-61,-40},{
                  -70,-40},{-80,-40},{-80,-66},{-104,-66},{-104,-78}}, color={255,0,
                  255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_lowLoad_vapValve_old;

        model plant_controller_full_old "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-260,220},{-220,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-360,242},{-340,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-240,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-200,90},{-220,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-280,90},{-260,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-260,-160},{-220,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{380,200},{360,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-200,270},{-220,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-200,-100},{-220,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-280,270},{-260,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-280,-100},{-260,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PID PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH,
            Td=Td_pumpHPH,
            N=Nd_pumpHPH)
            annotation (Placement(transformation(extent={{260,-160},{220,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{380,-180},{360,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{260,220},{220,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-380,-182},{-360,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{200,270},{220,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{280,270},{260,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PID PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB,
            Td=Td_valveTURB,
            N=Nd_valveTURB)
            annotation (Placement(transformation(extent={{260,40},{220,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{380,20},{360,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{200,90},{220,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{280,90},{260,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,242},{360,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,114e6])
            annotation (Placement(transformation(extent={{340,242},{320,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-340,-138},{-320,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-370,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,62},{360,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{340,62},{320,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{380,-138},{360,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{340,-138},{320,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-220,-200},{-200,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0; 30,0; 40,0; 50,0; 60,0; 70,5.257; 80,24.44; 90,67.83;
                100,143.1])
            annotation (Placement(transformation(extent={{200,-202},{180,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_t(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,0.6; 30,0.6; 40,0.6; 50,0.6; 60,0.6; 70,0.6; 80,0.6; 90,0.6;
                100,0.6])
            annotation (Placement(transformation(extent={{200,0},{180,20}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{120,50},{100,70}})));
          Modelica.Blocks.Math.Product product2
            annotation (Placement(transformation(extent={{160,56},{140,76}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{200,180},{180,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Math.Product product3
            annotation (Placement(transformation(extent={{160,236},{140,256}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,190})));
          Modelica.Blocks.Math.Product product4
                                               annotation (Placement(transformation(
                  extent={{-180,56},{-160,76}})));
          Modelica.Blocks.Math.Add add5 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0;
                80,0; 90,0; 100,0])
            annotation (Placement(transformation(extent={{-220,0},{-200,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-220,180},{-200,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-221,100},{-232,
                  100},{-232,76}},color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-221,280},{-232,
                  280},{-232,256}}, color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-232,-124},{-232,
                  -124},{-232,-102},{-232,-90},{-221,-90}},   color={255,0,255}));
          connect(PID_pumpSEP.TR, pumpSEP_TS.y) annotation (Line(points={{-240,76},{-240,
                  76},{-240,100},{-259,100}},
                                            color={0,0,127}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-259,280},{-272,
                  280},{-240,280},{-240,256}}, color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-240,-124},{-240,
                  -124},{-240,-92},{-240,-90},{-259,-90}},    color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{221,-100},{232,
                  -100},{232,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{259,-100},{259,
                  -100},{240,-100},{240,-124}}, color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-300,130},{-300,238},{-256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,-142},{256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{0,-60},{-300,-60},{-300,58},{-256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-300,-60},{-300,-142},{-256,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{221,280},
                  {232,280},{232,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{259,280},{
                  259,280},{240,280},{240,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{300,130},{300,238},{256,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{221,100},
                  {232,100},{232,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{259,100},
                  {259,100},{240,100},{240,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{300,-60},{300,58},{256,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-359,-128},{-352,-128},
                  {-342,-128}}, color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-319,-128},{-256,-128}}, color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-339,252},{
                  -256,252}},  color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-339,72},{-256,72}},           color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{256,252},{256,252},{319,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{342,252},{359,252}}, color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{342,72},{359,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{256,72},{288,72},{319,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{342,-128},{350,-128},{359,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{256,-128},{288,-128},{319,-128}},
                                                             color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-239,-190},{-222,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-199,-190},{
                  -150,-190},{-150,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{219,-192},{
                  210,-192},{202,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{179,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(PID_pumpHPH.CS, product1.u1) annotation (Line(points={{222,-140},
                  {202,-140},{180,-140},{180,-128},{162,-128}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD6.y, table_Y_t.u[1])
            annotation (Line(points={{219,10},{202,10}}, color={0,0,127}));
          connect(product2.y, add3.u1) annotation (Line(points={{139,66},{139,66},{
                  122,66}}, color={0,0,127}));
          connect(table_Y_t.y[1], add3.u2) annotation (Line(points={{179,10},{131,
                  10},{131,54},{122,54}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, add3.y)
            annotation (Line(points={{84,60},{99,60},{99,60}}, color={0,0,127}));
          connect(product2.u1, PID_valveTURB.CS) annotation (Line(points={{162,72},
                  {180,72},{180,60},{222,60}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{219,190},{210,
                  190},{202,190}}, color={0,0,127}));
          connect(product3.y, add4.u1) annotation (Line(points={{139,246},{139,246},
                  {122,246}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{179,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240},{99,240}}, color={0,0,127}));
          connect(product3.u1, PID_pumpMS.CS) annotation (Line(points={{162,252},{
                  180,252},{180,240},{222,240}}, color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-199,-190},
                  {-199,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{179,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(table_Y_t.y[1], product2.u2) annotation (Line(points={{179,10},{
                  170,10},{170,60},{162,60}}, color={0,0,127}));
          connect(table_w_MS.y[1], product3.u2) annotation (Line(points={{179,190},
                  {176,190},{170,190},{170,240},{162,240}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-222,-140},{
                  -216,-140},{-200,-140},{-200,-128},{-182,-128}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -92.5},{-104,-132}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-239,10},{-222,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{-199,10},
                  {-192,10},{-192,60},{-182,60}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add5.u2) annotation (Line(points={{-199,10},{-170,
                  10},{-170,54},{-142,54}}, color={0,0,127}));
          connect(product4.y, add5.u1) annotation (Line(points={{-159,66},{-142,66}},
                              color={0,0,127}));
          connect(add5.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -101.5,60},{-84,60}}, color={0,0,127}));
          connect(add5.y, add.u2) annotation (Line(points={{-119,60},{-98,60},{-98,
                  2}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, product4.u1) annotation (Line(points={{-222,60},{
                  -212,60},{-200,60},{-200,72},{-182,72}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-199,10},{-110,
                  10},{-110,2}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-239,190},{-222,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-199,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-199,190},{
                  -174,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246},{-142,246}}, color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(PID_valveRH.CS, product5.u1) annotation (Line(points={{-222,240},
                  {-200,240},{-200,252},{-182,252}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_full_old;

        model Plant_HP_IO_100_old
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(vap_in(p(start=46.4e5)), vap_out(p(start=
                    4.5e5))) annotation (Placement(transformation(extent={{124,
                    102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)) annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_simplified HPHs(
            FW_out(p(start=179.1e5)),
            SP1(p(start=8149000)),
            HPH1(HE(hotFluid(
                  hstart={2.22994e+006,2.16463e+006,2.08368e+006,1.98333e+006,
                      1.85886e+006,1.7044e+006,1.5126e+006,1.27426e+006,977805,
                      783922},
                  initOpt=ThermoPower.Choices.Init.Options.fixedState,
                  noInitialPressure=true)), flowJoin(out(h_outflow(start=
                        2229000))))) annotation (Placement(transformation(
                  extent={{18,-160},{118,-104}})));
          Old.plant_controller_HPpart_lin_highLoad_old controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Kp_pumpSEP=-14.5,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=5,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSmax_pumpFW=0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSmin_valveTURB=-0.9,
            CSmax_valveTURB=0.65,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            load_start=100,
            Kp_pumpFW=-1,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ti_valveTURB=95.23,
            Kp_valveTURB=-0.0000014,
            Ta_valveTURB=2,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            l_sp=0,
            CSmin_pumpSEP=-0.9,
            CSmax_pumpSEP=1,
            load_end=100,
            t_ramp=0,
            t_start=0,
            useTS_valveRH=true,
            useTS_pumpSEP=true,
            useTS_pumpFW=true,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            useTS_valveTURB=true,
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,-210},{340,-190}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,0},{-261.5,0}},            color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-32},{-261.5,-32}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-40},{-268,
                  -40},{-268,-48},{-261.5,-48}},            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-64},{-261.5,-64}},             color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,-200},{
                  -304,-200},{-270,-200},{-270,-80},{-261.5,-80}},        color={
                  0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=5000),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_100_old;

        model Plant_HP_IO_75_old
          "Model of the high pressure parto of the OTSG for linearization at 75% load"

          SteamTurbine.HPT HPTurb
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(vap_in(p(start=46.4e5)), vap_out(p(start=
                    4.5e5))) annotation (Placement(transformation(extent={{124,
                    102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)) annotation (
              Placement(transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_simplified HPHs(
            FW_out(p(start=179.1e5)),
            SP1(p(start=8149000)),
            HPH1(HE(hotFluid(
                  hstart={2.22994e+006,2.16463e+006,2.08368e+006,1.98333e+006,
                      1.85886e+006,1.7044e+006,1.5126e+006,1.27426e+006,977805,
                      783922},
                  initOpt=ThermoPower.Choices.Init.Options.fixedState,
                  noInitialPressure=true)), flowJoin(out(h_outflow(start=
                        2229000)))),
            const(k=0.1)) annotation (Placement(transformation(extent={{18,-160},
                    {118,-104}})));

          Old.plant_controller_HPpart_lin_highLoad_old controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Kp_pumpSEP=-14.5,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=5,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSmax_pumpFW=0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSmin_valveTURB=-0.9,
            CSmax_valveTURB=0.65,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Kp_pumpFW=-1,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ti_valveTURB=95.23,
            Kp_valveTURB=-0.0000014,
            Ta_valveTURB=2,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            l_sp=0,
            CSmin_pumpSEP=-0.9,
            CSmax_pumpSEP=1,
            t_ramp=0,
            t_start=0,
            useTS_valveRH=true,
            useTS_pumpFW=true,
            useTS_pumpHPH=true,
            useTS_pumpMS=true,
            useTS_valveTURB=true,
            load_start=75,
            load_end=75,
            useTS_pumpSEP=false,
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},{340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},{340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,-130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,-210},{340,-190}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph, w0=8) annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={54,-2})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,0},{-261.5,0}},            color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-32},{-261.5,-32}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,-40},{-268,
                  -40},{-268,-48},{-261.5,-48}},            color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-64},{-261.5,-64}},             color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,-200},{
                  -304,-200},{-270,-200},{-270,-80},{-261.5,-80}},        color={
                  0,0,127}));
          connect(HPHs.SP1, throughMassFlow.outlet) annotation (Line(points={{54.1111,
                  -101.2},{54,-101.2},{54,-12}},         color={0,0,255}));
          connect(HPTurb.SP7, throughMassFlow.inlet) annotation (Line(points={{54,
                  98.2},{54,98.2},{54,8}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(
              StartTime=2600,
              StopTime=5200,
              __Dymola_NumberOfIntervals=260),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_75_old;

        model Plant_HP_IO_50_old
          "Model of the high pressure parto of the OTSG for linearization at 50% load"

          SteamTurbine.HPT HPTurb(vap_in(p(start=100.5e5)))
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(vap_in(p(start=2161000)), vap_out(p(start=
                    217300))) annotation (Placement(transformation(extent={{124,
                    102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_noHPH OTSG(PDSteamSH(pin(start=
                   10100000)), separator(
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              w_small=1e4,
              noInitialPressure=false,
              noInitialLevel=true)) annotation (Placement(transformation(extent=
                   {{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_simplified HPHs(
            SP1(p(start=3898000)),
            FW_out(p(start=10320000)),
            HPH1(
              HE(hotFluid(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.noInit)),
              nominalColdFlow=45.93,
              nominalHotFlow=7.147,
              nominalColdPressure=10470000,
              nominalHotPressure=977600,
              nominalColdInletTemperature=427.45,
              nominalColdOutletTemperature=450.05,
              nominalHotInletTemperature=479.45,
              nominalHotOutletTemperature=433.35),
            HPH2(
              nominalColdFlow=45.93,
              nominalHotFlow=5.921,
              nominalColdDeltaP=0,
              nominalColdPressure=10410000,
              nominalHotPressure=3898000,
              nominalColdInletTemperature=450.05,
              nominalColdOutletTemperature=518.25,
              nominalHotInletTemperature=696.55,
              nominalHotOutletTemperature=479.45),
            DPSteamHPH2(pin(start=104.1e5)),
            DPSteamHPH1(pin(start=104.7e5)),
            const(k=0)) annotation (Placement(transformation(extent={{18,-160},
                    {118,-104}})));

          Old.plant_controller_HPpart_lin_highLoad_old controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Kp_pumpSEP=-14.5,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=5,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSmax_valveTURB=0.65,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ti_valveTURB=95.23,
            Kp_valveTURB=-0.0000014,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            CSmax_pumpSEP=1,
            t_ramp=0,
            t_start=0,
            useTS_pumpHPH=true,
            load_start=50,
            load_end=50,
            l_sp=4,
            Ta_valveTURB=250,
            CSmin_valveTURB=-0.99,
            Kp_pumpFW=-1,
            useTS_pumpMS=true,
            useTS_pumpSEP=false,
            useTS_valveRH=true,
            CSmax_pumpFW=0.3,
            useTS_pumpFW=false,
            CSmin_pumpSEP=-1,
            CSmin_pumpFW=0,
            useTS_valveTURB=false,
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},
                    {340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},
                    {340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},
                    {340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(HPTurb.SP7, HPHs.SP1) annotation (Line(
              points={{54,98.2},{54,98.2},{54,-101.2},{54.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,0},{-261.5,0}},            color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-32},{-261.5,-32}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -40},{-270,-40},{-270,-48},{-261.5,-48}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-64},{-261.5,-64}},             color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,-200},{
                  -304,-200},{-270,-200},{-270,-80},{-261.5,-80}},        color={
                  0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=5000),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_50_old;

        model Plant_HP_IO_50_spil_old
          "Model of the high pressure parto of the OTSG for linearization at 50% load"

          SteamTurbine.HPT HPTurb(vap_in(p(start=100.5e5)))
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(vap_in(p(start=2161000)), vap_out(p(start=
                    217300))) annotation (Placement(transformation(extent={{124,
                    102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_noHPH OTSG(PDSteamSH(pin(start=
                   10100000)), separator(
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              w_small=1e4,
              noInitialPressure=false,
              noInitialLevel=true)) annotation (Placement(transformation(extent=
                   {{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_simplified HPHs(
            SP1(p(start=3898000)),
            FW_out(p(start=10320000)),
            HPH1(
              HE(hotFluid(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.noInit)),
              nominalColdFlow=45.93,
              nominalHotFlow=7.147,
              nominalColdPressure=10470000,
              nominalHotPressure=977600,
              nominalColdInletTemperature=427.45,
              nominalColdOutletTemperature=450.05,
              nominalHotInletTemperature=479.45,
              nominalHotOutletTemperature=433.35),
            HPH2(
              nominalColdFlow=45.93,
              nominalHotFlow=5.921,
              nominalColdDeltaP=0,
              nominalColdPressure=10410000,
              nominalHotPressure=3898000,
              nominalColdInletTemperature=450.05,
              nominalColdOutletTemperature=518.25,
              nominalHotInletTemperature=696.55,
              nominalHotOutletTemperature=479.45),
            DPSteamHPH2(pin(start=104.1e5)),
            DPSteamHPH1(pin(start=104.7e5)),
            const(k=0)) annotation (Placement(transformation(extent={{18,-160},
                    {118,-104}})));

          Old.plant_controller_HPpart_lin_lowLoad_vapValve_old controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSmax_valveTURB=0.65,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ti_valveTURB=95.23,
            Kp_valveTURB=-0.0000014,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            CSmax_pumpSEP=1,
            t_ramp=0,
            t_start=0,
            useTS_pumpHPH=true,
            load_start=50,
            load_end=50,
            l_sp=4,
            CSmin_valveTURB=-0.99,
            Kp_pumpFW=-1,
            useTS_pumpSEP=false,
            CSmax_pumpFW=0.3,
            CSmin_pumpSEP=-1,
            CSmin_pumpFW=0,
            useTS_valveRH=true,
            useTS_pumpMS=true,
            Ta_valveTURB=50,
            useTS_valveTURB=true,
            useTS_pumpFW=true,
            Ta_pumpSEP=5,
            Kp_pumpSEP=-1.45,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},
                    {340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},
                    {340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},
                    {340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph, w0=5.4)   annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={54,2})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(
              points={{142.86,98.2},{142.86,70},{90.2222,70},{90.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,0},{-261.5,0}},            color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-32},{-261.5,-32}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -40},{-270,-40},{-270,-48},{-261.5,-48}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-64},{-261.5,-64}},             color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,-200},{
                  -304,-200},{-270,-200},{-270,-80},{-261.5,-80}},        color={
                  0,0,127}));
          connect(HPTurb.SP7, throughMassFlow.inlet) annotation (Line(points={{54,
                  98.2},{54,98.2},{54,12}}, color={0,0,255}));
          connect(HPHs.SP1, throughMassFlow.outlet) annotation (Line(points={{54.1111,
                  -101.2},{54,-101.2},{54,-8}},         color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=4500, __Dymola_NumberOfIntervals=1500),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_50_spil_old;

        model Plant_HP_IO_20_spil_transit_old
          "Model of the high pressure parto of the OTSG for linearization at 20% load"

          SteamTurbine.HPT HPTurb(vap_in(p(start=100.5e5)))
            annotation (Placement(transformation(extent={{16,102},{92,178}})));
          SteamTurbine.IPT IPTurb(vap_in(p(start=2161000)), vap_out(p(start=
                    217300))) annotation (Placement(transformation(extent={{124,
                    102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_noHPH OTSG(PDSteamSH(pin(start=
                   10100000)), separator(
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              w_small=1e4,
              noInitialPressure=false,
              noInitialLevel=true)) annotation (Placement(transformation(extent=
                   {{-160,-160},{-20,80}})));
          HeatExchangers.PreHeaters.HPH_train_simplified HPHs(
            SP1(p(start=3898000)),
            FW_out(p(start=10320000)),
            HPH1(
              HE(hotFluid(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.noInit)),
              nominalColdFlow=45.93,
              nominalHotFlow=7.147,
              nominalColdPressure=10470000,
              nominalHotPressure=977600,
              nominalColdInletTemperature=427.45,
              nominalColdOutletTemperature=450.05,
              nominalHotInletTemperature=479.45,
              nominalHotOutletTemperature=433.35),
            HPH2(
              nominalColdFlow=45.93,
              nominalHotFlow=5.921,
              nominalColdDeltaP=0,
              nominalColdPressure=10410000,
              nominalHotPressure=3898000,
              nominalColdInletTemperature=450.05,
              nominalColdOutletTemperature=518.25,
              nominalHotInletTemperature=696.55,
              nominalHotOutletTemperature=479.45),
            DPSteamHPH2(pin(start=104.1e5)),
            DPSteamHPH1(pin(start=104.7e5)),
            const(k=0)) annotation (Placement(transformation(extent={{18,-160},
                    {118,-104}})));

          Old.plant_controller_HPpart_lin_lowLoad_vapValve_old controllers(
            actuatorGain_valveRH=1,
            Ta_valveRH=2,
            Ti_pumpSEP=56.7,
            Td_pumpSEP=0,
            Nd_pumpSEP=1,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            TS_pumpSEP=0,
            Ta_pumpFW=5,
            Td_pumpHPH=0,
            Nd_pumpHPH=1,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=5,
            actuatorGain_pumpFW=1,
            P_mec_sp=79.7258e6,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=5,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpHPH=-0.5,
            CSmax_pumpHPH=0.5,
            CSstart_pumpHPH=0,
            TS_pumpHPH=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSmax_valveTURB=0.65,
            Nd_valveRH=10,
            Ti_valveRH=16,
            Td_valveRH=0,
            Ti_pumpFW=28.59,
            Td_pumpFW=7.147,
            Nd_pumpFW=30,
            Kp_pumpHPH=0.6461,
            Ti_pumpHPH=19.05,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            Ti_valveTURB=95.23,
            Kp_valveTURB=-0.0000014,
            Kp_valveRH=0.177,
            CSmin_valveRH=-0.9,
            CSmax_valveRH=1,
            CSstart_valveRH=0,
            TS_valveRH=0,
            CSmax_pumpSEP=1,
            useTS_pumpHPH=true,
            load_start=50,
            l_sp=4,
            CSmin_valveTURB=-0.99,
            Kp_pumpFW=-1,
            useTS_pumpSEP=false,
            CSmax_pumpFW=0.3,
            CSmin_pumpSEP=-1,
            CSmin_pumpFW=0,
            useTS_valveRH=true,
            useTS_pumpMS=true,
            Ta_valveTURB=50,
            useTS_valveTURB=true,
            useTS_pumpFW=true,
            Ta_pumpSEP=5,
            Kp_pumpSEP=-1.45,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_end=20,
            t_ramp=1e5,
            t_start=3000,
            booleanStep3(startTime=200000),
            T_RH_sp=826.05,
            T_MS_sp=563.15,
            T_FW_sp=553.15,
            p_sp=17611000)
            annotation (Placement(transformation(extent={{-260,-80},{-200,0}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{142,-110},{162,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{162,-150},{142,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-260,44},{-208,76}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=-90,
                origin={-180,60})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7895e5; 30,
                1.254e5; 40,1.713e5; 50,2.173e5; 60,2.631e5; 70,3.048e5; 80,
                3.527e5; 90,4.011e5; 100,4.5e5])
            annotation (Placement(transformation(extent={{248,200},{228,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,60})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sink(table=[20,0.9048e5; 30,
                1.435e5; 40,1.958e5; 50,2.478e5; 60,2.995e5; 70,3.465e5; 80,
                4.002e5; 90,4.543e5; 100,5.088e5])
            annotation (Placement(transformation(extent={{248,50},{228,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={272,0})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sink(table=[20,1.587e5; 30,
                2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{250,-10},{230,10}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-80})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_drain_sink(table=[20,1.587e5;
                30,2.525e5; 40,3.453e5; 50,4.381e5; 60,5.306e5; 70,6.143e5; 80,
                7.093e5; 90,8.046e5; 100,9e5])
            annotation (Placement(transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={222,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,524500; 30,
                586900; 40,626300; 50,656800; 60,683300; 70,705500; 80,728400; 90,
                749400; 100,768600]) annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,180},{-320,220}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,20},{-320,60}}),     iconTransformation(
                  extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{-360,-60},{-320,-20}}),
                iconTransformation(extent={{-360,-60},{-320,-20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-360,-140},{-320,-100}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-220},{-320,-180}}),
                                                               iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,190},
                    {340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,110},
                    {340,130}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MS = OTSG.sensT_MS.T annotation (Placement(transformation(extent={{320,30},
                    {340,50}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,-50},
                    {340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_RH = OTSG.sensT_RH.T annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l = OTSG.separator.level annotation (Placement(transformation(extent={{320,
                    -210},{340,-190}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph, w0=5.4,
            use_in_w0=true)                                         annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={54,2})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={4,6})));
          Modelica.Blocks.Tables.CombiTable1D SP7_w(table=[20,1.607; 30,2.806; 40,
                4.245; 50,5.4; 60,7.809; 70,8.488; 80,7.588; 90,6.322; 100,4.019])
            annotation (Placement(transformation(extent={{22,-4},{42,16}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={92,6})));
          Modelica.Blocks.Tables.CombiTable1D SP6_w(table=[20,0.33; 30,0.5678; 40,
                0.8767; 50,1.227; 60,1.582; 70,1.928; 80,2.415; 90,2.961; 100,
                3.709])
            annotation (Placement(transformation(extent={{110,-4},{130,16}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{95.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{12.2,48},{12.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{12.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{15.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{34.6667,-72},{34.6667,-101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{79.1111,
                  -180},{79.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{120.778,
                  -132},{120.778,-132},{136,-132},{136,-140},{142,-140}}, color={0,0,255}));
          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{120.778,
                  -115.2},{120.778,-115.2},{136,-115.2},{136,-100},{142,-100}},
                                                                          color={0,0,255}));
          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{98.5556,-200},{98.5556,
                  -161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP4, sinkPressure1.flange) annotation (Line(points={{179.76,
                  98.2},{179.76,40},{200,40}},        color={0,127,0},
              thickness=0.5));
          connect(controllers.signalBus, signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, Power_sensor.y) annotation (Line(
              points={{-180,60},{-192,60},{-205.4,60}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, sinkPressure2.flange) annotation (Line(
              points={{160.9,98.2},{160.9,-20},{200,-20}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{259,210},{
                  259,210},{250,210}}, color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  227,210},{220,210},{220,188.8}}, color={0,0,127}));
          connect(LOAD2.y,SP4_sink. u[1]) annotation (Line(points={{259,60},{259,60},
                  {250,60}},     color={0,0,127}));
          connect(LOAD3.y,SP5_sink. u[1])
            annotation (Line(points={{261,0},{261,0},{252,0}}, color={0,0,127}));
          connect(LOAD4.y,HPH1_drain_sink. u[1]) annotation (Line(points={{211,-80},
                  {211,-80},{202,-80}},      color={0,0,127}));
          connect(LOAD5.y,HPH1_FW_source. u[1]) annotation (Line(points={{211,-120},
                  {211,-120},{202,-120}},       color={0,0,127}));
          connect(SP4_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{227,
                  60},{206,60},{206,48.8}}, color={0,0,127}));
          connect(SP5_sink.y[1], sinkPressure2.in_p0) annotation (Line(points={{229,
                  0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(HPH1_drain_sink.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{148,-80},{148,-91.2}}, color={0,0,127}));
          connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{148,-120},{148,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,200},{-270,
                  200},{-270,0},{-261.5,0}},            color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,120},
                  {-280,120},{-280,-16.5333},{-261.5,-16.5333}}, color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,40},{-314,
                  40},{-290,40},{-290,-32},{-261.5,-32}},       color={0,0,127}));
          connect(du_w_HPH, controllers.du_w_HPH) annotation (Line(points={{-340,
                  -40},{-270,-40},{-270,-48},{-261.5,-48}}, color={0,0,127}));
          connect(du_w_RH, controllers.du_w_RH) annotation (Line(points={{-340,-120},{-280,
                  -120},{-280,-64},{-261.5,-64}},             color={0,0,127}));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{-340,-200},{
                  -304,-200},{-270,-200},{-270,-80},{-261.5,-80}},        color={
                  0,0,127}));
          connect(HPTurb.SP7, throughMassFlow.inlet) annotation (Line(points={{54,
                  98.2},{54,98.2},{54,12}}, color={0,0,255}));
          connect(HPHs.SP1, throughMassFlow.outlet) annotation (Line(points={{54.1111,
                  -101.2},{54,-101.2},{54,-8}},         color={0,0,255}));
          connect(SP7_w.u[1], LOAD6.y)
            annotation (Line(points={{20,6},{18,6},{15,6}}, color={0,0,127}));
          connect(SP7_w.y[1], throughMassFlow.in_w0)
            annotation (Line(points={{43,6},{48,6}}, color={0,0,127}));
          connect(LOAD7.y, SP6_w.u[1]) annotation (Line(points={{103,6},{105.5,6},
                  {108,6}}, color={0,0,127}));
          connect(IPTurb.SP6, HPHs.SP2) annotation (Line(points={{142.86,98.2},{
                  142.86,-44},{90.2222,-44},{90.2222,-101.2}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=4500, __Dymola_NumberOfIntervals=1500),
            __Dymola_experimentSetupOutput);
        end Plant_HP_IO_20_spil_transit_old;

        model plant_controller_HPpart_lin_highLoad
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(       k2=+1, k1=1)
                                                     annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,55.7; 70,
                64.2; 80,72.35; 90,80.45; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(                                                            table=[
                20,0.01; 30,0.01; 40,0.01; 50,0.01; 60,0.01; 70,5.257; 80,24.44;
                90,67.83; 100,143.1], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(table=[20,1.76067e-6; 30,
                2.65048e-6; 40,3.52138e-6; 50,4.55279e-6; 60,5.03874e-6; 70,
                5.03871e-6; 80,5.03821e-6; 90,5.03773e-6; 100,5.03668e-6],
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Gain    product2(k=0)
                                               annotation (Placement(transformation(
                  extent={{-190,70},{-170,90}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-110,-270})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS1(                                                           table=[4,
                0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1],
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(extent={{-80,-280},{-60,-260}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},
                  {-272,100},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{
                  -240,60},{-240,54},{-218,54},{-142,54}},
                                            color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -53},{-104,-132}},             color={0,0,127}));
          connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,100},
                  {-280,100},{-280,76}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,110},{120,110},{
                  220,110},{220,72},{212,72}}, color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(product2.y, add8.u1) annotation (Line(points={{-169,80},{-160,80},
                  {-160,66},{-142,66}}, color={0,0,127}));
          connect(du_w_SEP, product2.u) annotation (Line(points={{-140,100},{-170,
                  100},{-200,100},{-200,80},{-192,80}}, color={0,0,127}));
          connect(add8.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -84,60},{-84,60}}, color={0,0,127}));
          connect(add8.y, add.u2) annotation (Line(points={{-119,60},{-108,60},{-98,
                  60},{-98,2}}, color={0,0,127}));
          connect(LOAD10.y,table_T_MS1. u[1]) annotation (Line(points={{-99,-270},{
                  -90.5,-270},{-82,-270}},    color={0,0,127}));
          connect(signalBus.valveBP_CS, table_T_MS1.y[1]) annotation (Line(
              points={{0,60},{0,60},{0,-268},{0,-270},{-59,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad;

        model plant_controller_HPpart_lin_lowLoad
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.01; 30,0.01; 40,0.01; 50,0.01; 60,0.01; 70,5.257; 80,24.44;
                90,67.83; 100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,
                488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Interfaces.RealInput du_w_RH annotation (Placement(
                transformation(extent={{-120,260},{-160,300}}), iconTransformation(
                  extent={{-440,-200},{-400,-160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-320},{-400,-280}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-110},{-160,-70}}),
                iconTransformation(extent={{-440,40},{-400,80}})));
          Modelica.Blocks.Interfaces.RealInput du_w_HPH annotation (Placement(
                transformation(extent={{100,-110},{140,-70}}),  iconTransformation(
                  extent={{-440,-80},{-400,-40}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,280},{-400,320}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,90},{140,130}}),  iconTransformation(
                  extent={{-440,156},{-400,196}})));
          Modelica.Blocks.Math.Add add7
            annotation (Placement(transformation(extent={{-220,242},{-200,262}})));
          Modelica.Blocks.Math.Add add8
            annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add12
            annotation (Placement(transformation(extent={{200,-138},{180,-118}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(table=[20,1.76067e-6; 30,
                2.65048e-6; 40,3.52138e-6; 50,4.55279e-6; 60,5.03874e-6; 70,
                5.03871e-6; 80,5.03821e-6; 90,5.03773e-6; 100,5.03668e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Math.Gain    product2(k=1)
                                               annotation (Placement(transformation(
                  extent={{-190,70},{-170,90}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-110,-270})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS1(
                                                         smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.05; 80,0.20; 90,0.55; 100,1])
            annotation (Placement(transformation(extent={{-80,-280},{-60,-260}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},
                  {-272,100},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -170,-190},{-170,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140},{99,-140}}, color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-190,190},{-190,240},{-182,240}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -239,190},{-148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240},{-84,240}}, color={0,0,127}));
          connect(product5.u1, add7.y) annotation (Line(points={{-182,252},{-190,
                  252},{-199,252}}, color={0,0,127}));
          connect(PID_valveRH.CS, add7.u2) annotation (Line(points={{-262,240},{
                  -230,240},{-230,246},{-222,246}}, color={0,0,127}));
          connect(du_w_RH, add7.u1) annotation (Line(points={{-140,280},{-230,280},
                  {-230,258},{-222,258}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add8.u2) annotation (Line(points={{-262,60},{
                  -240,60},{-240,54},{-218,54},{-142,54}},
                                            color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-90},{-184,-90},
                  {-230,-90},{-230,-122},{-222,-122}}, color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(product1.u1, add12.y) annotation (Line(points={{162,-128},{179,
                  -128},{179,-128}}, color={0,0,127}));
          connect(add12.u2, PID_pumpHPH.CS) annotation (Line(points={{202,-134},{
                  214,-134},{214,-140},{262,-140}}, color={0,0,127}));
          connect(du_w_HPH, add12.u1) annotation (Line(points={{120,-90},{168,-90},
                  {214,-90},{214,-122},{202,-122}}, color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -53},{-104,-132}},             color={0,0,127}));
          connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,100},
                  {-280,100},{-280,76}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,110},{120,110},{
                  220,110},{220,72},{212,72}}, color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(product2.y, add8.u1) annotation (Line(points={{-169,80},{-160,80},
                  {-160,66},{-142,66}}, color={0,0,127}));
          connect(du_w_SEP, product2.u) annotation (Line(points={{-140,100},{-170,
                  100},{-200,100},{-200,80},{-192,80}}, color={0,0,127}));
          connect(add8.y, pumpSEP_dynamic.u) annotation (Line(points={{-119,60},{
                  -84,60},{-84,60}}, color={0,0,127}));
          connect(add8.y, add.u2) annotation (Line(points={{-119,60},{-108,60},{-98,
                  60},{-98,2}}, color={0,0,127}));
          connect(LOAD10.y,table_T_MS1. u[1]) annotation (Line(points={{-99,-270},{
                  -90.5,-270},{-82,-270}},    color={0,0,127}));
          connect(signalBus.valveBP_CS, table_T_MS1.y[1]) annotation (Line(
              points={{0,60},{0,60},{0,-268},{0,-270},{-59,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_lowLoad;

        model plant_controller_HPpart_old
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start "Start time [s]" annotation (Dialog(tab="Plant load"));

          //-- valveRH --
          parameter Modelica.SIunits.Temperature T_RH_sp
            "Reheat steam temperature set point" annotation (Dialog(tab="valveRH"));
          parameter Real Kp_valveRH "Controller proportional gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ti_valveRH "Controller integral time"
                                                                                annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Td_valveRH
            "Controller derivative time"                                          annotation (Dialog(tab="valveRH"));
          parameter Real Nd_valveRH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveRH"));
          parameter Real CSmin_valveRH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSmax_valveRH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveRH"));
          parameter Real CSstart_valveRH "Start value of CS" annotation (Dialog(tab="valveRH"));
          parameter Real actuatorGain_valveRH "Actuator gain" annotation (Dialog(tab="valveRH"));
          parameter Modelica.SIunits.Time Ta_valveRH "Actuator time constant" annotation (Dialog(tab="valveRH"));
          parameter Boolean useTS_valveRH "Tracking reference mode" annotation (Dialog(tab="valveRH"));
          parameter Real TS_valveRH "Tracking signal" annotation (Dialog(tab="valveRH"));

          //-- pumpSEP --
          parameter Modelica.SIunits.Height l_sp "Tank level set point" annotation (Dialog(tab="pumpSEP"));
          parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ti_pumpSEP "Controller integral time"
                                                                                annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Td_pumpSEP
            "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
          parameter Real Nd_pumpSEP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmin_pumpSEP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSmax_pumpSEP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
          parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
          parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
          parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant" annotation (Dialog(tab="pumpSEP"));
          parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
          parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

          //-- pumpFW --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            k=actuatorGain_valveRH,
            T=Ta_valveRH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-80,220},{-40,260}})));
          IndustrialControlSystems.Controllers.PI PID_valveRH(
            AntiWindup=true,
            useTS=useTS_valveRH,
            CSmin=CSmin_valveRH,
            CSmax=CSmax_valveRH,
            CS_start=CSstart_valveRH,
            Kp=Kp_valveRH,
            Ti=Ti_valveRH)
            annotation (Placement(transformation(extent={{-300,220},{-260,260}})));
          Modelica.Blocks.Sources.Constant T_RH_SP(k=T_RH_sp)
            annotation (Placement(transformation(extent={{-390,242},{-370,262}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-390,62},{-370,82}})));
          IndustrialControlSystems.Controllers.PI PID_pumpSEP(
            AntiWindup=true,
            useTS=useTS_pumpSEP,
            CSmin=CSmin_pumpSEP,
            CSmax=CSmax_pumpSEP,
            CS_start=CSstart_pumpSEP,
            Kp=Kp_pumpSEP,
            Ti=Ti_pumpSEP) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-280,60})));
         Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
            k=actuatorGain_pumpSEP,
            T=Ta_pumpSEP,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,60})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Math.Add add(k1=-1, k2=+1) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-104,-10})));
          Modelica.Blocks.Math.Feedback feedback
            annotation (Placement(transformation(extent={{-114,-130},{-94,-150}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-100},{-260,-80}})));
          Modelica.Blocks.Sources.Constant valveRH_TS(k=TS_valveRH)
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-100},{-300,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{400,-180},{380,-160}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
          Modelica.Blocks.Math.Max pumpFW_lim
            annotation (Placement(transformation(extent={{-20,-146},{-8,-134}})));
          Modelica.Blocks.Sources.Constant const(k=0)
            annotation (Placement(transformation(extent={{-34,-132},{-28,-126}})));
          Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-104,-42})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{-390,-182},{-370,-162}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{240,270},{260,290}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{240,90},{260,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(table=[20,14.887e6; 30,
                23.193e6; 40,31.710e6; 50,40.257e6; 60,48.842e6; 70,56.229e6; 80,
                63.953e6; 90,71.939e6; 100,79.535e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,558.35; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-380,-128})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(table=[20,100.1e5; 30,100.3e5;
                40,100.3e5; 50,100.5e5; 60,112.1e5; 70,128.5e5; 80,144.9e5; 90,
                161.1e5; 100,176.1e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(table=[20,558.05; 30,
                558.05; 40,557.75; 50,556.45; 60,528.45; 70,531.65; 80,533.15; 90,
                543.15; 100,553.15])
            annotation (Placement(transformation(extent={{370,-138},{350,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,64.64;
                80,72.9; 90,81.03; 100,88.59])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                0.01; 20,0.01; 30,0.01; 40,0.01; 50,0.01; 60,0.01; 70,5.257; 80,
                24.44; 90,67.83; 100,143.1])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                4.5,27.5; 20,122.1; 30,183.3; 40,244.2; 50,305.3; 60,366.3; 70,
                427.4; 80,488.4; 90,549.4; 100,610.6])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_w_SEP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,
                10.62; 20,47.18; 30,57.47; 40,59.89; 50,53.92; 60,0; 70,0; 80,0; 90,
                0; 100,0])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,190})));
          Modelica.Blocks.Math.Product product5
                                               annotation (Placement(transformation(
                  extent={{-180,236},{-160,256}})));
          Modelica.Blocks.Math.Add add6 annotation (Placement(transformation(extent={{-140,
                    230},{-120,250}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{180,50},{160,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(table=[20,1.76067e-6; 30,
                2.65048e-6; 40,3.52138e-6; 50,4.55279e-6; 60,5.03874e-6; 70,
                5.03871e-6; 80,5.03821e-6; 90,5.03773e-6; 100,5.03668e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-170,-270})));
          Modelica.Blocks.Tables.CombiTable1D table_w_RH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,6.08; 20,22.7; 30,39.02; 40,57.6; 50,78.65; 60,102.4; 70,
                126.9; 80,158.7; 90,195.2; 100,238.7])
            annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
          Modelica.Blocks.Tables.CombiTable1D table_valveBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.05; 80,0.20; 90,0.55;
                100,1]) annotation (Placement(transformation(extent={{-140,-280},
                    {-120,-260}})));
        equation
          connect(booleanStep.y, PID_pumpSEP.TS) annotation (Line(points={{-261,100},
                  {-272,100},{-272,76}},
                                  color={255,0,255}));
          connect(booleanStep1.y, PID_valveRH.TS) annotation (Line(points={{-261,
                  280},{-272,280},{-272,256}},
                                    color={255,0,255}));
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                  -124},{-272,-124},{-272,-102},{-272,-90},{-261,-90}},
                                                              color={255,0,255}));
          connect(valveRH_TS.y, PID_valveRH.TR) annotation (Line(points={{-299,280},
                  {-312,280},{-280,280},{-280,256}},
                                               color={0,0,127}));
          connect(PID_pumpFW.TR, pumpFW_TS.y) annotation (Line(points={{-280,-124},
                  {-280,-124},{-280,-92},{-280,-90},{-299,-90}},
                                                              color={0,0,127}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,
                  -100},{272,-100},{272,-124}},
                                     color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},
                  {299,-100},{280,-100},{280,-124}},
                                                color={0,0,127}));
          connect(signalBus.valveRH_CS, valveRH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,240},{-38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
              points={{0,60},{-20,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, PID_valveRH.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{-320,130},{-320,238},{-296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpFW_dynamic.y, pumpFW_lim.u2) annotation (Line(points={{-38,-140},{
                  -32,-140},{-32,-143.6},{-21.2,-143.6}},        color={0,0,127}));
          connect(const.y, pumpFW_lim.u1) annotation (Line(points={{-27.7,-129},{-24,-129},
                  {-24,-136.4},{-21.2,-136.4}},           color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_lim.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-7.4,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, gain.u)
            annotation (Line(points={{-104,-21},{-104,-30}},  color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{261,280},
                  {272,280},{272,256}},
                                   color={255,0,255}));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS.PV) annotation (Line(
              points={{0,60},{0,60},{0,130},{320,130},{320,238},{296,238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{261,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(valveTURB_TS.y, PID_valveTURB.TR) annotation (Line(points={{299,100},
                  {299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(LOAD1.y, table_T_MS.u[1]) annotation (Line(points={{-369,-128},{
                  -360,-128},{-362,-128}},
                                color={0,0,127}));
          connect(table_T_MS.y[1], PID_pumpFW.SP)
            annotation (Line(points={{-339,-128},{-322,-128},{-296,-128}},
                                                               color={0,0,127}));
          connect(T_RH_SP.y, PID_valveRH.SP) annotation (Line(points={{-369,252},{
                  -328,252},{-296,252}},
                               color={0,0,127}));
          connect(l_SP.y, PID_pumpSEP.SP)
            annotation (Line(points={{-369,72},{-328,72},{-296,72}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(table_T_FW.u[1], LOAD3.y)
            annotation (Line(points={{372,-128},{372,-128},{379,-128}},
                                                             color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_FW.y[1])
            annotation (Line(points={{296,-128},{349,-128}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{
                  -148,-190},{-148,-146},{-142,-146}}, color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  129,-192},{129,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},{99,
                  -140}},           color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{141,
                  190},{141,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-200,-190},{-200,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(pumpFW_dynamic.u, feedback.y) annotation (Line(points={{-84,-140},
                  {-90,-140},{-95,-140}}, color={0,0,127}));
          connect(add1.y, feedback.u1) annotation (Line(points={{-119,-140},{-116,
                  -140},{-112,-140}}, color={0,0,127}));
          connect(LOAD8.y, table_w_SEP.u[1])
            annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
          connect(table_w_SEP.y[1], add.u1) annotation (Line(points={{-239,10},{
                  -110,10},{-110,2}},
                                 color={0,0,127}));
          connect(product5.y, add6.u1) annotation (Line(points={{-159,246},{-142,
                  246}},            color={0,0,127}));
          connect(add6.y, valveRH_dynamic.u) annotation (Line(points={{-119,240},{
                  -84,240}},           color={0,0,127}));
          connect(gain.y, feedback.u2) annotation (Line(points={{-104,-53},{-104,
                  -53},{-104,-132}},             color={0,0,127}));
          connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,100},
                  {-280,100},{-280,76}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{159,60}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{182,54},{200,54},
                  {200,10},{219,10}}, color={0,0,127}));
          connect(PID_valveRH.CS, product5.u1) annotation (Line(points={{-262,240},
                  {-220,240},{-220,252},{-182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add4.u1) annotation (Line(points={{262,240},{212,
                  240},{160,240},{160,246},{122,246}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, pumpSEP_dynamic.u)
            annotation (Line(points={{-262,60},{-84,60}}, color={0,0,127}));
          connect(PID_pumpSEP.CS, add.u2) annotation (Line(points={{-262,60},{-182,
                  60},{-98,60},{-98,2}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,-140},{
                  -242,-140},{-220,-140},{-220,-128},{-182,-128}}, color={0,0,127}));
          connect(PID_valveTURB.CS, add5.u1) annotation (Line(points={{262,60},{220,
                  60},{220,66},{182,66}}, color={0,0,127}));
          connect(PID_pumpHPH.CS, product1.u1) annotation (Line(points={{262,-140},
                  {200,-140},{200,-128},{162,-128}}, color={0,0,127}));
          connect(LOAD9.y, table_w_RH.u[1])
            annotation (Line(points={{-279,190},{-262,190}}, color={0,0,127}));
          connect(table_w_RH.y[1], add6.u2) annotation (Line(points={{-239,190},{
                  -148,190},{-148,234},{-142,234}}, color={0,0,127}));
          connect(table_w_RH.y[1], product5.u2) annotation (Line(points={{-239,190},
                  {-200,190},{-200,240},{-182,240}}, color={0,0,127}));
          connect(LOAD10.y, table_valveBP.u[1]) annotation (Line(points={{-159,
                  -270},{-150.5,-270},{-142,-270}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, table_valveBP.y[1]) annotation (Line(
              points={{0,60},{0,60},{0,-270},{-119,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_old;
      end Old;
    end Control;
  end FullScale_280degC;

  package FullScale_245degC
    "Package containing the models regarding the OTSG design with 245 degC as FW OTSG nominal inlet temperature"

    package HeatExchangers
      "Package including all the heat exchangers model (OTSG and preheating train)"
      package BaseClasses "Partial models of the heat exchangers"
        partial model BaseWaterMSHeatExchanger
          "Base model for water/steam-MS fluid heat exchanger"
          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA inletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,-110},{
                    10,-90}}, rotation=0)));
          ThermoPower.Water.FlangeB outletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,90},{10,
                    110}}, rotation=0)));
          ThermoPower.Water.FlangeA inletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{-110,-10},{
                    -90,10}}, rotation=0)));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{90,-10},{110,
                    10}}, rotation=0)));
          annotation (Icon(graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{40,-82},{40,-24}}, color={135,135,135}),
                Line(points={{60,-60},{40,-24}}, color={135,135,135}),
                Line(points={{20,-60},{40,-24}}, color={135,135,135}),
                Line(points={{-48,0},{-74,-16}}, color={0,0,255}),
                Line(points={{-74,16},{-48,0}}, color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-110,-110},{110,110}}),
                                          graphics),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This partial model contains the basic components of a generic water/molten salt heat exchanger. Here the hot and cold media and the interfaces are defined.</span></p>
</html>"));

        end BaseWaterMSHeatExchanger;

        partial model BaseFeedwaterHeater
          "Base model for feedwater/steam extraction heat exchanger with drain inlet flow"
          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA ST_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,90},{-40,110}},rotation=0),
                iconTransformation(extent={{-10,90},{10,110}})));
          ThermoPower.Water.FlangeB DR_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,-110},{-40,-90}},rotation=
                   0), iconTransformation(extent={{-10,-110},{10,-90}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,-110},{60,-90}}, rotation=0),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeB FW_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{40,90},{60,110}},    rotation=
                   0), iconTransformation(extent={{-110,-10},{-90,10}})));
          ThermoPower.Water.FlangeA DR_in(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-110,-10},{-90,10}}),
                                         iconTransformation(extent={{-80,90},{-60,110}})));
        equation

          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                    {100,100}}),
                           graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{-40,80},{-40,20}}, color={135,135,135}),
                Line(points={{-20,56},{-40,20}}, color={135,135,135}),
                Line(points={{-60,56},{-40,20}}, color={135,135,135}),
                Line(points={{50,0},{74,-14}},   color={0,0,255}),
                Line(points={{72,14},{50,0}},   color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-100,-100},{100,100}}),
                                          graphics),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This partial model contains the basic components of a generic feedwater preheater. Here the media and the interfaces are defined.</span></p>
</html>"));
        end BaseFeedwaterHeater;

        partial model BaseOTSG "Base model of the OTSG "

          replaceable package coldMedium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              PreFlexMS.Media.MoltenSalt60_40_quad "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA RH_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,170},{200,190}}),
                                              iconTransformation(extent={{180,210},
                    {200,230}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,-220},{200,-200}}),
                                                iconTransformation(extent={{180,
                    -240},{200,-220}})));
          ThermoPower.Water.FlangeB RH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{90,300},{110,320}}), iconTransformation(extent={{10,300},
                    {30,320}})));
          ThermoPower.Water.FlangeB SH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{-10,300},{10,320}}),
                                              iconTransformation(extent={{90,300},
                    {110,320}})));
          ThermoPower.Water.FlangeB MS_HPH_out(redeclare package Medium = coldMedium)
                                                                                      annotation (Placement(
                transformation(extent={{-70,-320},{-50,-300}}),
                                                              iconTransformation(
                  extent={{10,-320},{30,-300}})));
          ThermoPower.Water.FlangeA MS_in(redeclare package Medium = hotMedium)
                                                                                annotation (Placement(transformation(extent={{-110,
                    300},{-90,320}}),      iconTransformation(extent={{-110,300},
                    {-90,320}})));
          ThermoPower.Water.FlangeB MS_out(redeclare package Medium = hotMedium)
                                                                                 annotation (Placement(transformation(extent={{10,-320},
                    {30,-300}}),           iconTransformation(extent={{-110,-320},
                    {-90,-300}})));
          ThermoPower.Water.FlangeB SEP_out(redeclare package Medium = coldMedium)
                                                                                   annotation (Placement(transformation(extent={{180,-90},{200,-70}})));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -300},{180,300}}),      graphics={
                Rectangle(extent={{-180,300},{180,-300}}, lineColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  fillColor={255,255,255}),
                Line(
                  points={{178,-228},{20,-228},{20,-244},{0,-248},{40,-258},{20,
                      -268},{20,-298}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{20,-228},{20,-150},{0,-140},{40,-130},{20,-120},{20,
                      -100},{0,-90},{40,-80},{20,-72},{20,20},{80,20}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{80,54},{120,-26}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid,
                  radius=10),
                Rectangle(
                  extent={{86,18},{114,-20}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Rectangle(
                  extent={{86,48},{114,10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Line(
                  points={{100,54},{100,116},{80,128},{120,138},{100,148},{100,
                      228},{100,238},{100,298}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Ellipse(
                  extent={{90,-46},{110,-66}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{92,-50},{108,-50},{100,-66},{92,-50}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{100,-66},{100,-80},{180,-80}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{100,-26},{100,-38},{100,-46}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{94,220},{94,222},{96,224},{100,226},{104,224},{106,222},
                      {106,220},{178,220}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Text(
                  extent={{-44,248},{28,212}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="RH"),
                Line(
                  points={{94,220},{70,220},{60,240},{50,200},{40,220},{20,220},{
                      20,300}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{120,150},{174,114}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="SH"),
                Text(
                  extent={{-68,-68},{-8,-110}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="EVA"),
                Text(
                  extent={{-64,-120},{-6,-164}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="ECO"),
                Text(
                  extent={{-80,-218},{-8,-284}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="MS_HPH"),
                Line(
                  points={{-100,298},{-100,220},{-80,208},{-120,200},{-80,190},{
                      -120,180},{-80,170},{-100,160},{-100,-60},{-120,-70},{-80,
                      -80},{-120,-90},{-80,-100},{-120,-110},{-80,-120},{-120,
                      -130},{-80,-140},{-120,-150},{-80,-160},{-120,-172},{-100,
                      -180},{-100,-298}},
                  color={255,0,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-78,134},{66,20}},
                  lineColor={0,0,0},
                  textString="OTSG")}),  Diagram(coordinateSystem(extent={{-180,
                    -300},{180,300}},
                           preserveAspectRatio=false)),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This partial model contains the basic components of a generic water/molten salt Once-Through Steam Generator (OTSG), with superheater and reheater in parallel. Here the hot and cold media and the interfaces are defined.</span></p>
</html>"));
        end BaseOTSG;

        partial model BaseHPHTrain
          "Base model of the high pressure heaters train"

          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA MS_HPH_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{10,-120},{30,-100}}),
                iconTransformation(extent={{30,-120},{50,-100}})));
          ThermoPower.Water.FlangeA SEP_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-130,100},{-110,120}}),
                iconTransformation(extent={{-130,100},{-110,120}})));
          ThermoPower.Water.FlangeA SP1(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-60,100},{-40,120}}),
                iconTransformation(extent={{-60,100},{-40,120}})));
          ThermoPower.Water.FlangeA SP2(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{80,100},{100,120}}),
                iconTransformation(extent={{70,100},{90,120}})));
          ThermoPower.Water.FlangeA FW_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{180,-10},{200,10}})));
          ThermoPower.Water.FlangeB FW_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-200,-10},{-180,10}})));
          ThermoPower.Water.FlangeB DR_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{180,-50},{200,-30}}),
                iconTransformation(extent={{180,50},{200,70}})));
        equation

          annotation (Diagram(coordinateSystem(extent={{-180,-100},{180,100}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-180,
                    -100},{180,100}}, preserveAspectRatio=false), graphics={
                Rectangle(
                  extent={{-180,100},{180,-100}},
                  lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{140,10},{160,-10}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{156,8},{156,-8},{140,0},{156,8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{30,-50},{50,-70}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{48,-66},{32,-66},{40,-50},{48,-66}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{60,20},{100,-20}},
                  lineColor={0,0,255}),
                Rectangle(
                  extent={{-60,20},{-20,-20}},
                  lineColor={0,0,255}),
                Rectangle(
                  extent={{-4,4},{4,-4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255}),
                Rectangle(
                  extent={{36,4},{44,-4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255}),
                Rectangle(
                  extent={{-128,8},{-112,-8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-50,-44},{-50,-36},{-40,-40},{-30,-36},{-30,-44},{-40,
                      -40},{-50,-44}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-50,100},{-50,72},{-50,20}},
                  color={0,127,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{80,100},{80,76},{80,20}},
                  color={0,127,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{180,0},{168,0},{160,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{140,0},{114,0},{100,0}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{60,0},{36,0},{-20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{40,-100},{40,-84},{40,-70}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-30,-40},{0,-40},{0,-4}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{40,-4},{40,-24},{40,-50}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Line(
                  points={{-30,20},{-30,30},{70,30},{70,20}},
                  color={0,127,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{90,20},{90,40},{90,60},{180,60}},
                  color={127,127,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-40,-40},{-40,-50}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Polygon(
                  points={{-44,-46},{-36,-46},{-36,-48},{-38,-50},{-42,-50},{-44,
                      -48},{-44,-46}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-60,-54},{-16,-88}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="HPH2"),
                Text(
                  extent={{62,-52},{104,-86}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="HPH1"),
                Line(
                  points={{-60,0},{-52,0},{-50,8},{-46,-6},{-42,8},{-38,-6},{-34,8},{-30,
                      -6},{-28,0},{-20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{60,0},{68,0},{70,8},{74,-6},{78,8},{82,-6},{86,8},{90,-6},{92,
                      0},{100,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-120,100},{-120,8}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-60,0},{-112,0}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-180,0},{-128,0}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Line(
                  points={{-120,-8},{-120,-40},{-50,-40}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None})}),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This partial model contains the basic components of a generic high-pressure feedwater preheater train, with two heat exchangers and the recirculation ports of separator and molten salt pre-heater. Here the media and the interfaces are defined.</span></p>
</html>"));
        end BaseHPHTrain;

        partial model BaseLPHTrain
          "Base model of the high pressure heaters train"

          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA SP6(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{130,100},{150,120}}),
                iconTransformation(extent={{130,100},{150,120}})));
          ThermoPower.Water.FlangeA SP4(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-150,100},{-130,120}}),
                iconTransformation(extent={{-150,100},{-130,120}})));
          ThermoPower.Water.FlangeA SP5(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-10,100},{10,120}}),
                iconTransformation(extent={{-10,100},{10,120}})));
          ThermoPower.Water.FlangeA FW_in(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{240,-10},{260,10}})));
          ThermoPower.Water.FlangeB FW_out(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-260,-10},{-240,10}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium =
                Medium) annotation (Placement(transformation(extent={{240,50},{
                    260,70}}), iconTransformation(extent={{240,50},{260,70}})));
        equation

          annotation (Diagram(coordinateSystem(extent={{-240,-100},{240,100}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-240,
                    -100},{240,100}}, preserveAspectRatio=false), graphics={
                Rectangle(
                  extent={{-240,100},{240,-100}},
                  lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{178,10},{198,-10}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{194,8},{194,-8},{178,0},{194,8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,20},{20,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{-140,100},{-140,72},{-140,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{238,0},{206,0},{198,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{120,0},{34,0},{20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-130,20},{-130,30},{-10,30},{-10,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{120,-36},{162,-66}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH1"),
                Line(
                  points={{-20,0},{-12,0},{-10,8},{-6,-6},{-2,8},{2,-6},{6,8},{
                      10,-6},{12,0},{20,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Rectangle(
                  extent={{-160,20},{-120,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{-160,0},{-152,0},{-150,8},{-146,-6},{-142,8},{-138,
                      -6},{-134,8},{-130,-6},{-128,0},{-120,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{0,100},{0,72},{0,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{10,20},{10,30},{130,30},{130,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{140,100},{140,72},{140,20}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{120,20},{160,-20}},
                  lineColor={0,0,255}),
                Line(
                  points={{120,0},{128,0},{130,8},{134,-6},{138,8},{142,-6},{
                      146,8},{150,-6},{152,0},{160,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{178,0},{178,0},{160,0}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Line(
                  points={{-20,0},{-112,0},{-120,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-160,0},{-232,0},{-240,0}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-20,-34},{22,-68}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH2"),
                Text(
                  extent={{-160,-34},{-118,-68}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="LPH3"),
                Line(
                  points={{150,20},{150,60},{220,60},{240,60}},
                  color={0,127,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled})}),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This partial model contains the basic components of a generic low-pressure feedwater preheater train, with three heat exchangers. Here the media and the interfaces are defined.</span></p>
</html>"));
        end BaseLPHTrain;
      end BaseClasses;

      package Components "Package of heat transfer-related components"
        model HE "Model of MS/steam heat exchanger"

          extends
            PreFlexMS.FullScale_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes of the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";

          ThermoPower.Water.Flow1DFV coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),
                               Icon(graphics),
            Documentation(info="<html>
<p>This is the model of a generic single-phase heat exchanger. Hot side, cold side and generic wall in between is represented through finite volumes, whose topology can be customized. The media and heat exchange models have the replaaceable attribute and they can be customized as well. The wall resistance is supposed to be concentrated, i.e. the Biot number is supposed to be much lower than 1. The model needs the following parameters/information for both hot and cold side:</p>
<ul>
<li><b>media</b> models;</li>
<li>heat exchange <b>mechanism</b> (UA constant, h = f(w), ...);</li>
<li>heat exchange <b>topology</b> (co-current, counter-current, shell&AMP;tube..);</li>
<li>number of <b>nodes</b> = number of volumes + 1;</li>
<li>fluid <b>volumes</b>;</li>
<li>heat exchange <b>surfaces</b>;</li>
<li>total <b>metal mass</b> between hot and cold side;</li>
<li>metal specific heat capacity;</li>
<li>nominal mass flow rates;</li>
<li>nominal inlet <b>pressure</b> and <b>pressure drops</b>;</li>
<li>nominal inlet and outlet <b>temperatures</b>.</li>
</ul>
<p><br>Because of numerical issues, it is strongly suggested to not use the distributed pressure drop feature within the Flow1D component, but to consider an equivalent pressure drop at inlet or outlet of the heat exchanger. This is reasonable, since the thermophysical properties involved in the heat exchange mechanism are weakly dependent on the pressure.</p>
</html>"));
        end HE;

        model HE_2ph "Model of MS/steam heat exchanger with phase change"

          extends
            PreFlexMS.FullScale_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          ThermoPower.Water.Flow1DFV2ph coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                                annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}),
                              graphics),
                               Icon(graphics),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This is the model of a generic two-phase heat exchanger, e.g. an evaporator or a condenser. Hot side, cold side and generic wall in between is represented through finite volumes, whose topology can be customized. The media and heat exchange models have the replaaceable attribute and they can be customized as well. The wall resistance is supposed to be concentrated, i.e. the Biot number is supposed to be much lower than 1. The model needs the following parameters/information for both hot and cold side:</span></p>
<ul>
<li><b><span style=\"font-family: MS Shell Dlg 2;\">media</b> models;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">heat exchange <b>mechanism</b> (UA constant, h = f(w), ...) of every phase;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">heat exchange <b>topology</b> (co-current, counter-current, shell&AMP;tube..);</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">number of <b>nodes</b> = number of volumes + 1;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">fluid <b>volumes</b>;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">heat exchange <b>surfaces</b>;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">total <b>metal mass</b> between hot and cold side;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">metal specific heat capacity;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">nominal mass flow rates;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">nominal inlet <b>pressure</b> and <b>pressure drops</b>;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">nominal inlet and outlet <b>temperatures</b>.</span></li>
</ul>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p>Because of numerical issues, it is strongly suggested to not use the distributed pressure drop feature within the Flow1D component, but to consider an equivalent pressure drop at inlet or outlet of the heat exchanger. This is reasonable, since the thermophysical properties involved in the heat exchange mechanism are weakly dependent on the pressure.</span></p>
</html>"));
        end HE_2ph;

        model FlowDependentHeatTransferCoefficient_switch
          "Flow-dependent h.t.c. gamma = gamma_nom*(w/wnom)^alpha"
          extends ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV;

           parameter Modelica.SIunits.Time t_switch "Switch time";
           parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma_nom_pre
            "Nominal heat transfer coefficient for t < t_switch";
           parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma_nom_post
            "Nominal heat transfer coefficient for t >= t_switch";
           parameter Modelica.SIunits.PerUnit alpha
            "Exponent in the flow-dependency law";
           parameter Modelica.SIunits.PerUnit beta=0.1
            "Fraction of nominal flow rate below which the heat transfer is not reduced";
           parameter Modelica.SIunits.MassFlowRate wnom_ht=wnom
            "Nominal flow rate for heat transfer correlation (single tube)";
           Medium.Temperature Tvol[Nw] "Fluid temperature in the volumes";
           Modelica.SIunits.CoefficientOfHeatTransfer gamma(start=gamma_nom_pre)
            "Actual heat transfer coefficient";
           Modelica.SIunits.PerUnit w_wnom(start=1, final unit="1")
            "Ratio between actual and nominal flow rate";
           Modelica.SIunits.PerUnit w_wnom_reg
            "Regularized ratio between actual and nominal flow rate";
        equation
          assert(Nw ==  Nf - 1, "Number of volumes Nw on wall side should be equal to number of volumes fluid side Nf - 1");

          // Computation of actual heat transfer coefficient with smooth lower saturation to avoid numerical singularities at low flows
          w_wnom = abs(w[1])/wnom_ht
            "Inlet flow rate used for the computation of the h.t.c.";
          w_wnom_reg = ThermoPower.Functions.smoothSat(
            w_wnom,
            beta,
            1e9,
            beta/2);
          if time < t_switch then
            gamma = homotopy(gamma_nom_pre*w_wnom_reg^alpha,
                             gamma_nom_pre);
          else
            gamma = homotopy(gamma_nom_post*w_wnom_reg^alpha,
                             gamma_nom_post);
          end if;

          for j in 1:Nw loop
             Tvol[j] = if useAverageTemperature then (T[j] + T[j + 1])/2 else T[j+1];
             Qw[j] = (Tw[j] - Tvol[j])*gamma*omega*l*Nt;
          end for;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
                    100,100}}),
                    graphics),
            Icon(graphics={Text(extent={{-100,-52},{100,-80}}, textString="%name")}),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This particular heat transfer model is used in steam side drainage simulation and it has been derived from the model &QUOT;<i>FlowDependentHeatTransferCoefficient &QUOT;, </i>of Thermopower library. The heat trasfer equation is part of an if-clause: once the OTSG is in steady-state condtion at the desired load, at time = t_switch the heat transfer coefficient is brought to a lower value (eventually zero), i.e. the heat exchanged trhough the wall is zero. </span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">When the heat exchanger drainage procedure is started because of an emergency, all the pumps are shut down and the turbine admission valve is closed to mantain the steam pressure as high as possible, while the safety valve at the SH outlet is fully opened to vent the system. In fact, steam pressure is strictly linked to the OTSG molten salt outlet temperature and should be kept sufficiently high during the molten salt drainage on shell side. From steam-water point of view, the worse scenario is the &QUOT;zero steam production&QUOT;, when the pressure lost rate is maximum.</span></p>
</html>"));
        end FlowDependentHeatTransferCoefficient_switch;

        model nonEquilibriumVessel
          "Base model of an adiabatic steam/liquid separator with separete liquid and vapour phases and no thermal equilibrium"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Length D "tank diameter";
          parameter Modelica.SIunits.Height H "Height of the tank";
          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
            "Cross Sectional Area";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Surface heat transfer coefficient";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Medium.SpecificEnthalpy hv_start
            "Start vapour specific enthalpy";
          parameter Medium.SpecificEnthalpy hl_start
            "Start liquid specific enthalpy";
          parameter Medium.AbsolutePressure p_start "Start pressure";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));
          parameter Boolean noInitialLevel=true
            "Remove initial equation on level"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,-50},{-40,-30}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeB steam_out(
                                           redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}},  rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));

          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{40,-80},{60,-60}})));

          Medium.ThermodynamicState liquid_state
            "Thermodynamic state of the liquid phase";
          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour phase";
          Medium.SaturationProperties sat
            "Saturation properties of the separator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate w_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_in
            "Medium inflow mass flow rate (liquid fraction)";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate wv_out "Medium steam outflow mass flow rate";
         // Medium.MassFlowRate w_hex "Condensation/evaporation vapour mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hv_out
            "Medium steam outlet specific enthalpy";
          Medium.SpecificEnthalpy hl_sat "Bubble point specific enthalpy";
          Medium.SpecificEnthalpy hv_sat "Dew-point specific enthalpy";
          Medium.SpecificEnthalpy hl(start = hl_start, stateSelect=StateSelect.prefer)
            "Liquid specific enthalpy";
          Medium.SpecificEnthalpy hv(start = hv_start, stateSelect=StateSelect.prefer)
            "Vapour specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Mv "Mass of vapour";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature Tv "Vapour temperature";
          Medium.Temperature Tl "Liquid temperature";
          Medium.Temperature T_sat "Saturation temperature";
          Medium.Temperature DT_sh "Separator degree of superheating";
          Medium.AbsolutePressure p(start = p_start, stateSelect=StateSelect.prefer)
            "Medium pressure";
          Modelica.SIunits.Density rhov "Vapour density";
          ThermoPower.Units.LiquidDensity rhol "Liquid density";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.MassFraction  x_in = Medium.vapourQuality(Medium.setState_ph(p,hl_in))
            "Inlet steam quality";
          //Modelica.SIunits.Power Q_hex "Condensation/evaporation thermal load";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          liquid_state = Medium.setState_ph(p,hl);
          vapour_state = Medium.setState_ph(p,hv);
          Tl = Medium.temperature(liquid_state);
          Tv = Medium.temperature(vapour_state);
          T_sat = Medium.saturationTemperature(p);
          hv_sat = Medium.dewEnthalpy(sat);
          hl_sat = Medium.bubbleEnthalpy(sat);
          rhol = Medium.density(liquid_state);
          rhov = Medium.density(vapour_state);
          drdp = Medium.density_derp_h(vapour_state);
          drdh = Medium.density_derh_p(vapour_state);
          wl_in = w_in*(1-x_in);

          //Mass and energy balances
          //Liquid
          rhol*A*der(zl) = w_in*(1-x_in) - wl_out;
          rhol*A*zl*der(hl) - A*zl*der(p) + A*(rhol*hl - p)*der(zl) = w_in*(1-x_in)*hl_sat - wl_out*hl;
          //Vapour
          (V-A*zl)*(drdp*der(p) + drdh*der(hv)) - rhov*A*der(zl) = w_in*x_in - wv_out;
          (V-A*zl)*(rhov + hv*drdh)*der(hv) + (V-A*zl)*(hv*drdp - 1)*der(p) + A*(p-rhov*hv)*der(zl)= w_in*x_in*hl_in - wv_out*hv;

          M = Ml + Mv;
          Mv = rhov*A*(H-zl);
          Ml = max(0,rhol*A*zl);

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hv_out = max(hv,hv_sat);
          hl_out = hl;

          steam_out.h_outflow = hv_out;
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(steam_out.h_outflow)
            "Dummy equation for flow reversal";

          w_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          wv_out = -steam_out.m_flow;
          assert(w_in > -w_small, "Flow reversal not supported at phase separator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at phase separator liquid outlet");
          assert(wv_out > -w_small, "Flow reversal not supported at phase separator steam outlet");
          water_in.p = p;
          steam_out.p = p;
          drained_out.p = p;
          assert(zl<H,"Separator full");

          // Level sensor output
          level = zl;
          // Degree of superheating sensor
          DT_sh = max(0,Tv - T_sat) + 273.15;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(hl) = 0;
            der(hv) = 0;
            der(zl) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            if not noInitialLevel then
              zl = zl_start;
            end if;
            hv = hv_start;
            hl = hl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<html>
<p>This is the model of the 2-phase gravity separator at the EVA2 steam outlet. Its aim is to separate saturated steam from saturated liquid by means of gravity, so that only vapor enters the superheater (wet-mode). When the steam condition is already superheated (dry-mode) at the inlet flange, the separator has no effect on steam condition, i.e. it is basically a piece of pipe. </p>
<p>It can be modelled as a cilindric vessel, with a diameter of 0.56 m and a height of 8 m. Other geometrical parameters are automatically evaluated by the model on the basis of these two base parameters. The saturated liquid flange is at the bottom and the saturated/superheated steam flange at the top of the vessel. Since the inlet flange is supposed to be in the higher part, there&apos;s no contact and so heat exchange between steam and liquid phase. The hypothesis of non thermal equilibrium within the vessel is conservative and reasonable. </p>
<p>The selected state are liquid level (mass liquid balance), pressure and steam enthalpy (mass and energy steam balances). </p>
<p>Modelling assumptions:</p>
<ul>
<li>the state can be either saturated liquid and saturated steam without thermodynamic equilibrium, or superheated steam. Phases are separated at the inlet flange, as function of the wet vapor quality;</li>
<li>full liquid state not supported. If the separator level equals its height, the simulaiton is stopped;</li>
<li>no flow reversal at the ports;</li>
<li>reference zero level @ empty tank;</li>
<li>level set point in dry-mode = 4 m; </li>
<li>liquid always in saturated conditions --&GT; no liquid energy balance needed;</li>
</ul>
</html>"));
        end nonEquilibriumVessel;

        model NusseltCondenser
          "Base model of feedwater heater condensing section based on Nusselt theory"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));
          Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                    {-60,0}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{-118,-74},{-98,-54}}),
                                              iconTransformation(extent={{-40,-80},{-60,
                    -60}})));

          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour";
          Medium.ThermodynamicState liquid_state
            "Thermodynamic state of the liquid";
          Medium.ThermodynamicState condensate_state[Nw]
            "Thermodynamic state of the condensate";
          Medium.ThermodynamicState steamIn_state
            "Thermodynamic state of the inlet vapour";
          Medium.ThermodynamicState drainedIn_state
            "Thermodynamic state of the inlet drain";
          Medium.SaturationProperties sat "Saturation properties of the vapour";

          parameter Integer Nw "Number of volumes, tube side";
          parameter Modelica.SIunits.Volume V "Total volume";
          parameter Modelica.SIunits.Area A "Cross Sectional Area";
          parameter Modelica.SIunits.Height H=V/A
            "Height of the condensing volume";
          parameter Modelica.SIunits.Area S "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC";
          parameter Modelica.SIunits.Time tauev=2
            "Time constant of bulk evaporation";
          parameter Modelica.SIunits.Height zl_set "Liquid level set point";
          parameter Modelica.SIunits.Height zl_start "Liquid level start";
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        public
          Medium.MassFlowRate ws_in "Steam mass flow rate";
          Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
          Medium.MassFlowRate wd_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
          Medium.MassFlowRate ww[Nw]
            "Condensed vapour mass flow rate in single volumes";
          Medium.MassFlowRate w_ev "Mass flowrate of bulk evaporation";
          Modelica.SIunits.Height zl(start = zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          Medium.Temperature Tv "Vapour temperature";
          Medium.Temperature Tl "Liquid temperature";
          Medium.Temperature Tc[Nw] "Condensate temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.DerDensityByPressure drdp_l
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh_l
            "Derivative of density by enthalpy";
          Modelica.SIunits.DerDensityByPressure drdp_v
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh_v
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv(start = Medium.dewEnthalpy(Medium.setSat_p(p_start)))
            "Specific vapor enthalpy";
          Modelica.SIunits.SpecificEnthalpy hl(start = Medium.bubbleEnthalpy(Medium.setSat_p(p_start)))
            "Specific liquid enthalpy";
          Modelica.SIunits.SpecificEnthalpy hc[Nw](start = ones(Nw)*Medium.bubbleEnthalpy(Medium.setSat_p(p_start)))
            "Specific condensate enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv_sat
            "Specific saturated steam enthalpy";
          Modelica.SIunits.SpecificEnthalpy hl_sat
            "Specific saturated liquid enthalpy";
          Modelica.SIunits.Density rho_v "Steam density";
          Modelica.SIunits.Density rho_l "Liquid density";
          Real x_s "Vapour quality at steam inlet";
          Real x_d "Vapour quality at drained inlet";
          Real x_l "Mass fraction of vapour in the liquid volume";
          Modelica.SIunits.Power Q_cond "Condensation thermal load";
          Modelica.SIunits.Power Qw[Nw]
            "Condensation thermal load on a single volume";
          Modelica.SIunits.Power Q_flux "Actual total condensing flux";
          //Modelica.SIunits.Power q_flux[Nw] "Actual total condensing flux";
          Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

          ThermoPower.Thermal.DHTVolumes DHT(
            N = Nw) annotation (Placement(
                transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                    {50,20}})));
        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          vapour_state = Medium.setState_ph(p,hv);
          liquid_state = Medium.setState_ph(p,hl);
          steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
          drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
          Tv = Medium.temperature(vapour_state);
          Tl = Medium.temperature(liquid_state);
          rho_v = Medium.density(vapour_state);
          hv_sat = Medium.dewEnthalpy(sat);
          hl_sat = Medium.bubbleEnthalpy(sat);
          T_sat = Medium.saturationTemperature(p);
          rho_l = Medium.density(liquid_state);
          drdp_v = Medium.density_derp_h(vapour_state);
          drdh_v = Medium.density_derh_p(vapour_state);
          drdp_l = Medium.density_derp_h(liquid_state);
          drdh_l = Medium.density_derh_p(liquid_state);
          x_s = Medium.vapourQuality(steamIn_state);
          x_d = Medium.vapourQuality(drainedIn_state);
          x_l = homotopy(if hl <= hl_sat then 0 else (hl - hl_sat)/(hv_sat - hl_sat), 0);

          //Mass and energy balances
          //Liquid mass balance
          Vl*(drdp_l*der(p) + drdh_l*der(hl)) + rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out - w_ev;
          //Liquid energy balance
          Vl*(rho_l + hl*drdh_l)*der(hl) + Vl*(hl*drdp_l - 1)*der(p) - A*(p-rho_l*hl)*der(zl) = ws_in*(1-x_s)*min(hs_in,hl_sat) + wd_in*(1-x_d)*min(hd_in,hl_sat) + Q_flux - wd_out*hl - w_ev*hv_sat;
          //Vapour mass balance
          Vv*(drdp_v*der(p) + drdh_v*der(hv)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d + w_ev - w_cond;
          Vl = A*zl;
          Vv = V - Vl;
          //Vapour energy balance
          Vv*(rho_v + hv*drdh_v)*der(hv) + Vv*(hv*drdp_v - 1)*der(p) + A*(p-rho_v*hv)*der(zl)= ws_in*x_s*max(hs_in,hv_sat) + wd_in*x_d*max(hd_in,hv_sat) - Q_flux + w_ev*hv_sat - Q_cond;

          for j in 1:Nw loop
            Qw[j] = max(0,gamma*S/Nw*(T_sat - Tc[j]) + ww[j]*(hv - hv_sat));
            ww[j] = Qw[j]/(hv - hc[j]);
            condensate_state[j] = Medium.setState_pT(p,Tc[j]);
            hc[j] = min(Medium.specificEnthalpy(condensate_state[j]),hl_sat);
            Tc[j] = (Tw[j] + T_sat)/2;
          end for;
          Q_flux = ww*hc;
          Q_cond = sum(Qw);
          w_cond = sum(ww);
          w_ev = x_l*rho_l*Vl/tauev;

          // Boundary conditions
          hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
             else if ws_in >= 0 then inStream(steam_in.h_outflow) else hv, inStream(
            steam_in.h_outflow));
          hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
             else if wd_in >= 0 then inStream(drained_in.h_outflow) else hv, inStream(
            drained_in.h_outflow));
          drained_out.h_outflow = hl;
          steam_in.h_outflow = inStream(drained_out.h_outflow);
          drained_in.h_outflow = inStream(drained_out.h_outflow);

          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          wd_out = -drained_out.m_flow;
          steam_in.p = p;
          drained_in.p = p;
          drained_out.p = p;

          Tw = DHT.T;
          Qw = -DHT.Q;

          // Level set-point definition
          zl_SP = zl_set;
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(zl) = 0;
            der(hv) = 0;
            der(hl) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            hv = hv_sat;
            hl = hl_sat;
            zl = zl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This is the model of the condensing section of a feedwater preheater (yellow part in picture below..). Its aim is to simulate the condensation of the steam extraction flow coming from the turbine and from the previous( if present..) higher pressure heater. The heat exchange mechanism is based on the Nusselt condensation theory, so that thermal equilibrium between steam and condensate phase is not present.</span></p>
<p><img src=\"modelica://PreFlexMS/Images/pre-heaters.png\"/></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">It can be modelled as a parallelepiped cavity crossed by a tubes bundle, over which steam condensation takes place. Since the temperature of the feedwater flowing within the bundle changes from cold to hot end, the cavity is divided into finite volumes and it exchanges heat through a distributed heat transfert connector. Heat exchange at liquid-vapor interface is neglected. The hypothesis of non thermal equilibrium within the vessel is conservative and reasonable. </span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">The selected state are liquid level and enthalpy (mass and energy liquid balance), pressure and steam enthalpy (mass and energy steam balances). </span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">Modelling assumptions:</span></p>
<ul>
<li><span style=\"font-family: MS Shell Dlg 2;\">the vapor state can be either saturated liquid and saturated steam without thermodynamic equilibrium, or superheated steam. Phases are separated at the vapor and drained inlet flange, as function of the wet vapor quality;</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">level set point = 0.1 m; </span></li>
</ul>
</html>"));
        end NusseltCondenser;

        model Deaerator "Base model of an adiabatic deaerator"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=L*H "Cross Sectional Area";
          parameter Modelica.SIunits.Length L "tank length";
          parameter Modelica.SIunits.Height H "Height of the tank (squared)";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{26,70},{46,90}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-120},{10,-100}})));
          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-140,-80},{-120,-60}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-48,10},{-28,30}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{120,-90},{140,
                    -70}})));
          Modelica.Blocks.Interfaces.RealOutput p_dea annotation (Placement(transformation(
                  extent={{-48,50},{-28,70}}), iconTransformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-38,60})));
          Medium.ThermodynamicState state
            "Thermodynamic state of the deaerator";
          Medium.SaturationProperties sat
            "Saturation properties of the deaerator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate wl_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate ws_in "Medium steam inlet mass flow rate";
          Medium.MassFlowRate wd_in "Medium drained inlet mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hs_in "Medium steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in
            "Medium drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hl "Medium internal specific enthalpy";
          Medium.SpecificEnthalpy hv "Medium internal specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          ThermoPower.Units.LiquidDensity rho_l "Density of the liquid medium";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h "Specific internal enthalpy";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.Density rho "Density";
          Modelica.SIunits.MassFraction  x "Mixture steam quality";
          Real vf "Void fraction";
          Integer phase(start = 2)
            "Definition of thermodynamic state in the separator";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          phase = if h >= hv then 1 else 2;
          state = Medium.setState_ph(p,h,phase);
          T = Medium.temperature(state);
          T_sat = Medium.saturationTemperature(p);
          hv = Medium.dewEnthalpy(sat);
          hl = Medium.bubbleEnthalpy(sat);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(state);
          drdh = Medium.density_derh_p(state);

          //Mass and energy balances
          V*(drdp*der(p) + drdh*der(h)) = wl_in - wl_out + ws_in + wd_in;
          V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = wl_in*hl_in - wl_out*hl_out + ws_in*hs_in + wd_in*hd_in;
          rho = Medium.density(state);
          x = Medium.vapourQuality(state);
          M = V*rho;
          Ml = M*(1-x);
          Ml = A*zl*rho_l;
          Vl = A*zl;
          Vv = V - Vl;
          vf = (H-zl)/H;

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hs_in = inStream(steam_in.h_outflow);
          hd_in = inStream(drained_in.h_outflow);
          hl_out = if phase == 1 then h else hl;

          steam_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";

          wl_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          assert(wl_in > -w_small, "Flow reversal not supported at deaerator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at deaerator liquid outlet");
          assert(ws_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          assert(wd_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          water_in.p = p;
          steam_in.p = p;
          drained_out.p = p + rho_l*zl*Modelica.Constants.g_n;
          drained_in.p = p;
          assert(vf>0,"Deaerator full");

          // Level set-point definition
          level = zl;
          p_dea = p;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            //h = h_start;
            zl = zl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-120,-10},{120,-92}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-10},{-116,-4},{-106,0},{-90,0},{-84,0},{-78,0},{-70,0},
                      {110,0},{116,-4},{120,-10},{-62,-10},{-120,-10}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-92},{-118,-98},{-114,-100},{-110,-100},{-106,-100},{-100,
                      -100},{-92,-100},{-86,-100},{114,-100},{118,-96},{120,-92},{-120,-92}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-34},{112,-88}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-16},{112,-34}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-16},{-110,-10},{-102,-8},{104,-8},{110,-10},{112,-16},{
                      -106,-16},{-112,-16}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-88},{-110,-92},{-104,-94},{0,-94},{106,-94},{110,-92},{
                      112,-88},{-112,-88}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,90},{26,0}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,90},{-26,96},{-20,100},{2,100},{8,100},{14,100},{16,100},
                      {22,98},{24,96},{26,90},{26,90},{-28,90}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-20,84},{-20,90},{-16,92},{14,92},{18,90},{18,84},{-14,84},{-20,
                      84}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,84},{18,-10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,76},{18,74}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,64},{10,62}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,40},{10,38}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,52},{18,50}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,28},{18,26}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,16},{10,14}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,4},{18,2}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This is the model of the deaerator, positioned in between high and low pressure feedwater trains. Its aim is actually not to simulate the deaeration phenomenon, which does not have a strong impact on the OTSG dynamics, but to take into account the thermal mixing dynamic of the streams involved. Moreover, no heat exchange surface is involved: it an be modelled as a parallelepiped cavity at thermodynamic equilibrium, where all the entering flow mix up. The hypothesis of thermal equilibrium within the vessel is reasonable, since it promotes the gases dissolution from feedwater mass flow. The steam blown away through the discharge valve is not taken into account within balances, since it is a small fraction and it is constantly replaced by the make-up water line (here not represented).</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">The selected state are liquid level and, pressure and enthalpy (liquid mass balance, vapour mass and energy steam balances). </span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">Modelling assumptions:</span></p>
<ul>
<li><span style=\"font-family: MS Shell Dlg 2;\">level set point = 2.0545 m. The design feedwater reservoir is 66 m3, with a corresponding vapour volumes of 20 m3: the vessel is supposed to be 12 m long, with a squared lateral section of 2.677*2.677 m2. Thus, the set point level can be evaluated as 66/(12*2.677) = 2.0545 m;</span></li>
</ul>
</html>"));
        end Deaerator;

        model Deaerator_controlled
          "Model of the deaerator, with level and pressure control interfaces"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=L*H "Cross Sectional Area";
          parameter Modelica.SIunits.Length L "tank length";
          parameter Modelica.SIunits.Height H "Height of the tank (squared)";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure";

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{40,30},{60,50}},
                  rotation=0), iconTransformation(extent={{26,70},{46,90}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-120},{10,-100}})));
          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-80,-30},{-60,-10}},
                  rotation=0), iconTransformation(extent={{-140,-80},{-120,-60}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-100,10},{-80,30}},
                  rotation=0), iconTransformation(extent={{-48,10},{-28,30}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{96,-20},{136,20}}), iconTransformation(extent={{60,-130},{100,
                    -90}})));
          Deaerator deaerator(
            L=L,
            H=H,
            zl_start=zl_start,
            p_start=p_start,
            h_start=h_start,
            w_small=w_small,
            redeclare package Medium = Medium,
            noInitialPressure=noInitialPressure)
            annotation (Placement(transformation(extent={{-40,-40},{40,40}})));
          ThermoPower.Water.ValveVap valveVap(
            thetanom=0.8,
            Fxt_full=0.4542722663,
            wnom=91.28,
            Av=0.053642779*0.3,
            redeclare package Medium = Medium,
            pnom=17100000,
            dpnom=100000,
            CheckValve=true)
                          annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={-50,20})));
        equation
          connect(deaerator.water_in, water_in) annotation (Line(points={{10.2857,
                  22.8571},{27.1428,22.8571},{27.1428,40},{50,40}},
                                                           color={0,0,255}));
          connect(deaerator.drained_out, drained_out)
            annotation (Line(points={{0,-31.4286},{0,-80}}, color={0,0,255}));
          connect(signalBus.valveDEA_PV, deaerator.p_dea) annotation (Line(
              points={{116,0},{116,0},{116,56},{116,80},{-20,80},{-20,18},{-16,
                  18},{-16,17.1429},{-10.8571,17.1429}},
              color={255,204,51},
              thickness=0.5));
          connect(drained_in, deaerator.drained_in) annotation (Line(points={{-70,-20},
                  {-37.1429,-20}},               color={0,0,255}));
          connect(signalBus.pumpCOND_PV, deaerator.level) annotation (Line(
              points={{116,0},{116,-22.8571},{37.1429,-22.8571}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDEA_CS, valveVap.theta) annotation (Line(
              points={{116,0},{116,0},{116,80},{-20,80},{-50,80},{-50,28}},
              color={255,204,51},
              thickness=0.5));
          connect(steam_in, valveVap.inlet) annotation (Line(points={{-90,20},{
                  -75,20},{-60,20}}, color={0,0,255}));
          connect(valveVap.outlet, deaerator.steam_in) annotation (Line(points={{-40,20},
                  {-28,20},{-28,5.71429},{-10.8571,5.71429}},           color={
                  0,0,255}));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}), graphics={
                Rectangle(
                  extent={{-120,-10},{120,-92}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-10},{-116,-4},{-106,0},{-90,0},{-84,0},{-78,0},{-70,0},
                      {110,0},{116,-4},{120,-10},{-62,-10},{-120,-10}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-92},{-118,-98},{-114,-100},{-110,-100},{-106,-100},{-100,
                      -100},{-92,-100},{-86,-100},{114,-100},{118,-96},{120,-92},{-120,-92}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-34},{112,-88}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-16},{112,-34}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-16},{-110,-10},{-102,-8},{104,-8},{110,-10},{112,-16},{
                      -106,-16},{-112,-16}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-88},{-110,-92},{-104,-94},{0,-94},{106,-94},{110,-92},{
                      112,-88},{-112,-88}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,90},{26,0}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,90},{-26,96},{-20,100},{2,100},{8,100},{14,100},{16,100},
                      {22,98},{24,96},{26,90},{26,90},{-28,90}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-20,84},{-20,90},{-16,92},{14,92},{18,90},{18,84},{-14,84},{-20,
                      84}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,84},{18,-10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,76},{18,74}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,64},{10,62}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,40},{10,38}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,52},{18,50}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,28},{18,26}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,16},{10,14}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,4},{18,2}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid)}), Diagram(coordinateSystem(
                  preserveAspectRatio=false, extent={{-140,-140},{140,140}})),
            Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">This model is an extension of the deaerator base model. It has an intercepting valve on bleed steam line (supposed to control deaerator pressure but WRONG ASSUMPTION).</span></p>
</html>"));
        end Deaerator_controlled;

        model Desuperheaters_controlled
          "Model of the desuperheaters used for hot start-up optimization"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Temperature T_start1
            "Start temperature of ramp 1";
          parameter Modelica.SIunits.Temperature T_end1
            "End temperature of ramp 1";
          parameter Modelica.SIunits.Time t_start1 "Start time of ramp 1";
          parameter Modelica.SIunits.Time t_end1 "End time of ramp 1";
          parameter Modelica.SIunits.Temperature T_start2
            "Start temperature of ramp 2";
          parameter Modelica.SIunits.Temperature T_end2
            "End temperature of ramp 2";
          parameter Modelica.SIunits.Time t_start2 "Start time of ramp 2";
          parameter Modelica.SIunits.Time t_end2 "End time of ramp 2";
          parameter Real TS_valves "Tracking signal" annotation (Dialog(tab="General"));

          //-- valveDES_SH --
          parameter Modelica.SIunits.Area Av_valveDES_SH = 2.32e-4
            "Valve flow coefficient"                                                        annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Real Kp_valveDES_SH = -0.01 "Controller proportional gain"
                                                                              annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Modelica.SIunits.Time Ti_valveDES_SH = 0.5
            "Controller integral time"                                                    annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Real CSmin_valveDES_SH = 0
            "Minimum value of control signal"                                annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Real CSmax_valveDES_SH = 1
            "Maximum value of control signal"                                annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Real CSstart_valveDES_SH = 0.5 "Start value of CS"
                                                                      annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Real actuatorGain_valveDES_SH = 1 "Actuator gain" annotation (Dialog(tab="General",group="SH - desuperheating"));
          parameter Modelica.SIunits.Time Ta_valveDES_SH = 0.3
            "Actuator time constant"                                                    annotation (Dialog(tab="General",group="SH - desuperheating"));

          //-- valveDES_RH --
          parameter Modelica.SIunits.Area Av_valveDES_RH = 4.32e-4
            "Valve flow coefficient"                                                        annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Real Kp_valveDES_RH = -0.01 "Controller proportional gain"
                                                                              annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Modelica.SIunits.Time Ti_valveDES_RH = 0.5
            "Controller integral time"                                                    annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Real CSmin_valveDES_RH = 0
            "Minimum value of control signal"                                annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Real CSmax_valveDES_RH = 1
            "Maximum value of control signal"                                annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Real CSstart_valveDES_RH = 0.5 "Start value of CS"
                                                                      annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Real actuatorGain_valveDES_RH = 1 "Actuator gain" annotation (Dialog(tab="General",group="RH - desuperheating"));
          parameter Modelica.SIunits.Time Ta_valveDES_RH = 0.3
            "Actuator time constant"                                                    annotation (Dialog(tab="General",group="RH - desuperheating"));

          ThermoPower.Water.SourcePressure sourcePressure(
            use_in_p0=true,
            use_in_h=true,
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-98,-50},{-78,-30}})));
          Modelica.Blocks.Tables.CombiTable1D DES_P_source(smoothness=
                Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                86.44e5; 30,89.06e5; 40,92.25e5; 50,99.52e5; 60,120e5; 70,
                132.8e5; 80,148.8e5; 90,164.2e5; 100,178.7e5]) annotation (
              Placement(transformation(extent={{-138,-30},{-118,-10}})));
          Modelica.Blocks.Tables.CombiTable1D DES_H_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{-138,10},{-118,30}})));
          ThermoPower.Water.ValveLiq valveRH(
            wnom=2,
            CheckValve=true,
            redeclare package Medium = Medium,
            Av=Av_valveDES_RH,
            pnom=8700000,
            dpnom=7200000) annotation (Placement(transformation(extent={{-40,16},{-20,36}})));
          ThermoPower.Water.Mixer desRH(
            noInitialPressure=true,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
            V=0.5,
            redeclare package Medium = Medium,
            hstart=3600000,
            pstart=864100)  annotation (Placement(transformation(extent={{18,10},{38,30}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = Medium)
                                                   annotation (Placement(
                transformation(extent={{50,14},{70,34}})));
          Modelica.Blocks.Sources.Ramp SP_ramp1(
            offset=0,
            height=T_end1 - T_start1,
            duration=t_end1 - t_start1,
            startTime=t_start1)
            annotation (Placement(transformation(extent={{200,-10},{180,10}})));
          IndustrialControlSystems.Controllers.PI PI_valveSH(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_valveDES_SH,
            CSmax=CSmax_valveDES_SH,
            CS_start=CSstart_valveDES_SH,
            Kp=Kp_valveDES_SH,
            Ti=Ti_valveDES_SH)
                      annotation (Placement(transformation(extent={{80,-60},{60,
                    -40}})));
          IndustrialControlSystems.Controllers.PI PI_valveRH(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_valveDES_RH,
            CSmax=CSmax_valveDES_RH,
            CS_start=CSstart_valveDES_RH,
            Kp=Kp_valveDES_RH,
            Ti=Ti_valveDES_RH)
                      annotation (Placement(transformation(extent={{80,60},{60,80}})));
          Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveDES_RH,
            T=Ta_valveDES_RH)
            annotation (Placement(transformation(extent={{0,60},{-20,80}})));
          Modelica.Blocks.Continuous.FirstOrder valveSH_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveDES_SH,
            T=Ta_valveDES_SH)
                   annotation (Placement(transformation(extent={{0,-60},{-20,
                    -40}})));
          Modelica.Blocks.Nonlinear.Limiter valveRH_lim(uMax=1, uMin=0)
            annotation (Placement(transformation(extent={{40,60},{20,80}})));
          Modelica.Blocks.Nonlinear.Limiter valveSH_lim(uMax=1, uMin=0)
            annotation (Placement(transformation(extent={{40,-60},{20,-40}})));
          Modelica.Blocks.Sources.Constant const(k=TS_valves)
            annotation (Placement(transformation(extent={{160,-40},{140,-20}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=t_end2)
            annotation (Placement(transformation(extent={{140,100},{120,120}})));
          ThermoPower.Water.Mixer desSH(
            noInitialPressure=true,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
            V=0.5,
            redeclare package Medium = Medium,
            hstart=3542000,
            pstart=8508000) annotation (Placement(transformation(extent={{58,-110},{78,-90}})));
          ThermoPower.Water.SensT sensT_SH(redeclare package Medium = Medium)
                                                   annotation (Placement(
                transformation(extent={{90,-106},{110,-86}})));
          ThermoPower.Water.ValveLiq valveSH(
            wnom=2.2,
            CheckValve=true,
            redeclare package Medium = Medium,
            Av=Av_valveDES_SH,
            pnom=8700000,
            dpnom=200000) annotation (Placement(transformation(extent={{-38,
                    -104},{-18,-84}})));
          ThermoPower.Water.FlangeA SH_in(redeclare package Medium = Medium)
                                          annotation (Placement(transformation(extent={{50,-160},
                    {70,-140}}),          iconTransformation(extent={{70,-220},{90,-200}})));
          ThermoPower.Water.FlangeB SH_out(redeclare package Medium = Medium)
                                           annotation (Placement(transformation(extent={
                    {130,-110},{150,-90}}), iconTransformation(extent={{200,-90},{220,-70}})));
          Modelica.Blocks.Interfaces.RealInput load annotation (Placement(
                transformation(extent={{-198,-20},{-158,20}}), iconTransformation(
                  extent={{-240,-20},{-200,20}})));
          ThermoPower.Water.FlangeA RH_in(redeclare package Medium = Medium)
                                          annotation (Placement(transformation(extent={{10,-22},
                    {30,-2}}),         iconTransformation(extent={{-80,-220},{-60,-200}})));
          ThermoPower.Water.FlangeB RH_out(redeclare package Medium = Medium)
                                           annotation (Placement(transformation(extent={
                    {130,10},{150,30}}), iconTransformation(extent={{200,70},{220,90}})));
          Modelica.Blocks.Sources.Ramp SP_initial(
            duration=500,
            offset=823.15,
            startTime=1000,
            height=T_start1 - 823.15)
            annotation (Placement(transformation(extent={{200,30},{180,50}})));
          Modelica.Blocks.Math.Add3 add
            annotation (Placement(transformation(extent={{166,-6},{154,6}})));
          Modelica.Blocks.Sources.Ramp SP_ramp2(
            offset=0,
            height=T_end2 - T_start2,
            duration=t_end2 - t_start2,
            startTime=t_start2)
            annotation (Placement(transformation(extent={{200,-50},{180,-30}})));
        equation
          connect(DES_H_source.y[1],sourcePressure. in_h) annotation (Line(
                points={{-117,20},{-84,20},{-84,-31}},     color={0,0,127}));
          connect(DES_P_source.y[1],sourcePressure. in_p0) annotation (Line(
                points={{-117,-20},{-92,-20},{-92,-30.8}},   color={0,0,127}));
          connect(valveRH.outlet,desRH. in1) annotation (Line(points={{-20,26},{-20,26},
                  {20,26}},                   color={0,0,255}));
          connect(desRH.out,sensT_RH. inlet)
            annotation (Line(points={{38,20},{38,20},{54,20}},
                                                           color={0,0,255}));
          connect(sensT_SH.T,PI_valveSH. PV) annotation (Line(points={{108,-90},
                  {120,-90},{120,-51},{78,-51}},   color={0,0,127}));
          connect(valveRH_dynamic.u,valveRH_lim. y)
            annotation (Line(points={{2,70},{19,70}},      color={0,0,127}));
          connect(valveRH_lim.u,PI_valveRH. CS)
            annotation (Line(points={{42,70},{61,70}},     color={0,0,127}));
          connect(valveSH_dynamic.u,valveSH_lim. y)
            annotation (Line(points={{2,-50},{19,-50}},    color={0,0,127}));
          connect(valveSH_lim.u,PI_valveSH. CS) annotation (Line(points={{42,-50},
                  {42,-50},{61,-50}},        color={0,0,127}));
          connect(booleanStep.y,PI_valveRH. TS) annotation (Line(points={{119,110},{119,
                  110},{66,110},{66,78}},              color={255,0,255}));
          connect(SH_in, desSH.in2)
            annotation (Line(points={{60,-150},{60,-150},{60,-106}}, color={0,0,255}));
          connect(valveSH.outlet, desSH.in1)
            annotation (Line(points={{-18,-94},{-20,-94},{60,-94}},color={0,0,255}));
          connect(desSH.out, sensT_SH.inlet)
            annotation (Line(points={{78,-100},{94,-100}}, color={0,0,255}));
          connect(sensT_SH.outlet, SH_out)
            annotation (Line(points={{106,-100},{140,-100}}, color={0,0,255}));
          connect(sourcePressure.flange, valveSH.inlet) annotation (Line(points={{-78,-40},
                  {-60,-40},{-60,-94},{-38,-94}}, color={0,0,255}));
          connect(valveSH_dynamic.y, valveSH.theta)
            annotation (Line(points={{-21,-50},{-28,-50},{-28,-86}}, color={0,0,127}));
          connect(sourcePressure.flange, valveRH.inlet) annotation (Line(points={{-78,-40},
                  {-72,-40},{-60,-40},{-60,26},{-40,26}}, color={0,0,255}));
          connect(RH_in, desRH.in2)
            annotation (Line(points={{20,-12},{20,1},{20,14}}, color={0,0,255}));
          connect(valveRH_dynamic.y, valveRH.theta)
            annotation (Line(points={{-21,70},{-30,70},{-30,34}}, color={0,0,127}));
          connect(sensT_RH.outlet, RH_out)
            annotation (Line(points={{66,20},{140,20}},          color={0,0,255}));
          connect(sensT_RH.T, PI_valveRH.PV) annotation (Line(points={{68,30},{100,30},{
                  100,69},{78,69}}, color={0,0,127}));
          connect(booleanStep.y, PI_valveSH.TS) annotation (Line(points={{119,110},
                  {90,110},{90,-20},{66,-20},{66,-42}},
                                               color={255,0,255}));
          connect(const.y, PI_valveSH.TR) annotation (Line(points={{139,-30},{
                  106,-30},{70,-30},{70,-42}},
                                     color={0,0,127}));
          connect(const.y, PI_valveRH.TR) annotation (Line(points={{139,-30},{110,-30},{
                  110,90},{70,90},{70,78}}, color={0,0,127}));
          connect(load, DES_H_source.u[1]) annotation (Line(points={{-178,0},{
                  -148,0},{-148,20},{-140,20}},
                                  color={0,0,127}));
          connect(load, DES_P_source.u[1]) annotation (Line(points={{-178,0},{
                  -164,0},{-148,0},{-148,-20},{-140,-20}},
                                             color={0,0,127}));
          connect(SP_ramp1.y, add.u2)
            annotation (Line(points={{179,0},{172,0},{167.2,0}}, color={0,0,127}));
          connect(SP_initial.y, add.u1) annotation (Line(points={{179,40},{172,40},{172,
                  4.8},{167.2,4.8}},          color={0,0,127}));
          connect(add.y, PI_valveSH.SP) annotation (Line(points={{153.4,0},{120,
                  0},{120,-44},{78,-44}}, color={0,0,127}));
          connect(add.y, PI_valveRH.SP) annotation (Line(points={{153.4,0},{138,
                  0},{120,0},{120,76},{78,76}}, color={0,0,127}));
          connect(SP_ramp2.y, add.u3) annotation (Line(points={{179,-40},{172,-40},{172,
                  -4.8},{167.2,-4.8}}, color={0,0,127}));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-200},
                    {200,200}}), graphics={
                Rectangle(
                  extent={{-200,200},{200,-200}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{60,-60},{100,-100}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{40,-80},{80,-80},{100,-66}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{80,-80},{100,-80}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{80,-80},{100,-92}},
                  color={0,0,255},
                  thickness=0.5),
                Rectangle(
                  extent={{-90,100},{-50,60}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-110,80},{-70,80},{-50,94}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-70,80},{-50,80}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-70,80},{-50,68}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{80,-200},{80,-100}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-70,-198},{-70,60}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-48,80},{196,80}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{100,-80},{200,-80}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-146,180},{154,132}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  textString="DESUPERHEATERS")}), Diagram(coordinateSystem(
                  preserveAspectRatio=false, extent={{-200,-200},{200,200}})));
        end Desuperheaters_controlled;

        model MSmixer_warm
          "Model of the hot/cold molten salt mixing for hot start up and warmkeeping "

          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Media.MoltenSalt60_40_quad,
            h=101200,
            p0=116000)
            annotation (Placement(transformation(extent={{-140,30},{-120,50}})));
          ThermoPower.Water.ThroughMassFlow
                                 coldPump(
            redeclare package Medium = Media.MoltenSalt60_40_quad,
            w0=9,
            allowFlowReversal=false,
            use_in_w0=true)
            annotation (Placement(transformation(extent={{-62,30},{-42,50}})));
          ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
                Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-98,34},{-78,54}})));
          ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
                Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{20,6},{40,-14}})));
          ThermoPower.Water.SourceMassFlow hotPump(
            h=518322,
            use_in_w0=true,
            redeclare package Medium = Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-100,0},{-80,-20}})));
          IndustrialControlSystems.Controllers.PI PI_T_MSin(
            AntiWindup=true,
            Ti=20,
            useTS=true,
            CSmin=1,
            CSmax=700,
            CS_start=600,
            Kp=0.5)
            annotation (Placement(transformation(extent={{10,-60},{-10,-80}})));
          Modelica.Blocks.Continuous.FirstOrder hotPumpDynamic(T=2, initType=
                Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(extent={{-20,-80},{-40,-60}})));
          Modelica.Blocks.Math.Add3 add3
            annotation (Placement(transformation(extent={{120,-92},{100,-72}})));
          Modelica.Blocks.Sources.Constant const3(k=0)
            annotation (Placement(transformation(extent={{160,-64},{140,-44}})));
          Modelica.Blocks.Sources.Step step(
            offset=0,
            height=100,
            startTime=20000)
            annotation (Placement(transformation(extent={{160,-96},{140,-76}})));
          Modelica.Blocks.Sources.Ramp ramp(
            height=-275,
            duration=4000,
            offset=838.15,
            startTime=5000)
            annotation (Placement(transformation(extent={{100,-50},{80,-30}})));
          ThermoPower.Water.FlowJoin
                                  mixer(
            redeclare package Medium = Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
          Modelica.Blocks.Continuous.FirstOrder coldPumpDynamic(T=2, initType=
                Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-20,60},{-40,80}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(
              startValue=true, startTime=5000)
            annotation (Placement(transformation(extent={{-40,-130},{-20,-110}})));
          ThermoPower.Water.SensW sensW(redeclare package Medium =
                Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{60,-6},{80,14}})));
          IndustrialControlSystems.Controllers.PI PI_w_MSin(
            Ti=5,
            useTS=true,
            CS_start=0,
            Kp=0.1,
            CSmax=700,
            CSmin=1)
            annotation (Placement(transformation(extent={{20,60},{0,80}})));
          Modelica.Blocks.Sources.Constant const5(k=0)
            annotation (Placement(transformation(extent={{40,100},{20,120}})));
          ThermoPower.Water.FlangeB flangeB(redeclare package Medium =
                Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{150,-10},{170,10}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{-100,-140},{-60,-100}}),
                iconTransformation(extent={{-20,-160},{20,-120}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep1(
              startValue=true, startTime=5000)
            annotation (Placement(transformation(extent={{-40,100},{-20,120}})));
          Modelica.Blocks.Logical.Switch switch
            annotation (Placement(transformation(extent={{-60,-68},{-80,-88}})));
          Modelica.Blocks.Sources.Constant const1(k=120)
            annotation (Placement(transformation(extent={{34,-110},{14,-90}})));
          Modelica.Blocks.Sources.Ramp w_tot1(
            height=10.598,
            duration=1080,
            offset=0,
            startTime=20000)
            annotation (Placement(transformation(extent={{100,54},{80,74}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{60,-86},{40,-66}})));
          Modelica.Blocks.Math.Add add1
            annotation (Placement(transformation(extent={{60,66},{40,86}})));
          Modelica.Blocks.Sources.Ramp ramp1(
            height=175,
            duration=1080,
            offset=0,
            startTime=20000)
            annotation (Placement(transformation(extent={{160,-130},{140,-110}})));
          Modelica.Blocks.Sources.Ramp w_tot2(
            duration=4000,
            startTime=5000,
            offset=120,
            height=-100)
            annotation (Placement(transformation(extent={{100,90},{80,110}})));
          Modelica.Blocks.Nonlinear.Limiter pumpCold_lim(uMin=0, uMax=700)
            annotation (Placement(transformation(extent={{-46,68},{-50,72}})));
          Modelica.Blocks.Nonlinear.Limiter pumpHot_lim(uMin=0, uMax=700)
            annotation (Placement(transformation(extent={{-46,-72},{-50,-68}})));
        equation
          connect(sourcePressure.flange,sensT_cold. inlet)
            annotation (Line(points={{-120,40},{-108,40},{-102,40},{-94,40}},
                                                       color={0,0,255}));
          connect(sensT_mix.T, PI_T_MSin.PV) annotation (Line(points={{38,-10},
                  {40,-10},{40,-30},{20,-30},{20,-69},{8,-69}}, color={0,0,127}));
          connect(hotPumpDynamic.u, PI_T_MSin.CS)
            annotation (Line(points={{-18,-70},{-9,-70}}, color={0,0,127}));
          connect(const3.y,add3. u1) annotation (Line(points={{139,-54},{132,
                  -54},{132,-74},{122,-74}},
                             color={0,0,127}));
          connect(step.y,add3. u2) annotation (Line(points={{139,-86},{132,-86},{
                  132,-82},{122,-82}},
                            color={0,0,127}));
          connect(hotPump.flange, mixer.in2) annotation (Line(points={{-80,-10},{
                  -6,-10},{-6,-4}},                  color={0,0,255}));
          connect(mixer.out,sensT_mix. inlet)
            annotation (Line(points={{6,0},{6,0},{24,0}},   color={0,0,255}));
          connect(sensT_mix.outlet,sensW. inlet)
            annotation (Line(points={{36,0},{64,0}}, color={0,0,255}));
          connect(coldPumpDynamic.u, PI_w_MSin.CS)
            annotation (Line(points={{-18,70},{1,70}}, color={0,0,127}));
          connect(sensW.w, PI_w_MSin.PV) annotation (Line(points={{78,10},{80,
                  10},{80,48},{30,48},{30,69},{18,69}}, color={0,0,127}));
          connect(const5.y, PI_w_MSin.TR) annotation (Line(points={{19,110},{10,
                  110},{10,78}}, color={0,0,127}));
          connect(booleanStep1.y, PI_w_MSin.TS) annotation (Line(points={{-19,
                  110},{6,110},{6,78}}, color={255,0,255}));
          connect(const1.y, PI_T_MSin.TR) annotation (Line(points={{13,-100},{0,
                  -100},{0,-78}}, color={0,0,127}));
          connect(booleanStep.y, PI_T_MSin.TS) annotation (Line(points={{-19,-120},
                  {-4,-120},{-4,-78}}, color={255,0,255}));
          connect(booleanStep.y, switch.u2) annotation (Line(points={{-19,-120},{
                  -4,-120},{-4,-92},{-46,-92},{-46,-78},{-58,-78}}, color={255,0,
                  255}));
          connect(signalBus.pumpMS_CS, switch.u1) annotation (Line(
              points={{-80,-120},{-52,-120},{-52,-86},{-58,-86}},
              color={255,204,51},
              thickness=0.5));
          connect(switch.y, hotPump.in_w0) annotation (Line(points={{-81,-78},{
                  -94,-78},{-94,-16}}, color={0,0,127}));
          connect(sensT_cold.outlet, coldPump.inlet) annotation (Line(points={{-82,40},
                  {-62,40}},                  color={0,0,255}));
          connect(coldPump.outlet, mixer.in1)
            annotation (Line(points={{-42,40},{-6,40},{-6,4}}, color={0,0,255}));
          connect(add3.y, add.u2) annotation (Line(points={{99,-82},{80,-82},{62,
                  -82}}, color={0,0,127}));
          connect(ramp.y, add.u1) annotation (Line(points={{79,-40},{72,-40},{72,
                  -70},{62,-70}}, color={0,0,127}));
          connect(ramp1.y, add3.u3) annotation (Line(points={{139,-120},{132,-120},
                  {132,-90},{122,-90}}, color={0,0,127}));
          connect(w_tot2.y, add1.u1) annotation (Line(points={{79,100},{70,100},{
                  70,82},{62,82}}, color={0,0,127}));
          connect(pumpCold_lim.u, coldPumpDynamic.y)
            annotation (Line(points={{-45.6,70},{-41,70}}, color={0,0,127}));
          connect(pumpCold_lim.y, coldPump.in_w0) annotation (Line(points={{-50.2,
                  70},{-56,70},{-56,46}}, color={0,0,127}));
          connect(switch.u3, pumpHot_lim.y) annotation (Line(points={{-58,-70},
                  {-50.2,-70}},            color={0,0,127}));
          connect(pumpHot_lim.u, hotPumpDynamic.y)
            annotation (Line(points={{-45.6,-70},{-41,-70}}, color={0,0,127}));
          connect(w_tot1.y, add1.u2) annotation (Line(points={{79,64},{70,64},{
                  70,70},{62,70}}, color={0,0,127}));
          connect(sensW.outlet, flangeB)
            annotation (Line(points={{76,0},{160,0}}, color={0,0,255}));
          connect(w_tot2.y, PI_w_MSin.SP) annotation (Line(points={{79,100},{50,
                  100},{50,92},{26,92},{26,76},{18,76}}, color={0,0,127}));
          connect(ramp.y, PI_T_MSin.SP) annotation (Line(points={{79,-40},{30,
                  -40},{30,-76},{8,-76}}, color={0,0,127}));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                    -160,-140},{160,140}}), graphics={
                Rectangle(
                  extent={{-160,140},{160,-140}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-122,-44},{-60,-104}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{-60,-36},{-122,-52}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{-60,-96},{-122,-112}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-116,-62},{-66,-90}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid,
                  textString="COLD MS"),
                Rectangle(
                  extent={{-120,98},{-58,38}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{-58,106},{-120,90}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,0,0},
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{-58,46},{-120,30}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-110,76},{-68,56}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={175,175,175},
                  fillPattern=FillPattern.Solid,
                  textString="HOT MS"),
                Line(
                  points={{-60,-80},{0,-80}},
                  color={0,0,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Ellipse(
                  extent={{0,-72},{16,-88}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.Sphere,
                  fillColor={0,0,255}),
                Polygon(
                  points={{4,-76},{4,-84},{14,-80},{4,-76}},
                  lineColor={0,0,0},
                  pattern=LinePattern.None,
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={255,255,255}),
                Ellipse(
                  extent={{0,68},{16,52}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.Sphere,
                  fillColor={0,0,255}),
                Polygon(
                  points={{4,64},{4,56},{14,60},{4,64}},
                  lineColor={0,0,0},
                  pattern=LinePattern.None,
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={255,255,255}),
                Line(
                  points={{-58,60},{0,60}},
                  color={0,0,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{16,60},{40,60},{40,0},{150,0}},
                  color={0,0,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{16,-80},{40,-80},{40,0}},
                  color={0,0,0},
                  thickness=0.5)}),          Diagram(coordinateSystem(
                  preserveAspectRatio=false, extent={{-160,-140},{160,140}})));
        end MSmixer_warm;

        package Test

          model test_nonEquilibrium_vessel_dryout
            "The vessel starts with some liquid, which is blown away by incoming steam"
            extends Modelica.Icons.Example;
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=92.49)
              annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=20,
              startTime=10,
              offset=2272800,
              height=6e5)
              annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
            nonEquilibriumVessel     vessel(
              D=0.56,
              H=8,
              noInitialPressure=true,
              gamma=0,
              hv_start=2.7e6,
              hl_start=1.3e6,
              zl_start=0.25,
              p_start=17710000) annotation (Placement(transformation(extent={{-18,-40},
                      {40,16}})));
            ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,20},{40,40}})));
          equation
            connect(ramp.y, sourceMassFlow.in_h) annotation (Line(
                points={{-39,20},{-26,20},{-26,-14}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(vessel.water_in, sourceMassFlow.flange) annotation (Line(
                points={{0.642857,-20},{-20,-20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(vessel.steam_out, sinkMassFlow.flange) annotation (Line(
                points={{11,12},{11,30},{20,30}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics), Icon(coordinateSystem(extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=50),
              __Dymola_experimentSetupOutput);
          end test_nonEquilibrium_vessel_dryout;

          model test_nonEquilibrium_vessel_filling
            "The vessel starts completely dry, then is filled by incoming wet steam"
            extends Modelica.Icons.Example;
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=92.49)
              annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=2872800,
              height=-6e5,
              duration=20,
              startTime=10)
              annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
            nonEquilibriumVessel     vessel(
              D=0.56,
              H=8,
              noInitialPressure=true,
              gamma=0,
              hv_start=2.7e6,
              hl_start=1.3e6,
              zl_start=0.25,
              p_start=17710000)                                     annotation (
               Placement(transformation(extent={{-20,-40},{40,16}})));
            ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{20,20},{40,40}})));
          equation
            connect(ramp.y, sourceMassFlow.in_h) annotation (Line(
                points={{-39,20},{-26,20},{-26,-14}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(vessel.water_in, sourceMassFlow.flange) annotation (Line(
                points={{-0.714286,-20},{-20,-20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(vessel.steam_out, sinkMassFlow.flange) annotation (Line(
                points={{10,12},{10,30},{20,30}},
                color={0,0,255},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}}),        graphics), Icon(coordinateSystem(extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=200),
              __Dymola_experimentSetupOutput);
          end test_nonEquilibrium_vessel_filling;

          model test_nonEquilibrium_vessel
            "Model test to check the non equilibrium vessel model"
            extends Modelica.Icons.Example;
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=22.49)
              annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=2872800,
              height=-(2872800 - 2272800),
              duration=100,
              startTime=5)
              annotation (Placement(transformation(extent={{-90,30},{-70,50}})));
            nonEquilibriumVessel             vessel(
              D=0.56,
              H=8,
              noInitialPressure=true,
              zl_start=1,
              noInitialLevel=false,
              gamma=0,
              hv_start=2.7e6,
              hl_start=1.3e6,
              p_start=17710000)
              annotation (Placement(transformation(extent={{-44,-18},{4,30}})));
            ThermoPower.Water.SinkPressure sinkMassFlow(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17700000)
              annotation (Placement(transformation(extent={{-10,50},{10,70}})));
            ThermoPower.Water.ValveLiq valveLiq(
              wnom=15,
              Av=5e-4*0.7,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=8500000,
              dpnom=1000000)
              annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, p0=7500000)
              annotation (Placement(transformation(extent={{40,-90},{60,-70}})));
            Modelica.Blocks.Logical.Switch switch1 annotation (Placement(
                  transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={10,-46})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{-6,-40},{2,-32}})));
            Modelica.Blocks.Sources.Constant const1(k=1)
              annotation (Placement(transformation(extent={{26,-40},{18,-32}})));
            Modelica.Blocks.Continuous.FirstOrder valveDRAIN_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=1) annotation (Placement(transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=270,
                  origin={10,-62})));
            Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=
                  56)
              annotation (Placement(transformation(extent={{26,-8},{20,-2}})));
            Modelica.Blocks.Logical.Hysteresis       greaterThreshold1(uLow=0.2,
                uHigh=0.3)
              annotation (Placement(transformation(extent={{-4,-10},{4,-2}})));
            Modelica.Blocks.Logical.And and1
              annotation (Placement(transformation(extent={{4,-4},{-4,4}},
                  rotation=90,
                  origin={10,-22})));
            Modelica.Blocks.Sources.Constant const2(k=80)
              annotation (Placement(transformation(extent={{54,8},{34,28}})));
            Modelica.Blocks.Sources.Ramp ramp1(
              duration=100,
              startTime=5,
              offset=2272800,
              height=(2872800 - 2272800))
              annotation (Placement(transformation(extent={{-90,70},{-70,90}})));
          equation
            connect(vessel.water_in, sourceMassFlow.flange) annotation (Line(
                points={{-28.5714,-0.857143},{-28.5714,0},{-50,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(vessel.steam_out, sinkMassFlow.flange) annotation (Line(
                points={{-20,26.5714},{-20,60},{-10,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveLiq.outlet,sinkPressure. flange) annotation (Line(
                points={{20,-80},{30,-80},{40,-80}},
                color={0,0,255},
                thickness=0.5));
            connect(const.y,switch1. u3) annotation (Line(points={{2.4,-36},{
                    5.2,-36},{5.2,-38.8}},
                                      color={0,0,127}));
            connect(const1.y,switch1. u1) annotation (Line(points={{17.6,-36},{
                    14.8,-36},{14.8,-38.8}},
                                           color={0,0,127}));
            connect(switch1.y,valveDRAIN_dynamic. u)
              annotation (Line(points={{10,-52.6},{10,-57.2}},
                                                             color={0,0,127}));
            connect(valveDRAIN_dynamic.y,valveLiq. theta)
              annotation (Line(points={{10,-66.4},{10,-72}},
                                                           color={0,0,127}));
            connect(and1.y,switch1. u2) annotation (Line(points={{10,-26.4},{10,
                    -26.4},{10,-38.8}},
                                color={255,0,255}));
            connect(vessel.drained_out, valveLiq.inlet) annotation (Line(points={{-20,
                    -9.42857},{-20,-80},{0,-80}},      color={0,0,255}));
            connect(const2.y, greaterThreshold.u) annotation (Line(points={{33,
                    18},{30,18},{30,-5},{26.6,-5}}, color={0,0,127}));
            connect(vessel.level, greaterThreshold1.u) annotation (Line(points={{
                    -11.4286,-6},{-11.4286,-6},{-4.8,-6}},    color={0,0,127}));
            connect(greaterThreshold1.y, and1.u1) annotation (Line(points={{4.4,-6},
                    {10,-6},{10,-17.2}},     color={255,0,255}));
            connect(greaterThreshold.y, and1.u2) annotation (Line(points={{19.7,
                    -5},{13.2,-5},{13.2,-17.2}}, color={255,0,255}));
            connect(ramp1.y, sourceMassFlow.in_h) annotation (Line(points={{-69,80},
                    {-56,80},{-56,6}},     color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})),                  Icon(coordinateSystem(extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=200),
              __Dymola_experimentSetupOutput);
          end test_nonEquilibrium_vessel;

          model test_NusseltCondenser_HPH2
            "Test of the condensing section of the last high pressure preheater"
            extends Modelica.Icons.Example;
            NusseltCondenser         baseNusseltCondenser(
              zl_set=0.1,
              zl_start=0.1,
              V=2.99*0.8,
              A=1,
              S=210*0.8,
              noInitialPressure=true,
              gamma=8000,
              Nw=5,
              p_start=8150000)
              annotation (Placement(transformation(extent={{-28,12},{28,68}})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-62,36},{-42,56}})));
            ThermoPower.Water.SourcePressure sourceMassFlow1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=8150000,
              h=2760e3)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.ValveLiq valveDrain(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=1.095752222e-6,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=8100000,
              dpnom=6300000,
              wnom=4.449,
              rhonom=900,
              thetanom=0.2,
              CheckValve=true,
              allowFlowReversal=false)
              annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.PowerPlants.Control.PID PID_level(
              PVmin=0,
              CSmin=0,
              steadyStateInit=true,
              PVmax=1,
              CSmax=1,
              PVstart=0.1,
              Ti=10,
              CSstart=0.2,
              Kp=-10)      annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-40,10})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=2037000)
              annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
            ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={34,40})));
            Modelica.Blocks.Sources.Step     T_in(
              height=-2,
              offset=563.15,
              startTime=1000)                               annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,60})));
            Modelica.Blocks.Sources.Constant T_out(k=567.15) annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,20})));
            Modelica.Blocks.Continuous.FirstOrder valveDynamic(      k=1,
              initType=Modelica.Blocks.Types.Init.InitialState,
              T=0.3,
              y_start=0.2)                                                annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-40,-20})));
          equation
            connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
              annotation (Line(
                points={{-20,80},{0,80},{0,64}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
              annotation (Line(
                points={{-42,46},{-26,46},{-26,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                points={{-10,26},{-44,26},{-44,20}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-10,38},{-36,38},{-36,20}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                  points={{0,-50},{0,-60},{20,-60}}, color={0,0,255}));
            connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
              annotation (Line(points={{0,22},{0,-30}},        color={0,0,255}));
            connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
               Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
            connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                  points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
            connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                  points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
            connect(PID_level.CS, valveDynamic.u)
              annotation (Line(points={{-40,0},{-40,-8}}, color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={
                    {-40,-31},{-40,-40},{-8,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=2000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false));
          end test_NusseltCondenser_HPH2;

          model test_NusseltCondenser_HPH1
            "Test of the condensing section of the first high pressure preheater"
            extends Modelica.Icons.Example;
            NusseltCondenser         baseNusseltCondenser(
              zl_set=0.1,
              zl_start=0.1,
              A=1,
              noInitialPressure=true,
              gamma=8000,
              Nw=5,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              V=2.01*0.8,
              S=300*0.8,
              p_start=1850000)
              annotation (Placement(transformation(extent={{-28,12},{28,68}})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{80,80},{100,100}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=4.449,
              h=998e3,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-62,38},{-42,58}})));
            ThermoPower.Water.SourcePressure sourceMassFlow1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=2796.2e3,
              p0=1815000)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.ValveLiq valveDrain(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph, Kv=1.095752222e-6,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              rhonom=900,
              thetanom=0.2,
              CheckValve=true,
              allowFlowReversal=false,
              wnom=7.484,
              pnom=1850000,
              dpnom=800000)
              annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.PowerPlants.Control.PID PID_level(
              PVmin=0,
              CSmin=0,
              steadyStateInit=true,
              PVmax=1,
              CSmax=1,
              PVstart=0.1,
              Ti=10,
              CSstart=0.2,
              Kp=-10)      annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-40,10})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1086000)
              annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
            ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={34,40})));
            Modelica.Blocks.Sources.Step     T_in(
              height=-2,
              startTime=1000,
              offset=474.15)                                annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,60})));
            Modelica.Blocks.Sources.Constant T_out(k=478.16) annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={70,20})));
            Modelica.Blocks.Continuous.FirstOrder valveDynamic(      k=1,
              initType=Modelica.Blocks.Types.Init.InitialState,
              T=0.3,
              y_start=0.2)                                                annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-40,-20})));
            Modelica.Blocks.Sources.Step step(
              startTime=2100,
              height=1,
              offset=4.449) annotation (Placement(transformation(extent={{-100,
                      60},{-80,80}})));
          equation
            connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
              annotation (Line(
                points={{-20,80},{0,80},{0,64}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
              annotation (Line(
                points={{-42,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                points={{-10,26},{-44,26},{-44,20}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-10,38},{-36,38},{-36,20}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                  points={{0,-50},{0,-60},{20,-60}}, color={0,0,255}));
            connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
              annotation (Line(points={{0,22},{0,-30}},        color={0,0,255}));
            connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
               Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
            connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                  points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
            connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                  points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
            connect(PID_level.CS, valveDynamic.u)
              annotation (Line(points={{-40,0},{-40,-8}}, color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={
                    {-40,-31},{-40,-40},{-8,-40}}, color={0,0,127}));
            connect(step.y, sourceMassFlow.in_w0) annotation (Line(points={{-79,70},
                    {-56,70},{-56,54}},     color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                      -100},{100,100}})),
              experiment(StopTime=4000),
              __Dymola_experimentSetupOutput);
          end test_NusseltCondenser_HPH1;

          model test_deaerator "Test model of the deaerator"

            extends Modelica.Icons.Example;

            Deaerator deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              h_start=1.2e6,
              p_start=1086000)
              annotation (Placement(transformation(extent={{-30,-22},{30,34}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=7.484,
              h=821.9e3,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{-60,2},{-40,-18}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3153e3,
              p0=1186000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,0},{-120,20}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=76.94,
              h=562.1e3,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{58,28},{38,48}})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
              CSmin=0,
              CSmax=100,
              Kp=500,
              Ti=100)        annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={90,-20})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=5)
                    annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={130,-20})));
            Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
              annotation (Placement(transformation(extent={{40,0},{60,20}})));
            ThermoPower.Water.SinkMassFlow    waterPump(
              use_in_w0=true,
              w0=88.59,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-54})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
            IndustrialControlSystems.Controllers.PI PID_pressure(
              CSmin=0,
              CSmax=1,
              Kp=0.0001,
              Ti=20) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=180,
                  origin={-40,40})));
            Modelica.Blocks.Continuous.FirstOrder valveDynamic(
                                                              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=0.3)
                    annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={-80,40})));
            Modelica.Blocks.Sources.Constant p_deaSP(k=10.86e5)
              annotation (Placement(transformation(extent={{10,54},{-10,74}})));
            Modelica.Blocks.Sources.Step step_pIN(
              offset=11.86e5,
              height=2e5,
              startTime=3000) annotation (Placement(transformation(extent={{-110,30},
                      {-130,50}})));
            Modelica.Blocks.Sources.Step step_wFW(
              offset=88.59,
              startTime=1000,
              height=10) annotation (Placement(transformation(extent={{60,-60},
                      {40,-40}})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=0.053642779*0.3,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=180,
                  origin={-100,10})));
            Modelica.Blocks.Sources.Step step_wFW1(
              height=1,
              offset=7.484,
              startTime=4000) annotation (Placement(transformation(extent={{-80,-50},
                      {-60,-30}})));
          equation
            connect(deaerator.drained_in, sourceMassFlow_DR.flange) annotation (
                Line(
                points={{-27.8571,-8},{-40,-8}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.water_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{7.71429,22},{20,22},{20,38},{38,38}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PID_level.CS,pumpDynamic. u) annotation (Line(
                points={{99,-20},{118,-20}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{61,10},{68,10},{68,-14},{82,-14}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.level, PID_level.PV) annotation (Line(
                points={{27.8571,-10},{54,-10},{54,-21},{82,-21}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.drained_out, waterPump.flange) annotation (Line(
                points={{0,-16},{0,-44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PID_pressure.CS, valveDynamic.u) annotation (Line(points={{-49,40},
                    {-49,40},{-68,40}},         color={0,0,127}));
            connect(step_pIN.y, sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{-131,40},{-134,40},{-134,19.2}},  color={0,0,127}));
            connect(sourceMassFlow_ST.flange, valveVap.inlet) annotation (Line(
                  points={{-120,10},{-115,10},{-110,10}},    color={0,0,255}));
            connect(valveVap.outlet, deaerator.steam_in) annotation (Line(
                  points={{-90,10},{-8.14286,10}},   color={0,0,255}));
            connect(valveVap.theta, valveDynamic.y) annotation (Line(points={{-100,18},
                    {-100,18},{-100,40},{-91,40}},            color={0,0,127}));
            connect(deaerator.p_dea, PID_pressure.PV) annotation (Line(points={{
                    -8.14286,18},{-20,18},{-20,39},{-32,39}},  color={0,0,127}));
            connect(p_deaSP.y, PID_pressure.SP) annotation (Line(points={{-11,64},
                    {-20,64},{-20,46},{-32,46}},     color={0,0,127}));
            connect(step_wFW.y, waterPump.in_w0)
              annotation (Line(points={{39,-50},{6,-50}}, color={0,0,127}));
            connect(pumpDynamic.y, sourceMassFlow_FW.in_w0) annotation (Line(
                  points={{141,-20},{150,-20},{150,50},{52,50},{52,44}}, color=
                    {0,0,127}));
            connect(step_wFW1.y, sourceMassFlow_DR.in_w0) annotation (Line(
                  points={{-59,-40},{-54,-40},{-54,-14}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-160,
                      -100},{160,100}})),
              experiment(StopTime=5000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Icon(coordinateSystem(extent={{-160,-100},{160,100}})));
          end test_deaerator;

        end Test;

        package Old "Package containing old component"

          model Equilibrium2phVessel
            "Base model of an adiabatic steam/liquid separator at thermodynamic equilibrium"

            replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
              Modelica.Media.Interfaces.PartialMedium "Medium"
              annotation (choicesAllMatching=true);

            parameter Modelica.SIunits.Length D "tank diameter";
            parameter Modelica.SIunits.Height H "Height of the tank";
            final parameter Modelica.SIunits.Volume V=A*H "Total volume";
            final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
              "Cross Sectional Area";
            parameter Modelica.SIunits.Height zl_start "Medium start level";
            parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
            parameter Medium.AbsolutePressure p_start "Start pressure";
            parameter Medium.MassFlowRate w_small = 1e-3
              "Small flow rate for reverse flow check";
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction";
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option";
            parameter Boolean noInitialPressure=false
              "Remove initial equation on pressure"
              annotation (Dialog(tab="Initialisation"),choices(checkBox=true));
            parameter Boolean noInitialLevel=true
              "Remove initial equation on level"
              annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

            ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                  min=if allowFlowReversal then -Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                    rotation=0), iconTransformation(extent={{-60,-50},{-40,-30}})));
            ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
                m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                  iconTransformation(extent={{-10,-100},{10,-80}})));
            ThermoPower.Water.FlangeB steam_out(
                                             redeclare package Medium = Medium,
                m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,82},{10,102}},  rotation=0),
                  iconTransformation(extent={{-10,110},{10,130}})));

            Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                    extent={{40,-80},{60,-60}}),iconTransformation(extent={{40,-80},{60,-60}})));
            Modelica.Blocks.Interfaces.RealOutput DT_sh annotation (Placement(transformation(
                    extent={{-228,68},{-208,88}}), iconTransformation(extent={{40,40},{60,
                      60}})));

            Medium.ThermodynamicState state
              "Thermodynamic state of the separator";
            Medium.SaturationProperties sat
              "Saturation properties of the separator";

          protected
            constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
          public
            Medium.MassFlowRate w_in "Medium inflow mass flow rate";
            Medium.MassFlowRate wl_in
              "Medium inflow mass flow rate (liquid fraction)";
            Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
            Medium.MassFlowRate wv_out "Medium steam outflow mass flow rate";
            Modelica.SIunits.Height zl(start=zl_start)
              "Medium level (relative to reference)";
            Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
            Medium.SpecificEnthalpy hl_out
              "Medium drained outlet specific enthalpy";
            Medium.SpecificEnthalpy hv_out
              "Medium steam outlet specific enthalpy";
            Medium.SpecificEnthalpy hl "Bubble point specific enthalpy";
            Medium.SpecificEnthalpy hv "Dew-point specific enthalpy";
            Modelica.SIunits.Mass M "Total mass";
            Modelica.SIunits.Mass Ml "Mass of liquid";
            Medium.Temperature T "Medium temperature";
            Medium.Temperature T_sat "Saturation temperature";
            Medium.AbsolutePressure p(start = p_start, stateSelect=StateSelect.prefer)
              "Medium pressure";
            Modelica.SIunits.SpecificEnthalpy h(start = h_start, stateSelect=StateSelect.prefer)
              "Specific mixture enthalpy";
            Modelica.SIunits.Density rho "Mixture density";
            ThermoPower.Units.LiquidDensity rho_l
              "Density of the liquid medium";
            Modelica.SIunits.DerDensityByPressure drdp
              "Derivative of density by pressure";
            Modelica.SIunits.DerDensityByEnthalpy drdh
              "Derivative of density by enthalpy";
            Modelica.SIunits.MassFraction  x_in = Medium.vapourQuality(Medium.setState_ph(p,hl_in))
              "Inlet steam quality";
            Modelica.SIunits.MassFraction  x "Mixture steam quality";

            Real vf "Void fraction";
            //Integer phase(start = 1) "Definition of thermodynamic state in the separator";

          equation
            // Fluid property calculations
            sat = Medium.setSat_p(p);
            //phase = if h > hv then 1 else 2;
            //when zl < 0.0001 then
            //  reinit(h, hv);
            //end when;
            state = Medium.setState_ph(p,h);
            T = Medium.temperature(state);
            T_sat = Medium.saturationTemperature(p);
            hv = Medium.dewEnthalpy(sat);
            hl = Medium.bubbleEnthalpy(sat);
            rho_l = Medium.bubbleDensity(sat);
            drdp = Medium.density_derp_h(state);
            drdh = Medium.density_derh_p(state);
            wl_in = w_in*(1-x_in);

            //Mass and energy balances
            V*(drdp*der(p) + drdh*der(h)) = w_in - wl_out - wv_out;
            V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = w_in*hl_in - wl_out*hl_out - wv_out*hv_out;
            rho = Medium.density(state);
            x = Medium.vapourQuality(state);
            M = V*rho;
            Ml = M*(1-x);
            Ml = A*zl*rho_l;
            vf =(H-zl)/H;

            // Boundary conditions
            hl_in = inStream(water_in.h_outflow);
            //hv_out = if h > hv then h else hv;
            //hl_out = if h > hv then h else hl;
            hv_out = max(h,hv);
            hl_out = min(h,hl);

            steam_out.h_outflow = hv_out;
            drained_out.h_outflow = hl_out;
            water_in.h_outflow = inStream(steam_out.h_outflow)
              "Dummy equation for flow reversal";

            w_in = water_in.m_flow;
            wl_out = -drained_out.m_flow;
            wv_out = -steam_out.m_flow;
            assert(w_in > -w_small, "Flow reversal not supported at phase separator inlet");
            assert(wl_out > -w_small, "Flow reversal not supported at phase separator liquid outlet");
            assert(wv_out > -w_small, "Flow reversal not supported at phase separator steam outlet");
            water_in.p = p;
            steam_out.p = p;
            drained_out.p = p;
            assert(vf>0,"Separator full");

            // Level sensor output
            level = zl;
            // Degree of superheating sensor
            DT_sh = max(0,T - T_sat) + 273.15;

          initial equation
            if initOpt == ThermoPower.Choices.Init.Options.noInit then
              // do nothing
            elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
              if not noInitialPressure then
                der(p) = 0;
              end if;
              der(h) = 0;
            elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
              if not noInitialPressure then
                p = p_start;
              end if;
              if not noInitialLevel then
                zl = zl_start;
              end if;
              h = h_start;
            else
              assert(false, "Unsupported initialisation option");
            end if;
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                      140}}),
                      graphics),
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,140}}),
                   graphics={
                  Rectangle(
                    extent={{-40,70},{40,-72}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                        80},{36,76},{40,70},{18,70},{-40,70}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                        -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,0},{28,-60}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,60},{28,0}},
                    lineColor={85,170,255},
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                        60}},
                    lineColor={85,170,255},
                    smooth=Smooth.None,
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                        {-28,-60}},
                    lineColor={0,0,255},
                    smooth=Smooth.None,
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-6,110},{6,80}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid)}),
              Documentation(info="<html>
<p>Modelling assumptions:</p>
<ul>
<li>The state can be either saturated liquid and saturated steam at thermodynamic equilibrium, or superheated steam.</li>
<li>Full liquid state not supported</li>
<li>No flow reversal at the ports</li>
<li>Reference zero level @ empty tank</li>
</ul>
</html>"));
          end Equilibrium2phVessel;

          model NusseltCondenser_noLevel
            "Base model of condensing section based on Nusselt theory, with enthalpy and pressure as states in vapour energy balance"

            replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
              Modelica.Media.Interfaces.PartialMedium "Medium"
              annotation (choicesAllMatching=true);

            ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
                m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                    rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
            ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
                m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                  iconTransformation(extent={{-10,-100},{10,-80}})));
            ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                  max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                  iconTransformation(extent={{-10,110},{10,130}})));
            Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                  transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                      {-60,0}})));
            Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                    extent={{-118,-74},{-98,-54}}),
                                                iconTransformation(extent={{-40,-80},{-60,
                      -60}})));

            Medium.ThermodynamicState vapour_state
              "Thermodynamic state of the vapour";
            Medium.ThermodynamicState steamIn_state
              "Thermodynamic state of the inlet vapour";
            Medium.ThermodynamicState drainedIn_state
              "Thermodynamic state of the inlet drain";
            Medium.SaturationProperties sat
              "Saturation properties of the vapour";

            parameter Integer Nw "Number of volumes, tube side";
            parameter Modelica.SIunits.Volume V "Total volume";
            parameter Modelica.SIunits.Area A "Cross Sectional Area";
            parameter Modelica.SIunits.Height H=V/A
              "Height of the condensing volume";
            parameter Modelica.SIunits.Area S "Heat transfer surface";
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC";
            parameter Modelica.SIunits.Height zl_set "Liquid level set point";
            parameter Modelica.SIunits.Height zl_start "Liquid level start";
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction";
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option";
            parameter Boolean noInitialPressure=false
              "Remove initial equation on pressure"
              annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          public
            Medium.MassFlowRate ws_in "Steam mass flow rate";
            Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
            Medium.MassFlowRate wd_out "Drained outet mass flow rate";
            Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
            Modelica.SIunits.Height zl(start = zl_start)
              "Medium level (relative to reference)";
            Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
            Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
            Medium.Temperature T "Medium temperature";
            Medium.Temperature T_sat "Medium saturation temperature";
            Modelica.SIunits.Volume Vv "Volume occupied by vapour";
            Medium.AbsolutePressure p "Medium pressure";
            Modelica.SIunits.DerDensityByPressure drdp
              "Derivative of density by pressure";
            Modelica.SIunits.DerDensityByEnthalpy drdh
              "Derivative of density by enthalpy";
            Modelica.SIunits.SpecificEnthalpy h(start = Medium.dewEnthalpy(Medium.setSat_p(p_start)))
              "Specific internal enthalpy";
            Modelica.SIunits.SpecificEnthalpy hv
              "Specific saturated steam enthalpy";
            Modelica.SIunits.Density rho_v "Steam density";
            Modelica.SIunits.Density rho_l "Liquid density";
            Real x_s "Vapour quality at steam inlet";
            Real x_d "Vapour quality at drained inlet";
            Modelica.SIunits.Power Q_cond "Condensation thermal load";
            Modelica.SIunits.Power Q_des_st
              "De-superheating power of steam inlet";
            Modelica.SIunits.Power Q_des_dr
              "De-superheating power of drained inlet";
            Modelica.SIunits.Power Qw[Nw]
              "Condensation thermal load on a single volume";
            Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

            ThermoPower.Thermal.DHTVolumes DHT(
              N = Nw) annotation (Placement(
                  transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                      {50,20}})));
          equation
            // Fluid property calculations
            sat = Medium.setSat_p(p);
            vapour_state = Medium.setState_ph(p,h);
            steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
            drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
            T = Medium.temperature(vapour_state);
            rho_v = Medium.density(vapour_state);
            hv = Medium.dewEnthalpy(sat);
            hd_out = Medium.bubbleEnthalpy(sat);
            T_sat = Medium.saturationTemperature(p);
            rho_l = Medium.bubbleDensity(sat);
            drdp = Medium.density_derp_h(vapour_state);
            drdh = Medium.density_derh_p(vapour_state);
            x_s = Medium.vapourQuality(steamIn_state);
            x_d = Medium.vapourQuality(drainedIn_state);

            //Mass and energy balances
            //Liquid mass balance
            rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out;
            //Vapour mass balance
            Vv*(drdp*der(p) + drdh*der(h)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d - w_cond;
            //ws_in*x_s + wd_in*x_d - w_cond = 0;
            Vl = A*zl;
            Vv = V - Vl;
            //Vapour energy balance
            //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
            Q_des_st = max(0,ws_in*(hs_in - hv));
            Q_des_dr = max(0,wd_in*(hd_in - hv));
            for j in 1:Nw loop
              Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
            end for;
            Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
            w_cond = Q_cond/(h - hd_out);

            // Boundary conditions
            hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
               else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
              steam_in.h_outflow));
            hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
               else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
              drained_in.h_outflow));
            drained_out.h_outflow = hd_out;
            steam_in.h_outflow = inStream(drained_out.h_outflow);
            drained_in.h_outflow = inStream(drained_out.h_outflow);

            ws_in = steam_in.m_flow;
            wd_in = drained_in.m_flow;
            wd_out = -drained_out.m_flow;
            steam_in.p = p;
            drained_in.p = p;
            drained_out.p = p;

            Tw = DHT.T;
            Qw = -DHT.Q;

            // Level set-point definition
            zl_SP = zl_set;
            level = zl;

          initial equation
            if initOpt == ThermoPower.Choices.Init.Options.noInit then
              // do nothing
            elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
              if not noInitialPressure then
                der(p) = 0;
              end if;
              der(zl) = 0;
              der(h) = 0;
            elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
              if not noInitialPressure then
                p = p_start;
              end if;
              h = hv;
              zl = zl_start;
            else
              assert(false, "Unsupported initialisation option");
            end if;
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                      140}})),
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                      {140,140}}),
                   graphics={
                  Rectangle(
                    extent={{-40,70},{40,-72}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                        80},{36,76},{40,70},{18,70},{-40,70}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                        -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,0},{28,-60}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,60},{28,0}},
                    lineColor={85,170,255},
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                        60}},
                    lineColor={85,170,255},
                    smooth=Smooth.None,
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                        {-28,-60}},
                    lineColor={0,0,255},
                    smooth=Smooth.None,
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-6,110},{6,80}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid)}),
              Documentation(info="<HTML></html>"));
          end NusseltCondenser_noLevel;

          model NusseltCondenser_onlyLevel
            "Base model of condensing section based on Nusselt theory, with level as states in vapour energy balance"

            replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
              Modelica.Media.Interfaces.PartialMedium "Medium"
              annotation (choicesAllMatching=true);

            ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
                m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                    rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
            ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
                m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                  iconTransformation(extent={{-10,-100},{10,-80}})));
            ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                  max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                  iconTransformation(extent={{-10,110},{10,130}})));
            Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                  transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                      {-60,0}})));
            Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                    extent={{-118,-74},{-98,-54}}),
                                                iconTransformation(extent={{-40,-80},{-60,
                      -60}})));

            Medium.ThermodynamicState vapour_state
              "Thermodynamic state of the vapour";
            Medium.ThermodynamicState steamIn_state
              "Thermodynamic state of the inlet vapour";
            Medium.ThermodynamicState drainedIn_state
              "Thermodynamic state of the inlet drain";
            Medium.SaturationProperties sat
              "Saturation properties of the vapour";

            parameter Integer Nw "Number of volumes, tube side";
            parameter Modelica.SIunits.Volume V "Total volume";
            parameter Modelica.SIunits.Area A "Cross Sectional Area";
            parameter Modelica.SIunits.Height H=V/A
              "Height of the condensing volume";
            parameter Modelica.SIunits.Area S "Heat transfer surface";
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC";
            parameter Modelica.SIunits.Height zl_set "Liquid level set point";
            parameter Modelica.SIunits.Height zl_start "Liquid level start";
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction";
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option";
            parameter Boolean noInitialPressure=false
              "Remove initial equation on pressure"
              annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          public
            Medium.MassFlowRate ws_in "Steam mass flow rate";
            Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
            Medium.MassFlowRate wd_out "Drained outet mass flow rate";
            Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
            Modelica.SIunits.Height zl(start = zl_start)
              "Medium level (relative to reference)";
            Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
            Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
            Medium.Temperature T "Medium temperature";
            Medium.Temperature T_sat "Medium saturation temperature";
            Modelica.SIunits.Volume Vv "Volume occupied by vapour";
            Medium.AbsolutePressure p "Medium pressure";
            Modelica.SIunits.DerDensityByPressure drdp
              "Derivative of density by pressure";
            Modelica.SIunits.DerDensityByEnthalpy drdh
              "Derivative of density by enthalpy";
            Modelica.SIunits.SpecificEnthalpy h(start = Medium.dewEnthalpy(Medium.setSat_p(p_start)))
              "Specific internal enthalpy";
            Modelica.SIunits.SpecificEnthalpy hv
              "Specific saturated steam enthalpy";
            Modelica.SIunits.Density rho_v "Steam density";
            Modelica.SIunits.Density rho_l "Liquid density";
            Real x_s "Vapour quality at steam inlet";
            Real x_d "Vapour quality at drained inlet";
            Modelica.SIunits.Power Q_cond "Condensation thermal load";
            Modelica.SIunits.Power Q_des_st
              "De-superheating power of steam inlet";
            Modelica.SIunits.Power Q_des_dr
              "De-superheating power of drained inlet";
            Modelica.SIunits.Power Qw[Nw]
              "Condensation thermal load on a single volume";
            Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

            ThermoPower.Thermal.DHTVolumes DHT(
              N = Nw) annotation (Placement(
                  transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                      {50,20}})));
          equation
            // Fluid property calculations
            sat = Medium.setSat_p(p);
            vapour_state = Medium.setState_ph(p,h);
            steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
            drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
            T = Medium.temperature(vapour_state);
            rho_v = Medium.density(vapour_state);
            hv = Medium.dewEnthalpy(sat);
            hd_out = Medium.bubbleEnthalpy(sat);
            T_sat = Medium.saturationTemperature(p);
            rho_l = Medium.bubbleDensity(sat);
            drdp = Medium.density_derp_h(vapour_state);
            drdh = Medium.density_derh_p(vapour_state);
            x_s = Medium.vapourQuality(steamIn_state);
            x_d = Medium.vapourQuality(drainedIn_state);

            //Mass and energy balances
            //Liquid mass balance
            rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out;
            //Vapour mass balance
            Vv*(drdp*der(p) + drdh*der(h)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d - w_cond;
            //ws_in*x_s + wd_in*x_d - w_cond = 0;
            Vl = A*zl;
            Vv = V - Vl;
            //Vapour energy balance
            //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //Vv*(rho_v + h*drdh)*der(h) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
            Q_des_st = max(0,ws_in*(hs_in - hv));
            Q_des_dr = max(0,wd_in*(hd_in - hv));
            for j in 1:Nw loop
              Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
            end for;
            Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
            w_cond = Q_cond/(h - hd_out);

            // Boundary conditions
            hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
               else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
              steam_in.h_outflow));
            hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
               else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
              drained_in.h_outflow));
            drained_out.h_outflow = hd_out;
            steam_in.h_outflow = inStream(drained_out.h_outflow);
            drained_in.h_outflow = inStream(drained_out.h_outflow);

            ws_in = steam_in.m_flow;
            wd_in = drained_in.m_flow;
            wd_out = -drained_out.m_flow;
            steam_in.p = p;
            drained_in.p = p;
            drained_out.p = p;

            Tw = DHT.T;
            Qw = -DHT.Q;

            // Level set-point definition
            zl_SP = zl_set;
            level = zl;

          initial equation
            if initOpt == ThermoPower.Choices.Init.Options.noInit then
              // do nothing
            elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
              if not noInitialPressure then
                der(p) = 0;
              end if;
              der(zl) = 0;
              der(h) = 0;
            elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
              if not noInitialPressure then
                p = p_start;
              end if;
              h = hv;
              zl = zl_start;
            else
              assert(false, "Unsupported initialisation option");
            end if;
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                      140}})),
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                      {140,140}}),
                   graphics={
                  Rectangle(
                    extent={{-40,70},{40,-72}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                        80},{36,76},{40,70},{18,70},{-40,70}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                        -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,0},{28,-60}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,60},{28,0}},
                    lineColor={85,170,255},
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                        60}},
                    lineColor={85,170,255},
                    smooth=Smooth.None,
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                        {-28,-60}},
                    lineColor={0,0,255},
                    smooth=Smooth.None,
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-6,110},{6,80}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid)}),
              Documentation(info="<HTML></html>"));
          end NusseltCondenser_onlyLevel;

          model NusseltCondenser_noLevelControl
            "Base model of condensing section based on Nusselt theory, ideal level control"

            replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
              Modelica.Media.Interfaces.PartialMedium "Medium"
              annotation (choicesAllMatching=true);

            ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
                m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                    rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
            ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
                m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                  iconTransformation(extent={{-10,-100},{10,-80}})));
            ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                  max=if allowFlowReversal then +Modelica.Constants.inf else 0))
              annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                  iconTransformation(extent={{-10,110},{10,130}})));
            Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                  transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                      {-60,0}})));
            Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                    extent={{-118,-74},{-98,-54}}),
                                                iconTransformation(extent={{-40,-80},{-60,
                      -60}})));

            Medium.ThermodynamicState vapour_state
              "Thermodynamic state of the vapour";
            Medium.ThermodynamicState steamIn_state
              "Thermodynamic state of the inlet vapour";
            Medium.ThermodynamicState drainedIn_state
              "Thermodynamic state of the inlet drain";
            Medium.SaturationProperties sat
              "Saturation properties of the vapour";

            parameter Integer Nw "Number of volumes, tube side";
            parameter Modelica.SIunits.Volume V "Total volume";
            parameter Modelica.SIunits.Area A "Cross Sectional Area";
            parameter Modelica.SIunits.Height H=V/A
              "Height of the condensing volume";
            parameter Modelica.SIunits.Area S "Heat transfer surface";
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC";
            parameter Modelica.SIunits.Height zl_set "Liquid level set point";
            parameter Modelica.SIunits.Height zl_start "Liquid level start";
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction";
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option";
            parameter Boolean noInitialPressure=false
              "Remove initial equation on pressure"
              annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          public
            Medium.MassFlowRate ws_in "Steam mass flow rate";
            Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
            //Medium.MassFlowRate wd_out "Drained outet mass flow rate";
            Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
            parameter Modelica.SIunits.Height zl(start = zl_start)
              "Medium level (relative to reference)";
            Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
            Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
            parameter Modelica.SIunits.Volume Vl=zl*A
              "Volume occupied by liquid medium";
            Medium.Temperature T "Medium temperature";
            Medium.Temperature T_sat "Medium saturation temperature";
            parameter Modelica.SIunits.Volume Vv=V - Vl
              "Volume occupied by vapour";
            Medium.AbsolutePressure p "Medium pressure";
            Modelica.SIunits.DerDensityByPressure drdp
              "Derivative of density by pressure";
            Modelica.SIunits.DerDensityByEnthalpy drdh
              "Derivative of density by enthalpy";
            Modelica.SIunits.SpecificEnthalpy h(start = Medium.dewEnthalpy(Medium.setSat_p(p_start)))
              "Specific internal enthalpy";
            Modelica.SIunits.SpecificEnthalpy hv
              "Specific saturated steam enthalpy";
            Modelica.SIunits.Density rho_v "Steam density";
            Modelica.SIunits.Density rho_l "Liquid density";
            Real x_s "Vapour quality at steam inlet";
            Real x_d "Vapour quality at drained inlet";
            Modelica.SIunits.Power Q_cond "Condensation thermal load";
            Modelica.SIunits.Power Q_des_st
              "De-superheating power of steam inlet";
            Modelica.SIunits.Power Q_des_dr
              "De-superheating power of drained inlet";
            Modelica.SIunits.Power Qw[Nw]
              "Condensation thermal load on a single volume";
            Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

            ThermoPower.Thermal.DHTVolumes DHT(
              N = Nw) annotation (Placement(
                  transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                      {50,20}})));
          equation
            // Fluid property calculations
            sat = Medium.setSat_p(p);
            vapour_state = Medium.setState_ph(p,h);
            steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
            drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
            T = Medium.temperature(vapour_state);
            rho_v = Medium.density(vapour_state);
            hv = Medium.dewEnthalpy(sat);
            hd_out = Medium.bubbleEnthalpy(sat);
            T_sat = Medium.saturationTemperature(p);
            rho_l = Medium.bubbleDensity(sat);
            drdp = Medium.density_derp_h(vapour_state);
            drdh = Medium.density_derh_p(vapour_state);
            x_s = Medium.vapourQuality(steamIn_state);
            x_d = Medium.vapourQuality(drainedIn_state);

            //Mass and energy balances
            //Liquid mass balance
            //rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out;
            //Vapour mass balance
            //Vv*(drdp*der(p) + drdh*der(h)) = ws_in*x_s + wd_in*x_d - w_cond;
            //ws_in*x_s + wd_in*x_d - w_cond = 0;
            //Vl = A*zl;
            //Vv = V - Vl;
            //Vapour energy balance
            Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
            //ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
            Q_des_st = max(0,ws_in*(hs_in - hv));
            Q_des_dr = max(0,wd_in*(hd_in - hv));
            for j in 1:Nw loop
              Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
            end for;
            Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
            w_cond = Q_cond/(h - hd_out);

            // Boundary conditions
            hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
               else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
              steam_in.h_outflow));
            hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
               else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
              drained_in.h_outflow));
            drained_out.h_outflow = hd_out;
            steam_in.h_outflow = inStream(drained_out.h_outflow);
            drained_in.h_outflow = inStream(drained_out.h_outflow);

            ws_in = steam_in.m_flow;
            wd_in = drained_in.m_flow;
            ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond = -drained_out.m_flow;
            steam_in.p = p;
            drained_in.p = p;
            drained_out.p = p;

            Tw = DHT.T;
            Qw = -DHT.Q;

            // Level set-point definition
            zl_SP = zl_set;
            level = zl;

          initial equation
            if initOpt == ThermoPower.Choices.Init.Options.noInit then
              // do nothing
            elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
              if not noInitialPressure then
                der(p) = 0;
              end if;
              der(zl) = 0;
              der(h) = 0;
            elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
              if not noInitialPressure then
                p = p_start;
              end if;
              h = hv;
              zl = zl_start;
            else
              assert(false, "Unsupported initialisation option");
            end if;
            annotation (
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                      140}})),
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                      {140,140}}),
                   graphics={
                  Rectangle(
                    extent={{-40,70},{40,-72}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                        80},{36,76},{40,70},{18,70},{-40,70}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                        -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                    lineColor={135,135,135},
                    smooth=Smooth.None,
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,0},{28,-60}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-28,60},{28,0}},
                    lineColor={85,170,255},
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                        60}},
                    lineColor={85,170,255},
                    smooth=Smooth.None,
                    fillColor={85,170,255},
                    fillPattern=FillPattern.Solid),
                  Polygon(
                    points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                        {-28,-60}},
                    lineColor={0,0,255},
                    smooth=Smooth.None,
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid),
                  Rectangle(
                    extent={{-6,110},{6,80}},
                    lineColor={135,135,135},
                    fillColor={135,135,135},
                    fillPattern=FillPattern.Solid)}),
              Documentation(info="<HTML></html>"));
          end NusseltCondenser_noLevelControl;
        end Old;
      end Components;

      package OTSG
        "Package containing all the Once Through Steam Generator models"

        model OTSG_init100_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, separator valve for drainage during transition"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
          inner ThermoPower.System system "System wide properties";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=Nhex_mono*2,
            Vhot=3.789,
            Vcold=0.781,
            Shot=314.9,
            Scold=248,
            Mm=3802,
            nominalColdFlow=24.51,
            nominalHotFlow=619.8,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                  1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                  1.29502e+006,1.30052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                558.906,561.752,563.806,565.297,566.385,567.182}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                  103396,100624}),
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                  1.64439e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                620.01}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={196390,188158,176706,156967,110743}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                  1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                  1.94183e+006,2.2136e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                626.498,627.06,627.186,627.848,629.177,631.842}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                  194368,192799}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                  2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                  2.72547e+006,2.78281e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                653.806,658.116,678.213,683.393,689.164,695.453}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                  284059,275898}),
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            gamma=0,
            zl_start=0.25,
            noInitialLevel=false,
            hv_start=2.7e6,
            hl_start=1.7e6,
            p_start=17200000,
            noInitialPressure=false)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                824.786}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,501167,469703,420819,359564}),
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                  3.42217e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                  3.55697e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                829.056}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,502650,475154,429572,356689}),
            nominalColdPressure=4781000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,200},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,262})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,12})));

          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamSH2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=24.51,
            dpnom=(0.5)*10^5,
            rhonom=747.38)       annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(
            thetanom=0.8,
            Fxt_full=0.4542722663,
            Av=0.053642779,
            wnom=91.28,
            redeclare package Medium = coldMedium,
            pnom=17100000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,238})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,36})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,210},{140,210},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,268}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,256},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                  -210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,210},{-46,210}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{-4.44089e-016,270},{-4.44089e-016,230},{0,230},{0,190}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0)
            annotation (Line(points={{-40,227},{-40,216}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-40,260},{-40,250}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                  124},{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255}));
          connect(sensP.flange, SH.outletCold)
            annotation (Line(points={{0,190},{0,156}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,8},{50,-218},{68,-218},{68,-220},{
                  82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(points={
                  {-60,-4},{-60,-4},{-60,2}}, color={0,0,255}));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,-48},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
              points={{-60,42},{-60,48},{-10,48}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.inlet, PDSteamEVA2.outlet)
            annotation (Line(points={{-60,30},{-60,22}}, color={0,0,255}));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(points=
                 {{80,20},{90,20},{100,20}}, color={0,0,255}));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,44}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-258},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init100_5nodes;

        model OTSG_init50_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, valve for separator draining added"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=Nhex_mono*2,
            Vhot=3.789,
            Vcold=0.781,
            Shot=314.9,
            Scold=248,
            Mm=3802,
            nominalColdFlow=24.51,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            nominalColdPressure=9200000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))       annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={105478,99880.5,96473.6,94384,93096.8}),
            nominalColdPressure=9249000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                  1.28694e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            nominalColdPressure=9074000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=false))         annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            nominalColdPressure=9000000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            w_small=1e4,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.7e6,
            noInitialLevel=false,
            zl_start=1,
            p_start=8935000,
            noInitialPressure=false)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006},
              noInitialPressure=false),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            nominalColdPressure=8935000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            nominalColdPressure=2290000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,266})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,14})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=24.51,
            dpnom=(0.5)*10^5,
            rhonom=747.38)       annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(
            thetanom=0.8,
            Fxt_full=0.4542722663,
            Av=0.053642779,
            wnom=91.28,
            redeclare package Medium = coldMedium,
            pnom=17100000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,234})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,38})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,208},{140,208},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,272}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,4}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,260},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,208},{-46,208}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,190}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                  -40,214}},           color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-40,260},{-40,246}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
          connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                  {0,190},{0,156}}, color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-218},{52,-218},{68,-218},{68,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
              points={{80,20},{90,20},{100,20}},
              color={0,0,255},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet) annotation (Line(
              points={{0,38},{0,20},{60,20}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(points=
                 {{-60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet) annotation (Line(points=
                  {{-60,24},{-60,24},{-60,32}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-252},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes;

        model OTSG_init20_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 20% load and 5 nodes, valve for separator draining added"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {552.444,552.442,552.431,
                552.375}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={85022,85247.3,85294.1,85302.9,85303.6}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23187e+006,1.23187e+006,1.23186e+006,1.23179e+006,
                  1.23141e+006},
              noInitialPressure=false),
            nominalColdPressure=8571520,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {552.513,552.631,552.847,
                553.239,553.954,555.257,557.639,561.997,570.009}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={134909,112113,99865.7,93217,89588.8,87603.5,86515.4,
                  85918.4,85590.6,85410.4}),
            nominalColdPressure=8525020,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=false))         annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.31523e+006,1.32499e+006,1.33594e+006,1.35256e+006,
                  1.37618e+006,1.40773e+006,1.44984e+006,1.50604e+006,
                  1.58098e+006,1.68078e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {578.238,581.215,581.236,
                582.514,585.835,590.262,596.16,604.006,614.424}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={352001,292727,248227,214852,189840,171106,157080,147206,
                  140707,134909}),
            nominalColdPressure=8524120,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            w_small=1e4,
            gamma=0,
            noInitialLevel=false,
            zl_start=4,
            hv_start=2.752e6,
            hl_start=1.341e6,
            p_start=8516000,
            noInitialPressure=false)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            tubeWalls(Tvolstart(displayUnit="K") = {739.899,806.205,831.393,
                837.415}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,516451,504598,455423,333567}),
            nominalColdPressure=8525910,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={2.752e+006,3.27777e+006,3.48994e+006,3.54107e+006,
                  3.55247e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            nominalColdPressure=892519,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.17466e+006,3.48069e+006,3.57763e+006,3.60955e+006,
                  3.62022e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {767.936,816.649,832.12,
                837.222}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,515618,505224,473664,374039}))
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,266})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,14})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=24.51,
            dpnom=(0.5)*10^5,
            rhonom=747.38)       annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(
            thetanom=0.8,
            Fxt_full=0.4542722663,
            Av=0.053642779,
            wnom=91.28,
            redeclare package Medium = coldMedium,
            pnom=8500000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,234})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,38})));
          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=Nhex_mono*2,
            Vhot=3.789,
            Vcold=0.781,
            Shot=314.9,
            Scold=248,
            Mm=3802,
            nominalColdFlow=24.51,
            nominalHotFlow=619.8,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                  1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                  1.29502e+006,1.30052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                558.906,561.752,563.806,565.297,566.385,567.182}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                  103396,100624}),
            nominalColdPressure=8600000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,208},{140,208},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,272}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,4}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,260},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,208},{-46,208}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,190}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                  -40,214}},           color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-40,260},{-40,246}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
          connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                  {0,190},{0,156}}, color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-218},{52,-218},{68,-218},{68,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
              points={{80,20},{90,20},{100,20}},
              color={0,0,255},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet) annotation (Line(
              points={{0,38},{0,20},{60,20}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(points=
                 {{-60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet) annotation (Line(points=
                  {{-60,24},{-60,24},{-60,32}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
              color={255,204,51},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-30,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(points={{-60,
                  -296},{-60,-296},{-60,-310}}, color={0,0,255}));
          connect(ECO.outletHot, HPH.inletHot) annotation (Line(
              points={{-76,-180},{-88,-180},{-100,-180},{-100,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init20_5nodes;

        model OTSG_init100_5nodes_drain
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, separator valve for drainage"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
          parameter Modelica.SIunits.Time t_switch;

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            Nhex=Nhex_mono*2,
            Vhot=3.789,
            Vcold=0.781,
            Shot=314.9,
            Scold=248,
            Mm=3802,
            nominalColdFlow=24.51,
            nominalHotFlow=619.8,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                  1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                  1.29502e+006,1.30052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                558.906,561.752,563.806,565.297,566.385,567.182}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                  103396,100624}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2197.5,
                gamma_nom_post=0,
                alpha=0.447465,
                t_switch=t_switch),
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                  1.64439e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                620.01}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={196390,188158,176706,156967,110743}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2204.3,
                gamma_nom_post=0,
                alpha=0.461561,
                t_switch=t_switch),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                  1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                  1.94183e+006,2.2136e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                626.498,627.06,627.186,627.848,629.177,631.842}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                  194368,192799}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2147.7,
                gamma_nom_post=0,
                alpha=0.447498,
                t_switch=t_switch),
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                  2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                  2.72547e+006,2.78281e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                653.806,658.116,678.213,683.393,689.164,695.453}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                  284059,275898}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2650,
                gamma_nom_post=0,
                alpha=0.389637,
                t_switch=t_switch),
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            noInitialPressure=true,
            gamma=0,
            zl_start=0.25,
            noInitialLevel=false,
            hv_start=2.7e6,
            hl_start=1.7e6,
            p_start=17200000,
            w_small=1e4)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                  3.42217e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                824.786}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,501167,469703,420819,359564}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2848.1,
                gamma_nom_post=0,
                alpha=0.28867,
                t_switch=t_switch),
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                  3.55697e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                829.056}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,502650,475154,429572,356689}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                gamma_nom_pre=2690.3,
                gamma_nom_post=0,
                alpha=0.320782,
                t_switch=t_switch),
            nominalColdPressure=4781000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,200},{-26,220}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,262})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,12})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamSH2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=24.51,
            dpnom=(0.5)*10^5,
            rhonom=747.38)       annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,238})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,36})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,210},{140,210},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,268}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,256},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                  -210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,210},{-46,210}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0)
            annotation (Line(points={{-40,227},{-40,216}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-40,260},{-40,250}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                  124},{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255}));
          connect(sensP.flange, SH.outletCold)
            annotation (Line(points={{0,190},{0,156}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,8},{50,-218},{68,-218},{68,-220},{
                  82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(points={
                  {-60,-4},{-60,-4},{-60,2}}, color={0,0,255}));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,-48},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
              points={{-60,42},{-60,48},{-10,48}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.inlet, PDSteamEVA2.outlet)
            annotation (Line(points={{-60,30},{-60,22}}, color={0,0,255}));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(points=
                 {{80,20},{90,20},{100,20}}, color={0,0,255}));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,44}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, sensP.flange) annotation (Line(
              points={{0,310},{0,310},{0,190}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init100_5nodes_drain;

        model OTSG_init50_5nodes_drain
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, valve for separator draining added"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
          parameter Modelica.SIunits.Time t_switch;

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={105478,99880.5,96473.6,94384,93096.8}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                  1.28694e+006},
              noInitialPressure=true),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                t_switch=t_switch,
                gamma_nom_pre=2204.3,
                gamma_nom_post=0,
                alpha=0.461561),
            nominalColdPressure=9249000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                t_switch=t_switch,
                gamma_nom_pre=2147.7,
                gamma_nom_post=0,
                alpha=0.447498),
            nominalColdPressure=9074000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                t_switch=t_switch,
                gamma_nom_pre=2650,
                gamma_nom_post=0,
                alpha=0.389637),
            nominalColdPressure=9000000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            noInitialPressure=true,
            w_small=1e4,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.7e6,
            noInitialLevel=false,
            zl_start=1,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                t_switch=t_switch,
                gamma_nom_pre=2848,
                gamma_nom_post=0,
                alpha=0.28867),
            nominalColdPressure=8935000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            redeclare model HeatTransferHot =
                Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                (
                t_switch=t_switch,
                gamma_nom_pre=2690.3,
                gamma_nom_post=0,
                alpha=0.320782),
            nominalColdPressure=2290000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,266})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,14})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,234})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            pout(start=89e5, fixed=true))  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,38})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,208},{140,208},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,272}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,4}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,260},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,208},{-46,208}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                  -40,214}},           color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{50,-50},{50,260},{-40,260},{-40,246}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                  {0,190},{0,156}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-218},{52,-218},{68,-218},{68,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
              points={{80,20},{90,20},{100,20}},
              color={0,0,255},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet) annotation (Line(
              points={{0,38},{0,20},{60,20}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(points=
                 {{-60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet) annotation (Line(points=
                  {{-60,24},{-60,24},{-60,32}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, sensP.flange) annotation (Line(
              points={{0,310},{0,310},{0,190}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-76,-180},{-100,-180},{-100,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_FW.outlet, MS_HPH_out) annotation (Line(
              points={{84,-230},{-60,-230},{-60,-310}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_drain;

        model OTSG_init50_5nodes_warm
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, valve for separator draining added"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=Nhex_mono*2,
            Vhot=3.789,
            Vcold=0.781,
            Shot=314.9,
            Scold=248,
            Mm=3802,
            nominalColdFlow=24.51,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            nominalColdPressure=9200000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))       annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            Vhot=44.506,
            Vcold=5.73,
            Shot=2385,
            Scold=1848.4,
            Mm=30279,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={105478,99880.5,96473.6,94384,93096.8}),
            nominalColdPressure=9249000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                  1.28694e+006},
              noInitialPressure=false))
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            Vhot=31.955,
            Vcold=9.805,
            Shot=2834.1,
            Scold=2108.5,
            Mm=62846,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            nominalColdPressure=9074000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=false))         annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=4.495,
            Vcold=1.028,
            Shot=489,
            Scold=354.5,
            Mm=7374,
            nominalColdFlow=91.28,
            nominalHotFlow=619.8,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            nominalColdPressure=9000000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.nonEquilibriumVessel separator(
            redeclare package Medium = coldMedium,
            H=8,
            D=0.56,
            w_small=1e4,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.7e6,
            noInitialLevel=false,
            zl_start=1,
            p_start=8935000,
            noInitialPressure=false)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow pumpSEP(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-50})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            Vhot=12.281,
            Vcold=2.339,
            Shot=1193.5,
            Scold=835.5,
            Mm=19349,
            nominalColdFlow=91.28,
            nominalHotFlow=381.3,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006},
              noInitialPressure=false),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            nominalColdPressure=8935000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            Vhot=9.255,
            Vcold=4.618,
            Shot=1371.1,
            Scold=1154.6,
            Mm=15054,
            nominalColdFlow=84.94,
            nominalHotFlow=238.6,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            nominalColdPressure=2290000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,160})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,266})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=160.88)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=590.03)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(0.5)*10^5,
            rhonom=92.917)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,14})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=84.86,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,180})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.SensW sens_wMS(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-96,270})));
          ThermoPower.Water.SensP sensP(
            redeclare package Medium = coldMedium) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={4,190})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=91.28,
            dpnom=(1/2)*10^5,
            rhonom=820.48)                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            wnom=24.51,
            dpnom=(0.5)*10^5,
            rhonom=747.38)       annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          ThermoPower.Water.ValveVap valveVap(
            thetanom=0.8,
            Fxt_full=0.4542722663,
            Av=0.053642779,
            wnom=91.28,
            redeclare package Medium = coldMedium,
            pnom=17100000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                origin={0,280})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,234})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=91.28,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8)                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-64,38})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,160},{174,160},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,208},{140,208},{140,176}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(HPH.outletCold, MS_HPH_out) annotation (Line(
              points={{-60,-296},{-60,-310}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,272}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
              points={{0,38},{0,-40},{1.77636e-015,-40}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,-4},{-60,4}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{140,144},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pumpSEP.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,260},{100,190}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,160},{100,160},{100,170}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, sens_wMS.inlet) annotation (Line(
              points={{-100,310},{-100,276}},
              color={255,0,0},
              thickness=0.5));
          connect(sens_wMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,264},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(sens_wMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,264},{-100,264},{-100,208},{-46,208}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
              points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,280},{8,280}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, valveVap.outlet) annotation (Line(
              points={{0,310},{0,290}},
              color={0,0,255},
              thickness=0.5));
          connect(valveVap.inlet, sensP.flange) annotation (Line(
              points={{0,270},{0,190}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                  -40,214}},           color={0,0,127}));
          connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
              points={{50,-50},{50,-46},{6,-46}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
          connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                  {0,190},{0,156}}, color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-218},{52,-218},{68,-218},{68,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
              points={{80,20},{90,20},{100,20}},
              color={0,0,255},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet) annotation (Line(
              points={{0,38},{0,20},{60,20}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(points=
                 {{-60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet) annotation (Line(points=
                  {{-60,24},{-60,24},{-60,32}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
              points={{50,-50},{50,-50},{50,-252},{50,-270},{-2,-270}},
              color={255,204,51},
              thickness=0.5));
          connect(sens_wMS.w, gain.u) annotation (Line(points={{-90,262},{-90,
                  262},{-90,254},{-40,254},{-40,246}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_warm;

        package Test

          package HE "Package of single heat exchanger test model"

            model test_heatExchangers_offDesign
              "Test model of all the heat exchangers, from nominal load to 20% load, steady-state initialisation"

              extends Modelica.Icons.Example;
              //Heat exchangers parameter
              parameter Integer Nhex_mono = 5
                "Number of nodes for single phase heat exchangers";
              parameter Integer Nhex_bi = 10
                "Number of nodes for biphase heat exchangers";

              ThermoPower.Water.SourceMassFlow sourceMS(
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                w0=381.3,
                h=519092,
                p0=1000000)
                annotation (Placement(transformation(extent={{-250,120},{-230,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=2755127)
                annotation (Placement(transformation(extent={{-250,20},{-230,40}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17132400)
                annotation (Placement(transformation(extent={{-190,180},{-170,200}})));
              ThermoPower.Water.SinkPressure sinkMS(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=855401)
                annotation (Placement(transformation(extent={{-160,120},{-140,140}})));
              ThermoPower.Water.PressDrop PDMSSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                wnom=381.3,
                dpnom=(10.5 - 8.55401)*10^5,
                rhonom=1797.2)
                annotation (Placement(transformation(extent={{-190,120},{-170,140}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=91.28,
                dpnom=(172 - 171.0324)*10^5,
                rhonom=50.398)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-210,160})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-340,240},{-320,260}})));
              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.847436, gamma_nom=1996.5),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.28867, gamma_nom=2848.1),
                Nhex=Nhex_mono,
                Vhot=12.281,
                Vcold=2.339,
                Shot=1193.5,
                Scold=835.5,
                Mm=19349,
                nominalColdFlow=91.28,
                nominalHotFlow=381.3,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                nominalColdPressure=17200000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=646.55,
                nominalColdOutletTemperature=823.96,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=733.58)
                annotation (Placement(transformation(extent={{-220,120},{-200,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS1(
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=false,
                w0=238.6,
                p0=1050000,
                h=519092)
                annotation (Placement(transformation(extent={{-40,120},{-20,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=84.94,
                h=3081212)
                annotation (Placement(transformation(extent={{-40,20},{-20,40}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=4733745)
                annotation (Placement(transformation(extent={{20,178},{40,198}})));
              ThermoPower.Water.SinkPressure sinkMS1(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=915515)
                annotation (Placement(transformation(extent={{50,120},{70,140}})));
              ThermoPower.Water.PressDrop PDMSRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_lin,
                wnom=238.6,
                dpnom=(1.34485)*10^5,
                rhonom=1796.9)
                annotation (Placement(transformation(extent={{20,120},{40,140}})));
              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=84.94,
                dpnom=(0.47256)*10^5,
                rhonom=12.775)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={0,160})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=963.6),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.320782, gamma_nom=2690.3),
                Nhex=Nhex_mono,
                Vhot=9.255,
                Vcold=4.618,
                Shot=1371.1,
                Scold=1154.6,
                Mm=15054,
                nominalColdFlow=84.94,
                nominalHotFlow=238.5,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                nominalColdPressure=4781000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=625.65,
                nominalColdOutletTemperature=826.06,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=734.05)
                annotation (Placement(transformation(extent={{-10,120},{10,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS2(
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                w0=619.8,
                h=196421)
                annotation (Placement(transformation(extent={{170,120},{190,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=1062835)
                annotation (Placement(transformation(extent={{172,20},{192,40}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17345880)
                annotation (Placement(transformation(extent={{230,178},{250,198}})));
              ThermoPower.Water.SinkPressure sinkMS2(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=279240)
                annotation (Placement(transformation(extent={{260,120},{280,140}})));
              ThermoPower.Water.PressDrop PDMSECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                wnom=619.8,
                dpnom=(1.7076)*10^5,
                rhonom=1901.7)
                annotation (Placement(transformation(extent={{230,120},{250,140}})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=91.28,
                dpnom=(0.54118)*10^5,
                rhonom=590.03)                 annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={210,160})));
              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4499),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2204.3),
                Nhex=Nhex_mono,
                Vhot=44.506,
                Vcold=5.73,
                Shot=2385,
                Scold=1848.4,
                Mm=30279,
                nominalColdFlow=91.28,
                nominalHotFlow=619.8,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                nominalColdPressure=17400000,
                nominalHotPressure=450000,
                nominalColdInletTemperature=518.15,
                nominalColdOutletTemperature=621.59,
                nominalHotInletTemperature=626.75,
                nominalHotOutletTemperature=569.15)
                annotation (Placement(transformation(extent={{200,120},{220,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam4(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=1649400)
                annotation (Placement(transformation(extent={{-100,-220},{-80,-200}})));
              ThermoPower.Water.SinkPressure sinkMS4(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=543863)
                annotation (Placement(transformation(extent={{-120,-120},{-140,-100}})));
              ThermoPower.Water.PressDrop PDMSEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                wnom=619.8,
                dpnom=(1.06137)*10^5,
                rhonom=1865.18)
                annotation (Placement(transformation(extent={{-80,-120},{-100,-100}})));
              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=91.28,
                dpnom=(0.0622)*10^5,
                rhonom=160.882)      annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={0,-60})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=3875*0.75,
                    gamma_nom_2ph=25350*0.75,
                    gamma_nom_vap=3875*0.75),
                Nhex=Nhex_bi,
                Vhot=31.955,
                Vcold=9.805,
                Shot=2834.1,
                Scold=2108.5,
                Mm=62846,
                nominalColdFlow=91.28,
                nominalHotFlow=619.8,
                nominalColdPressure=17300000,
                nominalHotPressure=650000,
                nominalColdInletTemperature=621.55,
                nominalColdOutletTemperature=626.9,
                nominalHotInletTemperature=689.01,
                nominalHotOutletTemperature=626.65,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
                                                    annotation (Placement(
                    transformation(extent={{-50,-120},{-70,-100}})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                w0=619.8,
                h=359728.2)
                annotation (Placement(transformation(extent={{120,-120},{100,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam5(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17228810)
                annotation (Placement(transformation(extent={{90,-220},{110,-200}})));
              ThermoPower.Water.PressDrop PDMSEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                wnom=619.8,
                dpnom=(0.2863)*10^5,
                rhonom=1825.49)
                annotation (Placement(transformation(extent={{10,-120},{-10,-100}})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=91.28,
                dpnom=(0.2119)*10^5,
                rhonom=93.08)        annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=90,
                    origin={70,-150})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_2ph=6000,
                    gamma_nom_liq=2600,
                    gamma_nom_vap=2600),
                generateInitCode=true,
                Nhex=Nhex_bi,
                Vhot=4.495,
                Vcold=1.028,
                Shot=489,
                Scold=354.5,
                Mm=7374,
                nominalColdFlow=91.28,
                nominalHotFlow=619.8,
                nominalColdPressure=17250000,
                nominalHotPressure=700000,
                nominalColdInletTemperature=626.69,
                nominalColdOutletTemperature=646.74,
                nominalHotInletTemperature=734.05,
                nominalHotOutletTemperature=689.01,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
                                                    annotation (Placement(
                    transformation(extent={{80,-100},{60,-120}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_SH(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,76.24; 30,114.4; 40,152.5; 50,190.6; 60,228.7; 70,266.8; 80,304.9; 90,
                    343.1; 100,381.2])
                annotation (Placement(transformation(extent={{-270,150},{-250,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,2752e3; 30,2751.7e3; 40,2751.2e3; 50,2745.5e3; 60,2834.3e3; 70,2817.3e3;
                    80,2799.2e3; 90,2780.1e3; 100,2756.1e3])
                annotation (Placement(transformation(extent={{-270,80},{-250,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,17.67; 30,26.99; 40,36.63; 50,46.95; 60,57.44; 70,66.02; 80,74.71; 90,
                    83.33; 100,91.3])
                annotation (Placement(transformation(extent={{-270,50},{-250,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.6e5; 70,124.1e5;
                    80,139.7e5; 90,155.1e5; 100,171e5])      annotation (Placement(
                    transformation(extent={{-230,210},{-210,230}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,8.839e5; 30,13.32e5; 40,17.87e5; 50,21.61e5; 60,27.45e5; 70,32.69e5;
                    80,37.23e5; 90,42.09e5; 100,47.32e5])
                annotation (Placement(transformation(extent={{-20,210},{0,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(            smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,3174663;
                    30,3128058; 40,3161343; 50,3153664; 60,3136798; 70,3126928; 80,3111837;
                    90,3090912; 100,3100875])
                annotation (Placement(transformation(extent={{-60,80},{-40,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,15.45; 30,23.35; 40,31.42; 50,39.99; 60,48.62; 70,58.12; 80,66.38; 90,
                    75.31; 100,84.96])
                annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_RH(
                                   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,47.46; 30,71.50; 40,95.40; 50,119.3; 60,143.2; 70,167.1; 80,190.9; 90,
                    214.7; 100,238.6])
                annotation (Placement(transformation(extent={{-60,150},{-40,170}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                    80,141.3e5; 90,157e5; 100,173e5])
                annotation (Placement(transformation(extent={{190,210},{210,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_ECO(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                    90,186692; 100,196390])
                annotation (Placement(transformation(extent={{150,180},{170,200}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8; 90,557.8;
                    100,619.8])
                annotation (Placement(transformation(extent={{150,150},{170,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1231872; 30,1252286; 40,1261764; 50,1256708; 60,1117992; 70,1062175;
                    80,1062373; 90,1062591; 100,1062835])
                annotation (Placement(transformation(extent={{150,80},{170,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,73.64; 30,112.5; 40,140.9; 50,126.9; 60,57.44; 70,66.02; 80,74.71; 90,
                    83.33; 100,91.28])
                annotation (Placement(transformation(extent={{150,50},{170,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.16e5; 30,85.37e5; 40,85.67e5; 50,89.35e5; 60,108.5e5; 70,124.9e5;
                    80,140.5e5; 90,156.1e5; 100,172e5])
                annotation (Placement(transformation(extent={{140,-190},{120,-170}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,352001; 30,350485; 40,348819; 50,345637; 60,358364; 70,359274; 80,360183;
                    90,360789; 100,359728])
                annotation (Placement(transformation(extent={{140,-60},{120,-40}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8; 90,557.8;
                    100,619.8])
                annotation (Placement(transformation(extent={{140,-90},{120,-70}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1231872; 30,1254900; 40,1267700; 50,1288400; 60,1465700; 70,1509000;
                    80,1564800; 90,1614700; 100,1649351])
                annotation (Placement(transformation(extent={{-120,-160},{-100,-140}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,73.64; 30,112.5; 40,140.9; 50,126.9; 60,57.44; 70,66.02; 80,74.71; 90,
                    83.33; 100,91.28])
                annotation (Placement(transformation(extent={{-120,-190},{-100,-170}})));

              Real load = sourceMS2.w/sourceMS2.w0;
              Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                t_ramp=8e6,
                load_end=20)
                            annotation (Placement(transformation(extent={{-300,
                        -220},{-260,-180}})));
              Modelica.Blocks.Sources.Ramp LOAD_SH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-310,130})));
              Modelica.Blocks.Sources.Ramp LOAD_RH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-100,130})));
              Modelica.Blocks.Sources.Ramp LOAD_ECO(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={110,130})));
              Modelica.Blocks.Sources.Ramp LOAD_EVA1(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-170,-160})));
              Modelica.Blocks.Sources.Ramp LOAD_EVA2(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={190,-110})));
            equation
              connect(sinkMS.flange, PDMSSH.outlet) annotation (Line(
                  points={{-160,130},{-170,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.outlet, sinkSteam.flange) annotation (Line(
                  points={{-210,170},{-210,190},{-190,190}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange, SH.inletCold) annotation (Line(
                  points={{-230,30},{-210,30},{-210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-230,130},{-220,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SH.outletHot, PDMSSH.inlet) annotation (Line(
                  points={{-200,130},{-190,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-210,150},{-210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS1.flange, PDMSRH.outlet) annotation (Line(
                  points={{50,130},{40,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.outlet, sinkSteam1.flange) annotation (Line(
                  points={{4.44089e-016,170},{0,170},{0,188},{20,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam1.flange, RH.inletCold) annotation (Line(
                  points={{-20,30},{0,30},{0,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS1.flange, RH.inletHot) annotation (Line(
                  points={{-20,130},{-10,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.outletHot,PDMSRH. inlet) annotation (Line(
                  points={{10,130},{20,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.inlet,RH. outletCold) annotation (Line(
                  points={{0,150},{0,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS2.flange, PDMSECO.outlet) annotation (Line(
                  points={{260,130},{250,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.outlet, sinkSteam2.flange) annotation (Line(
                  points={{210,170},{210,188},{230,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam2.flange, ECO.inletCold) annotation (Line(
                  points={{192,30},{210,30},{210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS2.flange, ECO.inletHot) annotation (Line(
                  points={{190,130},{200,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(ECO.outletHot, PDMSECO.inlet) annotation (Line(
                  points={{220,130},{230,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{210,150},{210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS4.flange,PDMSEVA1. outlet) annotation (Line(
                  points={{-120,-110},{-100,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange,EVA1. inletCold) annotation (Line(
                  points={{-80,-210},{-60,-210},{-60,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot,PDMSEVA1. inlet) annotation (Line(
                  points={{-70,-110},{-80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.inlet,EVA1. outletCold) annotation (Line(
                  points={{-10,-60},{-60,-60},{-60,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.outlet,sinkSteam5. flange) annotation (Line(
                  points={{70,-160},{70,-210},{90,-210}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS5.flange,EVA2. inletHot) annotation (Line(
                  points={{100,-110},{80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,PDMSEVA2. inlet) annotation (Line(
                  points={{60,-110},{10,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.inlet,EVA2. outletCold) annotation (Line(
                  points={{70,-140},{70,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(w_MS_SH.y[1], sourceMS.in_w0) annotation (Line(
                  points={{-249,160},{-244,160},{-244,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_SH.y[1], sourceSteam.in_w0) annotation (Line(
                  points={{-249,60},{-244,60},{-244,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_SH.y[1], sourceSteam.in_h) annotation (Line(
                  points={{-249,90},{-236,90},{-236,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_SH.y[1], sinkSteam.in_p0) annotation (Line(
                  points={{-209,220},{-184,220},{-184,198.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_RH.y[1], sourceSteam1.in_w0) annotation (Line(
                  points={{-39,60},{-34,60},{-34,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_RH.y[1], sourceSteam1.in_h) annotation (Line(
                  points={{-39,90},{-26,90},{-26,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_RH.y[1], sourceMS1.in_w0) annotation (Line(
                  points={{-39,160},{-34,160},{-34,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_RH.y[1], sinkSteam1.in_p0) annotation (Line(
                  points={{1,220},{26,220},{26,196.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_MS_ECO.y[1], sourceMS2.in_h)
                annotation (Line(points={{171,190},{184,190},{184,136}}, color={0,0,127}));
              connect(p_ST_ECO.y[1], sinkSteam2.in_p0) annotation (Line(points={{211,220},{222,
                      220},{236,220},{236,196.8}}, color={0,0,127}));
              connect(w_MS_ECO.y[1], sourceMS2.in_w0) annotation (Line(points={{171,160},{174,
                      160},{176,160},{176,136}}, color={0,0,127}));
              connect(h_ST_ECO.y[1], sourceSteam2.in_h) annotation (Line(points={{171,90},{176,
                      90},{186,90},{186,36}}, color={0,0,127}));
              connect(w_ST_ECO.y[1], sourceSteam2.in_w0)
                annotation (Line(points={{171,60},{178,60},{178,36}}, color={0,0,127}));
              connect(h_ST_EVA.y[1], sourceSteam4.in_h) annotation (Line(points={{-99,-150},
                      {-92,-150},{-86,-150},{-86,-204}}, color={0,0,127}));
              connect(w_ST_EVA.y[1], sourceSteam4.in_w0) annotation (Line(points={{-99,-180},
                      {-94,-180},{-94,-204}}, color={0,0,127}));
              connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(points={{10,-60},
                      {42,-60},{70,-60},{70,-100}},    color={0,0,255}));
              connect(EVA1.inletHot, PDMSEVA2.outlet)
                annotation (Line(points={{-50,-110},{-10,-110}},         color={0,0,255}));
              connect(h_MS_EVA.y[1], sourceMS5.in_h) annotation (Line(points={{119,-50},{106,
                      -50},{106,-104}}, color={0,0,127}));
              connect(w_MS_EVA.y[1], sourceMS5.in_w0) annotation (Line(points={{119,-80},{116,
                      -80},{114,-80},{114,-104}},   color={0,0,127}));
              connect(p_ST_EVA.y[1], sinkSteam5.in_p0) annotation (Line(points={{119,-180},{
                      106,-180},{96,-180},{96,-201.2}},   color={0,0,127}));
              connect(LOAD_SH.y, p_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,220},{-232,220}}, color={0,0,127}));
              connect(LOAD_SH.y, w_MS_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,160},{-272,160}}, color={0,0,127}));
              connect(LOAD_SH.y, h_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,90},{-272,90}}, color={0,0,127}));
              connect(LOAD_SH.y, w_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,60},{-272,60}}, color={0,0,127}));
              connect(LOAD_RH.y, p_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,220},{-22,220}}, color={0,0,127}));
              connect(LOAD_RH.y, w_MS_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,160},{-62,160}}, color={0,0,127}));
              connect(LOAD_RH.y, h_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,90},{-62,90}}, color={0,0,127}));
              connect(LOAD_RH.y, w_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,60},{-62,60}}, color={0,0,127}));
              connect(LOAD_ECO.y, p_ST_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,220},{188,220}}, color={0,0,127}));
              connect(LOAD_ECO.y, h_MS_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,190},{148,190}}, color={0,0,127}));
              connect(LOAD_ECO.y, w_MS_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,160},{148,160}}, color={0,0,127}));
              connect(LOAD_ECO.y, h_ST_ECO.u[1]) annotation (Line(points={{121,130},{126,130},
                      {130,130},{130,90},{148,90}}, color={0,0,127}));
              connect(LOAD_ECO.y, w_ST_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,60},{148,60}}, color={0,0,127}));
              connect(LOAD_EVA1.y, h_ST_EVA.u[1]) annotation (Line(points={{-159,-160},{-140,
                      -160},{-140,-150},{-122,-150}}, color={0,0,127}));
              connect(LOAD_EVA1.y, w_ST_EVA.u[1]) annotation (Line(points={{-159,-160},{-150,
                      -160},{-140,-160},{-140,-180},{-122,-180}}, color={0,0,127}));
              connect(LOAD_EVA2.y, h_MS_EVA.u[1]) annotation (Line(points={{179,-110},{170,-110},
                      {160,-110},{160,-50},{142,-50}}, color={0,0,127}));
              connect(LOAD_EVA2.y, w_MS_EVA.u[1]) annotation (Line(points={{179,-110},{160,-110},
                      {160,-80},{142,-80}}, color={0,0,127}));
              connect(LOAD_EVA2.y, p_ST_EVA.u[1]) annotation (Line(points={{179,-110},{160,-110},
                      {160,-180},{142,-180}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-340,
                        -260},{340,260}}),        graphics={Text(
                      extent={{-210,110},{-170,90}},
                      lineColor={0,0,255},
                      textString="SH"), Text(
                      extent={{0,110},{40,90}},
                      lineColor={0,0,255},
                      textString="RH"), Text(
                      extent={{210,110},{250,90}},
                      lineColor={0,0,255},
                      textString="ECO"),Text(
                      extent={{-18,-130},{22,-150}},
                      lineColor={0,0,255},
                      textString="EVA"),
                    Text(
                      extent={{-300,-20},{-208,-104}},
                      lineColor={28,108,200},
                      textString="NOTA BENE:
Con 20 nodi
non va ancora")}),                        Icon(coordinateSystem(extent={{-340,-260},{
                        340,260}})),
                experiment(StopTime=8e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign;

            model test_heatExchangers_offDesign_HPH
              "Test model of the MS_HPH, from nominal load to 20% load, steady-state initialisation"
              extends Modelica.Icons.Example;
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,120},{-100,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS3(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                w0=619.8,
                h=110237) annotation (Placement(transformation(extent={{-30,-20},
                        {-10,0}})));

              ThermoPower.Water.SourceMassFlow sourceSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=24.51,
                h=1062835)
                annotation (Placement(transformation(extent={{-30,-120},{-10,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17382090)
                annotation (Placement(transformation(extent={{30,40},{50,60}})));
              ThermoPower.Water.SinkPressure sinkMS3(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=220963) annotation (Placement(transformation(extent={{60,-20},
                        {80,0}})));

              ThermoPower.Water.PressDrop PDMSHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                wnom=619.8,
                dpnom=(0.29037)*10^5,
                rhonom=1905.6) annotation (Placement(transformation(extent={{30,
                        -20},{50,0}})));

              ThermoPower.Water.PressDrop PDSteamHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=24.51,
                dpnom=(0.17906)*10^5,
                rhonom=747.382)      annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={10,20})));
              Components.HE HPH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.536143, gamma_nom=3958.9),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.447465, gamma_nom=2197.5),
                Vhot=3.789,
                Vcold=0.781,
                Shot=314.9,
                Scold=248,
                Mm=3802,
                nominalColdFlow=24.51,
                nominalHotFlow=619.8,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Nhex=10,
                nominalColdPressure=17400000,
                nominalHotPressure=400000,
                nominalColdInletTemperature=518.15,
                nominalColdOutletTemperature=564.15,
                nominalHotInletTemperature=569.15,
                nominalHotOutletTemperature=563.15,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                    noInitialPressure=false))       annotation (Placement(
                    transformation(extent={{0,-20},{20,0}})));

              Modelica.Blocks.Tables.CombiTable1D p_ST_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                    70,126.1e5; 80,141.3e5; 90,157.8e5; 100,173.5e5])
                annotation (Placement(transformation(extent={{-10,90},{10,110}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                    70,91538; 80,97902; 90,103659; 100,110023])
                annotation (Placement(transformation(extent={{-50,50},{-30,70}})));

              //Real load = sourceMS2.w/sourceMS2.w0;
              Modelica.Blocks.Sources.Ramp LOAD_HPH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-90,0})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_HPH(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1231872; 30,1252286; 40,1261764; 50,1256708; 60,1117992; 70,1062175;
                    80,1062373; 90,1062591; 100,1062835])
                annotation (Placement(transformation(extent={{-50,-50},{-30,-30}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_HPH(table=[20,0.1; 30,
                    0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,6.473; 100,
                    24.51], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
                annotation (Placement(transformation(extent={{-50,-80},{-30,-60}})));
              Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                t_ramp=4e6,
                load_end=20)  annotation (Placement(transformation(extent={{-120,
                        -140},{-80,-100}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_HPH(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8; 90,557.8;
                    100,619.8])
                annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
            equation
              connect(sinkMS3.flange, PDMSHPH.outlet) annotation (Line(
                  points={{60,-10},{50,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.outlet, sinkSteam3.flange) annotation (Line(
                  points={{10,30},{10,50},{30,50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam3.flange, HPH.inletCold) annotation (Line(
                  points={{-10,-110},{10,-110},{10,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS3.flange, HPH.inletHot) annotation (Line(
                  points={{-10,-10},{0,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(HPH.outletHot, PDMSHPH.inlet) annotation (Line(
                  points={{20,-10},{30,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.inlet, HPH.outletCold) annotation (Line(
                  points={{10,10},{10,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(p_ST_HPH.y[1], sinkSteam3.in_p0) annotation (Line(points={{11,100},
                      {11,100},{36,100},{36,58.8}},       color={0,0,127}));
              connect(h_MS_HPH.y[1], sourceMS3.in_h) annotation (Line(points={{-29,60},{-16,
                      60},{-16,-4}},     color={0,0,127}));
              connect(LOAD_HPH.y, h_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,-40},{-52,-40}}, color={0,0,127}));
              connect(LOAD_HPH.y, w_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,-70},{-52,-70}}, color={0,0,127}));
              connect(h_ST_HPH.y[1], sourceSteam3.in_h) annotation (Line(points=
                     {{-29,-40},{-16,-40},{-16,-104}}, color={0,0,127}));
              connect(w_ST_HPH.y[1], sourceSteam3.in_w0) annotation (Line(
                    points={{-29,-70},{-24,-70},{-24,-104}}, color={0,0,127}));
              connect(LOAD_HPH.y, p_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-74,0},{-70,0},{-70,100},{-12,100}}, color={0,0,127}));
              connect(LOAD_HPH.y, h_MS_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,60},{-52,60}}, color={0,0,127}));
              connect(w_MS_HPH.y[1], sourceMS3.in_w0) annotation (Line(points={
                      {-29,30},{-24,30},{-24,-4}}, color={0,0,127}));
              connect(LOAD_HPH.y, w_MS_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,30},{-52,30}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -140},{120,140}}),        graphics={
                                        Text(
                      extent={{10,-30},{50,-50}},
                      lineColor={0,0,255},
                      textString="HPH")}),Icon(coordinateSystem(extent={{-120,-140},{120,140}})),
                experiment(StopTime=4e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign_HPH;

          end HE;

          package OTSG "Package of whole OTSG test models"

            model test_OTSG_100 "Test model of the OTSG at 100% load"
                extends Modelica.Icons.Example;
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062.9e3,
                w0=115.85,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=84.94,
                h=3103000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4732000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1050000,
                h=519092)   annotation (Placement(transformation(extent={{-60,
                        90},{-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=100000)  annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17350000)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=17000000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=24.51)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad
                controllers(
                Ta_pumpFW=5,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmax_pumpFW=0.3,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                load_start=100,
                load_end=100,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                t_start_ramp=0,
                CSmin_valveBP=0.1,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                Kp_valveTURB=-1.077e-11,
                Ti_valveTURB=2.164,
                useTS_valveTURB=false,
                useTS_pumpFW=false,
                Ti_pumpFW=100,
                Kp_pumpFW=-0.02,
                DT_SH_sp=20,
                Kp_pumpMS=4.57e-4,
                Ti_pumpMS=98.66,
                CSmin_pumpMS=-0 - 5,
                CSmax_pumpMS=0.5,
                Ta_pumpMS=2,
                CSmin_valveTURB=-0.5,
                CSmax_valveTURB=0.5,
                Ta_valveTURB=0.3,
                Kp_valveBP=-7.93e-6,
                Ti_valveBP=0.001,
                T_FW_sp=518.15,
                T_MS_sp=558.15) annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}}),
                    iconTransformation(extent={{-120,-120},{-100,-100}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              OTSG_init100_5nodes OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState) annotation (
                  Placement(transformation(extent={{-120,100},{-100,120}})));
            equation
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{6,-80},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                      {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},
                      {-6.66667,100},{-6.66667,61.6667}},
                                           color={0,0,255}));
              connect(sinkSH.flange, OTSG.SH_out) annotation (Line(points={{40,80},
                      {6.66667,80},{6.66667,61.6667}},
                                            color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -26.6667,-41.6667},{-26.6667,-60},{-30,-60}},
                                            color={0,0,255}));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                      -6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                                                   color={0,0,255}));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{21.6667,
                      46.6667},{40,46.6667},{40,40},{60,40}},         color={0,0,
                      255}));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{74,-80},{74,-26}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}})),
                experiment(StopTime=10000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_100;

            model test_OTSG_50 "Test model of the OTSG at 50% load"
              extends Modelica.Icons.Example;
              OTSG_init50_5nodes OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=46.95,
                h=1077.2e3)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=39.99,
                h=3152000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=2266000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=519092) annotation (Placement(transformation(extent={{-60,90},
                        {-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(
                  allowFlowReversal=false, initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=10320000)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=8830000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=0,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Schemes.PlantControlSchemes.plant_controller_HPpart_lowLoad
                controllers(
                actuatorGain_pumpSEP=1,
                actuatorGain_pumpHPH=1,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                actuatorGain_valveTURB=1,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                l_sp=4,
                t_ramp=0,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                load_start=50,
                load_end=50,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                CSmin_valveBP=0,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                t_start_ramp=0,
                useTS_pumpFW=false,
                CSmax_pumpFW=100,
                Ta_pumpFW=2,
                Ta_pumpMS=2,
                Ta_valveTURB=0.3,
                Ti_pumpFW=50,
                P_mec_sp=79725800,
                CSmin_pumpFW=2,
                CSstart_pumpFW=0,
                useTS_pumpSEP=false,
                useTS_valveTURB=false,
                CSmin_pumpSEP=-0.3,
                CSmax_pumpSEP=0.3,
                Kp_pumpMS=1.47e-4,
                Ti_pumpMS=29.12,
                CSmin_pumpMS=-0.5,
                CSmax_pumpMS=0.5,
                p_sp=17610000,
                Kp_valveTURB=-1.52e-11,
                Ti_valveTURB=3.626,
                CSmin_valveTURB=-0.5,
                CSmax_valveTURB=0.5,
                Kp_pumpFW=17.6,
                Kp_valveBP=-7.93e-6,
                Ti_valveBP=0.001,
                Ta_pumpHPH=0.3,
                T_FW_sp=558.15,
                Kp_pumpSEP=1.52e-2,
                Ti_pumpSEP=2.267,
                Ta_pumpSEP=2)   annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              Modelica.Icons.SignalBus signalBus annotation (Placement(
                    transformation(extent={{-70,-30},{-50,-10}}), iconTransformation(extent=
                       {{-120,-120},{-100,-100}})));
            equation
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(
                  points={{21.6667,-28.3333},{40,-28.3333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(
                  points={{21.6667,46.6667},{40,46.6667},{40,40},{60,40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                  points={{-40,100},{-26.6667,100},{-26.6667,61.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS.flange, OTSG.MS_out) annotation (Line(
                  points={{-30,-60},{-26,-60},{-26,-41.6667},{-26.6667,-41.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(
                  points={{-6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_out, sinkRH.flange) annotation (Line(
                  points={{-6.66667,61.6667},{-6.66667,100},{20,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SH_out, sinkSH.flange) annotation (Line(
                  points={{6.66667,61.6667},{6.66667,80},{40,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{21.6667,-3.33333},{40,-3.33333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-64,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{6,-80},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-80},{6,-80},{74,-80},{74,
                      -26}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model has to be initialized  in steady-state, through the system component, so that the pressure terms do no influence the mass flow balances. The OTSG can be selected between the 5 nodes and 20 nodes model. </span></p>
</html>"));
            end test_OTSG_50;

            model test_OTSG_20 "Test model of the OTSG at 20% load"
                extends Modelica.Icons.Example;
              OTSG_init20_5nodes OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=46.95,
                h=883.8e3)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=15.45,
                h=3175000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=883900)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=519092) annotation (Placement(transformation(extent={{-60,90},
                        {-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(
                  allowFlowReversal=false, initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=8400000)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=8508000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=0,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Schemes.PlantControlSchemes.plant_controller_HPpart_lowLoad
                controllers(
                actuatorGain_pumpSEP=1,
                actuatorGain_pumpHPH=1,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                actuatorGain_valveTURB=1,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                l_sp=4,
                t_ramp=0,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                CSmin_valveBP=0,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                t_start_ramp=0,
                useTS_pumpFW=false,
                CSmax_pumpFW=100,
                Ta_pumpFW=2,
                Ta_pumpMS=2,
                Ta_valveTURB=0.3,
                Ti_pumpFW=50,
                P_mec_sp=79725800,
                CSmin_pumpFW=2,
                CSstart_pumpFW=0,
                useTS_pumpSEP=false,
                useTS_valveTURB=false,
                Kp_pumpMS=1.47e-4,
                Ti_pumpMS=29.12,
                CSmin_pumpMS=-0.5,
                CSmax_pumpMS=0.5,
                Kp_valveTURB=-1.52e-11,
                Ti_valveTURB=3.626,
                CSmin_valveTURB=-0.5,
                CSmax_valveTURB=0.5,
                Kp_pumpFW=17.6,
                Kp_valveBP=-7.93e-6,
                Ti_valveBP=0.001,
                Ta_pumpHPH=0.3,
                Kp_pumpSEP=1.52e-2,
                Ti_pumpSEP=2.267,
                Ta_pumpSEP=2,
                load_start=20,
                load_end=20,
                p_sp=17610000,
                T_FW_sp=558.15,
                CSmin_pumpSEP=-0.5,
                CSmax_pumpSEP=0.5)
                                annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              Modelica.Icons.SignalBus signalBus annotation (Placement(
                    transformation(extent={{-70,-30},{-50,-10}}), iconTransformation(extent=
                       {{-120,-120},{-100,-100}})));
            equation
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(
                  points={{21.6667,-28.3333},{40,-28.3333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(
                  points={{21.6667,46.6667},{40,46.6667},{40,40},{60,40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                  points={{-40,100},{-26.6667,100},{-26.6667,61.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS.flange, OTSG.MS_out) annotation (Line(
                  points={{-30,-60},{-26,-60},{-26,-41.6667},{-26.6667,-41.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(
                  points={{-6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_out, sinkRH.flange) annotation (Line(
                  points={{-6.66667,61.6667},{-6.66667,100},{20,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SH_out, sinkSH.flange) annotation (Line(
                  points={{6.66667,61.6667},{6.66667,80},{40,80}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{21.6667,-3.33333},{40,-3.33333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-64,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{6,-80},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-80},{6,-80},{74,-80},{74,
                      -26}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model has to be initialized  in steady-state, through the system component, so that the pressure terms do no influence the mass flow balances. The OTSG can be selected between the 5 nodes and 20 nodes model. </span></p>
</html>"));
            end test_OTSG_20;

            model test_OTSG_FWsensitivity "Test model of the OTSG at 100% load"
              extends Modelica.Icons.Example;
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062.9e3,
                w0=115.85,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{80,-30},{60,-10}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=84.94,
                h=3103000,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4732000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1050000,
                h=519092)   annotation (Placement(transformation(extent={{-60,
                        90},{-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=100000)  annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17350000)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=17000000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=24.51)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad
                controllers(
                actuatorGain_pumpHPH=1,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                actuatorGain_valveTURB=1,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                load_start=100,
                load_end=100,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                t_start_ramp=0,
                CSmin_valveBP=0.1,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                useTS_valveTURB=false,
                DT_SH_sp=20,
                Kp_pumpMS=4.57e-4,
                Ti_pumpMS=98.66,
                CSmin_pumpMS=-0.5,
                CSmax_pumpMS=0.5,
                Ta_pumpMS=2,
                Ti_valveTURB=2.164,
                Ta_valveTURB=0.3,
                Kp_pumpFW=-0.02,
                Ti_pumpFW=100,
                CSmin_pumpFW=-0.5,
                CSmax_pumpFW=0.5,
                Ta_pumpFW=2,
                Kp_valveBP=-7.93e-6,
                Ti_valveBP=0.001,
                Ta_pumpHPH=0.3,
                Kp_valveTURB=-1.077e-11,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                useTS_pumpFW=true,
                T_FW_sp=518.15,
                T_MS_sp=563.15)
                               annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}}),
                    iconTransformation(extent={{-120,-120},{-100,-100}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              OTSG_init100_5nodes     OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
              Modelica.Blocks.Sources.Step step(
                startTime=10000,
                offset=115.85,
                height=+1) annotation (Placement(transformation(extent={{100,0},
                        {80,20}})));
              Modelica.Blocks.Sources.Step step1(
                startTime=10000,
                offset=84.94,
                height=+1) annotation (Placement(transformation(extent={{100,60},
                        {80,80}})));
            equation
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-100},{6,-100},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                      {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},
                      {-6.66667,100},{-6.66667,61.6667}},
                                           color={0,0,255}));
              connect(sinkSH.flange, OTSG.SH_out) annotation (Line(points={{40,80},
                      {6.66667,80},{6.66667,61.6667}},
                                            color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -26.6667,-41.6667},{-26.6667,-60},{-30,-60}},
                                            color={0,0,255}));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                      -6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                                                   color={0,0,255}));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{21.6667,
                      46.6667},{40,46.6667},{40,40},{60,40}},         color={0,0,
                      255}));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(step.y, sourceFW.in_w0) annotation (Line(points={{79,10},
                      {74,10},{74,-14}}, color={0,0,127}));
              connect(sourceRH.in_w0, step1.y) annotation (Line(points={{74,46},
                      {74,70},{79,70}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}})),
                experiment(StopTime=20000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_FWsensitivity;

            model test_OTSG_HPHsensitivity
              "Test model of the OTSG at 100% load"
              extends Modelica.Icons.Example;
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062.9e3,
                w0=115.85,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                w0=84.94,
                h=3103000)
                annotation (Placement(transformation(extent={{80,30},{60,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4732000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1050000,
                h=519092)   annotation (Placement(transformation(extent={{-60,
                        90},{-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=100000)  annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              ThermoPower.Water.SinkPressure sinkHPH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=17350000)
                annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=17000000)
                annotation (Placement(transformation(extent={{40,70},{60,90}})));
              ThermoPower.Water.ThroughMassFlow pump_HPH(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=24.51)
                annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
              Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad_wHPHsens
                controllers(
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSstart_pumpFW=0,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                load_start=100,
                load_end=100,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Nd_pumpMS=20,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                t_start_ramp=0,
                Kp_valveBP=1,
                Ti_valveBP=1,
                Td_valveBP=0,
                Nd_valveBP=20,
                CSmin_valveBP=0.1,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                Kp_valveTURB=-1.077e-11,
                Ti_valveTURB=2.164,
                useTS_valveTURB=false,
                useTS_pumpFW=false,
                Ti_pumpFW=100,
                Td_pumpFW=0,
                Kp_pumpFW=-0.02,
                DT_SH_sp=20,
                CSmax_pumpFW=0.4,
                Kp_pumpMS=4.57e-4,
                Ti_pumpMS=98.66,
                Td_pumpMS=1.128,
                CSmin_pumpMS=-0.5,
                CSmax_pumpMS=0.5,
                Ta_pumpMS=2,
                Ta_pumpFW=2,
                T_FW_sp=518.15,
                T_MS_sp=558.15) annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}}),
                    iconTransformation(extent={{-120,-120},{-100,-100}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              OTSG_init100_5nodes OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
            equation
              connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                  points={{20,-60},{40,-60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-80},{6,-80},{6,-66}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                      {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},
                      {-6.66667,100},{-6.66667,61.6667}},
                                           color={0,0,255}));
              connect(sinkSH.flange, OTSG.SH_out) annotation (Line(points={{40,80},
                      {6.66667,80},{6.66667,61.6667}},
                                            color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -26.6667,-41.6667},{-26.6667,-60},{-30,-60}},
                                            color={0,0,255}));
              connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                      -6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                                                   color={0,0,255}));
              connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{21.6667,
                      46.6667},{40,46.6667},{40,40},{60,40}},         color={0,0,
                      255}));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-80},{74,-80},{74,-26}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}})),                  Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}})),
                experiment(StopTime=30000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_HPHsensitivity;

            model test_recirculationSection
              "Test model to check the need of decoupling between feedwater and recirculated mass flow"
              extends Modelica.Icons.Example;
              Components.nonEquilibriumVessel separator(
                H=8,
                zl_start=4,
                D=0.56,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                noInitialPressure=true,
                gamma=50,
                hv_start=2.7e6,
                hl_start=1.3e6,
                p_start=10100000,
                noInitialLevel=false)
                annotation (Placement(transformation(extent={{-68,68},{-12,124}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                use_in_w0=true,
                w0=10,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={-40,16})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                rhonom=582.24,
                wnom=88.59,
                pin(start=102e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-180,22})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15,
                pin(start=103e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-180,-60})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250,
                pin(start=10150000),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-130,88})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Length sep_lev = separator.zl;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              Modelica.SIunits.MassFlowRate Fpos = ECO.coldFluid.w*(1-x_EVA2_out);
              Modelica.SIunits.MassFlowRate Fneg = separator.wl_out;
              Modelica.SIunits.SpecificEnthalpy Q1 = ECO.coldFluid.h[1];
              Modelica.SIunits.SpecificEnthalpy Q2 = Q_tot/ECO.coldFluid.w;

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-260,140},{-240,160}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062500,
                w0=45.93,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{110,-150},{90,-130}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-220,-110},
                        {-240,-90}})));

              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10100000)
                annotation (Placement(transformation(extent={{80,130},{100,150}})));
              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=180,
                    origin={-46,-136})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=305.3,
                h=328503,
                use_in_w0=false) annotation (Placement(transformation(extent={{
                        -130,70},{-150,50}})));

              ThermoPower.PowerPlants.Control.PID PID_levelControl(
                Ti=56,
                PVmin=0,
                PVmax=8,
                CSmin=0,
                PVstart=0.5392,
                CSstart=0.5,
                holdWhenSimplified=true,
                steadyStateInit=true,
                Kp=-14,
                CSmax=250)            annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,66})));
              Modelica.Blocks.Continuous.FirstOrder firstOrder(
                k=1,
                initType=Modelica.Blocks.Types.Init.SteadyState,
                y_start=53.92,
                T=2)           annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,38})));
              Modelica.Blocks.Sources.Constant const(k=4) annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={130,82})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                      1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                      1.94272e+006,2.02642e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                    602.087,604.627,607.543,610.89,614.73,619.134}),
                Vhot=3.905,
                Vcold=1.065,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000),
                Shot=429.2*1,
                Scold=338*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={344122,316769,292958,272234,254202,238514,224868,213001,202681,193708},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-164,44},{-196,76}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                      1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                      1.45658e+006,1.56606e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                    577.742,579.999,582.568,585.511,585.959,587.035}),
                Vhot=26.587,
                Vcold=8.651,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    alpha=1.6,
                    gamma_nom_2ph=10000),
                Shot=2251.9*1,
                Scold=1765.5*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={193708,157918,143681,138009,133137,128914,125226,121985,119121,116578},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-196,-36},{-164,-4}})));

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                      1.3288e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                    569.474}),
                Vhot=45.011,
                Vcold=5.752,
                Nhex=5,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={119114,110526,103784,98376.4,93969.4},
                  noInitialPressure=true))
                annotation (Placement(transformation(extent={{-164,-116},{-196,
                        -84}})));
              Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={90,-40})));
              Modelica.Blocks.Sources.Constant const1(k=0)
                annotation (Placement(transformation(extent={{140,-80},{120,-60}})));
              Modelica.Blocks.Sources.BooleanStep booleanStep3(startValue=true, startTime=1000)
                annotation (Placement(transformation(extent={{140,-50},{120,-30}})));
              Modelica.Blocks.Logical.Switch switch1 annotation (Placement(
                    transformation(
                    extent={{-10,10},{10,-10}},
                    rotation=270,
                    origin={98,-78})));
              Modelica.Blocks.Math.Add add(k1=-1, k2=1) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={90,-10})));
              Modelica.Blocks.Sources.Constant const2(k=53.92)
                annotation (Placement(transformation(extent={{140,0},{120,20}})));
              Modelica.Blocks.Math.Add add1(k1=1, k2=-1) annotation (Placement(
                    transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={104,-114})));
              Modelica.Blocks.Sources.Constant const3(k=45.93)
                annotation (Placement(transformation(extent={{160,-120},{140,-100}})));
              Modelica.Blocks.Sources.Step step(
                offset=305.3,
                startTime=1010,
                height=30) annotation (Placement(transformation(extent={{-80,30},
                        {-100,50}})));
            equation
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{-40,78},{-40,26}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-120,88},{-50,88}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(flowJoin.in1, sourceFW.flange) annotation (Line(
                  points={{-40,-140},{-40,-140},{90,-140}},
                  color={0,0,255},
                  thickness=0.5));
              connect(waterPump.outlet, flowJoin.in2) annotation (Line(
                  points={{-40,6},{-40,-132}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSH.flange, separator.steam_out) annotation (Line(
                  points={{80,140},{-40,140},{-40,120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(separator.level, PID_levelControl.PV)
                annotation (Line(points={{-30,82},{86,82},{86,76}},color={0,0,127}));
              connect(PID_levelControl.CS, firstOrder.u)
                annotation (Line(points={{90,56},{90,50}}, color={0,0,127}));
              connect(firstOrder.y, waterPump.in_w0)
                annotation (Line(points={{90,27},{90,20},{-34,20}},
                                                                  color={0,0,127}));
              connect(const.y, PID_levelControl.SP) annotation (Line(points={{119,82},
                      {108,82},{94,82},{94,76}},
                                        color={0,0,127}));
              connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
                  points={{-140,88},{-162,88},{-180,88},{-180,76}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletHot, sourceMS.flange) annotation (Line(
                  points={{-164,60},{-150,60}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-196,60},{-220,60},{-220,-20},{-196,-20}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-164,-20},{-152,-20},{-140,-20},{-140,-100},{-164,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(sinkMS.flange, ECO.outletHot) annotation (Line(
                  points={{-220,-100},{-208,-100},{-196,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{-180,-70},{-180,-77},{-180,-84}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                  points={{-180,-36},{-180,-36},{-180,-50}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamEVA1.inlet, EVA1.outletCold) annotation (Line(
                  points={{-180,12},{-180,12},{-180,-4}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-180,44},{-180,32}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, flowJoin.out) annotation (Line(
                  points={{-180,-116},{-140,-116},{-140,-136},{-52,-136}},
                  color={0,0,255},
                  thickness=0.5));
              connect(const1.y,switch1. u3) annotation (Line(points={{119,-70},{
                      119,-70},{112,-70},{112,-60},{106,-60},{106,-66}},
                                                      color={0,0,127}));
              connect(booleanStep3.y,switch1. u2) annotation (Line(points={{119,-40},
                      {119,-40},{112,-40},{112,-48},{98,-48},{98,-66}},    color={255,0,
                      255}));
              connect(gain.y, switch1.u1)
                annotation (Line(points={{90,-51},{90,-68},{90,-66}}, color={0,0,127}));
              connect(add.y, gain.u)
                annotation (Line(points={{90,-21},{90,-28}}, color={0,0,127}));
              connect(firstOrder.y, add.u2) annotation (Line(points={{90,27},{90,
                      27},{90,12},{84,12},{84,2}},
                                       color={0,0,127}));
              connect(const2.y, add.u1)
                annotation (Line(points={{119,10},{96,10},{96,2}}, color={0,0,127}));
              connect(switch1.y, add1.u2)
                annotation (Line(points={{98,-89},{98,-89},{98,-102}}, color={0,0,127}));
              connect(add1.y, sourceFW.in_w0) annotation (Line(points={{104,-125},
                      {104,-125},{104,-134}},
                                   color={0,0,127}));
              connect(const3.y, add1.u1) annotation (Line(points={{139,-110},{134,
                      -110},{124,-110},{124,-94},{110,-94},{110,-102}},
                                                             color={0,0,127}));
              connect(sourceMS.in_w0, step.y) annotation (Line(points={{-136,54},
                      {-136,40},{-101,40}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-260,-160},{260,160}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-260,-160},{260,160}}, preserveAspectRatio=false)),
                Documentation(info="<html>
<p>Test model to chek the need of a decoupler between separator pump and feedwater mass flow rate. The model is initialised at 50&percnt; load with the decoupler active. After 1000 s the decoupler is switched off, so that an equivalent step on the feedwater flow is performed. </p>
<p>The separator pump reacts and increases the recirculated mass flow, leading to the instability. If x is the vapor quality at evaporator outlet we can write:</p>
<p><img src=\"modelica://PreFlexMS/Images/equations/equation-LkR73UrL.png\" alt=\"rho*A*der(l) = (w_FW + w_SEP)*(1-x) - w_SEP  \"/>            --&GT;liquid mass balance on the separator</p>
<p><img src=\"modelica://PreFlexMS/Images/equations/equation-yxtUkHRo.png\" alt=\"x = (h_ECOin + (Q_ECO + Q_EVA)/(w_FW + w_SEP) + h_ls)/(h_vs - h_ls) \"/>                <img src=\"modelica://PreFlexMS/Images/equations/equation-EZkMMYs8.png\" alt=\"x = (Q1 + Q2 + h_ls)/(h_vs - h_ls) \"/>                     --&GT; vapor quality</p>
<p><br>As the results of the simulation show, the instability is due to a permanent dl/dt &GT; 0 after the the FW step.</p>
</html>"),      experiment(StopTime=1500),
                __Dymola_experimentSetupOutput);
            end test_recirculationSection;

            model test_feedwaterLevelControl
              "Test model to show the feasibility of the level control through the feedwater"
              extends Modelica.Icons.Example;
              Components.nonEquilibriumVessel separator(
                H=8,
                zl_start=4,
                D=0.56,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                noInitialPressure=true,
                gamma=50,
                hv_start=2.7e6,
                hl_start=1.3e6,
                p_start=10100000,
                noInitialLevel=false)
                annotation (Placement(transformation(extent={{-28,68},{28,124}})));
              ThermoPower.Water.ThroughMassFlow waterPump(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=53.92,
                use_in_w0=true)
                       annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=-90,
                    origin={0,16})));

              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                dpnom=(0.05828)*10^5,
                rhonom=582.24,
                wnom=88.59,
                pin(start=102e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,22})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.52492)*10^5,
                rhonom=768.15,
                pin(start=103e5),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                               annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-100,-60})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                wnom=88.59,
                dpnom=(0.11171)*10^5,
                rhonom=250,
                pin(start=10150000),
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                     annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-64,88})));
              //Overall parameter and variables:
              Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
              Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
              Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
              Modelica.SIunits.Length sep_lev = separator.zl;
              Real x_EVA1_out = EVA1.coldFluid.x[end];
              Real x_EVA2_out = EVA2.coldFluid.x[end];
              Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;
              Modelica.SIunits.MassFlowRate Fpos = ECO.coldFluid.w*(1-x_EVA2_out);
              Modelica.SIunits.MassFlowRate Fneg = separator.wl_out;
              Modelica.SIunits.SpecificEnthalpy Q1 = ECO.coldFluid.h[1];
              Modelica.SIunits.SpecificEnthalpy Q2 = Q_tot/ECO.coldFluid.w;

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-180,140},{-160,160}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=1062500,
                w0=45.93,
                use_in_w0=true)
                annotation (Placement(transformation(extent={{86,-152},{66,-132}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-140,-110},
                        {-160,-90}})));

              ThermoPower.Water.SinkPressure sinkSH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=10100000)
                annotation (Placement(transformation(extent={{70,128},{90,148}})));
              ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                    Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=180,
                    origin={-6,-136})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                w0=305.3,
                h=328503,
                use_in_w0=true)  annotation (Placement(transformation(extent={{
                        -50,70},{-70,50}})));

              ThermoPower.PowerPlants.Control.PID PID_levelControl(
                PVmin=0,
                PVmax=8,
                CSmin=0,
                PVstart=0.5392,
                holdWhenSimplified=true,
                Ti=50,
                CSmax=120,
                CSstart=0.4,
                Kp=1,
                steadyStateInit=true) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={80,10})));
              Modelica.Blocks.Continuous.FirstOrder firstOrder(
                k=1,
                initType=Modelica.Blocks.Types.Init.SteadyState,
                y_start=53.92,
                T=2)           annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=270,
                    origin={80,-52})));
              Modelica.Blocks.Sources.Step     const(
                startTime=1000,
                offset=4,
                height=1)                                 annotation (Placement(
                    transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={120,82})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Mm=5182,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.56606e+006,1.59353e+006,1.62512e+006,1.66145e+006,
                      1.70321e+006,1.75123e+006,1.80642e+006,1.86984e+006,
                      1.94272e+006,2.02642e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {596.276,597.951,599.875,
                    602.087,604.627,607.543,610.89,614.73,619.134}),
                Vhot=3.905,
                Vcold=1.065,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    alpha=1.6,
                    gamma_nom_liq=2000,
                    gamma_nom_2ph=5000,
                    gamma_nom_vap=2000),
                Shot=429.2*1,
                Scold=338*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17760000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=629.15,
                nominalColdOutletTemperature=648.65,
                nominalHotInletTemperature=732.05,
                nominalHotOutletTemperature=687.95,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={344122,316769,292958,272234,254202,238514,224868,213001,202681,193708},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-84,44},{-116,76}})));

              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                Mm=43100,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                nominalColdFlow=88.59,
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.33e+006,1.3378e+006,1.34658e+006,1.35651e+006,
                      1.36781e+006,1.38075e+006,1.39566e+006,1.41303e+006,
                      1.45658e+006,1.56606e+006}),
                tubeWalls(Tvolstart(displayUnit="K") = {572.404,573.98,575.749,
                    577.742,579.999,582.568,585.511,585.959,587.035}),
                Vhot=26.587,
                Vcold=8.651,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    wnom_ht=88.59,
                    gamma_nom_liq=3875,
                    gamma_nom_vap=3875,
                    alpha=1.6,
                    gamma_nom_2ph=10000),
                Shot=2251.9*1,
                Scold=1765.5*1,
                Nhex=10,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17810000,
                nominalHotPressure=730800,
                nominalColdInletTemperature=623.75,
                nominalColdOutletTemperature=629.32,
                nominalHotInletTemperature=688.04,
                nominalHotOutletTemperature=629.15,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={193708,157918,143681,138009,133137,128914,125226,121985,119121,116578},
                  noInitialPressure=true))          annotation (Placement(
                    transformation(extent={{-116,-36},{-84,-4}})));

              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalHotFlow=610.6,
                nominalColdFlow=88.59,
                Shot=2394.2,
                Scold=1855.5,
                Mm=30395,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4400),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2200),
                coldFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  Nt=1,
                  hstart={1.25188e+006,1.26536e+006,1.2819e+006,1.30253e+006,
                      1.3288e+006}),
                tubeWalls(Tvolstart(displayUnit="degC") = {558.324,561.292,564.934,
                    569.474}),
                Vhot=45.011,
                Vcold=5.752,
                Nhex=5,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                nominalColdPressure=17910000,
                nominalHotPressure=569600,
                nominalColdInletTemperature=553.15,
                nominalColdOutletTemperature=623.79,
                nominalHotInletTemperature=628.75,
                nominalHotOutletTemperature=586.72,
                hotFluid(
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={119114,110526,103784,98376.4,93969.4},
                  noInitialPressure=true))
                annotation (Placement(transformation(extent={{-84,-116},{-116,-84}})));
              Modelica.Blocks.Sources.Step step(
                offset=305.3,
                startTime=3000,
                height=-30)
                           annotation (Placement(transformation(extent={{-20,30},
                        {-40,50}})));
              Modelica.Blocks.Sources.Step step1(
                offset=53.92,
                height=-10,
                startTime=3500)
                annotation (Placement(transformation(extent={{48,10},{28,30}})));
            equation
              connect(separator.drained_out, waterPump.inlet) annotation (Line(
                  points={{0,78},{0,26}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}));
              connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                  points={{-54,88},{-10,88}},
                  color={0,0,255},
                  smooth=Smooth.None,
                  thickness=0.5));

              connect(flowJoin.in1, sourceFW.flange) annotation (Line(
                  points={{8.88178e-016,-140},{8.88178e-016,-142},{66,-142}},
                  color={0,0,255},
                  thickness=0.5));
              connect(waterPump.outlet, flowJoin.in2) annotation (Line(
                  points={{0,6},{0,-132}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sinkSH.flange, separator.steam_out) annotation (Line(
                  points={{70,138},{0,138},{0,120}},
                  color={0,0,255},
                  thickness=0.5));
              connect(separator.level, PID_levelControl.PV)
                annotation (Line(points={{10,82},{76,82},{76,20}}, color={0,0,127}));
              connect(PID_levelControl.CS, firstOrder.u)
                annotation (Line(points={{80,0},{80,0},{80,-40}},
                                                           color={0,0,127}));
              connect(const.y, PID_levelControl.SP) annotation (Line(points={{109,82},
                      {98,82},{84,82},{84,20}},
                                        color={0,0,127}));
              connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
                  points={{-74,88},{-74,88},{-100,88},{-100,76}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletHot, sourceMS.flange) annotation (Line(
                  points={{-84,60},{-70,60}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                  points={{-116,60},{-140,60},{-140,-20},{-116,-20}},
                  color={255,0,0},
                  thickness=0.5));
              connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                  points={{-84,-20},{-72,-20},{-60,-20},{-60,-100},{-84,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(sinkMS.flange, ECO.outletHot) annotation (Line(
                  points={{-140,-100},{-128,-100},{-116,-100}},
                  color={255,0,0},
                  thickness=0.5));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{-100,-70},{-100,-77},{-100,-84}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA1.inletCold, PDSteamECO.outlet) annotation (Line(
                  points={{-100,-36},{-100,-36},{-100,-50}},
                  color={0,0,255},
                  thickness=0.5));
              connect(PDSteamEVA1.inlet, EVA1.outletCold) annotation (Line(
                  points={{-100,12},{-100,12},{-100,-4}},
                  color={0,0,255},
                  thickness=0.5));
              connect(EVA2.inletCold, PDSteamEVA1.outlet) annotation (Line(
                  points={{-100,44},{-100,32}},
                  color={0,0,255},
                  thickness=0.5));
              connect(ECO.inletCold, flowJoin.out) annotation (Line(
                  points={{-100,-116},{-100,-116},{-100,-136},{-12,-136}},
                  color={0,0,255},
                  thickness=0.5));
              connect(sourceMS.in_w0, step.y) annotation (Line(points={{-56,54},{
                      -56,40},{-41,40}},    color={0,0,127}));
              connect(firstOrder.y, sourceFW.in_w0) annotation (Line(points={{80,
                      -63},{80,-63},{80,-136}}, color={0,0,127}));
              connect(waterPump.in_w0, step1.y) annotation (Line(points={{6,20},{
                      6,20},{27,20}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(extent={{-180,-160},{180,160}},
                      preserveAspectRatio=false)),           Icon(coordinateSystem(
                      extent={{-180,-160},{180,160}}, preserveAspectRatio=false)),
                Documentation(info="<html>
<p>Test model to chek the feasibility of controlling the separator level through the feedwater mass flow rate. The model is initialised at 50&percnt; load. After 1000 s the level set point is changed from 4m to 5m, in order to evaluate the y0/y step response. At 3000 s the MS mass flow is increased, and the controller react correctly by increasing the FW mass flow. According to this test, the control philosophy is correct. </p>
<p>Note that the decoupler between the feedwater and recirculating pump is not necessary, since the sysyem is naturally decoupled.</p>
</html>"),      experiment(StopTime=4000),
                __Dymola_experimentSetupOutput);
            end test_feedwaterLevelControl;

          end OTSG;

        end Test;

        package Old

          model OTSG_init100_5nodes
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                    1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                    1.29502e+006,1.30052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                  558.906,561.752,563.806,565.297,566.385,567.182}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                    103396,100624}),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447465, gamma_nom=2197.5),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=564.15,
              nominalHotInletTemperature=569.15,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-244},{-44,-276}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                    1.64439e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                  620.01}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={196390,188158,176706,156967,110743}),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15)
              annotation (Placement(transformation(extent={{-44,-176},{-76,-144}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                    1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                    1.94183e+006,2.2136e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                  626.498,627.06,627.186,627.848,629.177,631.842}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                    194368,192799}),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65) annotation (Placement(
                  transformation(extent={{-76,-96},{-44,-64}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                    2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                    2.72547e+006,2.78281e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                  653.806,658.116,678.213,683.393,689.164,695.453}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                    284059,275898}),
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01) annotation (Placement(
                  transformation(extent={{-44,-16},{-76,16}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=2.75412e6,
              p_start=17200000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-40})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                    3.42217e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                  824.786}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,501167,469703,420819,359564}),
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                    3.55697e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                  829.056}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,502650,475154,429572,356689}),
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={100,180})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-86,210},{-66,230}})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-40})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-120})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={60,242})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={188,2}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-216},{80,-196}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP_EVA(redeclare package Medium =
                  coldMedium) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=-90,
                  origin={-4,180})));
            ThermoPower.Water.PressDrop PDSteamSH2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-194})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-226})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-80,242})));
            Graphics.Label_input pumpMS_CS annotation (Placement(transformation(
                    extent={{-40,266},{-80,254}})));
            Graphics.Label_output valveBP_PV annotation (Placement(transformation(
                    extent={{60,-206},{20,-194}})));
            Graphics.Label_input valveTURB_CS
              annotation (Placement(transformation(extent={{62,286},{22,274}})));
            Graphics.Label_output pumpFW_PV_high
              annotation (Placement(transformation(extent={{32,60},{78,72}})));
            Graphics.Label_output pumpFW_PV_low
              annotation (Placement(transformation(extent={{32,36},{78,48}})));
            Graphics.Label_input pumpSEP_CS
              annotation (Placement(transformation(extent={{70,-30},{30,-42}})));
            Graphics.Label_output valveTURB_PV annotation (Placement(
                  transformation(extent={{-30,184},{-70,196}})));
            Graphics.Label_output pumpSEP_PV annotation (Placement(transformation(
                    extent={{60,-192},{20,-180}})));
          equation
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-260},{-100,-260},{-100,-160},{-76,-160}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-276},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-144},{-60,-130}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-30},{1.77636e-015,-30}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-30},{-60,-16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-64},{-60,-50}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,16},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,0},{-100,0},{-100,-80},{-76,-80}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-80},{-20,-80},{-20,-160},{-44,-160}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-210},{96,-210},{130,-210},{190,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,220},{-86,220}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP_EVA.p) annotation (Line(
                points={{188,2},{156,2},{156,222},{156,212},{10,212},{10,202},{6,202},{6,188},
                    {-10,188}},
                color={256,256,256},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-96},{-60,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-176},{-60,-180},{-60,-184}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-236},{-60,-244}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{188,2},{130,2},{130,264},{8,264},{8,280}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{188,2},{80,2},{80,-178},{96,-178},{96,-192},{86,-192},{
                    86,-196},{82,-196},{82,-200}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
                points={{188,2},{10,2},{10,62},{10,66}},
                color={256,256,256},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0)
              annotation (Line(points={{-80,235.4},{-80,235.4},{-80,226}},
                                                             color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{188,2},{12,2},{12,42},{10,42}},
                color={256,256,256},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,124},{0,126},
                    {0,110}},              color={0,0,255},
                thickness=0.5));
            connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                  points={{-6.66134e-016,90},{0,92},{0,80}}, color={0,0,255},
                thickness=0.5));
            connect(sensP_EVA.flange, SH.outletCold) annotation (Line(
                points={{0,180},{0,180},{0,156}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{188,2},{144,2},{144,296},{122,296},{-94,296},{-94,260}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{188,2},{138,2},{138,252},{-80,252},{-80,249.2}},
                thickness=0.5,
                color={255,255,255}));
            connect(RH_out, PDSteamRH.outlet) annotation (Line(
                points={{100,310},{100,310},{100,260},{98,260},{60,260},{60,252}},
                color={0,0,255},
                thickness=0.5));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{0,-50},{0,-50},{0,-80},{190,-80}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-210},{42,-210},{-60,-210},{-60,-216}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-210},{84,-210},{-60,-210},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-66,220},{-66,220},{100,220},{100,196}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{58,140},{100,140},{100,0},{-44,0}},
                color={255,0,0},
                thickness=0.5));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{100,164},{100,140},{100,0},{-44,0}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(valveVap.inlet, sensP_EVA.flange) annotation (Line(
                points={{0,270},{0,180}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletHot, MS_out) annotation (Line(
                points={{-44,-260},{-12,-260},{20,-260},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{188,2},{160,2},{160,-72},{6,-72},{6,-36}},
                color={256,256,256},
                thickness=0.5));
            connect(PDSteamRH.inlet, RH.outletCold) annotation (Line(
                points={{60,232},{60,180},{84,180}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,312},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{116,180},{190,180}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false), graphics={Line(
                    points={{80,-186},{80,-192},{80,-200},{78,-200}},
                    color={0,0,0},
                    thickness=0.5)}),                      Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init100_5nodes;

          model OTSG_init100_5nodes_lin
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447465, gamma_nom=2197.5),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                    1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                    1.29502e+006,1.30052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                  558.906,561.752,563.806,565.297,566.385,567.182}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                    103396,100624}),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=564.15,
              nominalHotInletTemperature=569.15,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-264},{-44,-296}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                    1.64439e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                  620.01}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={196390,188158,176706,156967,110743}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15)
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                    1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                    1.94183e+006,2.2136e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                  626.498,627.06,627.186,627.848,629.177,631.842}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                    194368,192799}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                    2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                    2.72547e+006,2.78281e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                  653.806,658.116,678.213,683.393,689.164,695.453}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                    284059,275898}),
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=2.75412e6,
              p_start=17200000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=false)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,6})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                    3.42217e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                  824.786}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,501167,469703,420819,359564}),
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                    3.55697e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                  829.056}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,502650,475154,429572,356689}),
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,200},{-26,220}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,262})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,10}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow pumpMS(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.PressDrop PDSteamSH2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-246})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Sources.RealExpression sensDT_MS(y=SH.hotFluid.T[end]
                   - RH.hotFluid.T[end])
              annotation (Placement(transformation(extent={{110,60},{80,80}})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,238})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,210},{140,210},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-296},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,268}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,16},{1.77636e-015,16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,256},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                    -210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-280},{-16,-280}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,10},{50,10},{50,280},{90,280},{90,270}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, pumpMS.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(pumpMS.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,210},{-46,210}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
                points={{50,10},{50,10},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,10},{50,10},{50,192},{50,182},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-256},{-60,-264}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,10},{50,10},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{-4.44089e-016,270},{-4.44089e-016,230},{0,230},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{50,10},{50,10},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
                points={{50,10},{50,10},{50,64},{50,66},{10,66}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0)
              annotation (Line(points={{-40,227},{-40,216}}, color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{50,10},{50,10},{50,260},{-40,260},{-40,250}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{50,10},{50,10},{50,44},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                    124},{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                  points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255}));
            connect(sensP.flange, SH.outletCold)
              annotation (Line(points={{0,190},{0,156}}, color={0,0,255}));
            connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
                points={{50,10},{48,10},{48,8},{50,8},{50,-220},{52,-220},{52,
                    -220},{82,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init100_5nodes_lin;

          model OTSG_init100_5nodes_lin_sepDrain
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, separator valve for drainage during transition"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447465, gamma_nom=2197.5),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                    1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                    1.29502e+006,1.30052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                  558.906,561.752,563.806,565.297,566.385,567.182}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                    103396,100624}),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=564.15,
              nominalHotInletTemperature=569.15,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-264},{-44,-296}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                    1.64439e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                  620.01}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={196390,188158,176706,156967,110743}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15)
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                    1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                    1.94183e+006,2.2136e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                  626.498,627.06,627.186,627.848,629.177,631.842}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                    194368,192799}),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                    2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                    2.72547e+006,2.78281e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                  653.806,658.116,678.213,683.393,689.164,695.453}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                    284059,275898}),
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=2.75412e6,
              p_start=17200000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-50})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                    3.42217e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                  824.786}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,501167,469703,420819,359564}),
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                    3.55697e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                  829.056}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,502650,475154,429572,356689}),
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,200},{-26,220}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,262})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,12})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,-50}),iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow pumpMS(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.PressDrop PDSteamSH2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-246})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,238})));
            ThermoPower.Water.ValveLiq valveLiq(
              redeclare package Medium = coldMedium,
              Av=3.702e-5,
              pnom=17200000,
              dpnom=17000000,
              wnom=4.45)
              annotation (Placement(transformation(extent={{60,10},{80,30}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  coldMedium, p0=101325)
              annotation (Placement(transformation(extent={{100,10},{120,30}})));
            Auxiliaries.Components.SensDT_sh sensT annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-64,36})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,210},{140,210},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-296},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,268}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-40},{1.77636e-015,-40}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,256},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                    -210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-280},{-16,-280}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{90,280},{90,270}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, pumpMS.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(pumpMS.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,210},{-46,210}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-256},{-60,-264}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{-4.44089e-016,270},{-4.44089e-016,230},{0,230},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0)
              annotation (Line(points={{-40,227},{-40,216}}, color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-40,260},{-40,250}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{50,-50},{50,-50},{50,44},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                    124},{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                  points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255}));
            connect(sensP.flange, SH.outletCold)
              annotation (Line(points={{0,190},{0,156}}, color={0,0,255}));
            connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,8},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(points={
                    {-60,-4},{-60,-4},{-60,2}}, color={0,0,255}));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,-50},{50,-50},{50,-48},{50,-48},{50,-46},{6,-46}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
                color={255,204,51},
                thickness=0.5));
            connect(sensT.outlet, separator.water_in) annotation (Line(points={{
                    -60,42},{-60,48},{-10,48}}, color={0,0,255}));
            connect(sensT.inlet, PDSteamEVA2.outlet) annotation (Line(points={{
                    -60,30},{-60,22},{-60,22}}, color={0,0,255}));
            connect(separator.drained_out, valveLiq.inlet)
              annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255}));
            connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(points=
                   {{80,20},{90,20},{100,20}}, color={0,0,255}));
            connect(signalBus.pumpFW_PV_high, sensT.DT_sh) annotation (Line(
                points={{50,-50},{50,-50},{50,84},{-70,84},{-70,44}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init100_5nodes_lin_sepDrain;

          model OTSG_init50_5nodes_lin
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447465, gamma_nom=2197.5),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="degC")),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=557.15,
              nominalColdOutletTemperature=558.15,
              nominalHotInletTemperature=559.15,
              nominalHotOutletTemperature=558.15,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true))        annotation (Placement(
                  transformation(extent={{-76,-264},{-44,-296}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={105478,99880.5,96473.6,94384,93096.8}),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                    1.28694e+006},
                noInitialPressure=true))
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                  570.351,573.127,576.732,577.41}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                    1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                    1.36366e+006,1.43431e+006},
                noInitialPressure=true))          annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                    1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                  592.425,595.747,599.741,604.541}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}))
                                                  annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=1500e3,
              p_start=8935000,
              w_small=1e4)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,6})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510311,486650,427909,323825}))
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));

            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                    3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510695,492652,453640,369304}))
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,266})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={48,10}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-246})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,234})));
            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8)                   annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,208},{140,208},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-296},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,272}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,16},{1.77636e-015,16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,260},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-280},{-16,-280}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{48,10},{48,10},{48,280},{90,280},{90,274}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,208},{-46,208}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{48,10},{48,10},{48,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{48,10},{48,10},{48,192},{48,182},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-256},{-60,-264}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{48,10},{48,10},{48,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{0,270},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{48,10},{48,10},{48,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{48,10},{48,10},{48,46},{48,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                    -40,214},{-40,214}}, color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{48,10},{48,10},{48,260},{-40,260},{-40,246}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{48,10},{48,10},{6,10}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH.outlet)
              annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH.inlet, separator.steam_out)
              annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
            connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                    {0,190},{0,156}}, color={0,0,255}));
            connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
                points={{48,10},{48,66},{10,66}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
                points={{48,10},{48,10},{48,-220},{50,-220},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init50_5nodes_lin;

          model OTSG_init50_5nodes_lin_sepDrain
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, valve for separator draining added"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447465, gamma_nom=2197.5),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="degC")),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=557.15,
              nominalColdOutletTemperature=558.15,
              nominalHotInletTemperature=559.15,
              nominalHotOutletTemperature=558.15,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true))        annotation (Placement(
                  transformation(extent={{-76,-264},{-44,-296}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={105478,99880.5,96473.6,94384,93096.8}),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                    1.28694e+006},
                noInitialPressure=true))
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                  570.351,573.127,576.732,577.41}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                    1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                    1.36366e+006,1.43431e+006},
                noInitialPressure=true))          annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                    1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                  592.425,595.747,599.741,604.541}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}))
                                                  annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=1500e3,
              p_start=8935000,
              w_small=1e4)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-50})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510311,486650,427909,323825}))
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));

            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                    3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510695,492652,453640,369304}))
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,266})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,14})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,-50}),iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-246})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,234})));
            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8)                   annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.ValveLiq valveLiq(
              redeclare package Medium = coldMedium,
              Av=3.702e-5,
              pnom=17200000,
              dpnom=17000000,
              wnom=4.45)
              annotation (Placement(transformation(extent={{60,10},{80,30}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  coldMedium, p0=101325)
              annotation (Placement(transformation(extent={{100,10},{120,30}})));
            Auxiliaries.Components.SensDT_sh sensT annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-64,38})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,208},{140,208},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-296},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,272}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-40},{1.77636e-015,-40}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,4}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,260},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-280},{-16,-280}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{90,280},{90,274}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,208},{-46,208}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-256},{-60,-264}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{0,270},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                    -40,214}},           color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-40,260},{-40,246}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,-50},{50,-46},{6,-46}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH.outlet)
              annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH.inlet, separator.steam_out)
              annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
            connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                    {0,190},{0,156}}, color={0,0,255}));
            connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,-218},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
                points={{80,20},{90,20},{100,20}},
                color={0,0,255},
                thickness=0.5));
            connect(separator.drained_out, valveLiq.inlet) annotation (Line(
                points={{0,38},{0,20},{60,20}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, separator.water_in) annotation (Line(points={{
                    -60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255}));
            connect(PDSteamEVA2.outlet, sensT.inlet) annotation (Line(points={{
                    -60,24},{-60,24},{-60,32}}, color={0,0,255}));
            connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, sensT.DT_sh) annotation (Line(
                points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init50_5nodes_lin_sepDrain;

          model OTSG_init100_5nodes_drainage
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, for drainage modeling purpose"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
            parameter Modelica.SIunits.Time t_switch;

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                    1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                    1.29502e+006,1.30052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
                  558.906,561.752,563.806,565.297,566.385,567.182}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                    103396,100624}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  gamma_nom_pre=2197.5,
                  gamma_nom_post=0,
                  alpha=0.447465,
                  t_switch=t_switch),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=564.15,
              nominalHotInletTemperature=569.15,
              nominalHotOutletTemperature=563.15) annotation (Placement(
                  transformation(extent={{-76,-244},{-44,-276}})));

            Components.HE_2ph
                          ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                    1.64439e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                  620.01}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={196390,188158,176706,156967,110743}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2204.3,
                  gamma_nom_post=0,
                  alpha=0.461561),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15)
              annotation (Placement(transformation(extent={{-44,-176},{-76,-144}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                    1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                    1.94183e+006,2.2136e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                  626.498,627.06,627.186,627.848,629.177,631.842}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                    194368,192799}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2147.7,
                  gamma_nom_post=0,
                  alpha=0.447498),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65) annotation (Placement(
                  transformation(extent={{-76,-96},{-44,-64}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                    2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                    2.72547e+006,2.78281e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                  653.806,658.116,678.213,683.393,689.164,695.453}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                    284059,275898}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2650,
                  gamma_nom_post=0,
                  alpha=0.389637),
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01) annotation (Placement(
                  transformation(extent={{-44,-16},{-76,16}})));

            Components.nonEquilibriumVessel     separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              w_small=1e-3,
              gamma=0,
              hv_start=2.7e6,
              hl_start=1.3e6,
              p_start=17200000)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-40})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                    3.42217e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                  824.786}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,501167,469703,420819,359564}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2848.1,
                  gamma_nom_post=0,
                  alpha=0.28867),
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));
            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                    3.55697e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                  829.056}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,502650,475154,429572,356689}),
              redeclare model HeatTransferHot =
                  PreFlexMS.FullScale_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2690.3,
                  gamma_nom_post=0,
                  alpha=0.320782),
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={100,180})));

            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-86,210},{-66,230}})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-40})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-120})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={60,242})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={188,2}), iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-216},{80,-196}})));
            ThermoPower.Water.ThroughMassFlow pumpMS(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP_EVA(redeclare package Medium =
                  coldMedium) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=-90,
                  origin={-4,180})));
            ThermoPower.Water.PressDrop PDSteamSH2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-194})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-226})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-80,242})));
            Graphics.Label_input pumpMS_CS annotation (Placement(transformation(
                    extent={{-40,266},{-80,254}})));
            Graphics.Label_output valveBP_PV annotation (Placement(transformation(
                    extent={{60,-206},{20,-194}})));
            Graphics.Label_output pumpFW_PV_high
              annotation (Placement(transformation(extent={{32,60},{78,72}})));
            Graphics.Label_output pumpFW_PV_low
              annotation (Placement(transformation(extent={{32,36},{78,48}})));
            Graphics.Label_input pumpSEP_CS
              annotation (Placement(transformation(extent={{70,-30},{30,-42}})));
            Graphics.Label_output valveTURB_PV annotation (Placement(
                  transformation(extent={{-30,184},{-70,196}})));
            Graphics.Label_output pumpSEP_PV annotation (Placement(transformation(
                    extent={{60,-192},{20,-180}})));
          equation
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-260},{-100,-260},{-100,-160},{-76,-160}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-276},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-144},{-60,-130}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-30},{1.77636e-015,-30}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-30},{-60,-16}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-64},{-60,-50}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,16},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,0},{-100,0},{-100,-80},{-76,-80}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-80},{-20,-80},{-20,-160},{-44,-160}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-210},{96,-210},{130,-210},{190,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(MS_in, pumpMS.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(pumpMS.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,220},{-86,220}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP_EVA.p) annotation (Line(
                points={{188,2},{156,2},{156,222},{156,212},{10,212},{10,202},{6,202},{6,188},
                    {-10,188}},
                color={256,256,256},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-96},{-60,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-176},{-60,-184}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-236},{-60,-244}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{188,2},{80,2},{80,-178},{96,-178},{96,-192},{86,-192},{
                    86,-196},{82,-196},{82,-200}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
                points={{188,2},{10,2},{10,62},{10,66}},
                color={256,256,256},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0)
              annotation (Line(points={{-80,235.4},{-80,235.4},{-80,226}},
                                                             color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{188,2},{12,2},{12,42},{10,42}},
                color={256,256,256},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,124},{0,126},
                    {0,110}},              color={0,0,255},
                thickness=0.5));
            connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                  points={{-6.66134e-016,90},{0,92},{0,80}}, color={0,0,255},
                thickness=0.5));
            connect(sensP_EVA.flange, SH.outletCold) annotation (Line(
                points={{0,180},{0,180},{0,156}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
                points={{188,2},{144,2},{144,296},{122,296},{-94,296},{-94,260}},
                color={256,256,256},
                thickness=0.5));

            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{188,2},{138,2},{138,252},{-80,252},{-80,249.2}},
                thickness=0.5,
                color={255,255,255}));
            connect(RH_out, PDSteamRH.outlet) annotation (Line(
                points={{100,310},{100,310},{100,260},{98,260},{60,260},{60,252}},
                color={0,0,255},
                thickness=0.5));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{0,-50},{0,-50},{0,-80},{190,-80}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-210},{42,-210},{-60,-210},{-60,-216}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-210},{84,-210},{-60,-210},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-66,220},{-66,220},{100,220},{100,196}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{58,140},{100,140},{100,0},{-44,0}},
                color={255,0,0},
                thickness=0.5));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{100,164},{100,140},{100,0},{-44,0}},
                color={255,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.outletHot, MS_out) annotation (Line(
                points={{-44,-260},{-12,-260},{20,-260},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{188,2},{160,2},{160,-72},{6,-72},{6,-36}},
                color={256,256,256},
                thickness=0.5));
            connect(PDSteamRH.inlet, RH.outletCold) annotation (Line(
                points={{60,232},{60,180},{84,180}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{116,180},{190,180}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(sensP_EVA.flange, SH_out) annotation (Line(
                points={{0,180},{0,310}},
                color={0,0,255},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false), graphics={Line(
                    points={{80,-186},{80,-192},{80,-200},{78,-200}},
                    color={0,0,0},
                    thickness=0.5)}),                      Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init100_5nodes_drainage;

          model OTSG_init50_5nodes_drainage
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
            parameter Modelica.SIunits.Time t_switch;

            Components.HE HPH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.536143, gamma_nom=3958.9),
              Nhex=Nhex_mono*2,
              Vhot=3.789,
              Vcold=0.781,
              Shot=314.9,
              Scold=248,
              Mm=3802,
              nominalColdFlow=24.51,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="degC")),
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true),
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2197.5,
                  gamma_nom_post=0,
                  alpha=0.447465),
              nominalColdPressure=17400000,
              nominalHotPressure=250000,
              nominalColdInletTemperature=557.15,
              nominalColdOutletTemperature=558.15,
              nominalHotInletTemperature=559.15,
              nominalHotOutletTemperature=558.15) annotation (Placement(
                  transformation(extent={{-76,-264},{-44,-296}})));

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={105478,99880.5,96473.6,94384,93096.8}),
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                    1.28694e+006},
                noInitialPressure=true),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2204.3,
                  gamma_nom_post=0,
                  alpha=0.461561),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15)
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                  570.351,573.127,576.732,577.41}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                    1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                    1.36366e+006,1.43431e+006},
                noInitialPressure=true),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2147.7,
                  gamma_nom_post=0,
                  alpha=0.447498),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65) annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                    1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                  592.425,595.747,599.741,604.541}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2650,
                  gamma_nom_post=0,
                  alpha=0.389637),
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01) annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.Old.Equilibrium2phVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              zl_start=0,
              D=0.56,
              noInitialPressure=true,
              h_start=1500e3,
              p_start=8935000,
              w_small=1e4)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-52})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510311,486650,427909,323825}),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2848.1,
                  gamma_nom_post=0,
                  alpha=0.28867),
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58)
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));

            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                    3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510695,492652,453640,369304}),
              redeclare model HeatTransferHot =
                  Pilot_245degC.HeatExchangers.Components.FlowDependentHeatTransferCoefficient_switch
                  (
                  t_switch=t_switch,
                  gamma_nom_pre=2690.3,
                  gamma_nom_post=0,
                  alpha=0.320782),
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05)
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,266})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-32,48})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,-48}),iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.PressDrop PDSteamHPH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=24.51,
              dpnom=(0.5)*10^5,
              rhonom=747.38)       annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-60,-246})));
            Modelica.Blocks.Sources.RealExpression sensDT_MS(y=SH.hotFluid.T[end]
                   - RH.hotFluid.T[end])
              annotation (Placement(transformation(extent={{110,60},{80,80}})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,234})));
            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8)                   annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.ValveLiq valveLiq(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=0.001,
              pnom=8000000,
              dpnom=7000000,
              wnom=80) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=0,
                  origin={34,8})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=1000000)
              annotation (Placement(transformation(extent={{54,-2},{74,18}})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,208},{140,208},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH.inletHot, ECO.outletHot) annotation (Line(
                points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(HPH.outletCold, MS_HPH_out) annotation (Line(
                points={{-60,-296},{-60,-310}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,272}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-42}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
                points={{-22,48},{-10,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,48},{-42,48}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,260},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
                points={{-44,-280},{-16,-280}},
                color={255,0,0},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,-48},{50,-48},{50,222},{90,222},{90,274}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,208},{-46,208}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{50,-48},{50,-48},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
                points={{-60,-256},{-60,-264}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
                points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{50,-48},{50,-48},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{50,-48},{50,-48},{50,-12},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                    -40,214}},           color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{50,-48},{50,-48},{50,260},{-40,260},{-40,246}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,-48},{28,-48},{6,-48}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, sensT_MS.T) annotation (Line(
                points={{50,-48},{50,-48},{50,-270},{-2,-270}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH.outlet)
              annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH.inlet, separator.steam_out)
              annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
            connect(SH_out, sensP.flange) annotation (Line(
                points={{0,310},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(sensP.flange, SH.outletCold) annotation (Line(
                points={{0,190},{0,190},{0,156}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,-48},{50,-48},{50,176},{10,176},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(valveLiq.outlet, sinkPressure.flange)
              annotation (Line(points={{44,8},{44,8},{54,8}}, color={0,0,255}));
            connect(separator.drained_out, valveLiq.inlet) annotation (Line(
                points={{0,38},{0,8},{24,8}},
                color={0,0,255},
                thickness=0.5));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{0,-62},{0,-62},{0,-80},{190,-80}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveSPURG_CS, valveLiq.theta) annotation (Line(
                points={{50,-48},{34,-48},{34,0}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init50_5nodes_drainage;

          model OTSG_init50_5nodes_lin_sepDrain_newSep_noHPH
            "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, valve for separator draining added"
            extends BaseClasses.BaseOTSG;

            //Heat exchangers parameter
            parameter Integer Nhex_mono = 5
              "Number of nodes for single phase heat exchangers";
            parameter Integer Nhex_bi = 10
              "Number of nodes for biphase heat exchangers";
            parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

            Components.HE ECO(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4499),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2204.3),
              Vhot=44.506,
              Vcold=5.73,
              Shot=2385,
              Scold=1848.4,
              Mm=30279,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {557.683,558.554,559.967,562.272}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={105478,99880.5,96473.6,94384,93096.8}),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.65,
              nominalHotOutletTemperature=569.15,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.25671e+006,1.25985e+006,1.26495e+006,1.27327e+006,
                    1.28694e+006},
                noInitialPressure=true))
              annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

            Components.HE_2ph
                          EVA1(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  alpha=1.6,
                  gamma_nom_liq=3875*0.75,
                  gamma_nom_2ph=10000*0.75,
                  gamma_nom_vap=3875*0.75),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.447498, gamma_nom=2147.7),
              Vhot=31.955,
              Vcold=9.805,
              Shot=2834.1,
              Scold=2108.5,
              Mm=62846,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                  570.351,573.127,576.732,577.41}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
              nominalColdPressure=17300000,
              nominalHotPressure=650000,
              nominalColdInletTemperature=621.55,
              nominalColdOutletTemperature=626.9,
              nominalHotInletTemperature=689.01,
              nominalHotOutletTemperature=626.65,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                    1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                    1.36366e+006,1.43431e+006},
                noInitialPressure=true))          annotation (Placement(
                  transformation(extent={{-76,-116},{-44,-84}})));
            Components.HE_2ph
                          EVA2(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_bi,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.389637, gamma_nom=2650),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                  (
                  wnom_ht=88.59,
                  gamma_nom_liq=2000,
                  gamma_nom_2ph=5000,
                  gamma_nom_vap=2000,
                  alpha=1.1),
              Vhot=4.495,
              Vcold=1.028,
              Shot=489,
              Scold=354.5,
              Mm=7374,
              nominalColdFlow=91.28,
              nominalHotFlow=619.8,
              nominalColdPressure=17250000,
              nominalHotPressure=700000,
              nominalColdInletTemperature=626.69,
              nominalColdOutletTemperature=646.74,
              nominalHotInletTemperature=734.05,
              nominalHotOutletTemperature=689.01,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                Nt=1,
                hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                    1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                  592.425,595.747,599.741,604.541}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}))
                                                  annotation (Placement(
                  transformation(extent={{-44,-36},{-76,-4}})));

            Components.nonEquilibriumVessel separator(
              redeclare package Medium = coldMedium,
              H=8,
              D=0.56,
              noInitialPressure=true,
              w_small=1e4,
              gamma=0,
              zl_start=4,
              hv_start=2.7e6,
              hl_start=1.7e6,
              p_start=8935000,
              noInitialLevel=false)
              annotation (Placement(transformation(extent={{-28,28},{28,84}})));
            ThermoPower.Water.ThroughMassFlow waterPump(
              redeclare package Medium = coldMedium,
              allowFlowReversal=false,
              w0=0,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-50})));

            Components.HE SH(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.847436, gamma_nom=1996.5),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.28867, gamma_nom=2848.1),
              Vhot=12.281,
              Vcold=2.339,
              Shot=1193.5,
              Scold=835.5,
              Mm=19349,
              nominalColdFlow=91.28,
              nominalHotFlow=381.3,
              nominalColdPressure=17200000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=646.55,
              nominalColdOutletTemperature=823.96,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=733.58,
              coldFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510311,486650,427909,323825}))
              annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                  rotation=0,
                  origin={0,140})));

            Components.HE RH(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = coldMedium,
              redeclare package hotMedium = hotMedium,
              Nhex=Nhex_mono,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.798347, gamma_nom=963.6),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.320782, gamma_nom=2690.3),
              Vhot=9.255,
              Vcold=4.618,
              Shot=1371.1,
              Scold=1154.6,
              Mm=15054,
              nominalColdFlow=84.94,
              nominalHotFlow=238.6,
              nominalColdPressure=4781000,
              nominalHotPressure=1050000,
              nominalColdInletTemperature=633.15,
              nominalColdOutletTemperature=826.06,
              nominalHotInletTemperature=838.65,
              nominalHotOutletTemperature=734.05,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                    3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
              tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
              hotFluid(
                FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true,
                hstart={519092,510695,492652,453640,369304}))
              annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                  rotation=-90,
                  origin={140,160})));
            ThermoPower.Water.ThroughMassFlow valveRH(
              redeclare package Medium = hotMedium,
              use_in_w0=true,
              w0=238.6)
              annotation (Placement(transformation(extent={{-46,198},{-26,218}})));
            ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={96,266})));

            ThermoPower.Water.PressDrop PDSteamEVA1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=160.88)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-60})));
            ThermoPower.Water.PressDrop PDSteamECO2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=590.03)          annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-140})));
            ThermoPower.Water.PressDrop PDSteamEVA2(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(0.5)*10^5,
              rhonom=92.917)       annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,14})));
            //Overall parameter and variables:
            Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
            Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
            Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
            Modelica.SIunits.Temperature T_RH = sensT_RH.T;
            Modelica.SIunits.Length sep_lev = separator.zl;
            Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
            Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
            Real x_EVA1_out = EVA1.coldFluid.x[end];
            Real x_EVA2_out = EVA2.coldFluid.x[end];
            Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
            Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
            Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
            Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

            ThermoPower.Water.PressDrop PDSteamRH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=84.86,
              dpnom=(0.5)*10^5,
              rhonom=12.775,
              redeclare package Medium = coldMedium)
                                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={100,180})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={50,-50}),iconTransformation(
                  extent={{-30,-30},{30,30}},
                  rotation=-90,
                  origin={-194,0})));
            ThermoPower.Water.SensT sensT_FW(
              redeclare package Medium = coldMedium)
              annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
            ThermoPower.Water.SensT sensT_MS(
              redeclare package Medium = hotMedium)
              annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
            ThermoPower.Water.ThroughMassFlow throughMassFlow(
              use_in_w0=true,
              redeclare package Medium = hotMedium,
              w0=619.8)
              annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={-100,256})));
            ThermoPower.Water.SensP sensP(
              redeclare package Medium = coldMedium) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={4,190})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = coldMedium,
              wnom=91.28,
              dpnom=(1/2)*10^5,
              rhonom=820.48)                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-60,-214})));
            ThermoPower.Water.ValveVap valveVap(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = coldMedium,
              pnom=17100000,
              dpnom=100000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={0,280})));
            Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-40,234})));
            ThermoPower.Water.PressDrop PDSteamSH(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=91.28,
              dpnom=(1)*10^5,
              redeclare package Medium = coldMedium,
              rhonom=92.8)                   annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={0,100})));
            ThermoPower.Water.ValveLiq valveLiq(
              redeclare package Medium = coldMedium,
              Av=3.702e-5,
              pnom=17200000,
              dpnom=17000000,
              wnom=4.45)
              annotation (Placement(transformation(extent={{60,10},{80,30}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  coldMedium, p0=101325)
              annotation (Placement(transformation(extent={{100,10},{120,30}})));
            Auxiliaries.Components.SensDT_sh sensT annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-64,38})));
          equation
            connect(RH.inletCold, RH_in) annotation (Line(
                points={{156,160},{174,160},{174,180},{190,180}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(valveRH.outlet, RH.inletHot) annotation (Line(
                points={{-26,208},{140,208},{140,176}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH_out, sensT_RH.outlet) annotation (Line(
                points={{100,310},{100,272}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.Filled,Arrow.None}));
            connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
                points={{-60,-164},{-60,-150}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(separator.drained_out, waterPump.inlet) annotation (Line(
                points={{0,38},{0,-40},{1.77636e-015,-40}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
                points={{-60,-50},{-60,-36}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
                points={{-60,-84},{-60,-70}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
                points={{-60,-4},{-60,4}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(RH.outletHot, EVA2.inletHot) annotation (Line(
                points={{140,144},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(SH.outletHot, EVA2.inletHot) annotation (Line(
                points={{16,140},{140,140},{140,-20},{-44,-20}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
                points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
                points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(waterPump.outlet, SEP_out) annotation (Line(
                points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
                points={{100,260},{100,190}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
                points={{124,160},{100,160},{100,170}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));

            connect(sensT_FW.inlet, FW_in) annotation (Line(
                points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,-210},{190,-210}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_MS.outlet, MS_out) annotation (Line(
                points={{-4,-280},{20,-280},{20,-310}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.valveRH_PV, sensT_RH.T) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{90,280},{90,274}},
                color={255,204,51},
                thickness=0.5));
            connect(MS_in, throughMassFlow.inlet) annotation (Line(
                points={{-100,310},{-100,266}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
                points={{-100,246},{-100,140},{-16,140}},
                color={255,0,0},
                thickness=0.5));
            connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
                points={{-100,246},{-100,246},{-100,208},{-46,208}},
                color={255,0,0},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-94,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
                points={{50,-50},{50,-50},{50,192},{50,182},{10,182}},
                color={255,204,51},
                thickness=0.5));
            connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
                points={{-60,-116},{-60,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
                points={{-60,-196},{-60,-204}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
                points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,280},{8,280}},
                color={255,204,51},
                thickness=0.5));
            connect(SH_out, valveVap.outlet) annotation (Line(
                points={{0,310},{0,290}},
                color={0,0,255},
                thickness=0.5));
            connect(valveVap.inlet, sensP.flange) annotation (Line(
                points={{0,270},{0,190}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
                points={{50,-50},{50,-50},{50,46},{50,42},{10,42}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,223},{
                    -40,214}},           color={0,0,127}));
            connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
                points={{50,-50},{50,-50},{50,260},{-40,260},{-40,246}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
                points={{50,-50},{50,-46},{6,-46}},
                color={255,204,51},
                thickness=0.5));
            connect(SH.inletCold, PDSteamSH.outlet)
              annotation (Line(points={{0,124},{0,110}}, color={0,0,255}));
            connect(PDSteamSH.inlet, separator.steam_out)
              annotation (Line(points={{0,90},{0,80}}, color={0,0,255}));
            connect(sensP.flange, SH.outletCold) annotation (Line(points={{0,190},
                    {0,190},{0,156}}, color={0,0,255}));
            connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
                points={{50,-50},{50,-50},{50,-218},{50,-220},{82,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(
                points={{80,20},{90,20},{100,20}},
                color={0,0,255},
                thickness=0.5));
            connect(separator.drained_out, valveLiq.inlet) annotation (Line(
                points={{0,38},{0,20},{60,20}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, separator.water_in) annotation (Line(points={{
                    -60,44},{-60,44},{-60,48},{-10,48}}, color={0,0,255}));
            connect(PDSteamEVA2.outlet, sensT.inlet) annotation (Line(points={{
                    -60,24},{-60,24},{-60,32}}, color={0,0,255}));
            connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
                points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, sensT.DT_sh) annotation (Line(
                points={{50,-50},{50,-50},{50,84},{-70,84},{-70,46}},
                color={255,204,51},
                thickness=0.5));
            connect(ECO.outletHot, sensT_MS.inlet) annotation (Line(points={{-76,-180},{-88,
                    -180},{-100,-180},{-100,-280},{-16,-280}}, color={0,0,255}));
            connect(sensT_FW.outlet, MS_HPH_out) annotation (Line(points={{84,
                    -230},{12,-230},{-60,-230},{-60,-310}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(
                    extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
              Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
          end OTSG_init50_5nodes_lin_sepDrain_newSep_noHPH;
        end Old;

      end OTSG;

      package FeedwaterTrain
        "Package containing all the pre-heaters train model"

        package Preheaters "Package containing feedwater preheaters models"
          model HPH_controlledLevel
            "Model of a high pressure feed water pre heater with level control and desuperheating section"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Desuperheating region parameters
            replaceable model HeatTransferCold_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatTransferHot_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatExchangerTopology_des =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            parameter Integer Nhex_des = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vhot_des
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vcold_des
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Shot_des
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Scold_des
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
            final parameter Modelica.SIunits.Length L_des=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_des
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Subcooling region parameters
            replaceable model HeatTransferCold_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatTransferHot_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatExchangerTopology_sub =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            parameter Integer Nhex_sub = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vhot_sub
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vcold_sub
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Shot_sub
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Scold_sub
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
            final parameter Modelica.SIunits.Length L_sub=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_sub
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS" annotation (Dialog(tab="Level controller"));

            ThermoPower.Water.Flow1DFV des_FW(
              final N=Nhex_des,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_des,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_des),
              final A=Vcold_des/L_des,
              final omega=Scold_des/L_des,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,76})));
            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,10})));
            ThermoPower.Water.Flow1DFV sub_FW(
              final N=Nhex_sub,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_sub),
              final A=Vcold_sub/L_sub,
              final omega=Scold_sub/L_sub,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-40})));
            ThermoPower.Water.Flow1DFV2ph des_SP(
              N=Nhex_des,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_des,
              A=Vhot_des/L_des,
              omega=Shot_des/L_des,
              wnom=nominalHotFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_des),
              redeclare model HeatTransfer = HeatTransferHot_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                            annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,76})));
            ThermoPower.Water.Flow1DFV2ph
                                       sub_SP(
              N=Nhex_sub,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              A=Vhot_sub/L_sub,
              omega=Shot_sub/L_sub,
              wnom=nominalHotFlow+nominalDrainFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_sub),
              redeclare model HeatTransfer = HeatTransferHot_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                            annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,-40})));
            Components.NusseltCondenser           NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-22},{-18,42}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              CheckValve=true,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.2,
              rhonom=900)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              CS_start=CSstart,
              AntiWindup=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.SteadyState)            annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_des(
              final Nw=Nhex_des - 1,
              final M=Mm_des,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
              TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,76})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_des)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,76})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
              final Nw=Nhex_sub - 1,
              final M=Mm_sub,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
              TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_sub)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,-40})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,10})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,10})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            ThermoPower.Water.PressDropLin pressDropLin(redeclare package
                Medium =
                  Medium,
              R=0.1e5)            annotation (Placement(transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-50,52})));
          equation
            Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
            Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
            connect(des_FW.infl, cond_FW.outfl) annotation (Line(
                points={{50,66},{50,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
                points={{50,0},{50,-30}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
                points={{-50,-50},{-50,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ST_in, des_SP.infl) annotation (Line(
                points={{-50,100},{-50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(FW_out, des_FW.outfl) annotation (Line(
                points={{50,100},{50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,19.1429},{-61.4286,19.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_FW.infl, FW_in) annotation (Line(
                points={{50,-50},{50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,7.71429},{-82,7.71429},{-82,-12}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
                points={{-45,76},{-3.6,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
                points={{3.72,76},{21.59,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
                points={{28.3,76},{45,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
                points={{28.3,-40},{45,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
                points={{-45,-40},{-3.6,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
                points={{3.72,-40},{21.59,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,10},{21.59,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,10},{28.3,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-29},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,10},{-39.7143,10},{-3.6,10}},
                                                  color={255,127,0}));
            connect(des_SP.outfl, pressDropLin.inlet)
              annotation (Line(points={{-50,66},{-50,58}}, color={0,0,255}));
            connect(pressDropLin.outlet, NusseltCondenser.steam_in) annotation (
                Line(points={{-50,46},{-50,37.4286}}, color={0,0,255}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,-6},{-75,-6},{-75,-12}},  color={0,0,127}));
            connect(NusseltCondenser.drained_out, sub_SP.infl) annotation (Line(
                  points={{-50,-10.5714},{-50,-30}},           color={0,0,255}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={{-76,-61},{
                    -76,-61},{-76,-68},{-76,-70},{-58,-70}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end HPH_controlledLevel;

          model HPH_controlledLevel_dp
            "Model of a high pressure feed water pre heater with level control and desuperheating section"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Desuperheating region parameters
            replaceable model HeatTransferCold_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatTransferHot_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatExchangerTopology_des =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            parameter Integer Nhex_des = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vhot_des
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vcold_des
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Shot_des
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Scold_des
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
            final parameter Modelica.SIunits.Length L_des=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_des
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Subcooling region parameters
            replaceable model HeatTransferCold_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatTransferHot_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatExchangerTopology_sub =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            parameter Integer Nhex_sub = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vhot_sub
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vcold_sub
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Shot_sub
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Scold_sub
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
            final parameter Modelica.SIunits.Length L_sub=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_sub
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS" annotation (Dialog(tab="Level controller"));

            ThermoPower.Water.Flow1DFV des_FW(
              final N=Nhex_des,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_des,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_des),
              final A=Vcold_des/L_des,
              final omega=Scold_des/L_des,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,76})));
            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,10})));
            ThermoPower.Water.Flow1DFV sub_FW(
              final N=Nhex_sub,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_sub),
              final A=Vcold_sub/L_sub,
              final omega=Scold_sub/L_sub,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-40})));
            ThermoPower.Water.Flow1DFV2ph des_SP(
              N=Nhex_des,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_des,
              A=Vhot_des/L_des,
              omega=Shot_des/L_des,
              wnom=nominalHotFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_des),
              redeclare model HeatTransfer = HeatTransferHot_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                            annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,76})));
            ThermoPower.Water.Flow1DFV2ph
                                       sub_SP(
              N=Nhex_sub,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              A=Vhot_sub/L_sub,
              omega=Shot_sub/L_sub,
              wnom=nominalHotFlow+nominalDrainFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_sub),
              redeclare model HeatTransfer = HeatTransferHot_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                            annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,-40})));
            Components.NusseltCondenser           NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=false)
              annotation (Placement(transformation(extent={{-82,-22},{-18,42}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CheckValve=true,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.2,
              rhonom=900)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              AntiWindup=true,
              CS_start=CSstart)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.InitialState)           annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_des(
              final Nw=Nhex_des - 1,
              final M=Mm_des,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
              TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,76})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_des)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,76})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
              final Nw=Nhex_sub - 1,
              final M=Mm_sub,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
              TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_sub)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,-40})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,10})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,10})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            ThermoPower.Water.PressDropLin pressDrop_des_cond(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              R=0.2e5) annotation (Placement(transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-50,52})));
            ThermoPower.Water.PressDropLin pressDrop_cond_sub(redeclare package
                Medium = Medium, R=0.2e5) annotation (Placement(transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=270,
                  origin={-50,-20})));
          equation
            Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
            Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
            connect(des_FW.infl, cond_FW.outfl) annotation (Line(
                points={{50,66},{50,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
                points={{50,0},{50,-30}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
                points={{-50,-50},{-50,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ST_in, des_SP.infl) annotation (Line(
                points={{-50,100},{-50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(FW_out, des_FW.outfl) annotation (Line(
                points={{50,100},{50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,19.1429},{-61.4286,19.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_FW.infl, FW_in) annotation (Line(
                points={{50,-50},{50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,7.71429},{-82,7.71429},{-82,-12}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
                points={{-45,76},{-3.6,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
                points={{3.72,76},{21.59,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
                points={{28.3,76},{45,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
                points={{28.3,-40},{45,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
                points={{-45,-40},{-3.6,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
                points={{3.72,-40},{21.59,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,10},{21.59,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,10},{28.3,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-29},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,10},{-39.7143,10},{-3.6,10}},
                                                  color={255,127,0}));
            connect(des_SP.outfl, pressDrop_des_cond.inlet)
              annotation (Line(points={{-50,66},{-50,58}}, color={0,0,255}));
            connect(pressDrop_des_cond.outlet, NusseltCondenser.steam_in)
              annotation (Line(points={{-50,46},{-50,37.4286}}, color={0,0,255}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,-6},{-75,-6},{-75,-12}},  color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={{-76,-61},{
                    -76,-61},{-76,-68},{-76,-70},{-58,-70}}, color={0,0,127}));
            connect(NusseltCondenser.drained_out, pressDrop_cond_sub.inlet)
              annotation (Line(points={{-50,-10.5714},{-50,-16}}, color={0,0,255}));
            connect(pressDrop_cond_sub.outlet, sub_SP.infl) annotation (Line(
                  points={{-50,-24},{-50,-27},{-50,-30}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end HPH_controlledLevel_dp;

          model LPH_controlledLevel
            "Model of a low pressure feed water pre heater with level control (no desuperheating section)"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS" annotation (Dialog(tab="Level controller"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=false)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,20})));
            Components.NusseltCondenser         NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              noInitialPressure=false)
              annotation (Placement(transformation(extent={{-82,-12},{-18,52}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.5,
              CheckValve=true)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              AntiWindup=true,
              CS_start=CSstart)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.SteadyState)            annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,20})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,20})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_cond+1] = vector([ones(Nhex_cond+1)*NusseltCondenser.Tv])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_cond+1] = vector([(NusseltCondenser.Tv+cond_FW.T[end])/2;tubeWalls_cond.Tvol[end:-1:1];(NusseltCondenser.Tv+cond_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_cond+1] = vector([cond_FW.T[end];cond_FW.heatTransfer.Tvol[end:-1:1];cond_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

          equation
            Q_Hot = NusseltCondenser.Q_cond;
            Q_Cold = cond_FW.Q;
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,29.1429},{-61.4286,29.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(
                points={{-61.4286,4},{-75,4},{-75,-12}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,17.7143},{-82,17.7143},{-82,-12}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,20},{21.59,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,20},{28.3,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-29},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,20},{-39.7143,20},{-3.6,20}},
                                                  color={255,127,0}));
            connect(NusseltCondenser.drained_out, valveDrain.inlet) annotation (Line(
                  points={{-50,-0.571429},{-50,-60}},           color={0,0,255}));
            connect(ST_in, NusseltCondenser.steam_in) annotation (Line(points={{-50,100},
                    {-50,47.4286}},              color={0,0,255}));
            connect(FW_out, cond_FW.outfl) annotation (Line(points={{50,100},{50,
                    100},{50,30}},color={0,0,255}));
            connect(cond_FW.infl, FW_in)
              annotation (Line(points={{50,10},{50,10},{50,-100}}, color={0,0,255}));
            connect(valveDynamic.y, valveDrain.theta)
              annotation (Line(points={{-76,-61},{-76,-70},{-58,-70}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end LPH_controlledLevel;

          model HPH_controlledLevel_lin
            "Model of a high pressure feed water pre heater with level control and desuperheating section for control tuning"
            extends BaseClasses.BaseFeedwaterHeater;

            parameter Modelica.SIunits.Time t_start_TS
              "Tracking signal start time";

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Desuperheating region parameters
            replaceable model HeatTransferCold_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatTransferHot_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatExchangerTopology_des =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            parameter Integer Nhex_des = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vhot_des
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vcold_des
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Shot_des
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Scold_des
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
            final parameter Modelica.SIunits.Length L_des=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_des
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Subcooling region parameters
            replaceable model HeatTransferCold_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatTransferHot_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatExchangerTopology_sub =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            parameter Integer Nhex_sub = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vhot_sub
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vcold_sub
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Shot_sub
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Scold_sub
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
            final parameter Modelica.SIunits.Length L_sub=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_sub
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
            parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real PVmin
              "Minimum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real PVmax
              "Maximum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

            ThermoPower.Water.Flow1DFV des_FW(
              final N=Nhex_des,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_des,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_des),
              final A=Vcold_des/L_des,
              final omega=Scold_des/L_des,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,76})));
            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,10})));
            ThermoPower.Water.Flow1DFV sub_FW(
              final N=Nhex_sub,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_sub),
              final A=Vcold_sub/L_sub,
              final omega=Scold_sub/L_sub,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-40})));
            ThermoPower.Water.Flow1DFV2ph des_SP(
              N=Nhex_des,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_des,
              A=Vhot_des/L_des,
              omega=Shot_des/L_des,
              wnom=nominalHotFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_des),
              redeclare model HeatTransfer = HeatTransferHot_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,76})));
            ThermoPower.Water.Flow1DFV sub_SP(
              N=Nhex_sub,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              A=Vhot_sub/L_sub,
              omega=Shot_sub/L_sub,
              wnom=nominalHotFlow+nominalDrainFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_sub),
              redeclare model HeatTransfer = HeatTransferHot_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,-40})));
            Components.NusseltCondenser           NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-22},{-18,42}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              rhonom=900,
              CheckValve=true,
              thetanom=0.2)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-74})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              useTS=true,
              CS_start=CSstart,
              AntiWindup=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-18})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.SteadyState)            annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-62})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_des(
              final Nw=Nhex_des - 1,
              final M=Mm_des,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
              TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,76})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_des)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,76})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
              final Nw=Nhex_sub - 1,
              final M=Mm_sub,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
              TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_sub)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,-40})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,10})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,10})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            ThermoPower.Water.PressDropLin pressDropLin(redeclare package
                Medium =
                  Medium,
              allowFlowReversal=false,
              R=0.5e5)            annotation (Placement(transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-50,52})));
            Modelica.Blocks.Interfaces.RealInput du_theta annotation (Placement(
                  transformation(extent={{-154,-60},{-114,-20}}),
                  iconTransformation(extent={{-120,-70},{-100,-50}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=270,
                  origin={-76,-42})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=t_start_TS)
              annotation (Placement(transformation(extent={{-160,-20},{-140,0}})));
          equation
            Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
            Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
            connect(des_FW.infl, cond_FW.outfl) annotation (Line(
                points={{50,66},{50,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
                points={{50,0},{50,-30}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
                points={{-50,-50},{-50,-64}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ST_in, des_SP.infl) annotation (Line(
                points={{-50,100},{-50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(FW_out, des_FW.outfl) annotation (Line(
                points={{50,100},{50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,19.1429},{-61.4286,19.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_FW.infl, FW_in) annotation (Line(
                points={{50,-50},{50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-84},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,7.71429},{-82,7.71429},{-82,-10}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
                points={{-45,76},{-3.6,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
                points={{3.72,76},{21.59,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
                points={{28.3,76},{45,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
                points={{28.3,-40},{45,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
                points={{-45,-40},{-3.6,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
                points={{3.72,-40},{21.59,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,10},{21.59,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,10},{28.3,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,10},{-39.7143,10},{-3.6,10}},
                                                  color={255,127,0}));
            connect(des_SP.outfl, pressDropLin.inlet)
              annotation (Line(points={{-50,66},{-50,58}}, color={0,0,255}));
            connect(pressDropLin.outlet, NusseltCondenser.steam_in) annotation (
                Line(points={{-50,46},{-50,37.4286}}, color={0,0,255}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,-6},{-75,-6},{-75,-10}},  color={0,0,127}));
            connect(NusseltCondenser.drained_out, sub_SP.infl) annotation (Line(
                  points={{-50,-10.5714},{-50,-30}},           color={0,0,255}));
            connect(valveDynamic.u, add.y)
              annotation (Line(points={{-76,-50},{-76,-46.4}}, color={0,0,127}));
            connect(PID_level.CS, add.u1) annotation (Line(points={{-76,-27},{-76,-30},{-74,
                    -30},{-73.6,-30},{-73.6,-37.2}},           color={0,0,127}));
            connect(du_theta, add.u2) annotation (Line(points={{-134,-40},{-86,-40},{-86,-36},
                    {-78,-36},{-78,-37.2},{-78.4,-37.2}},
                                                     color={0,0,127}));
            connect(booleanStep.y, PID_level.TS) annotation (Line(points={{-139,
                    -10},{-120,-10},{-120,-22},{-84,-22}}, color={255,0,255}));
            connect(PID_level.CS, PID_level.TR) annotation (Line(points={{-76,-27},{-76,-30},
                    {-92,-30},{-92,-18},{-84,-18}}, color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta)
              annotation (Line(points={{-76,-73},{-76,-74},{-58,-74}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end HPH_controlledLevel_lin;

          model LPH_controlledLevel_lin
            "Model of a low pressure feed water pre heater with level control (no desuperheating section) for linearization"
            extends BaseClasses.BaseFeedwaterHeater;

            parameter Modelica.SIunits.Time t_start_TS
              "Tracking signal start time";

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
            parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real PVmin
              "Minimum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real PVmax
              "Maximum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,20})));
            Components.NusseltCondenser         NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-12},{-18,52}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.5,
              CheckValve=true)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-76})));

            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,20})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,20})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_cond+1] = vector([ones(Nhex_cond+1)*NusseltCondenser.Tv])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_cond+1] = vector([(NusseltCondenser.Tv+cond_FW.T[end])/2;tubeWalls_cond.Tvol[end:-1:1];(NusseltCondenser.Tv+cond_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_cond+1] = vector([cond_FW.T[end];cond_FW.heatTransfer.Tvol[end:-1:1];cond_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            IndustrialControlSystems.Controllers.PI
                                                PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              useTS=true,
              CS_start=CSstart,
              AntiWindup=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-10})));
            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.SteadyState)            annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-54})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=t_start_TS)
              annotation (Placement(transformation(extent={{-160,-12},{-140,8}})));
            Modelica.Blocks.Interfaces.RealInput du_theta annotation (Placement(
                  transformation(extent={{-154,-52},{-114,-12}}),
                  iconTransformation(extent={{-120,-70},{-100,-50}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=270,
                  origin={-76,-34})));
          equation
            Q_Hot = NusseltCondenser.Q_cond;
            Q_Cold = cond_FW.Q;
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,29.1429},{-61.4286,29.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-86},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));

            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,20},{21.59,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,20},{28.3,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,20},{-39.7143,20},{-3.6,20}},
                                                  color={255,127,0}));
            connect(NusseltCondenser.drained_out, valveDrain.inlet) annotation (Line(
                  points={{-50,-0.571429},{-50,-66}},           color={0,0,255}));
            connect(ST_in, NusseltCondenser.steam_in) annotation (Line(points={{-50,100},
                    {-50,47.4286},{-50,47.4286}},color={0,0,255}));
            connect(FW_out, cond_FW.outfl) annotation (Line(points={{50,100},{50,
                    100},{50,30}},color={0,0,255}));
            connect(cond_FW.infl, FW_in)
              annotation (Line(points={{50,10},{50,10},{50,-100}}, color={0,0,255}));
            connect(booleanStep.y,PID_level. TS) annotation (Line(points={{-139,-2},{-116,
                    -2},{-116,-14},{-84,-14}},             color={255,0,255}));
            connect(PID_level.CS,PID_level. TR) annotation (Line(points={{-76,-19},{-76,-22},
                    {-92,-22},{-92,-10},{-84,-10}}, color={0,0,127}));
            connect(add.y, valveDynamic.u) annotation (Line(points={{-76,-38.4},{-76,-40.2},
                    {-76,-42}}, color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta)
              annotation (Line(points={{-76,-65},{-76,-76},{-58,-76}}, color={0,0,127}));
            connect(du_theta, add.u2) annotation (Line(points={{-134,-32},{-86,-32},{-86,-26},
                    {-78.4,-26},{-78.4,-29.2}}, color={0,0,127}));
            connect(PID_level.CS, add.u1) annotation (Line(points={{-76,-19},{-76,-24},{-73.6,
                    -24},{-73.6,-29.2}}, color={0,0,127}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,4},{-61.4286,4},{-75,4},{-75,-2}},
                                                       color={0,0,127}));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(points={{
                    -61.4286,17.7143},{-82,17.7143},{-82,-2}},
                                                      color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end LPH_controlledLevel_lin;
        end Preheaters;

        package HP_train
          "Package containing high-pressure feedwater train models"
          model HPH_train_controlledLevel_100
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            Auxiliaries.Components.pump_constEfficiency
                                              pumpFW(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=91.28,
              eta_iso=0.789)
              annotation (Placement(transformation(extent={{170,12},{150,-8}})));
            ThermoPower.Water.ThroughMassFlow pumpHPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={20,-56})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{24,-14},{4,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.ValveLiq valveBP(
              redeclare package Medium = Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000) annotation (Placement(transformation(extent={{-40,-38},
                      {-60,-58}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-114},{130,-74}}),
                  iconTransformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_des=3,
              Nhex_cond=3,
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              des_FW(hstart={1.268e6,1.28171e6,1.34722e6}),
              cond_FW(hstart={1.02902e6,1.20014e6,1.268e6}),
              sub_FW(hstart={979187,985072,994215,1.00820e6,1.02902e6}),
              des_SP(hstart={3.231e6,2.83893e6,2.75687e6}),
              sub_SP(hstart={1.32571e6,1.20114e6,1.11741e6,1.06269e6,1.02747e6}),
              CSmin=0.05,
              wnom=4.449,
              Kp=-9.126,
              Ti=42.99,
              nominalColdPressure=17630000,
              nominalHotPressure=8181000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=8181000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8150000,
              dpnom=6300000)
                        annotation (Placement(transformation(extent={{-70,-20},
                      {-30,20}})));

            Preheaters.HPH_controlledLevel HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmax=1,
              Nhex_des=3,
              Nhex_cond=3,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Nhex_sub=5,
              CSstart=0.2,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              des_FW(hstart={876813,877436,895998}),
              cond_FW(hstart={807696,856039,876813}),
              sub_FW(hstart={803100,803886,804877,806125,807696}),
              des_SP(hstart={3.281e6,2.73749e6,2.71925e6}),
              CSmin=0.05,
              sub_SP(hstart={878793,855666,836808,821450,808952}),
              wnom=7.484,
              nominalColdPressure=17630000,
              nominalHotPressure=1815000,
              nominalColdInletTemperature_des=477.15,
              nominalColdOutletTemperature_des=480.85,
              nominalHotInletTemperature_des=686.65,
              nominalHotOutletTemperature_des=480.75,
              p_start=1815000,
              nominalColdInletTemperature_cond=461.55,
              nominalColdOutletTemperature_cond=477.15,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1815000,
              dpnom=729000,
              Kp=-15.85,
              Ti=21.05) annotation (Placement(transformation(extent={{70,-20},{
                      110,20}})));
            Graphics.Label_input valveBP_CS annotation (Placement(transformation(
                    extent={{-98,-66},{-66,-54}})));
            Graphics.Label_input pumpFW_CS
              annotation (Placement(transformation(extent={{112,-20},{144,-8}})));
            Graphics.Label_input pumpHPH_CS
              annotation (Placement(transformation(extent={{80,-66},{42,-54}})));
          equation
            connect(pumpHPH.outlet, flowJoin.in2) annotation (Line(
                points={{20,-46},{20,-16},{20,-8}},
                color={0,0,255},
                thickness=0.5));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.inlet, flowJoin.out) annotation (Line(
                points={{-40,-48},{0,-48},{0,-4},{8,-4}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.outlet, sensT.inlet) annotation (Line(
                points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{20,0},{32,0}},
                color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpHPH_CS, pumpHPH.in_w0) annotation (Line(
                points={{110,-94},{110,-76},{28,-76},{28,-60},{26,-60}},
                color={256,256,256},
                thickness=0.5));

            connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
                points={{110,-94},{162,-94},{162,-20},{172,-20},{176,-20},{176,-8},
                    {160,-8},{160,-7}},
                color={255,255,255},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0},
                thickness=0.5));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,20}},
                             color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0},
                thickness=0.5));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{70,0}},        color={0,0,255},
                thickness=0.5));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{8,-4}}, color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_CS, valveBP.theta) annotation (Line(
                points={{110,-94},{110,-96},{108,-96},{18,-96},{18,-78},{-44,-78},
                    {-44,-56},{-50,-56}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpHPH.inlet, MS_HPH_in) annotation (Line(
                points={{20,-66},{20,-86},{20,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpFW.outfl, HPH1.FW_in) annotation (Line(points={{154,-5},{
                    148,-5},{148,0},{112,0}}, color={0,0,255}));
            connect(pumpFW.infl, FW_in)
              annotation (Line(points={{168,0},{190,0}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}}), graphics={Line(
                    points={{-50,-58},{-50,-60}},
                    color={0,0,0},
                    thickness=0.5), Line(
                    points={{160,-8},{160,-14}},
                    color={0,0,0},
                    thickness=0.5)}));
          end HPH_train_controlledLevel_100;

          model HPH_train_controlledLevel_100_dp
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            Auxiliaries.Components.pump_constEfficiency
                                              pumpFW(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=91.28,
              eta_iso=0.789)
              annotation (Placement(transformation(extent={{170,12},{150,-8}})));
            ThermoPower.Water.ThroughMassFlow pumpHPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={20,-56})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{24,-14},{4,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.ValveLiq valveBP(
              redeclare package Medium = Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000) annotation (Placement(transformation(extent={{-40,-38},
                      {-60,-58}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-114},{130,-74}}),
                  iconTransformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_des=3,
              Nhex_cond=3,
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              des_FW(hstart={1.268e6,1.28171e6,1.34722e6}),
              cond_FW(hstart={1.02902e6,1.20014e6,1.268e6}),
              sub_FW(hstart={979187,985072,994215,1.00820e6,1.02902e6}),
              des_SP(hstart={3.231e6,2.83893e6,2.75687e6}),
              sub_SP(hstart={1.32571e6,1.20114e6,1.11741e6,1.06269e6,1.02747e6}),
              CSmin=0.05,
              wnom=4.449,
              nominalColdPressure=17630000,
              nominalHotPressure=8181000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=8181000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8150000,
              dpnom=6300000,
              Kp=-9.126,
              Ti=42.99) annotation (Placement(transformation(extent={{-70,-20},
                      {-30,20}})));

            Preheaters.HPH_controlledLevel_dp HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmax=1,
              Nhex_des=3,
              Nhex_cond=3,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Nhex_sub=5,
              CSstart=0.2,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              des_FW(hstart={876813,877436,895998}),
              cond_FW(hstart={807696,856039,876813}),
              sub_FW(hstart={803100,803886,804877,806125,807696}),
              des_SP(hstart={3.281e6,2.73749e6,2.71925e6}),
              CSmin=0.05,
              sub_SP(hstart={878793,855666,836808,821450,808952}),
              wnom=7.484,
              Kp=-15.85,
              Ti=21.05,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=17630000,
              nominalHotPressure=1815000,
              nominalColdInletTemperature_des=477.15,
              nominalColdOutletTemperature_des=480.85,
              nominalHotInletTemperature_des=686.65,
              nominalHotOutletTemperature_des=480.75,
              p_start=1815000,
              nominalColdInletTemperature_cond=461.55,
              nominalColdOutletTemperature_cond=477.15,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1815000,
              dpnom=729000) annotation (Placement(transformation(extent={{70,-20},
                      {110,20}})));
            Graphics.Label_input valveBP_CS annotation (Placement(transformation(
                    extent={{-98,-66},{-66,-54}})));
            Graphics.Label_input pumpFW_CS
              annotation (Placement(transformation(extent={{112,-20},{144,-8}})));
            Graphics.Label_input pumpHPH_CS
              annotation (Placement(transformation(extent={{80,-66},{42,-54}})));
          equation
            connect(pumpHPH.outlet, flowJoin.in2) annotation (Line(
                points={{20,-46},{20,-16},{20,-8}},
                color={0,0,255},
                thickness=0.5));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.inlet, flowJoin.out) annotation (Line(
                points={{-40,-48},{0,-48},{0,-4},{8,-4}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.outlet, sensT.inlet) annotation (Line(
                points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{20,0},{32,0}},
                color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpHPH_CS, pumpHPH.in_w0) annotation (Line(
                points={{110,-94},{110,-76},{28,-76},{28,-60},{26,-60}},
                color={256,256,256},
                thickness=0.5));

            connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
                points={{110,-94},{162,-94},{162,-20},{172,-20},{176,-20},{176,-8},
                    {160,-8},{160,-7}},
                color={255,255,255},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,20}},
                               color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points={{-80,40},
                    {-72,40},{-64,40},{-64,20}},          color={0,127,0},
                thickness=0.5));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,20}},
                             color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0},
                thickness=0.5));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{70,0}},        color={0,0,255},
                thickness=0.5));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{8,-4}}, color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,0},
                    {-70,0}},            color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_CS, valveBP.theta) annotation (Line(
                points={{110,-94},{110,-96},{108,-96},{18,-96},{18,-78},{-44,-78},
                    {-44,-56},{-50,-56}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpHPH.inlet, MS_HPH_in) annotation (Line(
                points={{20,-66},{20,-86},{20,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpFW.outfl, HPH1.FW_in) annotation (Line(points={{154,-5},{
                    148,-5},{148,0},{112,0}}, color={0,0,255}));
            connect(pumpFW.infl, FW_in)
              annotation (Line(points={{168,0},{190,0}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}}), graphics={Line(
                    points={{-50,-58},{-50,-60}},
                    color={0,0,0},
                    thickness=0.5), Line(
                    points={{160,-8},{160,-14}},
                    color={0,0,0},
                    thickness=0.5)}));
          end HPH_train_controlledLevel_100_dp;

          model HPH_train_controlledLevel_50
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium
                = Medium,
              use_in_w0=true,
              w0=91.28)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91)        annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={40,-60})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{22,-14},{2,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              sub_FW(hstart={763758,767404,773564,783883,800868}),
              sub_SP(hstart={1.08271e6,951308,871475,823820,795624}),
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              tubeWalls_sub(Tvolstart={486.15,473.15,463.15,458.15}),
              Nhex_cond=5,
              Nhex_des=5,
              des_SP(hstart={3.289e6,2.96343e6,2.84697e6,2.79089e6,2.74785e6}),
              des_FW(hstart={1.00416e6,1.00966e6,1.0168e6,1.03169e6,1.07335e6}),
              tubeWalls_des(Tvolstart={584.493,534.57,519.498,515.452}),
              tubeWalls_cond(Tvolstart={513.148,509.461,504.33,496.809}),
              cond_FW(hstart={791228,873624,932205,974084,1.00416e6}),
              wnom=4.449,
              CSmin=0.05,
              zl_start=0.1,
              nominalColdPressure=9891000,
              nominalHotPressure=3941000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=3941000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8100000,
              dpnom=6300000,
              Kp=-9.128,
              Ti=42.99) annotation (Placement(transformation(extent={{-70,-20},
                      {-30,20}})));

            Preheaters.HPH_controlledLevel HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              cm=500,
              CSmax=1,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              CSstart=0.2,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              NusseltCondenser(noInitialPressure=true),
              Nhex_cond=10,
              tubeWalls_cond(Tvolstart={448.005,447.91,447.788,447.634,447.438,
                    447.189,446.873,446.47,445.958}),
              cond_FW(hstart={695485,706400,714988,721746,727066,731255,734553,
                    737159,739198,740811}),
              Ta=0.3,
              sub_FW(hstart={691100,691958,692965,694147,695533}),
              tubeWalls_sub(Tvolstart={443.75,442.35,441.15,440.15}),
              sub_SP(hstart={742039,732973,725244,718657,713045}),
              Nhex_sub=5,
              wnom=7.484,
              des_FW(hstart={739569,739802,757167}),
              Nhex_des=3,
              tubeWalls_des(Tvolstart={477.59,447.113}),
              CSmin=0.05,
              zl_start=0.1,
              Kp=-15.85,
              Ti=21.05,
              nominalColdPressure=9952000,
              nominalHotPressure=950000,
              nominalColdInletTemperature_des=445.05,
              nominalColdOutletTemperature_des=447.55,
              nominalHotInletTemperature_des=691.15,
              nominalHotOutletTemperature_des=473.15,
              p_start=850000,
              nominalColdInletTemperature_cond=437.15,
              nominalColdOutletTemperature_cond=446.95,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1800000,
              dpnom=1086000,
              des_SP(hstart={3.323e6,2.92784e6,2.91453e6})) annotation (
                Placement(transformation(extent={{70,-20},{110,20}})));
            ThermoPower.Water.ValveLiq valve_bypass(redeclare package Medium =
                  Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          equation
            connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
                points={{20,-110},{20,-90},{40,-90},{40,-70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
                points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{18,0},{32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
                points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
                color={255,204,51},
                thickness=0.5));
            connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
            connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0}));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0}));
            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,65},{
                    90,20}}, color={0,127,0}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0}));
            connect(HPH1.FW_in, pump_FW.outlet)
              annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{6,-4}}, color={0,0,255}));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255}));
            connect(valve_bypass.outlet, sensT.inlet) annotation (Line(points={{
                    -60,-48},{-90,-48},{-120,-48},{-120,0},{-140,0}}, color={0,0,
                    255}));
            connect(valve_bypass.inlet, flowJoin.out) annotation (Line(points={{
                    -40,-48},{0,-48},{0,-4},{6,-4}}, color={0,0,255}));
            connect(signalBus.valveBP_CS, valve_bypass.theta) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{-50,-80},{-50,-56}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}})));
          end HPH_train_controlledLevel_50;

          model HPH_train_controlledLevel_50_dp
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium
                = Medium,
              use_in_w0=true,
              w0=91.28)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91)        annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={40,-60})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{22,-14},{2,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              sub_FW(hstart={763758,767404,773564,783883,800868}),
              sub_SP(hstart={1.08271e6,951308,871475,823820,795624}),
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              tubeWalls_sub(Tvolstart={486.15,473.15,463.15,458.15}),
              Nhex_cond=5,
              Nhex_des=5,
              des_SP(hstart={3.289e6,2.96343e6,2.84697e6,2.79089e6,2.74785e6}),
              des_FW(hstart={1.00416e6,1.00966e6,1.0168e6,1.03169e6,1.07335e6}),
              tubeWalls_des(Tvolstart={584.493,534.57,519.498,515.452}),
              tubeWalls_cond(Tvolstart={513.148,509.461,504.33,496.809}),
              cond_FW(hstart={791228,873624,932205,974084,1.00416e6}),
              wnom=4.449,
              CSmin=0.05,
              zl_start=0.1,
              nominalColdPressure=9891000,
              nominalHotPressure=3941000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=3941000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8100000,
              dpnom=6300000,
              Kp=-9.128,
              Ti=42.99) annotation (Placement(transformation(extent={{-70,-20},
                      {-30,20}})));

            Preheaters.HPH_controlledLevel_dp HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              cm=500,
              CSmax=1,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              CSstart=0.2,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              NusseltCondenser(noInitialPressure=false),
              Nhex_cond=10,
              tubeWalls_cond(Tvolstart={448.005,447.91,447.788,447.634,447.438,
                    447.189,446.873,446.47,445.958}),
              cond_FW(hstart={695485,706400,714988,721746,727066,731255,734553,
                    737159,739198,740811}),
              Ta=0.3,
              sub_FW(hstart={691100,691958,692965,694147,695533}),
              tubeWalls_sub(Tvolstart={443.75,442.35,441.15,440.15}),
              sub_SP(hstart={742039,732973,725244,718657,713045}),
              Nhex_sub=5,
              wnom=7.484,
              des_FW(hstart={739569,739802,757167}),
              Nhex_des=3,
              tubeWalls_des(Tvolstart={477.59,447.113}),
              CSmin=0.05,
              zl_start=0.1,
              Kp=-15.85,
              Ti=21.05,
              nominalColdPressure=9952000,
              nominalHotPressure=850000,
              nominalColdInletTemperature_des=445.05,
              nominalColdOutletTemperature_des=447.55,
              nominalHotInletTemperature_des=691.15,
              nominalHotOutletTemperature_des=453.15,
              p_start=850000,
              nominalColdInletTemperature_cond=437.15,
              nominalColdOutletTemperature_cond=446.95,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1800000,
              dpnom=1086000,
              des_SP(hstart={3.323e6,2.32784e6,2.31453e6})) annotation (
                Placement(transformation(extent={{70,-20},{110,20}})));
            ThermoPower.Water.ValveLiq valve_bypass(redeclare package Medium =
                  Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          equation
            connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
                points={{20,-110},{20,-90},{40,-90},{40,-70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
                points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{18,0},{32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
                points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
                color={255,204,51},
                thickness=0.5));
            connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
            connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0}));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0}));
            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,65},{
                    90,20}}, color={0,127,0}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0}));
            connect(HPH1.FW_in, pump_FW.outlet)
              annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{6,-4}}, color={0,0,255}));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255}));
            connect(valve_bypass.outlet, sensT.inlet) annotation (Line(points={{
                    -60,-48},{-90,-48},{-120,-48},{-120,0},{-140,0}}, color={0,0,
                    255}));
            connect(valve_bypass.inlet, flowJoin.out) annotation (Line(points={{
                    -40,-48},{0,-48},{0,-4},{6,-4}}, color={0,0,255}));
            connect(signalBus.valveBP_CS, valve_bypass.theta) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{-50,-80},{-50,-56}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}})));
          end HPH_train_controlledLevel_50_dp;

          model HPH_train_controlledLevel_20_dp
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium
                = Medium,
              use_in_w0=true,
              w0=91.28)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91)        annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={40,-60})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{22,-14},{2,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              sub_SP(hstart={824737,711698,659103,634922,623854}),
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              tubeWalls_sub(Tvolstart={439.15,428.327,423.234,420.884}),
              des_SP(hstart={3.315e6,2.51589e6,2.46664e6}),
              des_FW(hstart={817929,823603,909538}),
              tubeWalls_des(Tvolstart={533.649,469.891}),
              tubeWalls_cond(Tvolstart={466.294,457.426}),
              cond_FW(hstart={642728,768404,817929}),
              wnom=4.449,
              CSmin=0.05,
              zl_start=0.1,
              Kp=-9.128,
              Ti=42.99,
              Nhex_des=3,
              Nhex_cond=3,
              sub_FW(hstart={620052,621248,623855,629518,641681}),
              nominalColdPressure=8635000,
              nominalHotPressure=800000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=800000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8100000,
              dpnom=6300000) annotation (Placement(transformation(extent={{-70,
                      -20},{-30,20}})));

            Preheaters.HPH_controlledLevel_dp HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              cm=500,
              CSmax=1,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              CSstart=0.2,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              NusseltCondenser(noInitialPressure=false),
              tubeWalls_cond(Tvolstart={412.653,412.85}),
              cond_FW(hstart={578900,591212,593427}),
              Ta=0.3,
              sub_FW(hstart={577693,577894,578151,578480,578900}),
              tubeWalls_sub(Tvolstart={411.264,410.777,410.395,410.097}),
              Nhex_sub=5,
              wnom=7.484,
              des_FW(hstart={592249,592308,618595}),
              Nhex_des=3,
              tubeWalls_des(Tvolstart={448.719,412.698}),
              CSmin=0.05,
              zl_start=0.1,
              Kp=-15.85,
              Ti=21.05,
              des_SP(hstart={3.345e6,1.35779e6,1.35325e6}),
              Nhex_cond=3,
              sub_SP(hstart={587397,583927,581213,579090,577430}),
              nominalColdPressure=8644000,
              nominalHotPressure=359400,
              nominalColdInletTemperature_des=445.05,
              nominalColdOutletTemperature_des=447.55,
              nominalHotInletTemperature_des=691.15,
              nominalHotOutletTemperature_des=453.15,
              p_start=359400,
              nominalColdInletTemperature_cond=437.15,
              nominalColdOutletTemperature_cond=446.95,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1800000,
              dpnom=1086000) annotation (Placement(transformation(extent={{70,-20},
                      {110,20}})));
            ThermoPower.Water.ValveLiq valve_bypass(redeclare package Medium =
                  Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=8635000,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          equation
            connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
                points={{20,-110},{20,-90},{40,-90},{40,-70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
                points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{18,0},{32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
                points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
                color={255,204,51},
                thickness=0.5));
            connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
            connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0}));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0}));
            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,65},{
                    90,20}}, color={0,127,0}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0}));
            connect(HPH1.FW_in, pump_FW.outlet)
              annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{6,-4}}, color={0,0,255}));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255}));
            connect(valve_bypass.outlet, sensT.inlet) annotation (Line(points={{
                    -60,-48},{-90,-48},{-120,-48},{-120,0},{-140,0}}, color={0,0,
                    255}));
            connect(valve_bypass.inlet, flowJoin.out) annotation (Line(points={{
                    -40,-48},{0,-48},{0,-4},{6,-4}}, color={0,0,255}));
            connect(signalBus.valveBP_CS, valve_bypass.theta) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{-50,-80},{-50,-56}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}})));
          end HPH_train_controlledLevel_20_dp;

          model HPH_train_controlledLevel_lin
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;

            parameter Modelica.SIunits.Time t_start_TS
              "Tracking signal start time";
            Auxiliaries.Components.pump_constEfficiency
                                              pumpFW(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=91.28,
              eta_iso=0.789)
              annotation (Placement(transformation(extent={{174,12},{154,-8}})));
            ThermoPower.Water.ThroughMassFlow pumpHPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={20,-56})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{24,-14},{4,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.ValveLiq valveBP(
              redeclare package Medium = Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000) annotation (Placement(transformation(extent={{-40,-38},
                      {-60,-58}})));
            ThermoPower.Water.PressDrop DP_FW_HPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DP_FW_HPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-114},{130,-74}}),
                  iconTransformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel_lin HPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_des=3,
              Nhex_cond=3,
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              CSstart=0.2,
              nominalDrainFlow=0,
              des_FW(hstart={1.268e6,1.28171e6,1.34722e6}),
              cond_FW(hstart={1.02902e6,1.20014e6,1.268e6}),
              sub_FW(hstart={979187,985072,994215,1.00820e6,1.02902e6}),
              des_SP(hstart={3.231e6,2.83893e6,2.75687e6}),
              sub_SP(hstart={1.32571e6,1.20114e6,1.11741e6,1.06269e6,1.02747e6}),
              CSmin=0.05,
              Ti=10,
              t_start_TS=t_start_TS,
              nominalColdPressure=17630000,
              nominalHotPressure=8181000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=8181000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              wnom=4.449,
              pnom=8150000,
              dpnom=6300000,
              Kp=-10) annotation (Placement(transformation(extent={{-70,-20},{-30,
                      20}})));

            Preheaters.HPH_controlledLevel_lin HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmax=1,
              Nhex_des=3,
              Nhex_cond=3,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Nhex_sub=5,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              CSstart=0.2,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              des_FW(hstart={876813,877436,895998}),
              cond_FW(hstart={807696,856039,876813}),
              sub_FW(hstart={803100,803886,804877,806125,807696}),
              des_SP(hstart={3.281e6,2.73749e6,2.71925e6}),
              CSmin=0.05,
              sub_SP(hstart={878793,855666,836808,821450,808952}),
              Ti=10,
              t_start_TS=t_start_TS,
              wnom=7.484,
              Kp=-1,
              nominalColdPressure=17630000,
              nominalHotPressure=1815000,
              nominalColdInletTemperature_des=477.15,
              nominalColdOutletTemperature_des=480.85,
              nominalHotInletTemperature_des=686.65,
              nominalHotOutletTemperature_des=480.75,
              p_start=1815000,
              nominalColdInletTemperature_cond=461.55,
              nominalColdOutletTemperature_cond=477.15,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1815000,
              dpnom=729000) annotation (Placement(transformation(extent={{70,-20},
                      {110,20}})));
            Modelica.Blocks.Interfaces.RealInput dtheta2 annotation (Placement(
                  transformation(extent={{-126,-50},{-86,-10}}),
                  iconTransformation(extent={{-200,-50},{-180,-30}})));
            Modelica.Blocks.Interfaces.RealInput dtheta1 annotation (Placement(
                  transformation(extent={{14,-50},{54,-10}}),
                  iconTransformation(extent={{-200,-90},{-180,-70}})));
          equation
            connect(pumpHPH.outlet, flowJoin.in2) annotation (Line(
                points={{20,-46},{20,-16},{20,-8}},
                color={0,0,255},
                thickness=0.5));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.inlet, flowJoin.out) annotation (Line(
                points={{-40,-48},{0,-48},{0,-4},{8,-4}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.outlet, sensT.inlet) annotation (Line(
                points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(flowJoin.in1, DP_FW_HPH1.outlet) annotation (Line(
                points={{20,0},{32,0}},
                color={0,0,255},
                thickness=0.5));
            connect(DP_FW_HPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpHPH_CS, pumpHPH.in_w0) annotation (Line(
                points={{110,-94},{110,-76},{40,-76},{40,-60},{26,-60}},
                color={244,125,35},
                thickness=0.5));

            connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
                points={{110,-94},{110,-94},{110,-76},{164,-76},{164,-7}},
                color={244,125,35},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0},
                thickness=0.5));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,20}},
                             color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0},
                thickness=0.5));
            connect(DP_FW_HPH1.inlet, HPH1.FW_out) annotation (Line(
                points={{52,0},{70,0}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{8,-4}}, color={0,0,255},
                thickness=0.5));
            connect(DP_FW_HPH2.inlet, HPH2.FW_out) annotation (Line(
                points={{-80,0},{-75,0},{-70,0}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_CS, valveBP.theta) annotation (Line(
                points={{110,-94},{110,-76},{106,-76},{16,-76},{16,-76},{-50,-76},{-50,-56},
                    {-50,-56}},
                color={244,125,35},
                thickness=0.5));
            connect(pumpHPH.inlet, MS_HPH_in) annotation (Line(
                points={{20,-66},{20,-86},{20,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(dtheta1, HPH1.du_theta) annotation (Line(points={{34,-30},{60,-30},{60,
                    -12},{68,-12}},             color={0,0,127}));
            connect(dtheta2, HPH2.du_theta) annotation (Line(points={{-106,-30},{-106,-30},
                    {-80,-30},{-80,-12},{-72,-12}},color={0,0,127}));
            connect(pumpFW.infl, FW_in)
              annotation (Line(points={{172,0},{190,0}}, color={0,0,255}));
            connect(pumpFW.outfl, HPH1.FW_in) annotation (Line(points={{158,-5},{
                    140,-5},{140,0},{112,0}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}})));
          end HPH_train_controlledLevel_lin;
        end HP_train;

        package LP_train
          "Package containing low-pressure feedwater train models"
          model LPH_train_controlledLevel_100
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              nominalColdPressure=1433000,
              nominalHotPressure=189300,
              p_start=189300,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150,
              Kp=-21,
              Ti=39.15)                                  annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              Kp=-5.431,
              Ti=79.38,
              nominalColdPressure=1505000,
              nominalHotPressure=55150,
              p_start=55150,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760)                               annotation (Placement(
                  transformation(extent={{120,-20},{160,20}})));
            Preheaters.HPH_controlledLevel LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              nominalColdPressure=1303000,
              nominalHotPressure=300000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=300000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300)                              annotation (Placement(
                  transformation(extent={{-160,-20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_100;

          model LPH_train_controlledLevel_100_dp
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              nominalColdPressure=1433000,
              nominalHotPressure=189300,
              p_start=189300,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150,
              Kp=-21,
              Ti=39.15,
              NusseltCondenser(noInitialPressure=false)) annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              nominalColdPressure=1505000,
              nominalHotPressure=55150,
              p_start=55150,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760,
              Kp=-5.431,
              Ti=79.38,
              NusseltCondenser(noInitialPressure=false)) annotation (Placement(
                  transformation(extent={{120,-20},{160,20}})));
            Preheaters.HPH_controlledLevel_dp
                                           LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              nominalColdPressure=1303000,
              nominalHotPressure=300000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=300000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300,
              NusseltCondenser(noInitialPressure=false)) annotation (Placement(
                  transformation(extent={{-160,-20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_100_dp;

          model LPH_train_controlledLevel_50
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              Kp=-21,
              Ti=39.15,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=707400,
              nominalHotPressure=96350,
              p_start=96350,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150,
              cond_FW(hstart={273453,353423,387572,402316}),
              tubeWalls_cond(Tvolstart={370.11,367.8695,362.7483})) annotation (
               Placement(transformation(extent={{-20,-20},{20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              Kp=-5.431,
              Ti=79.38,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=724300,
              nominalHotPressure=28140,
              p_start=28140,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760,
              cond_FW(hstart={183400,236904,261832,273453}),
              tubeWalls_cond(Tvolstart={338.83,336.48,331.49})) annotation (
                Placement(transformation(extent={{120,-20},{160,20}})));
            Preheaters.HPH_controlledLevel LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=676500,
              nominalHotPressure=166700,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=166700,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300,
              des_SP(hstart={2.9236e6,2.7843e6,2.7286e6,2.70575e6,2.69548e6,
                    2.6884e6}),
              sub_SP(hstart={465582,439833,424683,415300,409836}),
              des_FW(hstart={463555,463747,464024,464637,466135,469878}),
              cond_FW(hstart={403815,447507,463768}),
              sub_FW(hstart={402316,402463,402709,403123,403815}),
              tubeWalls_des(Tvolstart={421.482,398.765,389.817,386.391,385.509}),
              tubeWalls_cond(Tvolstart={384.327,381.78}),
              tubeWalls_sub(Tvolstart={374.801,372.4732,371.0826,370.2527}))
              annotation (Placement(transformation(extent={{-160,-20},{-120,20}})));

            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_50;

          model LPH_train_controlledLevel_50_dp
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              Kp=-21,
              Ti=39.15,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=707400,
              nominalHotPressure=96350,
              p_start=96350,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150,
              cond_FW(hstart={273453,353423,387572,402316}),
              tubeWalls_cond(Tvolstart={370.11,367.8695,362.7483})) annotation (
               Placement(transformation(extent={{-20,-20},{20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              Kp=-5.431,
              Ti=79.38,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=724300,
              nominalHotPressure=28140,
              p_start=28140,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760,
              cond_FW(hstart={183400,236904,261832,273453}),
              tubeWalls_cond(Tvolstart={338.83,336.48,331.49})) annotation (
                Placement(transformation(extent={{120,-20},{160,20}})));
            Preheaters.HPH_controlledLevel_dp
                                           LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              NusseltCondenser(noInitialPressure=false),
              nominalColdPressure=676500,
              nominalHotPressure=166700,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=166700,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300,
              des_SP(hstart={2.9236e6,2.7843e6,2.7286e6,2.70575e6,2.69548e6,
                    2.6884e6}),
              sub_SP(hstart={465582,439833,424683,415300,409836}),
              des_FW(hstart={463555,463747,464024,464637,466135,469878}),
              cond_FW(hstart={403815,447507,463768}),
              sub_FW(hstart={402316,402463,402709,403123,403815}),
              tubeWalls_des(Tvolstart={421.482,398.765,389.817,386.391,385.509}),
              tubeWalls_cond(Tvolstart={384.327,381.78}),
              tubeWalls_sub(Tvolstart={374.801,372.4732,371.0826,370.2527}))
              annotation (Placement(transformation(extent={{-160,-20},{-120,20}})));

            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_50_dp;

          model LPH_train_controlledLevel_20
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              Kp=-21,
              Ti=39.15,
              NusseltCondenser(noInitialPressure=false),
              cond_FW(hstart={210444,291231,313278,318445}),
              tubeWalls_cond(Tvolstart={348.8377,348.1806,345.5317}),
              nominalColdPressure=330800,
              nominalHotPressure=30000,
              p_start=30000,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150) annotation (Placement(transformation(extent={{-20,-20},
                      {20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              Kp=-5.431,
              Ti=79.38,
              NusseltCondenser(noInitialPressure=false),
              cond_FW(hstart={148100,195848,207567,210444}),
              tubeWalls_cond(Tvolstart={323.4029,322.7935,320.3106}),
              nominalColdPressure=333500,
              nominalHotPressure=12630,
              p_start=12630,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760) annotation (Placement(transformation(extent={{120,-20},
                      {160,20}})));
            Preheaters.HPH_controlledLevel LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              NusseltCondenser(noInitialPressure=false),
              des_SP(hstart={2.944e6,2.72955e6,2.67479e6,2.66045e6,2.65544e6,
                    2.65147e6}),
              sub_SP(hstart={366432,340746,328201,322076,319085}),
              cond_FW(hstart={317330,359694,368289}),
              sub_FW(hstart={316280,316349,316486,316764,317330}),
              tubeWalls_des(Tvolstart={400.315,370.9581,364.1711,362.3957,
                    361.7848}),
              tubeWalls_cond(Tvolstart={360.9991,359.9191}),
              tubeWalls_sub(Tvolstart={352.55,350.5625,349.591,349.1163}),
              des_FW(hstart={367493,367580,367691,368006,369207,373912}),
              nominalColdPressure=325900,
              nominalHotPressure=45000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=45000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300) annotation (Placement(transformation(extent={{-160,
                      -20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_20;

          model LPH_train_controlledLevel_20_dp
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Nhex_cond=4,
              Kp=-21,
              Ti=39.15,
              NusseltCondenser(noInitialPressure=false),
              cond_FW(hstart={210444,291231,313278,318445}),
              tubeWalls_cond(Tvolstart={348.8377,348.1806,345.5317}),
              nominalColdPressure=330800,
              nominalHotPressure=30000,
              p_start=30000,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150) annotation (Placement(transformation(extent={{-20,-20},
                      {20,20}})));
            Preheaters.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Nhex_cond=4,
              Kp=-5.431,
              Ti=79.38,
              NusseltCondenser(noInitialPressure=false),
              cond_FW(hstart={148100,195848,207567,210444}),
              tubeWalls_cond(Tvolstart={323.4029,322.7935,320.3106}),
              nominalColdPressure=333500,
              nominalHotPressure=12630,
              p_start=12630,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760) annotation (Placement(transformation(extent={{120,-20},
                      {160,20}})));
            Preheaters.HPH_controlledLevel_dp
                                           LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ta=0.3,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              Kp=-108.2,
              Ti=21.03,
              NusseltCondenser(noInitialPressure=false),
              des_SP(hstart={2.944e6,2.72955e6,2.67479e6,2.66045e6,2.65544e6,
                    2.65147e6}),
              sub_SP(hstart={366432,340746,328201,322076,319085}),
              cond_FW(hstart={317330,359694,368289}),
              sub_FW(hstart={316280,316349,316486,316764,317330}),
              tubeWalls_des(Tvolstart={400.315,370.9581,364.1711,362.3957,
                    361.7848}),
              tubeWalls_cond(Tvolstart={360.9991,359.9191}),
              tubeWalls_sub(Tvolstart={352.55,350.5625,349.591,349.1163}),
              des_FW(hstart={367493,367580,367691,368006,369207,373912}),
              nominalColdPressure=325900,
              nominalHotPressure=45000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=45000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300) annotation (Placement(transformation(extent={{-160,
                      -20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_20_dp;

          model LPH_train_controlledLevel_lin
            "Model of the low pressure feedwater train with level controllers for linearization"
            extends BaseClasses.BaseLPHTrain;

            parameter Modelica.SIunits.Time t_start_TS
              "Tracking signal start time";

            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop DP_FW_LPH1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=972,
              dpnom=72000)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop DP_FW_LPH2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=947,
              dpnom=130000)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop DP_FW_LPH3(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Preheaters.LPH_controlledLevel_lin LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Kp=-5,
              nominalColdPressure=1433000,
              nominalHotPressure=189300,
              Nhex_cond=4,
              p_start=189300,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150,
              t_start_TS=t_start_TS) annotation (Placement(transformation(
                    extent={{-20,-20},{20,20}})));
            Preheaters.LPH_controlledLevel_lin LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Kp=-1,
              nominalColdPressure=1505000,
              nominalHotPressure=55150,
              Nhex_cond=4,
              p_start=55150,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760,
              t_start_TS=t_start_TS) annotation (Placement(transformation(
                    extent={{120,-20},{160,20}})));
            Preheaters.HPH_controlledLevel_lin LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              pressDropLin(R=0.05e5),
              nominalColdPressure=1303000,
              nominalHotPressure=300000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=300000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300,
              Kp=-10,
              valveDrain(thetanom=0.5),
              t_start_TS=t_start_TS) annotation (Placement(transformation(
                    extent={{-160,-20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{204,-100},{244,-60}}), iconTransformation(
                    extent={{-20,-120},{20,-80}})));
            Modelica.Blocks.Interfaces.RealInput dtheta2 annotation (Placement(
                  transformation(extent={{-80,-60},{-40,-20}}),
                  iconTransformation(extent={{-260,-80},{-240,-60}})));
            Modelica.Blocks.Interfaces.RealInput dtheta1 annotation (Placement(
                  transformation(extent={{60,-60},{100,-20}}),
                  iconTransformation(extent={{-260,-110},{-240,-90}})));
            Modelica.Blocks.Interfaces.RealInput dtheta3 annotation (Placement(
                  transformation(extent={{-220,-60},{-180,-20}}),
                  iconTransformation(extent={{-260,-50},{-240,-30}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out,DP_FW_LPH3. outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(DP_FW_LPH2.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(DP_FW_LPH1.inlet, LPH1.FW_out) annotation (Line(
                points={{100,0},{114,0},{120,0}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, DP_FW_LPH1.outlet) annotation (Line(
                points={{22,0},{80,0}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in,DP_FW_LPH2. outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(DP_FW_LPH3.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{224,-80},{224,-80},{224,-74},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            connect(dtheta3, LPH3.du_theta) annotation (Line(points={{-200,-40},{-170,-40},
                    {-170,-12},{-162,-12}}, color={0,0,127}));
            connect(dtheta2, LPH2.du_theta) annotation (Line(points={{-60,-40},{-30,-40},{
                    -30,-12},{-22,-12}}, color={0,0,127}));
            connect(dtheta1, LPH1.du_theta) annotation (Line(points={{80,-40},{110,-40},{110,
                    -12},{118,-12}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel_lin;
        end LP_train;

        package Test

          package Preheaters_NusseltCondenser_tuning
            "Package containing test model for the Nusselt condenser type - for model tuning"

            package HPH2 "Test model of the HPH2"

              model test_condensingSection_FW
                "Test of the preheater condensing section"
                extends Modelica.Icons.Example;
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  final M=10000*0.7,
                  initOpt=ThermoPower.Choices.Init.Options.noInit)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={10,18})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                    Nw=5)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={35,18})));

                ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=27.94,
                  h=1029.4e3)
                  annotation (Placement(transformation(extent={{30,-30},{50,-10}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                  annotation (Placement(transformation(extent={{70,50},{90,70}})));
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                  annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Liquid,
                  noInitialPressure=true,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  A=0.53,
                  N=6,
                  wnom=27.94,
                  omega=210*0.7,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600))                      annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={60,18})));
                ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=270,
                      origin={-12,18})));
                Modelica.Blocks.Sources.Constant T_in(k=553.15) annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=0,
                      origin={-70,40})));
                Modelica.Blocks.Sources.Constant T_out(k=565.15) annotation (
                    Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=0,
                      origin={-70,0})));
              equation

                connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                    Line(
                    points={{13.72,18},{31.59,18}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV.wall)
                  annotation (Line(points={{38.3,18},{46,18},{55,18}},
                                                               color={255,127,0}));
                connect(flow1DFV.infl, sourceMassFlow2.flange)
                  annotation (Line(points={{60,8},{60,-20},{50,-20}}, color={0,0,255}));
                connect(flow1DFV.outfl, sinkPressure1.flange) annotation (Line(points={{60,28},
                        {60,28},{60,60},{70,60}}, color={0,0,255}));
                connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                      points={{-15,22},{-48,22},{-48,40},{-59,40}}, color={0,0,127}));
                connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                      points={{-14.8,14},{-48.2,14},{-48.2,0},{-59,0}}, color={0,0,
                        127}));
                connect(tempSource1DlinFV.wall, tubeWalls_cond.int)
                  annotation (Line(points={{-9,18},{6.4,18}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_condensingSection_FW;

              model test_condensingSection_ST
                "Test of the condensing section of the last high pressure preheater"
                extends Modelica.Icons.Example;
                Components.NusseltCondenser         baseNusseltCondenser(
                  zl_set=0.1,
                  zl_start=0.1,
                  A=1,
                  noInitialPressure=true,
                  Nw=5,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  V=2.99*0.7,
                  S=210*0.7,
                  gamma=4100,
                  p_start=8181000) annotation (Placement(transformation(extent={{
                          -28,12},{28,68}})));
                inner ThermoPower.System system
                  annotation (Placement(transformation(extent={{80,80},{100,100}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  h=540000,
                  w0=0)
                  annotation (Placement(transformation(extent={{-62,38},{-42,58}})));
                ThermoPower.Water.SourcePressure sourceMassFlow1(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  p0=8181000,
                  h=2755.9e3)
                  annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
                ThermoPower.Water.ValveLiq valveDrain(redeclare package Medium
                    = Modelica.Media.Water.WaterIF97_ph, Kv=6.9888689915e-7/0.2,
                  CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                  pnom=444900,
                  dpnom=8150000,
                  wnom=63,
                  thetanom=0.2)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=-90,
                      origin={0,-38})));
                IndustrialControlSystems.Controllers.PI
                                                    PID_level(
                  CSmin=0,
                  CSmax=1,
                  AntiWindup=true,
                  CS_start=0.5,
                  Kp=-9.126,
                  Ti=42.99)    annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=-90,
                      origin={-40,-10})));
                ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                  annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
                ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                  annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={34,40})));
                Modelica.Blocks.Sources.Constant T_in(k=553.15) annotation (Placement(
                      transformation(
                      extent={{10,-10},{-10,10}},
                      rotation=0,
                      origin={70,60})));
                Modelica.Blocks.Sources.Constant T_out(k=565.15) annotation (
                    Placement(transformation(
                      extent={{10,-10},{-10,10}},
                      rotation=0,
                      origin={70,20})));
              equation
                connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
                  annotation (Line(
                    points={{-20,80},{0,80},{0,64}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
                  annotation (Line(
                    points={{-42,48},{-10,48}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                    points={{-10,26},{-41,26},{-41,-2}},
                    color={0,0,127},
                    smooth=Smooth.None));
                connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                    points={{-10,38},{-34,38},{-34,-2}},
                    color={0,0,127},
                    smooth=Smooth.None));
                connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                      points={{0,-48},{0,-60},{20,-60}}, color={0,0,255}));
                connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
                  annotation (Line(points={{0,22},{0,22},{0,-28}}, color={0,0,255}));
                connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
                   Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
                connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                      points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
                connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                      points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
                connect(PID_level.CS, valveDrain.theta) annotation (Line(points=
                       {{-40,-19},{-40,-38},{-8,-38}}, color={0,0,127}));
                annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                          -100},{100,100}})));
              end test_condensingSection_ST;

              model test_condensingSection
                "Test of the preheater condensing section"
                extends Modelica.Icons.Example;
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                  annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  final M=10000*0.7,
                  Tstart1=563.15,
                  TstartN=567.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={10,20})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={35,20})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=27.94,
                  h=1029.4e3)
                  annotation (Placement(transformation(extent={{30,-28},{50,-8}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                  annotation (Placement(transformation(extent={{70,50},{90,70}})));
                ThermoPower.Water.Flow1DFV flow1DFV(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=1202.5e3,
                  hstartout=1262.5e3,
                  A=0.53*0.7,
                  omega=210*0.7,
                  wnom=27.94,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=2400))                      annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={60,20})));
                Components.NusseltCondenser         baseNusseltCondenser(
                  zl_set=0.1,
                  zl_start=0.1,
                  A=1,
                  noInitialPressure=true,
                  Nw=5,
                  V=2.99*0.7,
                  S=210*0.7,
                  gamma=4100,
                  p_start=8181000) annotation (Placement(transformation(extent={{
                          -48,-8},{8,48}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  h=540000,
                  w0=0)
                  annotation (Placement(transformation(extent={{-88,18},{-68,38}})));
                ThermoPower.Water.SourcePressure sourceMassFlow1(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  p0=8181000,
                  h=2755.9e3)
                  annotation (Placement(transformation(extent={{-66,50},{-46,70}})));
                ThermoPower.Water.ValveLin valveDrain(redeclare package Medium
                    = Modelica.Media.Water.WaterIF97_ph, Kv=6.9888689915e-7/0.2)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=-90,
                      origin={-20,-50})));
                ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                  annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
                IndustrialControlSystems.Controllers.PI PI_valve(
                  CSmin=0,
                  AntiWindup=true,
                  useTS=false,
                  CSmax=1,
                  CS_start=0.2,
                  Kp=-9.126,
                  Ti=42.99)
                          annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=270,
                      origin={-60,-20})));
              equation

                connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                    Line(
                    points={{13.72,20},{31.59,20}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1,flow1DFV. wall)
                  annotation (Line(points={{38.3,20},{55,20}}, color={255,127,0}));
                connect(flow1DFV.infl,sourceMassFlow2. flange)
                  annotation (Line(points={{60,10},{60,-18},{50,-18}},color={0,0,255}));
                connect(flow1DFV.outfl,sinkPressure1. flange) annotation (Line(points={{60,30},
                        {60,30},{60,60},{70,60}}, color={0,0,255}));
                connect(sourceMassFlow1.flange,baseNusseltCondenser. steam_in)
                  annotation (Line(
                    points={{-46,60},{-20,60},{-20,44}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(sourceMassFlow.flange,baseNusseltCondenser. drained_in)
                  annotation (Line(
                    points={{-68,28},{-30,28}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(valveDrain.outlet,sinkPressure. flange) annotation (Line(
                      points={{-20,-60},{-20,-80},{0,-80}},
                                                         color={0,0,255}));
                connect(baseNusseltCondenser.drained_out,valveDrain. inlet)
                  annotation (Line(points={{-20,2},{-20,-40}},     color={0,0,255}));
                connect(baseNusseltCondenser.level, PI_valve.PV) annotation (Line(
                      points={{-30,6},{-59,6},{-59,-12}}, color={0,0,127}));
                connect(baseNusseltCondenser.zl_SP, PI_valve.SP) annotation (Line(
                      points={{-30,18},{-30,18},{-66,18},{-66,-12}}, color={0,0,127}));
                connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-60,-29},
                        {-60,-29},{-60,-50},{-28,-50}},      color={0,0,127}));
                connect(baseNusseltCondenser.DHT, tubeWalls_cond.int)
                  annotation (Line(points={{-11,20},{6.4,20}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})),
                  experiment(StopTime=1000),
                  __Dymola_experimentSetupOutput);
              end test_condensingSection;

              model test_subcoolingSection
                "Test model of the subcooling section (HPH2)"
                extends Modelica.Icons.Example;
                ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=27.94,
                  h=977.1e3)  annotation (Placement(transformation(extent={{20,-50},
                          {40,-30}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=4.449,
                  h=1325.7e3)
                  annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
                ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                    Medium = Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                  annotation (Placement(transformation(extent={{60,30},{80,50}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=8181000)
                  annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
                inner ThermoPower.System system annotation (Placement(
                      transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV_FW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  hstartin=1197.5e3,
                  hstartout=1202.5e3,
                  A=0.53*0.15,
                  omega=210*0.15,
                  wnom=27.94,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=2400))
                              annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,0})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
                  final cm=500,
                  final Nw=5,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  final M=10000*0.15,
                  Tstart1=548.15,
                  TstartN=563.15) annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,0})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,0})));
                ThermoPower.Water.Flow1DFV flow1DFV_SP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  hstartin=1.3e6,
                  hstartout=1.2e6,
                  A=2.99*0.15,
                  omega=210*0.15,
                  wnom=4.449,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600)) annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,0})));
              equation

                connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                      points={{60,40},{50,40},{50,10}}, color={0,0,255}));
                connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                      points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
                connect(tubeWalls_sub.ext, heatExchangerTopology_cond.side2)
                  annotation (Line(
                    points={{-8.28,0},{9.59,0}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                  annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
                connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                      points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
                connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                      points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
                connect(flow1DFV_SP.wall, tubeWalls_sub.int) annotation (Line(
                      points={{-45,0},{-15.6,0}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_subcoolingSection;

              model test_desuperheatingSection
                "Test model of the subcooling section (HPH2)"
                extends Modelica.Icons.Example;
                ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=27.94,
                  h=1257.3e3) annotation (Placement(transformation(extent={{20,-50},
                          {40,-30}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=4.449,
                  h=3231e3)
                  annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
                ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                    Medium = Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                  annotation (Placement(transformation(extent={{60,30},{80,50}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=8181000)
                  annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
                inner ThermoPower.System system annotation (Placement(
                      transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV_FW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600),
                  hstartin=1275.5e3,
                  hstartout=1320e3,
                  A=0.53*0.15,
                  omega=210*0.15,
                  wnom=27.94)       annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,0})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_des(
                  final cm=500,
                  final Nw=5,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  final M=1000,
                  Tstart1=548.15,
                  TstartN=563.15) annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,0})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,0})));
                ThermoPower.Water.Flow1DFV flow1DFV_SP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  hstartin=3.216e6,
                  hstartout=2760e3,
                  A=2.99*0.15,
                  omega=210*0.15,
                  wnom=4.449,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600)) annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,0})));
              equation

                connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                      points={{60,40},{50,40},{50,10}}, color={0,0,255}));
                connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                      points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
                connect(tubeWalls_des.ext, heatExchangerTopology_cond.side2)
                  annotation (Line(
                    points={{-8.28,0},{9.59,0}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                  annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
                connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                      points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
                connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                      points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
                connect(flow1DFV_SP.wall, tubeWalls_des.int) annotation (Line(
                      points={{-45,0},{-15.6,0}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_desuperheatingSection;

              model test_HPH2 "Test model of the complete HPH2"
                extends Modelica.Icons.Example;
                ThermoPower.Water.SourcePressure sourceMassFlowSP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  p0=8181000,
                  h=3231e3)
                  annotation (Placement(transformation(extent={{-80,80},{-60,100}})));
                ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                    Medium = Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                  annotation (Placement(transformation(extent={{60,80},{80,100}})));
                ThermoPower.Water.Flow1DFV FW_des(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=1275.5e3,
                  hstartout=1320e3,
                  A=0.53*0.15,
                  omega=210*0.15,
                  wnom=27.94,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600))                     annotation (
                    Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,50})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  final M=10000*0.15,
                  Tstart1=548.15,
                  TstartN=563.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,50})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,50})));
                ThermoPower.Water.Flow1DFV SP_des(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=3.216e6,
                  hstartout=2760e3,
                  A=2.99*0.15,
                  omega=210*0.15,
                  wnom=4.449,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600))                     annotation (
                    Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,50})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond1(
                  final cm=500,
                  final Nw=5,
                  final M=10000*0.7,
                  Tstart1=563.15,
                  TstartN=567.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,6})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond1(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,6})));
                ThermoPower.Water.Flow1DFV FW_cond(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=1202.5e3,
                  hstartout=1262.5e3,
                  A=0.53*0.7,
                  omega=210*0.7,
                  wnom=27.94,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=2400))                     annotation (
                    Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,6})));
                Components.NusseltCondenser         SP_cond(
                  zl_set=0.1,
                  zl_start=0.1,
                  A=1,
                  Nw=5,
                  noInitialPressure=true,
                  V=2.99*0.7,
                  S=210*0.7,
                  gamma=4100,
                  p_start=8181000) annotation (Placement(transformation(extent={{
                          -78,-22},{-22,34}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  h=540000,
                  w0=0)
                  annotation (Placement(transformation(extent={{-90,4},{-70,24}})));
                IndustrialControlSystems.Controllers.PI PI_valve(
                  CSmin=0,
                  AntiWindup=true,
                  useTS=false,
                  CSmax=1,
                  CS_start=0.2,
                  Kp=-9.126,
                  Ti=43)  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=270,
                      origin={-80,-34})));
                ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=27.94,
                  h=977.1e3)  annotation (Placement(transformation(extent={{30,-88},
                          {50,-68}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                  annotation (Placement(transformation(extent={{-30,-88},{-10,-68}})));
                ThermoPower.Water.Flow1DFV sub_FW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  hstartin=1197.5e3,
                  hstartout=1202.5e3,
                  N=6,
                  A=0.53*0.15,
                  omega=210*0.15,
                  wnom=27.94,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=2400))
                       annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,-34})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond2(
                  final cm=500,
                  final M=1000,
                  final Nw=5,
                  Tstart1=548.15,
                  TstartN=563.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,-34})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond2(
                    redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                    Nw=5)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,-34})));
                ThermoPower.Water.Flow1DFV SP_sub(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  hstartin=1.3e6,
                  hstartout=1.2e6,
                  N=6,
                  A=2.99*0.15,
                  omega=210*0.15,
                  wnom=4.449,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=3600))
                       annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,-34})));
                ThermoPower.Water.ValveLin valveDrain(redeclare package Medium
                    = Modelica.Media.Water.WaterIF97_ph, Kv=6.575589005e-7/0.6)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=-90,
                      origin={-50,-60})));
                inner ThermoPower.System system annotation (Placement(
                      transformation(extent={{-100,-100},{-80,-80}})));
              equation
                connect(sinkPressureFW.flange, FW_des.outfl) annotation (Line(
                      points={{60,90},{50,90},{50,60}}, color={0,0,255}));
                connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                    Line(
                    points={{-8.28,50},{9.59,50}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, FW_des.wall)
                  annotation (Line(points={{16.3,50},{45,50}}, color={255,127,0}));
                connect(sourceMassFlowSP.flange, SP_des.infl) annotation (Line(
                      points={{-60,90},{-50,90},{-50,60}}, color={0,0,255}));
                connect(SP_des.wall, tubeWalls_cond.int) annotation (Line(points={{
                        -45,50},{-15.6,50}}, color={255,127,0}));
                connect(tubeWalls_cond1.ext, heatExchangerTopology_cond1.side2)
                  annotation (Line(
                    points={{-8.28,6},{9.59,6}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond1.side1, FW_cond.wall)
                  annotation (Line(points={{16.3,6},{45,6}}, color={255,127,0}));
                connect(sourceMassFlow.flange, SP_cond.drained_in) annotation (Line(
                    points={{-70,14},{-60,14}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(SP_cond.level, PI_valve.PV) annotation (Line(points={{-60,
                        -8},{-79,-8},{-79,-26}}, color={0,0,127}));
                connect(SP_cond.zl_SP, PI_valve.SP) annotation (Line(points={{-60,4},
                        {-60,4},{-86,4},{-86,-26}}, color={0,0,127}));
                connect(SP_cond.DHT, tubeWalls_cond1.int) annotation (Line(points={
                        {-41,6},{-28,6},{-15.6,6}}, color={255,127,0}));
                connect(SP_des.outfl, SP_cond.steam_in)
                  annotation (Line(points={{-50,40},{-50,30}}, color={0,0,255}));
                connect(FW_des.infl, FW_cond.outfl) annotation (Line(points={{50,40},
                        {50,40},{50,16}}, color={0,0,255}));
                connect(sourceMassFlowFW.flange, sub_FW.infl) annotation (Line(
                      points={{50,-78},{50,-78},{50,-44}}, color={0,0,255}));
                connect(tubeWalls_cond2.ext, heatExchangerTopology_cond2.side2)
                  annotation (Line(
                    points={{-8.28,-34},{9.59,-34}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond2.side1, sub_FW.wall) annotation (
                   Line(points={{16.3,-34},{45,-34}}, color={255,127,0}));
                connect(SP_sub.wall, tubeWalls_cond2.int) annotation (Line(points={
                        {-45,-34},{-15.6,-34}}, color={255,127,0}));
                connect(SP_cond.drained_out, SP_sub.infl) annotation (Line(points={
                        {-50,-12},{-50,-12},{-50,-24}}, color={0,0,255}));
                connect(FW_cond.infl, sub_FW.outfl) annotation (Line(points={{50,-4},
                        {50,-4},{50,-24}}, color={0,0,255}));
                connect(SP_sub.outfl, valveDrain.inlet) annotation (Line(points={{
                        -50,-44},{-50,-44},{-50,-50}}, color={0,0,255}));
                connect(valveDrain.outlet, sinkPressure1.flange) annotation (Line(
                      points={{-50,-70},{-50,-78},{-30,-78}}, color={0,0,255}));
                connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-80,
                        -43},{-80,-60},{-58,-60}}, color={0,0,127}));
                annotation (Diagram(coordinateSystem(preserveAspectRatio=false,
                        extent={{-100,-100},{100,100}})),
                  experiment(StopTime=1000),
                  __Dymola_experimentSetupOutput,
                  Documentation(info="<html>
<p>Model of the HPH2, used for parameters tuning and results check.</p>
</html>"));
              end test_HPH2;
            end HPH2;

            package HPH1 "Test models of the HPH1"

              model test_condensingSection_FW
                "Test of the preheater condensing section"
                extends Modelica.Icons.Example;
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  final M=7500*0.85,
                  initOpt=ThermoPower.Choices.Init.Options.noInit)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={10,18})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                    Nw=5)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={35,18})));

                ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=91.28,
                  h=808.6e3)
                  annotation (Placement(transformation(extent={{30,-30},{50,-10}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=17630000)
                  annotation (Placement(transformation(extent={{70,50},{90,70}})));
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                  annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Liquid,
                  noInitialPressure=true,
                  A=0.53,
                  N=6,
                  wnom=91.28,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=4000),
                  omega=300*0.85)                                       annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={60,18})));
                ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=270,
                      origin={-12,18})));
                Modelica.Blocks.Sources.Constant T_in(k=473.15) annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=0,
                      origin={-70,40})));
                Modelica.Blocks.Sources.Constant T_out(k=480.15) annotation (
                    Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=0,
                      origin={-70,0})));
              equation

                connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                    Line(
                    points={{13.72,18},{31.59,18}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV.wall)
                  annotation (Line(points={{38.3,18},{55,18}}, color={255,127,0}));
                connect(flow1DFV.infl, sourceMassFlow2.flange)
                  annotation (Line(points={{60,8},{60,-20},{50,-20}}, color={0,0,255}));
                connect(flow1DFV.outfl, sinkPressure1.flange) annotation (Line(points={{60,28},
                        {60,28},{60,60},{70,60}}, color={0,0,255}));
                connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                      points={{-15,22},{-48,22},{-48,40},{-59,40}}, color={0,0,127}));
                connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                      points={{-14.8,14},{-48.2,14},{-48.2,0},{-59,0}}, color={0,0,
                        127}));
                connect(tempSource1DlinFV.wall, tubeWalls_cond.int)
                  annotation (Line(points={{-9,18},{6.4,18}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_condensingSection_FW;

              model test_condensingSection_ST
                "Test of the condensing section of the last high pressure preheater"
                extends Modelica.Icons.Example;
                Components.NusseltCondenser         baseNusseltCondenser(
                  zl_set=0.1,
                  zl_start=0.1,
                  A=1,
                  noInitialPressure=true,
                  Nw=5,
                  V=2.01*0.85,
                  gamma=8000,
                  S=300*0.85,
                  p_start=1815000) annotation (Placement(transformation(extent={{
                          -28,12},{28,68}})));
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                  annotation (Placement(transformation(extent={{-100,80},{-80,
                          100}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=4.449,
                  h=997.8e3)
                  annotation (Placement(transformation(extent={{-60,38},{-40,58}})));
                ThermoPower.Water.SourcePressure sourceMassFlow1(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  p0=1815000,
                  h=2796.2e3)
                  annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
                ThermoPower.Water.ValveLin valveDrain(redeclare package Medium
                    = Modelica.Media.Water.WaterIF97_ph, Kv=1.026611797e-5/0.2)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=-90,
                      origin={0,-38})));
                IndustrialControlSystems.Controllers.PI
                                                    PID_level(
                  CSmin=0,
                  CSmax=1,
                  Kp=-15.85,
                  Ti=21.05,
                  CS_start=0.5,
                  AntiWindup=true)
                               annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=-90,
                      origin={-40,-10})));
                ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1086000)
                  annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
                ThermoPower.Thermal.TempSource1DlinFV tempSource1DlinFV(Nw=5)
                  annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={34,40})));
                Modelica.Blocks.Sources.Constant T_in(k=473.15) annotation (Placement(
                      transformation(
                      extent={{10,-10},{-10,10}},
                      rotation=0,
                      origin={70,60})));
                Modelica.Blocks.Sources.Constant T_out(k=480.15) annotation (
                    Placement(transformation(
                      extent={{10,-10},{-10,10}},
                      rotation=0,
                      origin={70,20})));
              equation
                connect(sourceMassFlow1.flange, baseNusseltCondenser.steam_in)
                  annotation (Line(
                    points={{-20,80},{0,80},{0,64}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(sourceMassFlow.flange, baseNusseltCondenser.drained_in)
                  annotation (Line(
                    points={{-40,48},{-10,48}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(baseNusseltCondenser.level, PID_level.PV) annotation (Line(
                    points={{-10,26},{-41,26},{-41,-2}},
                    color={0,0,127},
                    smooth=Smooth.None));
                connect(baseNusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                    points={{-10,38},{-34,38},{-34,-2}},
                    color={0,0,127},
                    smooth=Smooth.None));
                connect(PID_level.CS, valveDrain.cmd) annotation (Line(points={{-40,-19},
                        {-40,-19},{-40,-38},{-8,-38}},      color={0,0,127}));
                connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
                      points={{0,-48},{0,-60},{20,-60}}, color={0,0,255}));
                connect(baseNusseltCondenser.drained_out, valveDrain.inlet)
                  annotation (Line(points={{0,22},{0,22},{0,-28}}, color={0,0,255}));
                connect(tempSource1DlinFV.wall, baseNusseltCondenser.DHT) annotation (
                   Line(points={{31,40},{20,40},{9,40}}, color={255,127,0}));
                connect(tempSource1DlinFV.temperature_1, T_in.y) annotation (Line(
                      points={{37,44},{50,44},{50,60},{59,60}}, color={0,0,127}));
                connect(tempSource1DlinFV.temperature_Nw, T_out.y) annotation (Line(
                      points={{36.8,36},{50,36},{50,20},{59,20}}, color={0,0,127}));
                annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                          -100},{100,100}})));
              end test_condensingSection_ST;

              model test_condensingSection
                "Test of the preheater condensing section"
                extends Modelica.Icons.Example;
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                  annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  final M=7500*0.85,
                  Tstart1=563.15,
                  TstartN=567.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={10,20})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CoCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={35,20})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow2(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=91.28,
                  h=808.6e3)
                  annotation (Placement(transformation(extent={{30,-28},{50,-8}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=17630000)
                  annotation (Placement(transformation(extent={{70,50},{90,70}})));
                ThermoPower.Water.Flow1DFV flow1DFV(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=780.2e3,
                  hstartout=873.2e3,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=4000),
                  A=0.53*0.85,
                  wnom=91.28,
                  omega=300*0.85)                                       annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={60,20})));
                Components.NusseltCondenser baseNusseltCondenser(
                  zl_set=0.1,
                  zl_start=0.1,
                  A=1,
                  noInitialPressure=true,
                  Nw=5,
                  V=2.01*0.85,
                  gamma=8000,
                  S=300*0.85,
                  p_start=1815000) annotation (Placement(transformation(extent=
                          {{-48,-8},{8,48}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlow(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=4.449,
                  h=997.8e3)
                  annotation (Placement(transformation(extent={{-88,18},{-68,38}})));
                ThermoPower.Water.SourcePressure sourceMassFlow1(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  h=2796.2e3,
                  p0=1815000)
                  annotation (Placement(transformation(extent={{-66,50},{-46,70}})));
                ThermoPower.Water.ValveLin valveDrain(redeclare package Medium
                    = Modelica.Media.Water.WaterIF97_ph, Kv=1.026611797e-5/0.2)
                  annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=-90,
                      origin={-20,-50})));
                ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1086000)
                  annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
                IndustrialControlSystems.Controllers.PI PI_valve(
                  CSmin=0,
                  CS_start=0.6,
                  AntiWindup=true,
                  useTS=false,
                  CSmax=1,
                  Kp=-15.85,
                  Ti=21.05)
                          annotation (Placement(transformation(
                      extent={{-10,10},{10,-10}},
                      rotation=270,
                      origin={-60,-20})));

              Real DT = baseNusseltCondenser.T_sat - baseNusseltCondenser.Tw[3];
              Real UA = baseNusseltCondenser.gamma*baseNusseltCondenser.S;

              equation
                connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                    Line(
                    points={{13.72,20},{31.59,20}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1,flow1DFV. wall)
                  annotation (Line(points={{38.3,20},{55,20}}, color={255,127,0}));
                connect(flow1DFV.infl,sourceMassFlow2. flange)
                  annotation (Line(points={{60,10},{60,-18},{50,-18}},color={0,0,255}));
                connect(flow1DFV.outfl,sinkPressure1. flange) annotation (Line(points={{60,30},
                        {60,30},{60,60},{70,60}}, color={0,0,255}));
                connect(sourceMassFlow1.flange,baseNusseltCondenser. steam_in)
                  annotation (Line(
                    points={{-46,60},{-20,60},{-20,44}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(sourceMassFlow.flange,baseNusseltCondenser. drained_in)
                  annotation (Line(
                    points={{-68,28},{-30,28}},
                    color={0,0,255},
                    smooth=Smooth.None));
                connect(valveDrain.outlet,sinkPressure. flange) annotation (Line(
                      points={{-20,-60},{-20,-80},{0,-80}},
                                                         color={0,0,255}));
                connect(baseNusseltCondenser.drained_out,valveDrain. inlet)
                  annotation (Line(points={{-20,2},{-20,-40}},     color={0,0,255}));
                connect(baseNusseltCondenser.level, PI_valve.PV) annotation (Line(
                      points={{-30,6},{-59,6},{-59,-12}}, color={0,0,127}));
                connect(baseNusseltCondenser.zl_SP, PI_valve.SP) annotation (Line(
                      points={{-30,18},{-30,18},{-66,18},{-66,-12}}, color={0,0,127}));
                connect(PI_valve.CS, valveDrain.cmd) annotation (Line(points={{-60,-29},{-60,-29},
                        {-60,-50},{-28,-50}},                color={0,0,127}));
                connect(baseNusseltCondenser.DHT, tubeWalls_cond.int)
                  annotation (Line(points={{-11,20},{6.4,20}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})),
                  experiment(StopTime=1000),
                  __Dymola_experimentSetupOutput);
              end test_condensingSection;

              model test_subcoolingSection
                "Test model of the subcooling section (HPH2)"
                extends Modelica.Icons.Example;
                ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=91.28,
                  h=803.3e3) annotation (Placement(transformation(extent={{20,-50},
                          {40,-30}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=7.484,
                  h=886.5e3)
                  annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
                ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                    Medium = Modelica.Media.Water.WaterIF97_ph, p0=18380000)
                  annotation (Placement(transformation(extent={{60,30},{80,50}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                  annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
                inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                                annotation (Placement(
                      transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV_FW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=1197.5e3,
                  hstartout=1202.5e3,
                  A=0.53*0.05,
                  omega=300*0.05,
                  wnom=91.28,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=4000))
                                  annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,0})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  final M=7500*0.05,
                  Tstart1=548.15,
                  TstartN=563.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,0})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,0})));
                ThermoPower.Water.Flow1DFV flow1DFV_SP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  hstartin=1.3e6,
                  hstartout=1.2e6,
                  omega=300*0.05,
                  wnom=7.484,
                  A=2.01*0.05,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=5000)) annotation (Placement(
                      transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,0})));
              equation

                connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                      points={{60,40},{50,40},{50,10}}, color={0,0,255}));
                connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                      points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
                connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                    Line(
                    points={{-8.28,0},{9.59,0}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                  annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
                connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                      points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
                connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                      points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
                connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                  annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_subcoolingSection;

              model test_desuperheatingSection
                "Test model of the subcooling section (HPH2)"
                extends Modelica.Icons.Example;
                ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  w0=91.28,
                  h=877.224e3)
                             annotation (Placement(transformation(extent={{20,-50},
                          {40,-30}})));
                ThermoPower.Water.SourceMassFlow sourceMassFlowSP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  h=3280.7e3,
                  w0=3.034)
                  annotation (Placement(transformation(extent={{-80,30},{-60,50}})));
                ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                    Medium = Modelica.Media.Water.WaterIF97_ph, p0=17630000)
                  annotation (Placement(transformation(extent={{60,30},{80,50}})));
                ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                    Medium =
                      Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                  annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
                inner ThermoPower.System system annotation (Placement(
                      transformation(extent={{-100,80},{-80,100}})));
                ThermoPower.Water.Flow1DFV flow1DFV_FW(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  A=0.53*0.1,
                  hstartin=1275.5e3,
                  hstartout=1320e3,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=4000),
                  wnom=91.28,
                  omega=300*0.08)  annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=90,
                      origin={50,0})));
                ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
                  final cm=500,
                  final Nw=5,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  final M=7500*0.1,
                  Tstart1=548.15,
                  TstartN=563.15)
                  annotation (Placement(transformation(
                      extent={{-12,12},{12,-12}},
                      rotation=-90,
                      origin={-12,0})));
                ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(
                    Nw=5, redeclare model HeatExchangerTopology =
                      ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow)
                  annotation (Placement(transformation(
                      extent={{-12,-11},{12,11}},
                      rotation=-90,
                      origin={13,0})));
                ThermoPower.Water.Flow1DFV flow1DFV_SP(
                  redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                  L=1,
                  FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true,
                  N=6,
                  initOpt=ThermoPower.Choices.Init.Options.steadyState,
                  hstartin=3.216e6,
                  hstartout=2760e3,
                  A=2.01*0.1,
                  wnom=3.034,
                  redeclare model HeatTransfer =
                      ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                      (alpha=0.8, gamma_nom=2000),
                  omega=300*0.08)  annotation (Placement(transformation(
                      extent={{-10,-10},{10,10}},
                      rotation=270,
                      origin={-50,0})));
              equation

                connect(sinkPressureFW.flange, flow1DFV_FW.outfl) annotation (Line(
                      points={{60,40},{50,40},{50,10}}, color={0,0,255}));
                connect(sourceMassFlowFW.flange, flow1DFV_FW.infl) annotation (Line(
                      points={{40,-40},{50,-40},{50,-10}}, color={0,0,255}));
                connect(tubeWalls_cond.ext,heatExchangerTopology_cond. side2) annotation (
                    Line(
                    points={{-8.28,0},{9.59,0}},
                    color={255,127,0},
                    smooth=Smooth.None));
                connect(heatExchangerTopology_cond.side1, flow1DFV_FW.wall)
                  annotation (Line(points={{16.3,0},{45,0}}, color={255,127,0}));
                connect(sourceMassFlowSP.flange, flow1DFV_SP.infl) annotation (Line(
                      points={{-60,40},{-50,40},{-50,10}}, color={0,0,255}));
                connect(flow1DFV_SP.outfl, sinkPressure1.flange) annotation (Line(
                      points={{-50,-10},{-50,-40},{-40,-40}}, color={0,0,255}));
                connect(flow1DFV_SP.wall, tubeWalls_cond.int)
                  annotation (Line(points={{-45,0},{-15.6,0}}, color={255,127,0}));
                annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                        preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                          -100,-100},{100,100}})));
              end test_desuperheatingSection;
            end HPH1;

            model test_HPH2 "Test model of the HPH2"
              extends Modelica.Icons.Example;
              Preheaters.HPH_controlledLevel HPH2(
                A=1,
                zl_set=0.1,
                zl_start=0.1,
                cm=500,
                Ta=0.3,
                CSmin=0,
                CSmax=1,
                Nhex_des=3,
                Nhex_cond=3,
                Nhex_sub=5,
                redeclare model HeatTransferCold_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=2400),
                redeclare model HeatTransferHot_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                Vhot_des=2.99*0.15,
                Vcold_des=0.53*0.15,
                Shot_des=210*0.15,
                Scold_des=210*0.15,
                Mm_des=10000*0.15,
                Vhot_cond=2.99*0.7,
                Shot_cond=210*0.7,
                gamma=4100,
                redeclare model HeatTransferCold_cond =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=2400),
                Vcold_cond=0.53*0.7,
                Scold_cond=210*0.7,
                Mm_cond=10000*0.7,
                nominalColdFlow=27.94,
                nominalHotFlow=4.449,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare model HeatTransferCold_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=2400),
                redeclare model HeatTransferHot_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3600),
                Vhot_sub=2.99*0.15,
                Vcold_sub=0.53*0.15,
                Shot_sub=210*0.15,
                Scold_sub=210*0.15,
                Mm_sub=10000*0.15,
                CSstart=0.2,
                nominalDrainFlow=0,
                wnom=4.449,
                Kp=-9.126,
                Ti=42.99,
                nominalColdPressure=17630000,
                nominalHotPressure=8181000,
                nominalColdInletTemperature_des=557.15,
                nominalColdOutletTemperature_des=572.15,
                nominalHotInletTemperature_des=707.15,
                nominalHotOutletTemperature_des=570.15,
                p_start=8181000,
                nominalColdInletTemperature_cond=547.15,
                nominalColdOutletTemperature_cond=561.15,
                nominalColdInletTemperature_sub=499.45,
                nominalColdOutletTemperature_sub=510.15,
                nominalHotInletTemperature_sub=569.65,
                nominalHotOutletTemperature_sub=504.15,
                pnom=8150000,
                dpnom=6300000)
                          annotation (Placement(transformation(extent={{-20,-20},
                        {20,20}})));

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=3231e3,
                p0=8181000)
                annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=17400000)
                annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                              annotation (Placement(transformation(
                      extent={{-100,80},{-80,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=27.94,
                h=977.1e3)
                annotation (Placement(transformation(extent={{80,-10},{60,10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=1815000)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=540000,
                w0=0)
                annotation (Placement(transformation(extent={{-60,22},{-40,42}})));
              Modelica.Blocks.Sources.Step step(
                height=5,
                startTime=500,
                offset=27.94)
                annotation (Placement(transformation(extent={{40,20},{60,40}})));
            equation
              connect(sourceMassFlowSP.flange, HPH2.ST_in) annotation (Line(points={{-20,60},
                      {0,60},{0,20}},           color={0,0,255}));
              connect(sinkPressureFW.flange, HPH2.FW_out) annotation (Line(points={{-60,0},
                      {-20,0}},                 color={0,0,255}));
              connect(HPH2.FW_in, sourceMassFlowFW.flange)
                annotation (Line(points={{22,0},{42,0},{60,0}},
                                                         color={0,0,255}));
              connect(HPH2.DR_out, sinkPressure1.flange) annotation (Line(points={{0,-20},
                      {0,-20},{0,-60},{20,-60}},        color={0,0,255}));
              connect(sourceMassFlow.flange, HPH2.DR_in) annotation (Line(points={{-40,32},
                      {-14,32},{-14,20}},         color={0,0,255}));
              connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                      30},{74,30},{74,6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</span></p>
</html>"));
            end test_HPH2;

            model test_HPH1 "Test model of the HPH1"
              extends Modelica.Icons.Example;
              Preheaters.HPH_controlledLevel HPH1(
                Vcold_des=0.53*0.1,
                A=1,
                zl_set=0.1,
                zl_start=0.1,
                cm=500,
                Ta=0.3,
                CSmin=0,
                CSmax=1,
                Nhex_des=3,
                Nhex_cond=3,
                redeclare model HeatTransferCold_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                Vhot_des=2.01*0.1,
                Vhot_cond=2.01*0.8,
                redeclare model HeatTransferCold_cond =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                Vcold_cond=0.53*0.8,
                Mm_cond=7500*0.8,
                redeclare model HeatTransferCold_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                Nhex_sub=5,
                CSstart=0.2,
                nominalColdFlow=91.28,
                nominalHotFlow=3.034,
                nominalDrainFlow=4.449,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare model HeatTransferHot_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=2000),
                Shot_des=300*0.08,
                Scold_des=300*0.08,
                Mm_des=7500*0.1,
                Shot_cond=300*0.8,
                Scold_cond=300*0.8,
                redeclare model HeatTransferHot_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=5000),
                Vhot_sub=2.01*0.05,
                Vcold_sub=0.53*0.05,
                Shot_sub=300*0.05,
                Scold_sub=300*0.05,
                Mm_sub=7500*0.05,
                wnom=7.484,
                valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
                gamma=8000,
                nominalColdPressure=17630000,
                nominalHotPressure=1815000,
                nominalColdInletTemperature_des=477.15,
                nominalColdOutletTemperature_des=480.85,
                nominalHotInletTemperature_des=686.65,
                nominalHotOutletTemperature_des=480.75,
                p_start=1815000,
                nominalColdInletTemperature_cond=461.55,
                nominalColdOutletTemperature_cond=477.15,
                nominalColdInletTemperature_sub=460.35,
                nominalColdOutletTemperature_sub=461.55,
                nominalHotInletTemperature_sub=480.65,
                nominalHotOutletTemperature_sub=466.35,
                pnom=1815000,
                dpnom=800000,
                Kp=-15.85,
                Ti=21.05) annotation (Placement(transformation(extent={{-20,-20},
                        {20,20}})));

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=3280.7e3,
                p0=1815000)
                annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=17630000)
                annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                              annotation (Placement(transformation(
                      extent={{-100,80},{-80,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=91.28,
                h=803.3e3)
                annotation (Placement(transformation(extent={{80,-10},{60,10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=1086000)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=997.8e3,
                w0=4.449)
                annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
              Modelica.Blocks.Sources.Step step(
                height=5,
                startTime=500,
                offset=91.28)
                annotation (Placement(transformation(extent={{40,20},{60,40}})));
            equation
              connect(sourceMassFlowSP.flange, HPH1.ST_in) annotation (Line(points=
                      {{-20,60},{0,60},{0,20}}, color={0,0,255}));
              connect(sinkPressureFW.flange, HPH1.FW_out) annotation (Line(points={
                      {-60,0},{-40,0},{-20,0}}, color={0,0,255}));
              connect(HPH1.FW_in, sourceMassFlowFW.flange)
                annotation (Line(points={{22,0},{60,0}}, color={0,0,255}));
              connect(HPH1.DR_out, sinkPressure1.flange) annotation (Line(points={{
                      0,-20},{0,-20},{0,-60},{20,-60}}, color={0,0,255}));
              connect(sourceMassFlow.flange, HPH1.DR_in) annotation (Line(points={{-40,30},
                      {-14,30},{-14,20}},         color={0,0,255}));
              connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                      30},{74,30},{74,6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
            end test_HPH1;

            model test_LPH3
              "Test model of the LPH3 with desuperheating section"
              extends Modelica.Icons.Example;
              Preheaters.HPH_controlledLevel LPH3(
                A=1,
                zl_set=0.1,
                zl_start=0.1,
                cm=500,
                Ta=0.3,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalColdFlow=76.94,
                CSstart=0.5,
                redeclare model HeatTransferCold_cond =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                nominalHotFlow=2.48,
                nominalDrainFlow=0,
                Vhot_des=5.87*0.05,
                Vcold_des=0.5*0.05,
                Shot_des=225.64*0.05,
                Scold_des=0225.64*0.05,
                Mm_des=5000*0.05,
                Vhot_cond=5.87*0.9,
                Shot_cond=225.64*0.9,
                Vcold_cond=0.5*0.9,
                Scold_cond=225.64*0.9,
                Mm_cond=5000*0.9,
                redeclare model HeatTransferHot_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=3000, alpha=0.8),
                CSmin=0.05,
                CSmax=1,
                Vhot_sub=5.87*0.05,
                Vcold_sub=0.5*0.05,
                Shot_sub=225.64*0.05,
                Scold_sub=225.64*0.05,
                Mm_sub=5000*0.05,
                redeclare model HeatTransferCold_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3000),
                wnom=2.475,
                Nhex_cond=3,
                Nhex_sub=5,
                redeclare model HeatTransferCold_des =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3000),
                redeclare model HeatTransferHot_sub =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=3000),
                gamma=8000,
                Nhex_des=3,
                Kp=-108.2,
                Ti=21.03,
                nominalColdPressure=1303000,
                nominalHotPressure=300000,
                nominalColdInletTemperature_des=403.15,
                nominalColdOutletTemperature_des=406.75,
                nominalHotInletTemperature_des=485.25,
                nominalHotOutletTemperature_des=410.15,
                p_start=300000,
                nominalColdInletTemperature_cond=391.15,
                nominalColdOutletTemperature_cond=403.15,
                nominalColdInletTemperature_sub=388.65,
                nominalColdOutletTemperature_sub=391.15,
                nominalHotInletTemperature_sub=405.15,
                nominalHotOutletTemperature_sub=393.65,
                pnom=327600,
                dpnom=138300)
                          annotation (Placement(transformation(extent={{-20,-20},
                        {20,20}})));

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=2889.6e3,
                p0=327600)
                annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=1303000)
                annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                              annotation (Placement(transformation(
                      extent={{-100,80},{-80,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=76.94,
                h=485.5e3)
                annotation (Placement(transformation(extent={{80,-10},{60,10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=189300)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                h=506e3,
                w0=0)
                annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
              Modelica.Blocks.Sources.Step step(
                height=5,
                offset=76.94,
                startTime=500)
                annotation (Placement(transformation(extent={{40,20},{60,40}})));
            equation
              connect(sourceMassFlowSP.flange,LPH3. ST_in) annotation (Line(points={{-20,60},
                      {0,60},{0,20}},           color={0,0,255}));
              connect(sinkPressureFW.flange,LPH3. FW_out) annotation (Line(points={{-60,0},
                      {-20,0}},                 color={0,0,255}));
              connect(LPH3.FW_in, sourceMassFlowFW.flange)
                annotation (Line(points={{22,0},{42,0},{60,0}},
                                                         color={0,0,255}));
              connect(LPH3.DR_out, sinkPressure1.flange) annotation (Line(points={{0,-20},
                      {0,-20},{0,-60},{20,-60}},        color={0,0,255}));
              connect(sourceMassFlow.flange,LPH3. DR_in) annotation (Line(points={{-40,30},
                      {-14,30},{-14,20}},         color={0,0,255}));
              connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                      30},{74,30},{74,6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
            end test_LPH3;

            model test_LPH2 "Test model of the LPH2"
              extends Modelica.Icons.Example;
              Preheaters.LPH_controlledLevel LPH2(
                A=1,
                zl_set=0.1,
                zl_start=0.1,
                cm=500,
                Ta=0.3,
                CSmin=0,
                CSmax=1,
                Nhex_cond=3,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalColdFlow=76.94,
                CSstart=0.5,
                nominalHotFlow=4.9,
                nominalDrainFlow=2.475,
                Vhot_cond=7.03,
                Shot_cond=268.36,
                Vcold_cond=0.58,
                Scold_cond=268.36,
                Mm_cond=5000,
                gamma=7000,
                redeclare model HeatTransferCold_cond =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                wnom=7.375,
                nominalColdPressure=1433000,
                nominalHotPressure=189300,
                p_start=189300,
                nominalColdInletTemperature_cond=353.95,
                nominalColdOutletTemperature_cond=388.65,
                pnom=189300,
                dpnom=134150,
                Kp=-16.21,
                Ti=39.15) annotation (Placement(transformation(extent={{-20,-20},
                        {20,20}})));

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=189300,
                h=2786.9e3)
                annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=1433000)
                annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                              annotation (Placement(transformation(
                      extent={{-100,80},{-80,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=76.94,
                h=339.4e3)
                annotation (Placement(transformation(extent={{80,-10},{60,10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=55150)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=2.475,
                h=506e3)
                annotation (Placement(transformation(extent={{-60,22},{-40,42}})));
              Modelica.Blocks.Sources.Step step(
                height=5,
                startTime=500,
                offset=76.94)
                annotation (Placement(transformation(extent={{40,20},{60,40}})));
            equation
              connect(sourceMassFlowSP.flange,LPH2. ST_in) annotation (Line(points=
                      {{-20,60},{0,60},{0,20}}, color={0,0,255}));
              connect(sinkPressureFW.flange,LPH2. FW_out) annotation (Line(points={
                      {-60,0},{-40,0},{-20,0}}, color={0,0,255}));
              connect(LPH2.FW_in, sourceMassFlowFW.flange)
                annotation (Line(points={{22,0},{60,0}}, color={0,0,255}));
              connect(LPH2.DR_out, sinkPressure1.flange) annotation (Line(points={{
                      0,-20},{0,-20},{0,-60},{20,-60}}, color={0,0,255}));
              connect(sourceMassFlow.flange,LPH2. DR_in) annotation (Line(points={{
                      -40,32},{-14,32},{-14,20}}, color={0,0,255}));
              connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                      30},{74,30},{74,6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
            end test_LPH2;

            model test_LPH1 "Test model of the LPH1"
              extends Modelica.Icons.Example;
              Preheaters.LPH_controlledLevel LPH1(
                A=1,
                zl_set=0.1,
                zl_start=0.1,
                cm=500,
                Ta=0.3,
                CSmin=0,
                CSmax=1,
                Nhex_cond=3,
                redeclare model HeatTransferCold_cond =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.8, gamma_nom=4000),
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                nominalColdFlow=76.94,
                nominalHotFlow=3.813,
                nominalDrainFlow=7.375,
                Vhot_cond=9.01,
                Shot_cond=323.24,
                Vcold_cond=0.7,
                Scold_cond=323.24,
                Mm_cond=6400,
                gamma=4000,
                CSstart=0.5,
                wnom=11.19,
                nominalColdPressure=1505000,
                nominalHotPressure=55150,
                p_start=55150,
                nominalColdInletTemperature_cond=327.69,
                nominalColdOutletTemperature_cond=353.95,
                pnom=55150,
                dpnom=43760,
                Kp=-5.431,
                Ti=79.38) annotation (Placement(transformation(extent={{-20,-20},
                        {20,20}})));

              ThermoPower.Water.SourcePressure sourceMassFlowSP(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                p0=55150,
                h=2287.3e3)
                annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
              ThermoPower.Water.SinkPressure sinkPressureFW(redeclare package
                  Medium = Modelica.Media.Water.WaterIF97_ph, p0=1505000)
                annotation (Placement(transformation(extent={{-60,-10},{-80,10}})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                              annotation (Placement(transformation(
                      extent={{-100,80},{-80,100}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlowFW(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=76.94,
                h=229.4e3)
                annotation (Placement(transformation(extent={{80,-10},{60,10}})));
              ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                  Medium =
                    Modelica.Media.Water.WaterIF97_ph, p0=11390)
                annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
              ThermoPower.Water.SourceMassFlow sourceMassFlow(
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=7.375,
                h=497.4e3)
                annotation (Placement(transformation(extent={{-60,22},{-40,42}})));
              Modelica.Blocks.Sources.Step step(
                height=5,
                startTime=500,
                offset=76.94)
                annotation (Placement(transformation(extent={{40,20},{60,40}})));
            equation
              connect(sourceMassFlowSP.flange,LPH1. ST_in) annotation (Line(points=
                      {{-20,60},{0,60},{0,20}}, color={0,0,255}));
              connect(sinkPressureFW.flange,LPH1. FW_out) annotation (Line(points={
                      {-60,0},{-40,0},{-20,0}}, color={0,0,255}));
              connect(LPH1.FW_in, sourceMassFlowFW.flange)
                annotation (Line(points={{22,0},{60,0}}, color={0,0,255}));
              connect(LPH1.DR_out, sinkPressure1.flange) annotation (Line(points={{
                      0,-20},{0,-20},{0,-60},{20,-60}}, color={0,0,255}));
              connect(sourceMassFlow.flange,LPH1. DR_in) annotation (Line(points={{
                      -40,32},{-14,32},{-14,20}}, color={0,0,255}));
              connect(step.y, sourceMassFlowFW.in_w0) annotation (Line(points={{61,
                      30},{74,30},{74,6}}, color={0,0,127}));
              annotation (
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                        -100},{100,100}})),
                experiment(StopTime=1000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
<p>Test model of the second high pressure heater. Step on the inlet feedwater mass flow to check the validity of the heat exchange model.</p>
</html>"));
            end test_LPH1;
          end Preheaters_NusseltCondenser_tuning;

          model test_HPH_train_offDesign_controlledLevel
            "Test model of the HPH_train for offDesign checking, Nusselt condense type"
            import PreFlexMS;
            extends Modelica.Icons.Example;
            PreFlexMS.FullScale_245degC.HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs(HPH2(des_SP(noInitialPressure=true)), HPH1(des_SP(
                    noInitialPressure=true)))
              annotation (Placement(transformation(extent={{-60,-40},{80,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,30},{160,50}})));
            ThermoPower.Water.SourcePressure sourcePressure(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1384500,
              p0=18140000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-100,-110},{-80,-90}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=17910000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,-10},{-160,10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, w0=0,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{80,90},{60,110}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-40,70},{-20,90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-240,160},{-220,180}})));
            PreFlexMS.FullScale_245degC.Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad
              controllers(
              Ta_pumpFW=5,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=5,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpMS=5,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSmax_pumpFW=0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSmin_pumpMS=-0.9,
              CSmax_pumpMS=1,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              Kp_pumpFW=-1,
              Ti_pumpFW=28.59,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Kp_pumpMS=1.2e-7,
              Ti_pumpMS=114.3,
              Ti_valveTURB=95.23,
              Kp_valveTURB=-0.0000014,
              Ta_valveTURB=2,
              useTS_pumpFW=true,
              useTS_pumpHPH=true,
              useTS_pumpMS=true,
              useTS_valveTURB=true,
              load_start=loadCalc.load_start,
              load_end=loadCalc.load_end,
              t_ramp=loadCalc.t_ramp,
              Kp_valveBP=1,
              Ti_valveBP=1,
              CSmin_valveBP=0,
              CSmax_valveBP=1,
              CSstart_valveBP=0.5,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              useTS_valveBP=true,
              TS_valveBP=0,
              DT_SH_sp=20,
              t_start_ramp=loadCalc.t_start,
              T_FW_sp=553.15,
              T_MS_sp=563.15)
                             annotation (Placement(transformation(extent={{120,
                      -160},{80,-120}})));
            Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                  transformation(extent={{-48,-124},{-40,-116}})));
            Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-138},{-40,-130}})));
            Modelica.Blocks.Sources.Constant valveBP_PV(k=0) annotation (
                Placement(transformation(extent={{-48,-168},{-40,-160}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-6,-146},{6,-134}})));
            Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
              annotation (Placement(transformation(extent={{-48,-154},{-40,-146}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              t_ramp=8e5,
              t_start=5000,
              load_start=100,
              load_end=20) annotation (Placement(transformation(extent={{-220,-160},
                      {-180,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-40})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceH(table=[20,1232.1e3;
                  30,1252.4e3; 40,1262e3; 50,1256.5e3; 60,1118.1e3; 70,1062.2e3;
                  80,1062.4e3; 90,1293.5e3; 100,1289e3])   annotation (Placement(
                  transformation(extent={{-140,-50},{-120,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,-70})));
            Modelica.Blocks.Tables.CombiTable1D HPH_sourceP(table=[20,86.35e5;
                  30,88.66e5; 40,91.88e5; 50,98.91e5; 60,119.1e5; 70,131.6e5;
                  80,147.2e5; 90,162.3e5; 100,176.3e5])
                                            annotation (Placement(transformation(
                    extent={{-140,-80},{-120,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-210,30})));
            Modelica.Blocks.Tables.CombiTable1D FW_sinkP(table=[20,85.44e5; 30,
                  86.74e5; 40,87.97e5; 50,92.49e5; 60,109.5e5; 70,126.1e5; 80,
                  142e5; 90,157.8e5; 100,174e5])   annotation (Placement(
                  transformation(extent={{-180,20},{-160,40}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-70})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,565.4e3;
                  30,622.1e3; 40,660.2e3; 50,691.1e3; 60,717.7e3; 70,744.1e3;
                  80,764.1e3; 90,783.8e3; 100,803.1e3])
                                                     annotation (Placement(
                  transformation(extent={{180,-80},{160,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,60})));
            Modelica.Blocks.Tables.CombiTable1D dea_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,50},{180,70}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,140})));
            Modelica.Blocks.Tables.CombiTable1D SP1_sourceH(table=[20,3315e3;
                  30,3307e3; 40,3300e3; 50,3289e3; 60,3272e3; 70,3261e3; 80,
                  3243e3; 90,3226e3; 100,3231e3])
                                          annotation (Placement(transformation(
                    extent={{-60,130},{-40,150}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-90,110})));
            Modelica.Blocks.Tables.CombiTable1D SP1_sourceP(table=[20,15.4e5;
                  30,23.19e5; 40,31.11e5; 50,39.41e5; 60,47.63e5; 70,56.66e5;
                  80,64.34e5; 90,72.55e5; 100,81.81e5])
                                     annotation (Placement(transformation(extent=
                      {{-60,100},{-40,120}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,130})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,160})));
            Modelica.Blocks.Tables.CombiTable1D SP2_sourceP(table=[20,3.594e5;
                  30,5.378e5; 40,7.149e5; 50,8.978e5; 60,10.78e5; 70,12.74e5;
                  80,14.41e5; 90,16.22e5; 100,18.15e5])
              annotation (Placement(transformation(extent={{40,150},{60,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,120})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceH(table=[20,1342e3;
                  30,1343.3e3; 40,1344.8e3; 50,1361.9e3; 60,1444.4e3; 70,
                  1511.3e3; 80,1573.6e3; 90,1634.9e3; 100,1700.4e3])
                                                           annotation (Placement(
                  transformation(extent={{-160,110},{-140,130}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,90})));
            Modelica.Blocks.Tables.CombiTable1D sep_sourceW(table=[20,55.97; 30,
                  85.48; 40,104.3; 50,79.95; 60,0; 70,0; 80,0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-90,-6},{-110,14}})));
            Modelica.Blocks.Tables.CombiTable1D SP2_sourceH(table=[20,3345e3;
                  30,3338e3; 40,3331e3; 50,3323e3; 60,3315e3; 70,3305e3; 80,
                  3298e3; 90,3289e3; 100,3281e3])
              annotation (Placement(transformation(extent={{40,120},{60,140}})));
            Modelica.Blocks.Sources.Constant fake_input(k=2) annotation (
                Placement(transformation(extent={{140,-110},{120,-90}})));
          equation
            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(
                points={{83.8889,24},{110,24},{110,40},{140,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
                points={{-80,-100},{25.5556,-100},{25.5556,-44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(
                points={{-120,60},{-36,60},{-36,44},{-36.6667,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST.flange, HPHs.SP2) annotation (Line(
                points={{60,100},{41.1111,100},{41.1111,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_ST1.flange, HPHs.SP1) annotation (Line(
                points={{-20,80},{-9.44444,80},{-9.44444,44}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{83.8889,0},{140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{52.7778,-41.6},{52.7778,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
                points={{0,-140},{-12,-140},{-12,-134},{-39.6,-134}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
                points={{0,-140},{0,-140},{-12,-140},{-12,-150},{-39.6,-150}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, controllers.signalBus) annotation (Line(
                points={{0,-140},{38,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(HPH_sourceH.y[1], sourcePressure.in_h) annotation (Line(
                  points={{-119,-40},{-104,-40},{-86,-40},{-86,-91}}, color={0,0,
                    127}));
            connect(LOAD1.y, HPH_sourceH.u[1]) annotation (Line(points={{-159,-40},
                    {-150,-40},{-142,-40}}, color={0,0,127}));
            connect(LOAD2.y, HPH_sourceP.u[1]) annotation (Line(points={{-159,-70},
                    {-150,-70},{-142,-70}}, color={0,0,127}));
            connect(HPH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
                  points={{-119,-70},{-106,-70},{-94,-70},{-94,-90.8}}, color={0,
                    0,127}));
            connect(LOAD3.y, FW_sinkP.u[1]) annotation (Line(points={{-199,30},{
                    -190,30},{-182,30}}, color={0,0,127}));
            connect(FW_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{
                    -159,30},{-152,30},{-146,30},{-146,8.8}}, color={0,0,127}));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{199,-70},
                    {199,-70},{182,-70}}, color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{159,-70},{146,-70},{146,-9}}, color={0,0,127}));
            connect(dea_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,60},{146,60},{146,48.8}}, color={0,0,127}));
            connect(LOAD7.y,SP1_sourceH. u[1]) annotation (Line(points={{-79,140},
                    {-70,140},{-62,140}}, color={0,0,127}));
            connect(LOAD8.y,SP1_sourceP. u[1]) annotation (Line(points={{-79,110},
                    {-70,110},{-62,110}}, color={0,0,127}));
            connect(LOAD10.y,SP2_sourceP. u[1]) annotation (Line(points={{21,160},
                    {30,160},{38,160}}, color={0,0,127}));
            connect(SP1_sourceH.y[1], sourceMassFlow_ST1.in_h) annotation (Line(
                  points={{-39,140},{-34,140},{-26,140},{-26,89}}, color={0,0,127}));
            connect(LOAD11.y, sep_sourceH.u[1]) annotation (Line(points={{-179,
                    120},{-170,120},{-162,120}}, color={0,0,127}));
            connect(LOAD12.y, sep_sourceW.u[1]) annotation (Line(points={{-179,90},
                    {-162,90}},           color={0,0,127}));
            connect(sep_sourceW.y[1], sourceMassFlow.in_w0) annotation (Line(
                  points={{-139,90},{-134,90},{-134,66}}, color={0,0,127}));
            connect(sep_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-139,120},{-126,120},{-126,66}}, color={0,0,127}));
            connect(dea_sinkP.u[1], LOAD6.y)
              annotation (Line(points={{202,60},{219,60}}, color={0,0,127}));
            connect(sensT.inlet, HPHs.FW_out)
              annotation (Line(points={{-94,0},{-63.8889,0}}, color={0,0,255}));
            connect(sinkPressure.flange, sensT.outlet)
              annotation (Line(points={{-140,0},{-106,0}}, color={0,0,255}));
            connect(SP1_sourceP.y[1], sourceMassFlow_ST1.in_p0) annotation (Line(
                  points={{-39,110},{-39,110},{-34,110},{-34,89.2}}, color={0,0,
                    127}));
            connect(SP2_sourceP.y[1], sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{61,160},{74,160},{74,109.2}}, color={0,0,127}));
            connect(LOAD9.y,SP2_sourceH. u[1]) annotation (Line(points={{21,130},
                    {38,130}},          color={0,0,127}));
            connect(SP2_sourceH.y[1], sourceMassFlow_ST.in_h) annotation (Line(
                  points={{61,130},{66,130},{66,109}}, color={0,0,127}));
            connect(fake_input.y, controllers.u_Pmec) annotation (Line(points={{119,
                    -100},{100,-100},{100,-118.667}},      color={0,0,127}));
            connect(dea_sinkP.y[1], sourcePressure1.in_p0) annotation (Line(
                  points={{179,60},{170,60},{170,-20},{154,-20},{154,-9.2}},
                  color={0,0,127}));
            connect(signalBus.valveBP_PV, valveBP_PV.y) annotation (Line(
                points={{0,-140},{-12,-140},{-12,-164},{-39.6,-164}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, pumpFW_PV.y) annotation (Line(
                points={{0,-140},{-12,-140},{-12,-120},{-39.6,-120}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -180},{240,180}}), graphics={Text(
                    extent={{90,172},{230,100}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    textStyle={TextStyle.Bold,TextStyle.Italic},
                    textString="Con le condizioni al contorno corrette la
temperatura di uscita dell'acqua di alimento 
e' coerente con i PFD, cosi' come le pressioni di
spillamento in quanto imposte. Cio' dovuto al
differente modello di scambio termico.")}),
              Icon(coordinateSystem(extent={{-240,-180},{240,180}})),
              experiment(StopTime=805000),
              __Dymola_experimentSetupOutput);
          end test_HPH_train_offDesign_controlledLevel;

          model test_LPH_train_offDesign_controlledLevel
            "Test model of the LPH_train for offDesign checking, Nusselt condense type"
            import PreFlexMS;
            extends Modelica.Icons.Example;
            PreFlexMS.FullScale_245degC.HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
              LPHs(
              LPH3(des_SP(noInitialPressure=true), sub_SP(noInitialPressure=
                      true)),
              LPH2(NusseltCondenser(noInitialPressure=true)),
              LPH1(NusseltCondenser(noInitialPressure=true)))
                                                             annotation (
                Placement(transformation(extent={{-88,-40},{110,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,14},{160,34}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=17910000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-140,-10},{-160,10}})));
            ThermoPower.Water.SourcePressure sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-120,70},{-100,90}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,90},{120,110}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-20,90},{0,110}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-240,160},{-220,180}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_ramp=8e5,
              t_start=5000,
              load_end=20) annotation (Placement(transformation(extent={{-220,-160},
                      {-180,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-210,30})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-70})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{180,-80},{160,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,60})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{200,50},{180,70}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,160})));
            Modelica.Blocks.Tables.CombiTable1D SP5_sourceH(table=[20,2839.6e3;
                  30,2832.2e3; 40,2825.5e3; 50,2818.4e3; 60,2811.7e3; 70,
                  2804.5e3; 80,2798.7e3; 90,2792.4e3; 100,2786.2e3])
                                          annotation (Placement(transformation(
                    extent={{-40,150},{-20,170}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,130})));
            Modelica.Blocks.Tables.CombiTable1D SP5_sourceP(table=[20,0.4008e5;
                  30,0.5888e5; 40,0.7738e5; 50,0.9635e5; 60,1.15e5; 70,1.35e5;
                  80,1.52e5; 90,1.702e5; 100,1.893e5])
                                     annotation (Placement(transformation(extent={{-40,120},
                      {-20,140}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={70,130})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={70,160})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceP(table=[20,0.1263e5;
                  30,0.1778e5; 40,0.2287e5; 50,0.2814e5; 60,0.3346e5; 70,
                  0.3919e5; 80,0.4414e5; 90,0.4947e5; 100,0.5515e5])
              annotation (Placement(transformation(extent={{100,150},{120,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,140})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sourceH(table=[20,2944e3;
                  30,2937.3e3; 40,2930.7e3; 50,2923.6e3; 60,2916.5e3; 70,
                  2908.8e3; 80,2902.7e3; 90,2895.9e3; 100,2899e3])
                                                           annotation (Placement(
                  transformation(extent={{-140,130},{-120,150}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-170,110})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sourceP(table=[20,0.6861e5;
                  30,1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5;
                  80,2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{-140,100},{-120,120}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-104,-6},{-124,14}})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceH(table=[20,2070.9e3;
                  30,2175.2e3; 40,2223.3e3; 50,2252.5e3; 60,2269.5e3; 70,
                  2282.5e3; 80,2284e3; 90,2285.8e3; 100,2287.3e3])
              annotation (Placement(transformation(extent={{100,120},{120,140}})));
            Modelica.Blocks.Tables.CombiTable1D dea_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{-180,20},{-160,40}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={90,-90})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceW(table=[20,14.85; 30,
                  22.25; 40,29.67; 50,37.42; 60,45.15; 70,53.51; 80,60.78; 90,
                  68.59; 100,76.94]) annotation (Placement(transformation(
                    extent={{60,-100},{40,-80}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-10,-110},{30,-70}})));
          equation
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{114.125,0},{140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{199,-70},
                    {199,-70},{182,-70}}, color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{159,-70},{146,-70},{146,-9}}, color={0,0,127}));
            connect(cond_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,60},{146,60},{146,32.8}}, color={0,0,127}));
            connect(LOAD7.y,SP5_sourceH. u[1]) annotation (Line(points={{-59,160},
                    {-50,160},{-42,160}}, color={0,0,127}));
            connect(LOAD8.y,SP5_sourceP. u[1]) annotation (Line(points={{-59,130},
                    {-50,130},{-42,130}}, color={0,0,127}));
            connect(LOAD10.y,SP6_sourceP. u[1]) annotation (Line(points={{81,160},
                    {90,160},{98,160}}, color={0,0,127}));
            connect(SP5_sourceH.y[1], sourceMassFlow_ST1.in_h) annotation (Line(
                  points={{-19,160},{-14,160},{-6,160},{-6,109}},  color={0,0,127}));
            connect(LOAD11.y,SP4_sourceH. u[1]) annotation (Line(points={{-159,
                    140},{-150,140},{-142,140}}, color={0,0,127}));
            connect(LOAD12.y,SP4_sourceP. u[1]) annotation (Line(points={{-159,
                    110},{-142,110}},     color={0,0,127}));
            connect(SP4_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-119,140},{-106,140},{-106,89}}, color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD6.y)
              annotation (Line(points={{202,60},{219,60}}, color={0,0,127}));
            connect(sensT.inlet,LPHs. FW_out)
              annotation (Line(points={{-108,0},{-92.125,0}}, color={0,0,255}));
            connect(sinkPressure.flange, sensT.outlet)
              annotation (Line(points={{-140,0},{-120,0}}, color={0,0,255}));
            connect(SP5_sourceP.y[1], sourceMassFlow_ST1.in_p0) annotation (Line(
                  points={{-19,130},{-19,130},{-14,130},{-14,109.2}},color={0,0,
                    127}));
            connect(SP6_sourceP.y[1], sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{121,160},{134,160},{134,109.2}},
                                                         color={0,0,127}));
            connect(LOAD9.y,SP6_sourceH. u[1]) annotation (Line(points={{81,130},
                    {98,130}},          color={0,0,127}));
            connect(SP6_sourceH.y[1], sourceMassFlow_ST.in_h) annotation (Line(
                  points={{121,130},{126,130},{126,109}},
                                                       color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                  points={{114.125,24},{140,24}}, color={0,0,255}));
            connect(SP4_sourceP.y[1], sourceMassFlow.in_p0) annotation (Line(
                  points={{-119,110},{-114,110},{-114,89.2}}, color={0,0,127}));
            connect(sourceMassFlow.flange,LPHs. SP4) annotation (Line(points={{
                    -100,80},{-76,80},{-46.75,80},{-46.75,44}}, color={0,0,255}));
            connect(sourceMassFlow_ST1.flange,LPHs. SP5) annotation (Line(
                  points={{0,100},{11,100},{11,44}}, color={0,0,255}));
            connect(sourceMassFlow_ST.flange,LPHs. SP6) annotation (Line(points=
                   {{120,100},{94,100},{68.75,100},{68.75,44}}, color={0,0,255}));
            connect(LOAD3.y, dea_sinkP.u[1]) annotation (Line(points={{-199,30},
                    {-190.5,30},{-182,30}}, color={0,0,127}));
            connect(dea_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points=
                   {{-159,30},{-152,30},{-146,30},{-146,8.8}}, color={0,0,127}));
            connect(LOAD1.y, FW_sourceW.u[1]) annotation (Line(points={{79,-90},
                    {62,-90}},            color={0,0,127}));
            connect(signalBus, LPHs.signalBus) annotation (Line(
                points={{10,-90},{10,-40},{11,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, FW_sourceW.y[1]) annotation (Line(
                points={{10,-90},{39,-90},{39,-90}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -180},{240,180}}), graphics={Text(
                    extent={{28,-102},{168,-174}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    textStyle={TextStyle.Bold,TextStyle.Italic},
                    textString="Con le condizioni al contorno corrette la
temperatura di uscita dell'acqua di alimento 
e' coerente con i PFD, cosi' come le pressioni di
spillamento in quanto imposte. Cio' dovuto al
differente modello di scambio termico.")}),
              Icon(coordinateSystem(extent={{-240,-180},{240,180}})),
              experiment(StopTime=805000),
              __Dymola_experimentSetupOutput);
          end test_LPH_train_offDesign_controlledLevel;

        end Test;

        package Old
          "Package containing old models, kept for compatibily issues"
          model HPH_controlledLevel
            "Model of a high pressure feed water pre heater with level control and desuperheating section"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Desuperheating region parameters
            replaceable model HeatTransferCold_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatTransferHot_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatExchangerTopology_des =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            parameter Integer Nhex_des = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vhot_des
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vcold_des
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Shot_des
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Scold_des
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
            final parameter Modelica.SIunits.Length L_des=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_des
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Subcooling region parameters
            replaceable model HeatTransferCold_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatTransferHot_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatExchangerTopology_sub =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            parameter Integer Nhex_sub = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vhot_sub
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vcold_sub
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Shot_sub
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Scold_sub
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
            final parameter Modelica.SIunits.Length L_sub=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_sub
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
            parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real PVmin
              "Minimum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real PVmax
              "Maximum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

            ThermoPower.Water.Flow1DFV des_FW(
              final N=Nhex_des,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_des,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_des),
              final A=Vcold_des/L_des,
              final omega=Scold_des/L_des,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,76})));
            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,10})));
            ThermoPower.Water.Flow1DFV sub_FW(
              final N=Nhex_sub,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_sub),
              final A=Vcold_sub/L_sub,
              final omega=Scold_sub/L_sub,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-40})));
            ThermoPower.Water.Flow1DFV2ph des_SP(
              N=Nhex_des,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_des,
              A=Vhot_des/L_des,
              omega=Shot_des/L_des,
              wnom=nominalHotFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_des),
              redeclare model HeatTransfer = HeatTransferHot_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,76})));
            ThermoPower.Water.Flow1DFV2ph
                                       sub_SP(
              N=Nhex_sub,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              A=Vhot_sub/L_sub,
              omega=Shot_sub/L_sub,
              wnom=nominalHotFlow+nominalDrainFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_sub),
              redeclare model HeatTransfer = HeatTransferHot_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,-40})));
            Components.NusseltCondenser           NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-22},{-18,42}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CheckValve=true,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.2,
              rhonom=900)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            ThermoPower.PowerPlants.Control.PID PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              Td=Td,
              Nd=Nd,
              PVmin=PVmin,
              PVmax=PVmax,
              PVstart=PVstart,
              CSstart=CSstart,
              steadyStateInit=true,
              holdWhenSimplified=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.InitialState)           annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_des(
              final Nw=Nhex_des - 1,
              final M=Mm_des,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
              TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,76})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_des)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,76})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
              final Nw=Nhex_sub - 1,
              final M=Mm_sub,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
              TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_sub)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,-40})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,10})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,10})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            ThermoPower.Water.PressDropLin pressDropLin(redeclare package
                Medium =
                  Medium,
              allowFlowReversal=false,
              R=0.1e5)            annotation (Placement(transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-50,52})));
          equation
            Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
            Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
            connect(des_FW.infl, cond_FW.outfl) annotation (Line(
                points={{50,66},{50,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
                points={{50,0},{50,-30}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
                points={{-50,-50},{-50,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ST_in, des_SP.infl) annotation (Line(
                points={{-50,100},{-50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(FW_out, des_FW.outfl) annotation (Line(
                points={{50,100},{50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,19.1429},{-61.4286,19.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_FW.infl, FW_in) annotation (Line(
                points={{50,-50},{50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,7.71429},{-80,7.71429},{-80,-10}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
                points={{-45,76},{-3.6,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
                points={{3.72,76},{21.59,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
                points={{28.3,76},{45,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
                points={{28.3,-40},{45,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
                points={{-45,-40},{-3.6,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
                points={{3.72,-40},{21.59,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,10},{21.59,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,10},{28.3,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-30},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,10},{-39.7143,10},{-3.6,10}},
                                                  color={255,127,0}));
            connect(des_SP.outfl, pressDropLin.inlet)
              annotation (Line(points={{-50,66},{-50,58}}, color={0,0,255}));
            connect(pressDropLin.outlet, NusseltCondenser.steam_in) annotation (
                Line(points={{-50,46},{-50,37.4286}}, color={0,0,255}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,-6},{-72,-6},{-72,-10}},  color={0,0,127}));
            connect(NusseltCondenser.drained_out, sub_SP.infl) annotation (Line(
                  points={{-50,-10.5714},{-50,-30}},           color={0,0,255}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={{-76,-61},{
                    -76,-61},{-76,-68},{-76,-70},{-58,-70}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end HPH_controlledLevel;

          model LPH_controlledLevel
            "Model of a low pressure feed water pre heater with level control (no desuperheating section)"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
            parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real PVmin
              "Minimum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real PVmax
              "Maximum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,20})));
            Components.NusseltCondenser         NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-12},{-18,52}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.5,
              CheckValve=true)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            ThermoPower.PowerPlants.Control.PID PID_level(
            Kp=Kp,
            Ti=Ti,
            Td=Td,
            CSmin=CSmin,
            CSmax=CSmax,
              Nd=20,
              PVmax=PVmax,
              PVstart=PVstart,
              CSstart=CSstart,
              PVmin=PVmin,
              steadyStateInit=true,
              holdWhenSimplified=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.SteadyState)            annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,20})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,20})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_cond+1] = vector([ones(Nhex_cond+1)*NusseltCondenser.Tv])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_cond+1] = vector([(NusseltCondenser.Tv+cond_FW.T[end])/2;tubeWalls_cond.Tvol[end:-1:1];(NusseltCondenser.Tv+cond_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_cond+1] = vector([cond_FW.T[end];cond_FW.heatTransfer.Tvol[end:-1:1];cond_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

          equation
            Q_Hot = NusseltCondenser.Q_cond;
            Q_Cold = cond_FW.Q;
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,29.1429},{-61.4286,29.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(
                points={{-61.4286,4},{-72,4},{-72,-10}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,17.7143},{-80,17.7143},{-80,-10}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,20},{21.59,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,20},{28.3,20}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-30},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,20},{-39.7143,20},{-3.6,20}},
                                                  color={255,127,0}));
            connect(NusseltCondenser.drained_out, valveDrain.inlet) annotation (Line(
                  points={{-50,-0.571429},{-50,-60}},           color={0,0,255}));
            connect(ST_in, NusseltCondenser.steam_in) annotation (Line(points={{-50,100},
                    {-50,47.4286},{-50,47.4286}},color={0,0,255}));
            connect(FW_out, cond_FW.outfl) annotation (Line(points={{50,100},{50,
                    100},{50,30}},color={0,0,255}));
            connect(cond_FW.infl, FW_in)
              annotation (Line(points={{50,10},{50,10},{50,-100}}, color={0,0,255}));
            connect(valveDynamic.y, valveDrain.theta)
              annotation (Line(points={{-76,-61},{-76,-70},{-58,-70}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end LPH_controlledLevel;

          model HPH_controlledLevel_dp
            "Model of a high pressure feed water pre heater with level control and desuperheating section"
            extends BaseClasses.BaseFeedwaterHeater;

            //Common parameters
            parameter Modelica.SIunits.MassFlowRate nominalColdFlow
              "Nominal flow rate of cold fluid";
            parameter Modelica.SIunits.MassFlowRate nominalHotFlow
              "Nominal flow rate of hot fluid (desuperheating region)";
            parameter Modelica.SIunits.MassFlowRate nominalDrainFlow
              "Nominal flow rate of drained fluid";
            parameter Modelica.SIunits.Pressure nominalColdPressure
              "Nominal inlet pressure of cold fluid";
            parameter Modelica.SIunits.Pressure nominalColdDeltaP
              "Nominal cold fluid pressure loss";
            parameter Modelica.SIunits.Pressure nominalHotPressure
              "Nominal inlet pressure of hot fluid";
            parameter Modelica.SIunits.Pressure nominalHotDeltaP
              "Nominal hot fluid pressure loss";

            //Desuperheating region parameters
            replaceable model HeatTransferCold_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatTransferHot_des =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            replaceable model HeatExchangerTopology_des =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Desuperheating"));
            parameter Integer Nhex_des = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vhot_des
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Volume Vcold_des
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Shot_des
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Area Scold_des
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Desuperheating"));
            final parameter Modelica.SIunits.Length L_des=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_des
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_des
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_des
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Desuperheating"));

            //Condensing region parameters
            parameter Integer Nhex_cond = 5
              "Number of nodes for the condensing region"                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Volume Vhot_cond "Total volume" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area A "Cross Sectional Area" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height H=Vhot_cond/A
              "Height of the condensing volume"                                               annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Area Shot_cond "Heat transfer surface" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
              "Nusselt theory HTC" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_set "Liquid level set point" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Height zl_start "Liquid level start" annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter Modelica.SIunits.Pressure p_start "Medium start pressure"
                                                                                annotation (Dialog(tab="Condensing", group="Hot side"));
            outer ThermoPower.System system "System wide properties";
            parameter Boolean allowFlowReversal=system.allowFlowReversal
              "= true to allow flow reversal, false restricts to design direction"
                                                                                   annotation (Dialog(tab="Condensing", group="Hot side"));
            parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
              "Initialisation option" annotation (Dialog(tab="Condensing", group="Hot side"));

            replaceable model HeatTransferCold_cond =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            replaceable model HeatExchangerTopology_cond =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Volume Vcold_cond
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Area Scold_cond
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Condensing", group="Cold side"));
            final parameter Modelica.SIunits.Length L_cond=1
              "Lenght of the fluid path (unused)"                                                annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_cond
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_cond
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Condensing", group="Cold side"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_cond
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Condensing", group="Cold side"));

            //Subcooling region parameters
            replaceable model HeatTransferCold_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, cold fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatTransferHot_sub =
              ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
              "Heat transfer model, hot fluid side"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            replaceable model HeatExchangerTopology_sub =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
              constrainedby
              ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
              "Heat exchanger topology"
              annotation(choicesAllMatching = true,Dialog(tab="Subcooling"));
            parameter Integer Nhex_sub = 2
              "Number of nodes for the desuperheating region" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vhot_sub
              "Volume of the fluid in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Volume Vcold_sub
              "Volume of the fluid in the cold side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Shot_sub
              "Heat transfer surface in the hot side" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Area Scold_sub
              "Heat transfer surface in the cold side" annotation (Dialog(tab="Subcooling"));
            final parameter Modelica.SIunits.Length L_sub=1
              "Lenght of the fluid path (unused)"                                               annotation (Dialog(tab="Desuperheating"));
            parameter Modelica.SIunits.Mass Mm_sub
              "Mass of the metal between the two fluids" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalColdOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotInletTemperature_sub
              "Nominal value of cold fluid temperature at the inlet" annotation (Dialog(tab="Subcooling"));
            parameter Modelica.SIunits.Temperature nominalHotOutletTemperature_sub
              "Nominal value of cold fluid temperature at the outlet" annotation (Dialog(tab="Subcooling"));

            parameter Modelica.SIunits.SpecificHeatCapacity cm
              "Specific heat capacity of metal";

            //Controller parameters
            parameter Modelica.SIunits.MassFlowRate wnom
              "Nominal valve mass flow"                                            annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure pnom
              "Nominal inlet valve pressure"                                        annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Pressure dpnom
              "Nominal valve pressure drop"                                         annotation (Dialog(tab="Level controller"));
            parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
            parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
            parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));
            parameter Real PVmin
              "Minimum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real PVmax
              "Maximum value of process variable for scaling"                    annotation (Dialog(tab="Level controller"));
            parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
            parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
            parameter Real CSstart=0.6 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));

            ThermoPower.Water.Flow1DFV des_FW(
              final N=Nhex_des,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_des,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_des),
              final A=Vcold_des/L_des,
              final omega=Scold_des/L_des,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,76})));
            ThermoPower.Water.Flow1DFV cond_FW(
              final N=Nhex_cond,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_cond,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_cond),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_cond),
              final A=Vcold_cond/L_cond,
              final omega=Scold_cond/L_cond,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_cond,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                               annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,10})));
            ThermoPower.Water.Flow1DFV sub_FW(
              final N=Nhex_sub,
              H=0,
              wnom=nominalColdFlow,
              pstart=nominalColdPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              dpnom=nominalColdDeltaP,
              rhonom=Medium.density_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalColdPressure,
                  nominalColdInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalColdPressure -
                  nominalColdDeltaP, nominalColdOutletTemperature_sub),
              final A=Vcold_sub/L_sub,
              final omega=Scold_sub/L_sub,
              Dhyd=1,
              redeclare model HeatTransfer = HeatTransferCold_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                              annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-40})));
            ThermoPower.Water.Flow1DFV2ph des_SP(
              N=Nhex_des,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_des,
              A=Vhot_des/L_des,
              omega=Shot_des/L_des,
              wnom=nominalHotFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_des),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_des),
              redeclare model HeatTransfer = HeatTransferHot_des,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,76})));
            ThermoPower.Water.Flow1DFV2ph
                                       sub_SP(
              N=Nhex_sub,
              H=0,
              Dhyd=1,
              pstart=nominalHotPressure,
              redeclare package Medium = Medium,
              L=L_sub,
              A=Vhot_sub/L_sub,
              omega=Shot_sub/L_sub,
              wnom=nominalHotFlow+nominalDrainFlow,
              dpnom=nominalHotDeltaP,
              rhonom=Medium.density_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartin=Medium.specificEnthalpy_pT(nominalHotPressure,
                  nominalHotInletTemperature_sub),
              hstartout=Medium.specificEnthalpy_pT(nominalHotPressure -
                  nominalHotDeltaP, nominalHotOutletTemperature_sub),
              redeclare model HeatTransfer = HeatTransferHot_sub,
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true)                             annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-50,-40})));
            Components.NusseltCondenser           NusseltCondenser(
              V=Vhot_cond,
              A=A,
              S=Shot_cond,
              zl_set=zl_set,
              zl_start=zl_start,
              p_start=p_start,
              gamma=gamma,
              Nw=Nhex_cond - 1,
              allowFlowReversal=false,
              noInitialPressure=true)
              annotation (Placement(transformation(extent={{-82,-22},{-18,42}})));
            ThermoPower.Water.ValveLiq        valveDrain(
              redeclare package Medium = Medium,
              allowFlowReversal=false,
              CheckValve=true,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              pnom=pnom,
              dpnom=dpnom,
              wnom=wnom,
              thetanom=0.2,
              rhonom=900)
                       annotation (
               Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-50,-70})));
            ThermoPower.PowerPlants.Control.PID PID_level(
            Kp=Kp,
            Ti=Ti,
            CSmin=CSmin,
            CSmax=CSmax,
              Td=Td,
              Nd=Nd,
              PVmin=PVmin,
              PVmax=PVmax,
              PVstart=PVstart,
              CSstart=CSstart,
              steadyStateInit=true,
              holdWhenSimplified=true)
                             annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=-90,
                  origin={-76,-20})));

            Modelica.Blocks.Continuous.FirstOrder valveDynamic(T=Ta, k=1,
              y_start=CSstart,
              initType=Modelica.Blocks.Types.Init.InitialState)           annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-76,-50})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_des(
              final Nw=Nhex_des - 1,
              final M=Mm_des,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_des + nominalHotOutletTemperature_des)/2,
              TstartN=(nominalColdOutletTemperature_des + nominalHotInletTemperature_des)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,76})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_des(Nw=Nhex_des -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_des)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,76})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_sub(
              final Nw=Nhex_sub - 1,
              final M=Mm_sub,
              final cm=cm,
              Tstart1=(nominalColdInletTemperature_sub + nominalHotOutletTemperature_sub)/2,
              TstartN=(nominalColdOutletTemperature_sub + nominalHotInletTemperature_sub)/2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,-40})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_sub(Nw=Nhex_sub -
                  1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_sub)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,-40})));
            ThermoPower.Thermal.MetalWallFV tubeWalls_cond(
              final Nw=Nhex_cond - 1,
              final M=Mm_cond,
              final cm=cm,
              TstartN=(nominalColdInletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              Tstart1=(nominalColdOutletTemperature_cond + Medium.saturationTemperature(p_start))/2,
              initOpt=ThermoPower.Choices.Init.Options.noInit)
              annotation (Placement(transformation(
                  extent={{-12,12},{12,-12}},
                  rotation=-90,
                  origin={0,10})));
            ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology_cond(Nw=Nhex_cond
                   - 1, redeclare model HeatExchangerTopology =
                  HeatExchangerTopology_cond)
              annotation (Placement(transformation(
                  extent={{-12,-11},{12,11}},
                  rotation=-90,
                  origin={25,10})));

            Modelica.SIunits.Power Q_Hot "Power from the hot side";
            Modelica.SIunits.Power Q_Cold "Power to the cold side";
            Modelica.SIunits.Temperature T_hot_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_SP.T[1];des_SP.heatTransfer.Tvol;des_SP.T[end];ones(Nhex_cond-1)*NusseltCondenser.T_sat;sub_SP.T[1];sub_SP.heatTransfer.Tvol;sub_SP.T[end]])
              "Hot temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_wall_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([(des_SP.T[1]+des_FW.T[end])/2;tubeWalls_des.Tvol[end:-1:1];(des_SP.T[end]+des_FW.T[1])/2;tubeWalls_cond.Tvol[end:-1:1];(sub_SP.T[1]+sub_FW.T[end])/2;tubeWalls_sub.Tvol[end:-1:1];(sub_SP.T[end]+sub_FW.T[1])/2])
              "Wall temperature vector (hot in the left side)";
            Modelica.SIunits.Temperature T_cold_prof[Nhex_des+Nhex_cond+Nhex_sub+1] = vector([des_FW.T[end];des_FW.heatTransfer.Tvol[end:-1:1];des_FW.T[1];cond_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[end];sub_FW.heatTransfer.Tvol[end:-1:1];sub_FW.T[1]])
              "Cold temperature vector (hot in the left side)";

            ThermoPower.Water.PressDropLin pressDropLin(redeclare package
                Medium =
                  Medium,
              allowFlowReversal=false,
              R=0.1e5)            annotation (Placement(transformation(
                  extent={{-6,-6},{6,6}},
                  rotation=270,
                  origin={-50,52})));
            ThermoPower.Water.PressDropLin pressDropLin1(redeclare package
                Medium =
                  Medium, R=0.3e5)
                                 annotation (Placement(transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=270,
                  origin={-50,-20})));
          equation
            Q_Hot = -des_SP.Q + NusseltCondenser.Q_cond - sub_SP.Q;
            Q_Cold = des_FW.Q + cond_FW.Q + sub_FW.Q;
            connect(des_FW.infl, cond_FW.outfl) annotation (Line(
                points={{50,66},{50,20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_FW.infl, sub_FW.outfl) annotation (Line(
                points={{50,0},{50,-30}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_SP.outfl, valveDrain.inlet) annotation (Line(
                points={{-50,-50},{-50,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ST_in, des_SP.infl) annotation (Line(
                points={{-50,100},{-50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(FW_out, des_FW.outfl) annotation (Line(
                points={{50,100},{50,86}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DR_in, NusseltCondenser.drained_in) annotation (Line(
                points={{-100,0},{-100,19.1429},{-61.4286,19.1429}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sub_FW.infl, FW_in) annotation (Line(
                points={{50,-50},{50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(valveDrain.outlet, DR_out) annotation (Line(
                points={{-50,-80},{-50,-100}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(NusseltCondenser.zl_SP, PID_level.SP) annotation (Line(
                points={{-61.4286,7.71429},{-80,7.71429},{-80,-10}},
                color={0,0,127},
                smooth=Smooth.None));

            connect(des_SP.wall, tubeWalls_des.int) annotation (Line(
                points={{-45,76},{-3.6,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_des.ext, heatExchangerTopology_des.side2) annotation (Line(
                points={{3.72,76},{21.59,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_des.side1, des_FW.wall) annotation (Line(
                points={{28.3,76},{45,76}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(heatExchangerTopology_sub.side1, sub_FW.wall) annotation (Line(
                points={{28.3,-40},{45,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(sub_SP.wall, tubeWalls_sub.int) annotation (Line(
                points={{-45,-40},{-3.6,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_sub.ext, heatExchangerTopology_sub.side2) annotation (Line(
                points={{3.72,-40},{21.59,-40}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(tubeWalls_cond.ext, heatExchangerTopology_cond.side2) annotation (
                Line(
                points={{3.72,10},{21.59,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(cond_FW.wall, heatExchangerTopology_cond.side1) annotation (Line(
                points={{45,10},{28.3,10}},
                color={255,127,0},
                smooth=Smooth.None));
            connect(PID_level.CS, valveDynamic.u) annotation (Line(
                points={{-76,-30},{-76,-38}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(NusseltCondenser.DHT, tubeWalls_cond.int) annotation (Line(points={{
                    -39.7143,10},{-39.7143,10},{-3.6,10}},
                                                  color={255,127,0}));
            connect(des_SP.outfl, pressDropLin.inlet)
              annotation (Line(points={{-50,66},{-50,58}}, color={0,0,255}));
            connect(pressDropLin.outlet, NusseltCondenser.steam_in) annotation (
                Line(points={{-50,46},{-50,37.4286}}, color={0,0,255}));
            connect(NusseltCondenser.level, PID_level.PV) annotation (Line(points={{
                    -61.4286,-6},{-72,-6},{-72,-10}},  color={0,0,127}));
            connect(valveDynamic.y, valveDrain.theta) annotation (Line(points={{-76,-61},{
                    -76,-61},{-76,-68},{-76,-70},{-58,-70}}, color={0,0,127}));
            connect(NusseltCondenser.drained_out, pressDropLin1.inlet)
              annotation (Line(points={{-50,-10.5714},{-50,-16}}, color={0,0,255}));
            connect(pressDropLin1.outlet, sub_SP.infl) annotation (Line(points={{
                    -50,-24},{-50,-27},{-50,-30}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-100,-100},{100,100}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{
                      -100,-100},{100,100}})));
          end HPH_controlledLevel_dp;

          model HPH_train_controlledLevel_100
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            Auxiliaries.Components.pump_constEfficiency
                                              pumpFW(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=91.28,
              eta_iso=0.789)
              annotation (Placement(transformation(extent={{170,12},{150,-8}})));
            ThermoPower.Water.ThroughMassFlow pumpHPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91) annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={20,-56})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{24,-14},{4,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.ValveLiq valveBP(
              redeclare package Medium = Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000) annotation (Placement(transformation(extent={{-40,-38},
                      {-60,-58}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-114},{130,-74}}),
                  iconTransformation(extent={{90,-124},{130,-84}})));

            Old.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_des=3,
              Nhex_cond=3,
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              CSstart=0.2,
              nominalDrainFlow=0,
              des_FW(hstart={1.268e6,1.28171e6,1.34722e6}),
              cond_FW(hstart={1.02902e6,1.20014e6,1.268e6}),
              sub_FW(hstart={979187,985072,994215,1.00820e6,1.02902e6}),
              des_SP(hstart={3.231e6,2.83893e6,2.75687e6}),
              sub_SP(hstart={1.32571e6,1.20114e6,1.11741e6,1.06269e6,1.02747e6}),
              CSmin=0.05,
              Ti=10,
              nominalColdPressure=17630000,
              nominalHotPressure=8181000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=8181000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              wnom=4.449,
              pnom=8150000,
              dpnom=6300000,
              Kp=-10) annotation (Placement(transformation(extent={{-70,-20},{-30,
                      20}})));

            Old.HPH_controlledLevel_dp HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmax=1,
              Nhex_des=3,
              Nhex_cond=3,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Nhex_sub=5,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              CSstart=0.2,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              des_FW(hstart={876813,877436,895998}),
              cond_FW(hstart={807696,856039,876813}),
              sub_FW(hstart={803100,803886,804877,806125,807696}),
              des_SP(hstart={3.281e6,2.73749e6,2.71925e6}),
              CSmin=0.05,
              sub_SP(hstart={878793,855666,836808,821450,808952}),
              Ti=10,
              nominalColdPressure=17630000,
              nominalHotPressure=1815000,
              nominalColdInletTemperature_des=477.15,
              nominalColdOutletTemperature_des=480.85,
              nominalHotInletTemperature_des=686.65,
              nominalHotOutletTemperature_des=480.75,
              p_start=1815000,
              nominalColdInletTemperature_cond=461.55,
              nominalColdOutletTemperature_cond=477.15,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              wnom=7.484,
              pnom=1815000,
              dpnom=729000,
              Kp=-1) annotation (Placement(transformation(extent={{70,-20},{110,
                      20}})));
            Graphics.Label_input valveBP_CS annotation (Placement(transformation(
                    extent={{-98,-66},{-66,-54}})));
            Graphics.Label_input pumpFW_CS
              annotation (Placement(transformation(extent={{112,-20},{144,-8}})));
            Graphics.Label_input pumpHPH_CS
              annotation (Placement(transformation(extent={{80,-66},{42,-54}})));
          equation
            connect(pumpHPH.outlet, flowJoin.in2) annotation (Line(
                points={{20,-46},{20,-16},{20,-8}},
                color={0,0,255},
                thickness=0.5));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.inlet, flowJoin.out) annotation (Line(
                points={{-40,-48},{0,-48},{0,-4},{8,-4}},
                color={0,0,255},
                thickness=0.5));
            connect(valveBP.outlet, sensT.inlet) annotation (Line(
                points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{20,0},{32,0}},
                color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                thickness=0.5));
            connect(signalBus.pumpHPH_CS, pumpHPH.in_w0) annotation (Line(
                points={{110,-94},{110,-76},{28,-76},{28,-60},{26,-60}},
                color={256,256,256},
                thickness=0.5));

            connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
                points={{110,-94},{162,-94},{162,-20},{172,-20},{176,-20},{176,-8},
                    {160,-8},{160,-7}},
                color={255,255,255},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0},
                thickness=0.5));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));

            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,20}},
                             color={0,127,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0},
                thickness=0.5));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{70,0}},        color={0,0,255},
                thickness=0.5));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{8,-4}}, color={0,0,255},
                thickness=0.5));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255},
                thickness=0.5));
            connect(signalBus.valveBP_CS, valveBP.theta) annotation (Line(
                points={{110,-94},{110,-96},{108,-96},{18,-96},{18,-78},{-44,-78},
                    {-44,-56},{-50,-56}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpHPH.inlet, MS_HPH_in) annotation (Line(
                points={{20,-66},{20,-86},{20,-110}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpFW.outfl, HPH1.FW_in) annotation (Line(points={{154,-5},{
                    148,-5},{148,0},{112,0}}, color={0,0,255}));
            connect(pumpFW.infl, FW_in)
              annotation (Line(points={{168,0},{190,0}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}}), graphics={Line(
                    points={{-50,-58},{-50,-60}},
                    color={0,0,0},
                    thickness=0.5), Line(
                    points={{160,-8},{160,-14}},
                    color={0,0,0},
                    thickness=0.5)}));
          end HPH_train_controlledLevel_100;

          model HPH_train_controlledLevel_50
            "Model of the high pressure feedwater train with level controllers"
            extends BaseClasses.BaseHPHTrain;
            ThermoPower.Water.ThroughMassFlow pump_FW(redeclare package Medium
                = Medium,
              use_in_w0=true,
              w0=91.28)
              annotation (Placement(transformation(extent={{160,10},{140,-10}})));
            ThermoPower.Water.ThroughMassFlow pump_MS_HPH(
              redeclare package Medium = Medium,
              use_in_w0=true,
              w0=24.91)        annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=90,
                  origin={40,-60})));
            ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{22,-14},{2,6}})));
            ThermoPower.Water.SensT sensT(redeclare package Medium =
                         Medium)
              annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=3218000,
              w0=0)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            ThermoPower.Water.PressDrop DPSteamHPH1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              rhonom=867.7,
              wnom=91.28,
              dpnom=240000)
              annotation (Placement(transformation(extent={{52,-10},{32,10}})));
            ThermoPower.Water.PressDrop DPSteamHPH2(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=27.94,
              rhonom=731.3,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{90,-124},{130,-84}})));

            Preheaters.HPH_controlledLevel HPH2(
              A=1,
              zl_set=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              cm=500,
              Ti=10,
              Ta=0.3,
              CSmax=1,
              NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
              valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
              Nhex_sub=5,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_des=2.99*0.15,
              Vcold_des=0.53*0.15,
              Shot_des=210*0.15,
              Scold_des=210*0.15,
              Mm_des=10000*0.15,
              Vhot_cond=2.99*0.7,
              Shot_cond=210*0.7,
              gamma=4100,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              Vcold_cond=0.53*0.7,
              Scold_cond=210*0.7,
              Mm_cond=10000*0.7,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2400),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3600),
              Vhot_sub=2.99*0.15,
              Vcold_sub=0.53*0.15,
              Shot_sub=210*0.15,
              Scold_sub=210*0.15,
              Mm_sub=10000*0.15,
              CSstart=0.2,
              nominalDrainFlow=0,
              CSmin=0.05,
              sub_FW(hstart={763758,767404,773564,783883,800868}),
              sub_SP(hstart={1.08271e6,951308,871475,823820,795624}),
              nominalColdFlow=27.94,
              nominalHotFlow=4.449,
              tubeWalls_sub(Tvolstart={486.15,473.15,463.15,458.15}),
              Nhex_cond=5,
              Nhex_des=5,
              des_SP(hstart={3.289e6,2.96343e6,2.84697e6,2.79089e6,2.74785e6}),
              des_FW(hstart={1.00416e6,1.00966e6,1.0168e6,1.03169e6,1.07335e6}),
              tubeWalls_des(Tvolstart={584.493,534.57,519.498,515.452}),
              tubeWalls_cond(Tvolstart={513.148,509.461,504.33,496.809}),
              cond_FW(hstart={791228,873624,932205,974084,1.00416e6}),
              zl_start=0.1,
              wnom=4.449,
              Kp=-10,
              nominalColdPressure=17630000,
              nominalHotPressure=8181000,
              nominalColdInletTemperature_des=557.15,
              nominalColdOutletTemperature_des=572.15,
              nominalHotInletTemperature_des=707.15,
              nominalHotOutletTemperature_des=570.15,
              p_start=3941000,
              nominalColdInletTemperature_cond=547.15,
              nominalColdOutletTemperature_cond=561.15,
              nominalColdInletTemperature_sub=499.45,
              nominalColdOutletTemperature_sub=510.15,
              nominalHotInletTemperature_sub=569.65,
              nominalHotOutletTemperature_sub=504.15,
              pnom=8100000,
              dpnom=6300000) annotation (Placement(transformation(extent={{-70,
                      -20},{-30,20}})));

            Preheaters.HPH_controlledLevel_dp HPH1(
              Vcold_des=0.53*0.1,
              A=1,
              zl_set=0.1,
              cm=500,
              Ti=10,
              CSmax=1,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vhot_des=2.01*0.1,
              Vhot_cond=2.01*0.8,
              gamma=8000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              Vcold_cond=0.53*0.8,
              Mm_cond=7500*0.8,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              CSstart=0.2,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=2000),
              Shot_des=300*0.08,
              Scold_des=300*0.08,
              Mm_des=7500*0.1,
              Shot_cond=300*0.8,
              Scold_cond=300*0.8,
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=5000),
              Vhot_sub=2.01*0.05,
              Vcold_sub=0.53*0.05,
              Shot_sub=300*0.05,
              Scold_sub=300*0.05,
              Mm_sub=7500*0.05,
              CSmin=0.05,
              nominalColdFlow=91.28,
              nominalHotFlow=3.034,
              nominalDrainFlow=4.449,
              zl_start=0.1,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              NusseltCondenser(noInitialPressure=true),
              Nhex_cond=10,
              tubeWalls_cond(Tvolstart={448.005,447.91,447.788,447.634,447.438,
                    447.189,446.873,446.47,445.958}),
              cond_FW(hstart={695485,706400,714988,721746,727066,731255,734553,
                    737159,739198,740811}),
              Ta=0.3,
              sub_FW(hstart={691100,691958,692965,694147,695533}),
              tubeWalls_sub(Tvolstart={443.75,442.35,441.15,440.15}),
              sub_SP(hstart={742039,732973,725244,718657,713045}),
              Nhex_sub=5,
              Nhex_des=4,
              wnom=7.484,
              Kp=-1,
              nominalColdPressure=17870000,
              nominalHotPressure=1815000,
              nominalColdInletTemperature_des=445.05,
              nominalColdOutletTemperature_des=447.55,
              nominalHotInletTemperature_des=691.15,
              nominalHotOutletTemperature_des=453.15,
              p_start=850000,
              nominalColdInletTemperature_cond=437.15,
              nominalColdOutletTemperature_cond=446.95,
              nominalColdInletTemperature_sub=460.35,
              nominalColdOutletTemperature_sub=461.55,
              nominalHotInletTemperature_sub=480.65,
              nominalHotOutletTemperature_sub=466.35,
              pnom=1800000,
              dpnom=1086000) annotation (Placement(transformation(extent={{70,-20},
                      {110,20}})));
            ThermoPower.Water.ValveLiq valve_bypass(redeclare package Medium =
                  Medium,
              Kv=3.820434783e-4/1,
              Av=7.8775e-3,
              wnom=87.87,
              pnom=17630000,
              dpnom=230000)
              annotation (Placement(transformation(extent={{-40,-38},{-60,-58}})));
          equation
            connect(MS_HPH_in, pump_MS_HPH.inlet) annotation (Line(
                points={{20,-110},{20,-90},{40,-90},{40,-70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(pump_MS_HPH.outlet, flowJoin.in2) annotation (Line(
                points={{40,-50},{40,-20},{20,-20},{20,-8},{18,-8}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(SEP_in, sensT.inlet) annotation (Line(
                points={{-120,110},{-120,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sensT.outlet, FW_out) annotation (Line(
                points={{-152,0},{-190,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
                points={{18,0},{32,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
                points={{-100,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_MS_HPH.in_w0) annotation (Line(
                points={{110,-104},{110,-80},{60,-80},{60,-64},{46,-64}},
                color={255,204,51},
                thickness=0.5));
            connect(FW_in, pump_FW.inlet)  annotation (Line(points={{190,0},{160,0}}, color={0,0,255}));
            connect(signalBus.pumpFW_CS, pump_FW.in_w0) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{154,-80},{154,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                    {-50,20}}, color={0,127,0}));
            connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
                   {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0}));
            connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                    -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0}));
            connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,65},{
                    90,20}}, color={0,127,0}));
            connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                    -40},{190,-40}}, color={0,127,0}));
            connect(HPH1.FW_in, pump_FW.outlet)
              annotation (Line(points={{112,0},{140,0}}, color={0,0,255}));
            connect(DPSteamHPH1.inlet, HPH1.FW_out)
              annotation (Line(points={{52,0},{61,0},{70,0}}, color={0,0,255}));
            connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                    0},{0,-4},{6,-4}}, color={0,0,255}));
            connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                    0},{-75,0},{-70,0}}, color={0,0,255}));
            connect(valve_bypass.outlet, sensT.inlet) annotation (Line(points={{
                    -60,-48},{-90,-48},{-120,-48},{-120,0},{-140,0}}, color={0,0,
                    255}));
            connect(valve_bypass.inlet, flowJoin.out) annotation (Line(points={{
                    -40,-48},{0,-48},{0,-4},{6,-4}}, color={0,0,255}));
            connect(signalBus.valveBP_CS, valve_bypass.theta) annotation (Line(
                points={{110,-104},{110,-104},{110,-80},{-50,-80},{-50,-56}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                      -100},{180,100}})));
          end HPH_train_controlledLevel_50;

          model LPH_train_controlledLevel
            "Model of the low pressure feedwater train with level controllers"
            extends BaseClasses.BaseLPHTrain;
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Medium,
              h=540000,
              w0=0)
              annotation (Placement(transformation(extent={{-200,30},{-180,50}})));
            ThermoPower.Water.PressDrop pressDrop(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=72000,
              rhonom=972)
              annotation (Placement(transformation(extent={{100,-10},{80,10}})));
            ThermoPower.Water.PressDrop pressDrop1(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              dpnom=130000,
              rhonom=947)
              annotation (Placement(transformation(extent={{-40,-10},{-60,10}})));
            ThermoPower.Water.PressDrop pressDrop2(
              redeclare package Medium = Medium,
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              wnom=76.94,
              rhonom=932,
              allowFlowReversal=false,
              dpnom=220000)
              annotation (Placement(transformation(extent={{-180,-10},{-200,10}})));

            Old.LPH_controlledLevel LPH2(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              nominalHotFlow=4.9,
              nominalDrainFlow=2.475,
              Vhot_cond=7.03,
              Shot_cond=268.36,
              Vcold_cond=0.58,
              Scold_cond=268.36,
              Mm_cond=5000,
              gamma=7000,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              redeclare package Medium = Medium,
              wnom=7.375,
              Kp=-5,
              nominalColdPressure=1433000,
              nominalHotPressure=189300,
              Nhex_cond=4,
              p_start=189300,
              nominalColdInletTemperature_cond=353.95,
              nominalColdOutletTemperature_cond=388.65,
              pnom=189300,
              dpnom=134150) annotation (Placement(transformation(extent={{-20,-20},
                      {20,20}})));
            Old.LPH_controlledLevel LPH1(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              CSmin=0,
              CSmax=1,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              nominalHotFlow=3.813,
              nominalDrainFlow=7.375,
              Vhot_cond=9.01,
              Shot_cond=323.24,
              Vcold_cond=0.7,
              Scold_cond=323.24,
              Mm_cond=6400,
              gamma=4000,
              CSstart=0.5,
              redeclare package Medium = Medium,
              wnom=11.19,
              Kp=-1,
              nominalColdPressure=1505000,
              nominalHotPressure=55150,
              Nhex_cond=4,
              p_start=55150,
              nominalColdInletTemperature_cond=327.69,
              nominalColdOutletTemperature_cond=353.95,
              pnom=55150,
              dpnom=43760) annotation (Placement(transformation(extent={{120,-20},
                      {160,20}})));
            Old.HPH_controlledLevel LPH3(
              A=1,
              zl_set=0.1,
              zl_start=0.1,
              cm=500,
              Ti=10,
              Td=0,
              Ta=0.3,
              Nd=20,
              PVmin=0,
              PVmax=1,
              PVstart=0.1,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              nominalColdFlow=76.94,
              CSstart=0.5,
              redeclare model HeatTransferCold_cond =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=4000),
              nominalHotFlow=2.48,
              nominalDrainFlow=0,
              Vhot_des=5.87*0.05,
              Vcold_des=0.5*0.05,
              Shot_des=225.64*0.05,
              Scold_des=0225.64*0.05,
              Mm_des=5000*0.05,
              Vhot_cond=5.87*0.9,
              Shot_cond=225.64*0.9,
              Vcold_cond=0.5*0.9,
              Scold_cond=225.64*0.9,
              Mm_cond=5000*0.9,
              redeclare model HeatTransferHot_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (gamma_nom=3000, alpha=0.8),
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              CSmin=0.05,
              CSmax=1,
              Vhot_sub=5.87*0.05,
              Vcold_sub=0.5*0.05,
              Shot_sub=225.64*0.05,
              Scold_sub=225.64*0.05,
              Mm_sub=5000*0.05,
              redeclare model HeatTransferCold_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              wnom=2.475,
              Nhex_cond=3,
              Nhex_sub=5,
              Nhex_des=6,
              redeclare model HeatTransferCold_des =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              redeclare model HeatTransferHot_sub =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.8, gamma_nom=3000),
              gamma=8000,
              pressDropLin(R=0.05e5),
              nominalColdPressure=1303000,
              nominalHotPressure=300000,
              nominalColdInletTemperature_des=403.15,
              nominalColdOutletTemperature_des=406.75,
              nominalHotInletTemperature_des=485.25,
              nominalHotOutletTemperature_des=410.15,
              p_start=300000,
              nominalColdInletTemperature_cond=391.15,
              nominalColdOutletTemperature_cond=403.15,
              nominalColdInletTemperature_sub=388.65,
              nominalColdOutletTemperature_sub=391.15,
              nominalHotInletTemperature_sub=405.15,
              nominalHotOutletTemperature_sub=393.65,
              pnom=327600,
              dpnom=138300,
              Kp=-10,
              valveDrain(thetanom=0.5)) annotation (Placement(transformation(
                    extent={{-160,-20},{-120,20}})));
            ThermoPower.Water.ThroughMassFlow pumpCOND(redeclare package Medium
                = Medium, use_in_w0=true)
              annotation (Placement(transformation(extent={{230,10},{210,-10}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-20,-120},{20,-80}})));
          equation

            connect(SP5, LPH2.ST_in)
              annotation (Line(points={{0,110},{0,20}}, color={0,127,0},
                thickness=0.5));
            connect(SP6, LPH1.ST_in) annotation (Line(points={{140,110},{140,110},
                    {140,20}}, color={0,127,0},
                thickness=0.5));
            connect(LPH2.DR_out, LPH1.DR_in) annotation (Line(points={{0,-20},{0,
                    -20},{0,-36},{0,-40},{60,-40},{60,40},{126,40},{126,20}},
                  color={0,127,0},
                thickness=0.5));
            connect(LPH1.DR_out, drained_out) annotation (Line(points={{140,-20},
                    {140,-20},{140,-40},{200,-40},{200,60},{250,60}}, color={0,127,0},
                thickness=0.5));

            connect(FW_out, pressDrop2.outlet)
              annotation (Line(points={{-250,0},{-200,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop1.inlet, LPH2.FW_out)
              annotation (Line(points={{-40,0},{-20,0}}, color={0,0,255},
                thickness=0.5));
            connect(pressDrop.inlet, LPH1.FW_out) annotation (Line(points={{100,0},
                    {114,0},{120,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH2.FW_in, pressDrop.outlet)
              annotation (Line(points={{22,0},{80,0}}, color={0,0,255},
                thickness=0.5));
            connect(LPH3.FW_in, pressDrop1.outlet) annotation (Line(
                points={{-118,0},{-87,0},{-60,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pressDrop2.inlet, LPH3.FW_out) annotation (Line(
                points={{-180,0},{-168,0},{-160,0}},
                color={0,0,255},
                thickness=0.5));
            connect(sourceMassFlow_DR.flange, LPH3.DR_in) annotation (Line(
                points={{-180,40},{-154,40},{-154,20}},
                color={0,0,255},
                thickness=0.5));
            connect(LPH3.DR_out, LPH2.DR_in) annotation (Line(
                points={{-140,-20},{-140,-40},{-80,-40},{-80,40},{-14,40},{-14,20}},
                color={0,127,0},
                thickness=0.5));

            connect(SP4, LPH3.ST_in) annotation (Line(
                points={{-140,110},{-140,20}},
                color={0,127,0},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
                points={{0,-100},{0,-80},{224,-80},{224,-6}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpCOND.outlet, LPH1.FW_in) annotation (Line(
                points={{210,0},{162,0}},
                color={0,0,255},
                thickness=0.5));
            connect(pumpCOND.inlet, FW_in) annotation (Line(
                points={{230,0},{250,0}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-240,
                      -100},{240,100}})));
          end LPH_train_controlledLevel;
        end Old;
      end FeedwaterTrain;
    end HeatExchangers;

    package SteamTurbine "Package containing all the steam turbines models"

      package Corps "Package containing turbie corps models"

        model HPT "Model of the high pressure turbine"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
            constrainedby Modelica.Media.Interfaces.PartialMedium
            "Medium model"
            annotation(choicesAllMatching = true);

          parameter Real w_seal
            "Gland steam for sealing, as fraction of outgoing steam";
          outer ThermoPower.System system "System wide properties";

          Modelica.SIunits.Power Pm "Mechanical power";

          ThermoPower.Water.SteamTurbineStodola HPT1(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=91.28,
            pnom=17000000,
            eta_iso_nom=0.87,
            Kt=0.0035649)
            annotation (Placement(transformation(extent={{-26,-10},{-6,10}})));
          ThermoPower.Water.SteamTurbineStodola HPT2(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=86.85,
            eta_iso_nom=0.86,
            Kt=0.0071127,
            pnom=8181000)
            annotation (Placement(transformation(extent={{28,-10},{48,10}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_HP_in annotation (
              Placement(transformation(extent={{-114,-10},{-94,10}}),
                iconTransformation(extent={{-120,-10},{-100,10}})));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_HP_out
            annotation (Placement(transformation(extent={{94,-10},{114,10}}),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={
                    {-86,14},{-74,26}}), iconTransformation(extent={{-120,50},{-100,70}})));
          ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{74,14},{86,26}}),
                iconTransformation(extent={{-120,-90},{-100,-70}})));

          ThermoPower.Water.FlangeB SP6(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{2,-86},{14,-74}}), iconTransformation(
                  extent={{-10,-120},{10,-100}})));

          ThermoPower.Water.SinkMassFlow sinkMassFlow(
            redeclare package Medium = Medium, use_in_w0=true)
            annotation (Placement(transformation(extent={{60,50},{80,70}})));
          Modelica.Blocks.Sources.RealExpression realExpression(y=w_seal*HPT2.w)
            annotation (Placement(transformation(extent={{20,70},{40,90}})));
          ThermoPower.Water.PressDrop pressDrop_HPT1_HPH2(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=4.449,
            rhonom=27.7,
            dpnom=60000)    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={8,-40})));
        equation
          Pm = HPT1.omega*HPT1.tau + HPT2.omega*HPT2.tau;
          connect(HPT1.shaft_b, HPT2.shaft_a) annotation (Line(
              points={{-9.6,0},{31.4,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(HPT2.shaft_b, flange_HP_out) annotation (Line(
              points={{44.4,0},{104,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(HPT1.outlet, HPT2.inlet) annotation (Line(
              points={{-8,8},{30,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(HPT2.outlet, vap_out) annotation (Line(
              points={{46,8},{46,20},{80,20}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(flange_HP_in, HPT1.shaft_a) annotation (Line(
              points={{-104,0},{-22.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(vap_in, HPT1.inlet)
            annotation (Line(points={{-80,20},{-24,20},{-24,8}}, color={0,0,255}));
          connect(HPT2.outlet, sinkMassFlow.flange)
            annotation (Line(points={{46,8},{46,60},{60,60}}, color={0,0,255}));
          connect(realExpression.y, sinkMassFlow.in_w0)
            annotation (Line(points={{41,80},{66,80},{66,66}}, color={0,0,127}));
          connect(HPT1.outlet, pressDrop_HPT1_HPH2.inlet)
            annotation (Line(points={{-8,8},{8,8},{8,-30}}, color={0,0,255}));
          connect(pressDrop_HPT1_HPH2.outlet, SP6)
            annotation (Line(points={{8,-50},{8,-50},{8,-80}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Polygon(
                  points={{40,20},{40,-20},{68,-46},{68,48},{40,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-94,60},{-100,60},{-60,60},{-60,20}},
                  color={0,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{-100,8},{-60,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{-34,8},{40,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{68,8},{100,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Line(
                  points={{68,-46},{68,-60},{68,-80},{10,-80}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{-34,-44},{-34,-60},{0,-60},{0,-100}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{18,-60},{0,-60},{40,-60},{40,-20}},
                  color={0,0,0},
                  thickness=0.5),
                           Text(extent={{-106,96},{110,66}},
                  textString="%name",
                  lineColor={0,0,0}),
                Line(
                  points={{-100,-80},{-10,-80}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-10,-80},{-10,-78},{-8,-74},{-6,-72},{-2,-70},{2,-70},{6,-72},
                      {8,-74},{10,-78},{10,-80}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end HPT;

        model HPT_valves "Model of the high pressure turbine"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
            constrainedby Modelica.Media.Interfaces.PartialMedium
            "Medium model"
            annotation(choicesAllMatching = true);

          parameter Real w_seal
            "Gland steam for sealing, as fraction of outgoing steam";
          outer ThermoPower.System system "System wide properties";
          parameter Modelica.SIunits.Time t_step1 "First step time";
          parameter Modelica.SIunits.Time t_step2 "First step time";
          parameter Real u_step1_init = 1;
          parameter Real u_step2_init = 0;
          parameter Real A_step1 = -1;
          parameter Real A_step2 = 1;
          Modelica.SIunits.Power  Pm "Mechanical power";

          ThermoPower.Water.SteamTurbineStodola HPT1(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=91.28,
            pnom=17000000,
            eta_iso_nom=0.87,
            Kt=0.0035649)
            annotation (Placement(transformation(extent={{-26,-10},{-6,10}})));
          ThermoPower.Water.SteamTurbineStodola HPT2(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=86.85,
            eta_iso_nom=0.86,
            Kt=0.0071127,
            pnom=8181000)
            annotation (Placement(transformation(extent={{28,-10},{48,10}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_HP_in annotation (
              Placement(transformation(extent={{-114,-10},{-94,10}}),
                iconTransformation(extent={{-120,-10},{-100,10}})));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_HP_out
            annotation (Placement(transformation(extent={{94,-10},{114,10}}),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={
                    {-86,14},{-74,26}}), iconTransformation(extent={{-120,50},{-100,70}})));
          ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{74,14},{86,26}}),
                iconTransformation(extent={{-120,-90},{-100,-70}})));

          ThermoPower.Water.FlangeB SP6(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{2,-86},{14,-74}}), iconTransformation(
                  extent={{-10,-120},{10,-100}})));

          ThermoPower.Water.SinkMassFlow sinkMassFlow(
            redeclare package Medium = Medium, use_in_w0=true)
            annotation (Placement(transformation(extent={{60,50},{80,70}})));
          Modelica.Blocks.Sources.RealExpression realExpression(y=w_seal*HPT2.w)
            annotation (Placement(transformation(extent={{20,70},{40,90}})));
          ThermoPower.Water.ValveVap valve_HPT1_HPH2(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            wnom=4.449,
            rhonom=27.7,
            CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
            CheckValve=true,
            pnom=8181000,
            dpnom=60000) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={8,-40})));
        protected
          Modelica.Blocks.Continuous.FirstOrder firstOrder(
            k=1,
            T=0.3,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{32,-42},{28,-38}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{42,-42},{38,-38}})));
          Modelica.Blocks.Sources.Step step1(
            height=A_step1,
            startTime=t_step1,
            offset=u_step1_init)
            annotation (Placement(transformation(extent={{52,-36},{48,-32}})));
          Modelica.Blocks.Sources.Step step2(
            height=A_step2,
            offset=u_step2_init,
            startTime=t_step2)
            annotation (Placement(transformation(extent={{52,-48},{48,-44}})));
        equation
          Pm = HPT1.omega*HPT1.tau + HPT2.omega*HPT2.tau;
          connect(HPT1.shaft_b, HPT2.shaft_a) annotation (Line(
              points={{-9.6,0},{31.4,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(HPT2.shaft_b, flange_HP_out) annotation (Line(
              points={{44.4,0},{104,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(HPT1.outlet, HPT2.inlet) annotation (Line(
              points={{-8,8},{30,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(HPT2.outlet, vap_out) annotation (Line(
              points={{46,8},{46,20},{80,20}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(flange_HP_in, HPT1.shaft_a) annotation (Line(
              points={{-104,0},{-22.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(vap_in, HPT1.inlet)
            annotation (Line(points={{-80,20},{-24,20},{-24,8}}, color={0,0,255}));
          connect(HPT2.outlet, sinkMassFlow.flange)
            annotation (Line(points={{46,8},{46,60},{60,60}}, color={0,0,255}));
          connect(realExpression.y, sinkMassFlow.in_w0)
            annotation (Line(points={{41,80},{66,80},{66,66}}, color={0,0,127}));
          connect(HPT1.outlet, valve_HPT1_HPH2.inlet)
            annotation (Line(points={{-8,8},{8,8},{8,-30}}, color={0,0,255}));
          connect(valve_HPT1_HPH2.outlet, SP6)
            annotation (Line(points={{8,-50},{8,-50},{8,-80}}, color={0,0,255}));
          connect(firstOrder.u,add. y)
            annotation (Line(points={{32.4,-40},{37.8,-40}}, color={0,0,127}));
          connect(step1.y,add. u1) annotation (Line(points={{47.8,-34},{46,-34},{46,-38.8},
                  {42.4,-38.8}}, color={0,0,127}));
          connect(step2.y,add. u2) annotation (Line(points={{47.8,-46},{46,-46},{46,-41.2},
                  {42.4,-41.2}}, color={0,0,127}));
          connect(valve_HPT1_HPH2.theta, firstOrder.y) annotation (Line(points={{16,-40},
                  {27.8,-40},{27.8,-40}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Polygon(
                  points={{40,20},{40,-20},{68,-46},{68,48},{40,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-94,60},{-100,60},{-60,60},{-60,20}},
                  color={0,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{-100,8},{-60,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{-34,8},{40,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{68,8},{100,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Line(
                  points={{68,-46},{68,-60},{68,-80},{10,-80}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{-34,-44},{-34,-60},{0,-60},{0,-100}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{18,-60},{0,-60},{40,-60},{40,-20}},
                  color={0,0,0},
                  thickness=0.5),
                           Text(extent={{-106,96},{110,66}},
                  textString="%name",
                  lineColor={0,0,0}),
                Line(
                  points={{-100,-80},{-10,-80}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-10,-80},{-10,-78},{-8,-74},{-6,-72},{-2,-70},{2,-70},{6,-72},
                      {8,-74},{10,-78},{10,-80}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end HPT_valves;

        model IPT "Model of the intermediate  pressure turbine"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
            constrainedby Modelica.Media.Interfaces.PartialMedium
            "Medium model"
            annotation(choicesAllMatching = true);

          outer ThermoPower.System system "System wide properties";

          Modelica.SIunits.Power Pm "Mechanical power";

          ThermoPower.Water.SteamTurbineStodola IPT1(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=84.96,
            pnom=4624000,
            eta_iso_nom=0.897,
            Kt=0.01219794)
            annotation (Placement(transformation(extent={{-48,-10},{-28,10}})));
          ThermoPower.Water.SteamTurbineStodola IPT2(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=81.93,
            pnom=1861000,
            eta_iso_nom=0.8931,
            Kt=0.03106815)
            annotation (Placement(transformation(extent={{-8,-10},{12,10}})));

          ThermoPower.Water.SteamTurbineStodola IPT3(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=75.05,
            pnom=1144000,
            eta_iso_nom=0.8939,
            Kt=0.03648821)
            annotation (Placement(transformation(extent={{32,-10},{52,10}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_IP_in annotation (
              Placement(transformation(extent={{-114,-10},{-94,10}}),
                iconTransformation(extent={{-120,-10},{-100,10}})));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_IP_out
            annotation (Placement(transformation(extent={{94,-10},{114,10}}),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={{-98,14},
                    {-86,26}}),          iconTransformation(extent={{-120,50},{-100,70}})));
          ThermoPower.Water.PressDrop pressDrop_OTSG_IPT(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=84.96,
            dpnom=108000,
            rhonom=12.8)
            annotation (Placement(transformation(extent={{-80,10},{-60,30}})));
          ThermoPower.Water.PressDrop pressDrop_IPT1_HPH1(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            rhonom=6.01,
            wnom=3.034,
            dpnom=46000)    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-20,-40})));
          ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{86,14},{98,26}}),
                iconTransformation(extent={{100,50},{120,70}})));

          ThermoPower.Water.FlangeB SP5(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{-26,-86},{-14,-74}}),
                iconTransformation(extent={{-44,-120},{-24,-100}})));

          ThermoPower.Water.PressDrop pressDrop_IPT2_DEA(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=6.877,
            dpnom=58000,
            rhonom=4.07) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={20,-40})));
          ThermoPower.Water.FlangeB SP4(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{14,-86},{26,-74}}),iconTransformation(
                  extent={{2,-120},{22,-100}})));

          ThermoPower.Water.PressDrop pressDrop_IPT3_LPH3(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=2.475,
            rhonom=1.56,
            dpnom=17200)    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={60,-40})));
          ThermoPower.Water.FlangeB SP3(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{54,-86},{66,-74}}), iconTransformation(
                  extent={{50,-120},{70,-100}})));

        equation
          Pm = IPT1.omega*IPT1.tau + IPT2.omega*IPT2.tau + IPT3.omega*IPT3.tau;
          connect(IPT1.shaft_b,IPT2. shaft_a) annotation (Line(
              points={{-31.6,0},{-4.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPT1.outlet,pressDrop_IPT1_HPH1. inlet) annotation (Line(
              points={{-30,8},{-20,8},{-20,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT1.outlet,IPT2. inlet) annotation (Line(
              points={{-30,8},{-6,8}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(pressDrop_IPT1_HPH1.outlet,SP5)  annotation (Line(
              points={{-20,-50},{-20,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flange_IP_in,IPT1. shaft_a) annotation (Line(
              points={{-104,0},{-44.6,0}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(pressDrop_IPT2_DEA.outlet,SP4)  annotation (Line(
              points={{20,-50},{20,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.outlet, pressDrop_IPT2_DEA.inlet) annotation (Line(
              points={{10,8},{20,8},{20,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pressDrop_IPT3_LPH3.outlet,SP3)  annotation (Line(
              points={{60,-50},{60,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT3.outlet,pressDrop_IPT3_LPH3. inlet) annotation (Line(
              points={{50,8},{60,8},{60,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.outlet, IPT3.inlet) annotation (Line(
              points={{10,8},{34,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.shaft_b, IPT3.shaft_a) annotation (Line(
              points={{8.4,0},{35.4,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(vap_in, pressDrop_OTSG_IPT.inlet) annotation (Line(
              points={{-92,20},{-80,20}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pressDrop_OTSG_IPT.outlet, IPT1.inlet) annotation (Line(
              points={{-60,20},{-46,20},{-46,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT3.outlet, vap_out)
            annotation (Line(points={{50,8},{50,8},{92,8},{92,20}}, color={0,0,255}));
          connect(IPT3.shaft_b, flange_IP_out)
            annotation (Line(points={{48.4,0},{104,0},{104,0}}, color={0,0,0}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Polygon(
                  points={{-16,20},{-16,-20},{12,-46},{12,48},{-16,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-80,60},{-100,60},{-60,60},{-60,20}},
                  color={0,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{-100,8},{-60,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{-34,8},{-16,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{80,8},{100,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                           Text(extent={{-106,96},{110,66}},
                  textString="%name",
                  lineColor={0,0,0}),
                Polygon(
                  points={{32,20},{32,-20},{60,-46},{60,48},{32,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{12,8},{32,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{60,8},{80,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Line(
                  points={{-34,-44},{-34,-60},{-34,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-16,-20},{-16,-60},{-34,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{12,-44},{12,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{32,-20},{32,-60},{12,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{60,-46},{60,-74},{60,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{76,-20},{76,-42},{76,-60},{60,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{76,-20},{76,60},{100,60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end IPT;

        model IPT_valves
          "Model of the intermediate pressure turbine with interceptions valve on steam extractions"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
            constrainedby Modelica.Media.Interfaces.PartialMedium
            "Medium model"
            annotation(choicesAllMatching = true);

          outer ThermoPower.System system "System wide properties";
          parameter Modelica.SIunits.Time t_step1 "First step time";
          parameter Modelica.SIunits.Time t_step2 "First step time";
          parameter Real u_step1_init = 1;
          parameter Real u_step2_init = 0;
          parameter Real A_step1 = -1;
          parameter Real A_step2 = 1;

          Modelica.SIunits.Power Pm "Mechanical power";

          ThermoPower.Water.SteamTurbineStodola IPT1(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=84.96,
            pnom=4624000,
            eta_iso_nom=0.897,
            Kt=0.01219794)
            annotation (Placement(transformation(extent={{-48,-10},{-28,10}})));
          ThermoPower.Water.SteamTurbineStodola IPT2(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=81.93,
            pnom=1861000,
            eta_iso_nom=0.8931,
            Kt=0.03106815)
            annotation (Placement(transformation(extent={{-8,-10},{12,10}})));

          ThermoPower.Water.SteamTurbineStodola IPT3(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=75.05,
            pnom=1144000,
            eta_iso_nom=0.8939,
            Kt=0.03648821)
            annotation (Placement(transformation(extent={{32,-10},{52,10}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_IP_in annotation (
              Placement(transformation(extent={{-114,-10},{-94,10}}),
                iconTransformation(extent={{-120,-10},{-100,10}})));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_IP_out
            annotation (Placement(transformation(extent={{94,-10},{114,10}}),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={{-98,14},
                    {-86,26}}),          iconTransformation(extent={{-120,50},{-100,70}})));
          ThermoPower.Water.PressDrop pressDrop_OTSG_IPT(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=84.96,
            dpnom=108000,
            rhonom=12.8)
            annotation (Placement(transformation(extent={{-80,10},{-60,30}})));
          ThermoPower.Water.ValveVap valve_IPT1_HPH1(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            rhonom=6.01,
            wnom=3.034,
            CheckValve=true,
            pnom=1861000,
            dpnom=46000,
            CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint) annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={-20,-40})));
          ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{86,14},{98,26}}),
                iconTransformation(extent={{100,50},{120,70}})));

          ThermoPower.Water.FlangeB SP5(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{-26,-86},{-14,-74}}),
                iconTransformation(extent={{-44,-120},{-24,-100}})));

          ThermoPower.Water.ValveVap valve_IPT2_DEA(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            wnom=6.877,
            rhonom=4.07,
            CheckValve=true,
            pnom=1144000,
            dpnom=58000,
            CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint) annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={20,-40})));
          ThermoPower.Water.FlangeB SP4(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{14,-86},{26,-74}}),iconTransformation(
                  extent={{2,-120},{22,-100}})));

          ThermoPower.Water.ValveVap valve_IPT3_LPH3(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            wnom=2.475,
            rhonom=1.56,
            CheckValve=true,
            CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
            pnom=345000,
            dpnom=17200) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=-90,
                origin={60,-40})));
          ThermoPower.Water.FlangeB SP3(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{54,-86},{66,-74}}), iconTransformation(
                  extent={{50,-120},{70,-100}})));

        protected
          Modelica.Blocks.Continuous.FirstOrder firstOrder(
            k=1,
            T=0.3,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{-54,-62},{-50,-58}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{-64,-62},{-60,-58}})));
          Modelica.Blocks.Sources.Step step1(
            height=A_step1,
            startTime=t_step1,
            offset=u_step1_init)
            annotation (Placement(transformation(extent={{-74,-56},{-70,-52}})));
          Modelica.Blocks.Sources.Step step2(
            height=A_step2,
            offset=u_step2_init,
            startTime=t_step2)
            annotation (Placement(transformation(extent={{-74,-68},{-70,-64}})));
        equation
          Pm = IPT1.omega*IPT1.tau + IPT2.omega*IPT2.tau + IPT3.omega*IPT3.tau;
          connect(IPT1.shaft_b,IPT2. shaft_a) annotation (Line(
              points={{-31.6,0},{-4.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPT1.outlet, valve_IPT1_HPH1.inlet) annotation (Line(
              points={{-30,8},{-20,8},{-20,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT1.outlet,IPT2. inlet) annotation (Line(
              points={{-30,8},{-6,8}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(valve_IPT1_HPH1.outlet, SP5) annotation (Line(
              points={{-20,-50},{-20,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flange_IP_in,IPT1. shaft_a) annotation (Line(
              points={{-104,0},{-44.6,0}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(valve_IPT2_DEA.outlet, SP4) annotation (Line(
              points={{20,-50},{20,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.outlet, valve_IPT2_DEA.inlet) annotation (Line(
              points={{10,8},{20,8},{20,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(valve_IPT3_LPH3.outlet, SP3) annotation (Line(
              points={{60,-50},{60,-80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT3.outlet, valve_IPT3_LPH3.inlet) annotation (Line(
              points={{50,8},{60,8},{60,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.outlet, IPT3.inlet) annotation (Line(
              points={{10,8},{34,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT2.shaft_b, IPT3.shaft_a) annotation (Line(
              points={{8.4,0},{35.4,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(vap_in, pressDrop_OTSG_IPT.inlet) annotation (Line(
              points={{-92,20},{-80,20}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(pressDrop_OTSG_IPT.outlet, IPT1.inlet) annotation (Line(
              points={{-60,20},{-46,20},{-46,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(IPT3.outlet, vap_out)
            annotation (Line(points={{50,8},{50,8},{92,8},{92,20}}, color={0,0,255}));
          connect(IPT3.shaft_b, flange_IP_out)
            annotation (Line(points={{48.4,0},{104,0}},         color={0,0,0}));
          connect(firstOrder.u,add. y)
            annotation (Line(points={{-54.4,-60},{-59.8,-60}},
                                                             color={0,0,127}));
          connect(step1.y,add. u1) annotation (Line(points={{-69.8,-54},{-66,-54},{-66,-58},
                  {-66,-58.8},{-64.4,-58.8}},
                                 color={0,0,127}));
          connect(step2.y,add. u2) annotation (Line(points={{-69.8,-66},{-66,-66},{-66,-62},
                  {-66,-61.2},{-64.4,-61.2}},
                                 color={0,0,127}));
          connect(firstOrder.y, valve_IPT1_HPH1.theta) annotation (Line(points=
                  {{-49.8,-60},{-40,-60},{-40,-40},{-28,-40}}, color={0,0,127}));
          connect(firstOrder.y, valve_IPT2_DEA.theta) annotation (Line(points={
                  {-49.8,-60},{0,-60},{0,-40},{12,-40}}, color={0,0,127}));
          connect(firstOrder.y, valve_IPT3_LPH3.theta) annotation (Line(points=
                  {{-49.8,-60},{40,-60},{40,-40},{52,-40}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Polygon(
                  points={{-16,20},{-16,-20},{12,-46},{12,48},{-16,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-80,60},{-100,60},{-60,60},{-60,20}},
                  color={0,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{-100,8},{-60,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{-34,8},{-16,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{80,8},{100,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                           Text(extent={{-106,96},{110,66}},
                  textString="%name",
                  lineColor={0,0,0}),
                Polygon(
                  points={{32,20},{32,-20},{60,-46},{60,48},{32,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{12,8},{32,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{60,8},{80,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Line(
                  points={{-34,-44},{-34,-60},{-34,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-16,-20},{-16,-60},{-34,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{12,-44},{12,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{32,-20},{32,-60},{12,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{60,-46},{60,-74},{60,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{76,-20},{76,-42},{76,-60},{60,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{76,-20},{76,60},{100,60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end IPT_valves;

        model LPT "Model of the low  pressure turbine"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
            constrainedby Modelica.Media.Interfaces.PartialMedium
            "Medium model"
            annotation(choicesAllMatching = true);

          parameter Real w_seal_1
            "Gland steam from sealing, as fraction of LPT1 steam";
          parameter Real w_seal_2
            "Gland steam from sealing, as fraction of LPT2 steam";
          outer ThermoPower.System system "System wide properties";

          Modelica.SIunits.Power Pm "Mechanical power";

          ThermoPower.Water.SteamTurbineStodola LPT1(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=73.92,
            pnom=345000,
            eta_iso_nom=0.904,
            Kt=0.12237797)
            annotation (Placement(transformation(extent={{-48,-10},{-28,10}})));
          ThermoPower.Water.SteamTurbineStodola LPT2(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=69.02,
            eta_iso_nom=0.905,
            Kt=0.16371926,
            pnom=195000)
            annotation (Placement(transformation(extent={{-8,-10},{12,10}})));

          ThermoPower.Water.SteamTurbineStodola LPT3(
            redeclare package Medium = Medium,
            eta_mech=1,
            partialArc_nom=1,
            PRstart=2.15,
            wnom=65.73,
            pnom=57000,
            eta_iso_nom=0.8931,
            Kt=0.47922832)
            annotation (Placement(transformation(extent={{32,-10},{52,10}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_LP_in annotation (
              Placement(transformation(extent={{-114,-10},{-94,10}}),
                iconTransformation(extent={{-120,-10},{-100,10}})));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_LP_out
            annotation (Placement(transformation(extent={{94,-10},{114,10}}),
                iconTransformation(extent={{100,-10},{120,10}})));
          ThermoPower.Water.FlangeA vap_in annotation (Placement(transformation(extent={{-98,14},
                    {-86,26}}),          iconTransformation(extent={{-120,50},{-100,70}})));
          ThermoPower.Water.PressDrop pressDrop_LPT1_LPH2(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=4.9,
            rhonom=0.99,
            dpnom=5900)     annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-20,-40})));
          ThermoPower.Water.FlangeB vap_out(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{86,14},{98,26}}),
                iconTransformation(extent={{100,50},{120,70}})));

          ThermoPower.Water.PressDrop pressDrop_LPT2_LPH1(
            redeclare package Medium = Medium,
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            allowFlowReversal=false,
            wnom=3.813,
            rhonom=0.4134,
            dpnom=1700)      annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={20,-40})));
          ThermoPower.Water.FlangeB SP2(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{-26,-86},{-14,-74}}),
                                                                   iconTransformation(
                  extent={{-64,-120},{-44,-100}})));

          ThermoPower.Water.FlangeB SP1(redeclare package Medium = Medium) annotation (
              Placement(transformation(extent={{14,-86},{26,-74}}), iconTransformation(
                  extent={{-2,-120},{18,-100}})));

          ThermoPower.Water.SourceMassFlow glandSteam1(
            redeclare package Medium = Medium,
            use_in_w0=true,
            h=3103000)
            annotation (Placement(transformation(extent={{-20,50},{-40,70}})));
          Modelica.Blocks.Sources.RealExpression expression1(y=w_seal_1*LPT1.w)
            annotation (Placement(transformation(extent={{-84,70},{-60,90}})));
          ThermoPower.Water.SourceMassFlow glandSteam2(
            redeclare package Medium = Medium,
            use_in_w0=true,
            h=354.4e3)
            annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
          Modelica.Blocks.Sources.RealExpression expression2(y=w_seal_2*LPT2.w)
            annotation (Placement(transformation(extent={{36,-50},{60,-70}})));
        equation
          Pm = LPT1.omega*LPT1.tau + LPT2.omega*LPT2.tau + LPT3.omega*LPT3.tau;
          connect(LPT1.shaft_b,LPT2. shaft_a) annotation (Line(
              points={{-31.6,0},{-4.6,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(LPT1.outlet,pressDrop_LPT1_LPH2. inlet) annotation (Line(
              points={{-30,8},{-20,8},{-20,-30}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPT1.outlet,LPT2. inlet) annotation (Line(
              points={{-30,8},{-6,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(flange_LP_in,LPT1. shaft_a) annotation (Line(
              points={{-104,0},{-44.6,0}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(LPT2.outlet,LPT3. inlet) annotation (Line(
              points={{10,8},{34,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPT2.shaft_b,LPT3. shaft_a) annotation (Line(
              points={{8.4,0},{35.4,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(vap_in, LPT1.inlet) annotation (Line(
              points={{-92,20},{-46,20},{-46,8}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPT3.outlet, vap_out) annotation (Line(points={{50,8},{56,8},{60,8},{60,
                  20},{92,20}}, color={0,0,255}));
          connect(LPT3.shaft_b, flange_LP_out)
            annotation (Line(points={{48.4,0},{104,0}},         color={0,0,0}));
          connect(pressDrop_LPT1_LPH2.outlet, SP2)
            annotation (Line(points={{-20,-50},{-20,-80}}, color={0,0,255}));
          connect(pressDrop_LPT2_LPH1.outlet, SP1)
            annotation (Line(points={{20,-50},{20,-80}}, color={0,0,255}));
          connect(expression1.y, glandSteam1.in_w0) annotation (Line(points={{
                  -58.8,80},{-26,80},{-26,66}}, color={0,0,127}));
          connect(glandSteam1.flange, LPT1.inlet) annotation (Line(points={{-40,
                  60},{-46,60},{-46,8}}, color={0,0,255}));
          connect(expression2.y, glandSteam2.in_w0) annotation (Line(points={{
                  61.2,-60},{74,-60},{74,-26}}, color={0,0,127}));
          connect(LPT2.outlet, pressDrop_LPT2_LPH1.inlet)
            annotation (Line(points={{10,8},{20,8},{20,-30}}, color={0,0,255}));
          connect(glandSteam2.flange, pressDrop_LPT2_LPH1.inlet) annotation (Line(
                points={{60,-20},{20,-20},{20,-30}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Polygon(
                  points={{-20,18},{-20,-22},{8,-48},{8,46},{-20,18}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-80,20},{-80,-20},{-54,-44},{-54,48},{-80,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-100,60},{-100,60},{-80,60},{-80,20}},
                  color={0,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{-100,8},{-80,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{-54,8},{-20,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{80,8},{100,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                           Text(extent={{-106,96},{110,66}},
                  textString="%name",
                  lineColor={0,0,0}),
                Polygon(
                  points={{40,20},{40,-20},{68,-46},{68,48},{40,20}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{8,8},{40,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Rectangle(
                  extent={{68,8},{80,-8}},
                  lineColor={0,0,0},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={160,160,164}),
                Line(
                  points={{-54,-44},{-54,-60},{-54,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{-20,-22},{-20,-60},{-54,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{8,-48},{8,-100}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{40,-20},{40,-60},{8,-60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{68,48},{68,60},{100,60}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None)}));
        end LPT;

      end Corps;

      package ThermalStress
        "Package containing model for tutbine stresses evaluation"

        model CylinderFourier
          "Thermal model of a hollow cylinder by Fourier's equation - 1 axial node and Nr radial nodes"
          import Modelica.SIunits.*;
          import ThermoPower.Choices.CylinderFourier.NodeDistribution;
          extends ThermoPower.Icons.MetalWall;

          parameter Integer Nr=2 "Number of radial nodes";
          parameter NodeDistribution nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.uniform
            "Node distribution";
          parameter Modelica.SIunits.Length rint "Internal radius";
          parameter Modelica.SIunits.Length rext "External radius";
          parameter Modelica.SIunits.Length L "Cylinder length";
          parameter Modelica.SIunits.Density rhom "Material density";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Material specific heat capacity";
          parameter Modelica.SIunits.ThermalConductivity km
            "Material thermal conductivity";
          parameter Modelica.SIunits.Temperature Tstartint=300
            "Temperature start value at rint (first node)"
            annotation (Dialog(tab="Initialisation"));
          parameter Modelica.SIunits.Temperature Tstartext=300
            "Temperature start value at rext (last node)"
            annotation (Dialog(tab="Initialisation"));
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option" annotation (Dialog(tab="Initialisation"));
          constant Real pi=Modelica.Constants.pi;
          outer ThermoPower.System system "System wide properties";

          Modelica.SIunits.Length r[Nr](fixed=false) "Node radii";
        protected
          Modelica.SIunits.Length r1_2[Nr - 1](fixed=false) "Slice mean radii";
          Modelica.SIunits.Length r_lin[Nr](fixed=false)
            "Linearly distributed radii";
          Real A[Nr](fixed=false);
          Real B[Nr](fixed=false);
          Real C[Nr](fixed=false);

        public
          Modelica.SIunits.Temperature T[Nr](start=linspace(
                Tstartint,
                Tstartext,
                Nr)) "Nodal temperatures";
          Modelica.SIunits.Temperature Tm "Mean temperature";

          ThermoPower.Thermal.DHTVolumes
                                  internalBoundary(final N=1) annotation (Placement(
                transformation(extent={{-20,20},{20,40}}, rotation=0)));
          ThermoPower.Thermal.DHTVolumes
                                  externalBoundary(final N=1) annotation (Placement(
                transformation(extent={{-20,-40},{20,-20}}, rotation=0)));

        equation
          // Generation of the temperature node distribution
          r_lin = linspace(
              rint,
              rext,
              Nr) "Linearly distributed node radii";
          for i in 1:Nr loop
            if nodeDistribution == NodeDistribution.uniform then
              r[i] = r_lin[i] "Uniform distribution of node radii";
            elseif nodeDistribution == NodeDistribution.thickInternal then
              r[i] = rint + 1/(rext - rint)*(r_lin[i] - rint)^2
                "Quadratically distributed node radii - thickest at rint";
            elseif nodeDistribution == NodeDistribution.thickExternal then
              r[i] = rext - 1/(rext - rint)*(rext - r_lin[i])^2
                "Quadratically distributed node radii - thickest at rext";
            elseif nodeDistribution == NodeDistribution.thickBoth then
              if r_lin[i] <= (rint + rext)/2 then
                r[i] = 2/(rext - rint)*(r_lin[i] - rint)^2 + rint
                  "Quadratically distributed node radii - thickest at rint";
              else
                r[i] = -2/(rext - rint)*(r_lin[i] - rext)^2 + rext
                  "Quadratically distributed node radii - thickest at rext";
              end if;
            else
              r[i] = 0;
              assert(true, "Unsupported NodeDistribution type");
            end if;
          end for;
          for i in 1:Nr - 1 loop
            r1_2[i] = (r[i + 1] + r[i])/2;
          end for;

          // Spatially discretized coefficients of Fourier's equation
          for i in 2:Nr - 1 loop
            A[i] = r1_2[i - 1]/(r[i]*(r[i] - r[i - 1])*(r1_2[i] - r1_2[i - 1]));
            C[i] = r1_2[i]/(r[i]*(r[i + 1] - r[i])*(r1_2[i] - r1_2[i - 1]));
            B[i] = -A[i] - C[i];
          end for;
          // Not used by Fourier equations
          A[1] = 0;
          B[1] = 0;
          C[1] = 0;
          A[Nr] = 0;
          B[Nr] = 0;
          C[Nr] = 0;

          // Thermal field
          for i in 2:Nr - 1 loop
            rhom*cm/km*der(T[i]) = A[i]*T[i - 1] + B[i]*T[i] + C[i]*T[i + 1]
              "Fourier's equation";
          end for;

          // Thermal boundary conditions
          internalBoundary.T[1] = T[1];
          externalBoundary.T[1] = T[Nr];
          internalBoundary.Q[1] = -km*(T[2] - T[1])/(r[2] - r[1])*2*pi*rint*L;
          externalBoundary.Q[1] = km*(T[Nr] - T[Nr - 1])/(r[Nr] - r[Nr - 1])*2*pi*rext*L;

          // Mean temperature
          Tm = 1/(rext^2 - rint^2)*sum((T[i]*r[i] + T[i + 1]*r[i + 1])*(r[i + 1] - r[
            i]) for i in 1:Nr - 1);
          //  Tm = sum(T)/Nr;
        initial equation
          // Initial conditions
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            der(T[2:Nr - 1]) = zeros(Nr - 2);
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
             T[2:Nr-1] = linspace(Tstartint,Tstartext,Nr-2);
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Icon(graphics={
                Text(
                  extent={{-94,52},{-42,24}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Int"),
                Text(
                  extent={{-90,-24},{-42,-50}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Ext"),
                Text(
                  extent={{-98,-44},{102,-72}},
                  lineColor={191,95,0},
                  textString="%name")}),
            Documentation(info="<html>
This is the 1D thermal model of a solid hollow cylinder by Fourier's equations.
<p>The model is axis-symmetric, has one node in the longitudinal direction, and <tt>Nr</tt> nodes in the radial direction. The two connectors correspond to the internal and external surfaces; if one of the surface is thermally insulated, just leave the connector unconnected (no connection on a <tt>DHT</tt> connector means zero heat flux). The temperature-dependent properties of the material are described by the replaceable <tt>MaterialModel</tt> model.
<p><b>Modelling options</b></p>
The radial distribution of the nodes can be chosen by selecting the value of <tt>nodeDistribution</tt>:
<ul>
<li> <tt>Choices.CylinderFourier.NodeDistribution.uniform</tt> uniform distribution, nodes are equally spaced;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickInternal</tt> quadratic distribution, nodes are thickest near the internal surface;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickExternal</tt> quadratic distribution, nodes are thickest near the external surface;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickBoth</tt> quadratic distribution, nodes are thickest near both surfaces.
</ul>
</html>",       revisions="<html>
<ul>
<li><i>30 Dec 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Bugs fixed in boundary condition and node distribution.</li>
<li><i>1 May 2005</i>
    by <a href=\"mailto:luca.bascetta@polimi.it\">Luca Bascetta</a>:<br>
       First release.</li>
</ul>
</html>"));
        end CylinderFourier;

        model TurbineStresses
          "Model of the total equivalent turbine stresses at the first rotor section"
          extends CylinderFourier;

          parameter Real Kt=2 "Machine geometric factor for thermal stresses";
          parameter Modelica.SIunits.ModulusOfElasticity E
            "Metal Young's module";
          parameter Modelica.SIunits.LinearTemperatureCoefficient alpha
            "Expansion linear coefficient";
          parameter Modelica.SIunits.PoissonNumber ni "Poisson's coefficient";

          Modelica.SIunits.NormalStress intMechanicalStress[3]
            "Mechanical stress at the internal surface (radial-tangential-axial)";
          Modelica.SIunits.NormalStress extMechanicalStress[3]
            "Mechanical stress at the external surface (radial-tangential-axial)";
          Modelica.SIunits.NormalStress intThermalStress[3]
            "Thermal stress at the internal surface (radial-tangential-axial)";
          Modelica.SIunits.NormalStress extThermalStress[3]
            "Thermal stress at the external surface (radial-tangential-axial)";
          Modelica.SIunits.NormalStress totalExtTangentialStress=
            extMechanicalStress[2]+extThermalStress[2]
            "Total tangential stress at the external surface";
          Modelica.SIunits.NormalStress intEquivalentStress
            "Equivalent stress at the internal surface";
          Modelica.SIunits.NormalStress extEquivalentStress
            "Equivalent stress at the external surface";
          Modelica.Mechanics.Rotational.Interfaces.Flange_a shaft annotation (
              Placement(transformation(extent={{-110,-10},{-90,10}}),
                iconTransformation(extent={{-110,-10},{-90,10}})));
        equation
          // Boundary conditions
          shaft.tau = 0;

          // Mechanical stresses
          intMechanicalStress[1] = 0 "Radial mechanical stress at rint";
          intMechanicalStress[2] = (3+ni)/4 * rhom*der(shaft.phi)^2
             *(rext^2+(1-ni)/(3+ni)*rint^2)
            "Tangential mechanical stress at rint";
          intMechanicalStress[3] = 0 "Axial mechanical stress at rint";

          extMechanicalStress[1] = 0 "Radial mechanical stress at rext";
          extMechanicalStress[2] = (3+ni)/4 * rhom*der(shaft.phi)^2
            *(rint^2+(1-ni)/(3+ni)*rext^2)
            "Tangential mechanical stress at rext";
          extMechanicalStress[3] = 0 "Axial mechanical stress at rext";

          // Thermal stresses
          intThermalStress[1] = 0 "Radial thermal stress at rint";
          intThermalStress[2] = alpha*E/(1 - ni)*(Tm - T[1])
            "Tangential thermal stress at rint";
          intThermalStress[3] = alpha*E/(1 - ni)*(Tm - T[1])
            "Axial thermal stress at rint";

          extThermalStress[1] = 0 "Radial thermal stress at rext";
          extThermalStress[2] = alpha*E/(1 - ni)*(Tm - T[Nr])
            "Tangential thermal stress at rext";
          extThermalStress[3] = alpha*E/(1 - ni)*(Tm - T[Nr])
            "Axial thermal stress at rext";

          intEquivalentStress = sqrt(intMechanicalStress[2]^2 + intThermalStress[2]^2 +
                                     intMechanicalStress[2]   * intThermalStress[2]);
          extEquivalentStress = Kt * noEvent(abs(extThermalStress[2]));
          annotation (
            Documentation(revisions="<html>
<ul>
<li><i>10 May 2005</i>
    by <a href=\"mailto:luca.bascetta@polimi.it\">Luca Bascetta</a>:<br>
       First release.</li>
</ul>
</html>",         info="<html>
This model extends <tt>CylinderThermalStress</tt> by adding the computation of the mechanical stress due to the centrifugal forces in a rotating cylinder. A rotational shaft connector is provided to connect to the shaft model.

<p>This model can be used to describe the stress state in the section of a steam turbine shaft corresponding to a single blade row.</p>
</html>"));
        end TurbineStresses;

        model turbineStressCalculator
          "Model of a turbine equivalent stresses calculator "
          replaceable package Medium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model";

          // Heat exchange parameters-variables
          replaceable model HeatTransfer =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model between steam and turbine"
            annotation(choicesAllMatching = true);

          //Geometrical parameters
          parameter Integer Nhex = 2 "Number of nodes for the steam section" annotation(group="Geometry");
          parameter Integer Nr = 2
            "Number of radial nodes for the tubesheets/manifolds" annotation(group="Geometry");
          parameter Modelica.SIunits.Volume V_steam
            "Volume of the fluid in the hot side (bundle)" annotation(group="Geometry");
          parameter Modelica.SIunits.Area S_steam = L_steam*D_ext_rotor*pi
            "Heat transfer surface in the hot side (bundle)" annotation(group="Geometry");
          parameter Modelica.SIunits.Length L_steam "Tubesheet thickness" annotation(group="Geometry");
          parameter Modelica.SIunits.Length D_ext_rotor
            "Shell external diameter"                                             annotation(group="Geometry");
          parameter Modelica.SIunits.Length D_int_rotor
            "Shell internal diameter"                                             annotation(group="Geometry");

          //Metal parameters
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal" annotation(group="Metal specification");
          parameter Modelica.SIunits.ThermalConductivity km
            "Metal thermal conductivity" annotation(group="Metal specification");
          parameter Modelica.SIunits.Density rhom "Density of metal" annotation(group="Metal specification");
          parameter Real Kt=2 "Machine geometric factor for thermal stresses" annotation(group="Metal specification");
          parameter Modelica.SIunits.ModulusOfElasticity E
            "Metal Young's module"                                                annotation(group="Metal specification");
          parameter Modelica.SIunits.LinearTemperatureCoefficient alpha
            "Expansion linear coefficient" annotation(group="Metal specification");
          parameter Modelica.SIunits.PoissonNumber ni "Poisson's coefficient" annotation(group="Metal specification");

          //Steam nominal conditions
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid" annotation(group="Steam conditions");
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid" annotation(group="Steam conditions");
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss" annotation(group="Steam conditions");
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet" annotation(group="Steam conditions");
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet" annotation(group="Steam conditions");
          constant Real pi=Modelica.Constants.pi;

          ThermoPower.Water.FlangeA flangeA(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
          ThermoPower.Water.FlangeB flangeB(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{90,-10},{110,10}})));
          ThermoPower.Water.Flow1DFV flow1DFV(redeclare package Medium = Medium,
            N=Nhex,
            redeclare model HeatTransfer = HeatTransfer,
            omega=D_ext_rotor*pi,
            L=L_steam,
            A=V_steam/L_steam,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            dpnom=nominalColdDeltaP,
            noInitialPressure=true)
            annotation (Placement(transformation(extent={{-10,-30},{10,-10}})));
          TurbineStresses turbineStresses(
            L=L_steam,
            rhom=rhom,
            cm=cm,
            km=km,
            Kt=Kt,
            E=E,
            alpha=alpha,
            ni=ni,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal,
            rint=D_int_rotor/2,
            rext=D_ext_rotor/2)
            annotation (Placement(transformation(extent={{-16,0},{16,32}})));

          Modelica.Mechanics.Rotational.Interfaces.Flange_a turb_shaft
            annotation (Placement(transformation(extent={{-48,6},{-28,26}}),
                iconTransformation(extent={{-80,-110},{-60,-90}})));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in
            annotation (Placement(transformation(extent={{-10,36},{10,56}})));
          Modelica.Blocks.Sources.Constant ext_flux_int(k=0)
            annotation (Placement(transformation(extent={{-40,50},{-20,70}})));
        equation
          connect(flangeA, flow1DFV.infl) annotation (Line(points={{-100,0},{-80,0},{-60,
                  0},{-60,-20},{-10,-20}}, color={0,0,255}));
          connect(flow1DFV.outfl, flangeB) annotation (Line(points={{10,-20},{60,-20},{60,
                  0},{100,0}}, color={0,0,255}));
          connect(turb_shaft, turbineStresses.shaft)
            annotation (Line(points={{-38,16},{-16,16}}, color={0,0,0}));
          connect(turbineStresses.externalBoundary, flow1DFV.wall)
            annotation (Line(points={{0,11.2},{0,-15}}, color={255,127,0}));
          connect(ext_flux_int.y, heatSource1DFV_in.power)
            annotation (Line(points={{-19,60},{0,60},{0,50}}, color={0,0,127}));
          connect(heatSource1DFV_in.wall, turbineStresses.internalBoundary)
            annotation (Line(points={{0,43},{0,20.8}}, color={255,127,0}));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
                  Rectangle(
                  extent={{-100,100},{100,-100}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid), Text(
                  extent={{-82,60},{80,-60}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  textString="Turbine stresses")}),                      Diagram(
                coordinateSystem(preserveAspectRatio=false)));
        end turbineStressCalculator;
      end ThermalStress;

      package Test

        model test_HPT "Test model of the high pressure turbine"
          extends Modelica.Icons.Example;
          Corps.HPT HPTurbine(w_seal=0.022)
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{72,-10},{52,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3427000,
            p0=17000000)
            annotation (Placement(transformation(extent={{-78,30},{-58,50}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=4782000)
            annotation (Placement(transformation(extent={{-60,-70},{-80,-50}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
          ThermoPower.Water.SinkMassFlow sinkSP6(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph, w0=4.449)
            annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
        equation

          connect(HPTurbine.flange_HP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{52,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, HPTurbine.vap_in) annotation (Line(
              points={{-58,40},{-22,40},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, HPTurbine.vap_out) annotation (Line(
              points={{-60,-60},{-22,-60},{-22,-16}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(HPTurbine.SP6, sinkSP6.flange) annotation (Line(points={{0,
                  -22},{0,-60},{20,-60}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})));
        end test_HPT;

        model test_IPT "Test model of the intermediate pressure turbine"
          extends Modelica.Icons.Example;
          Corps.IPT IPTurbine
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{80,-10},{60,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=4732000,
            h=3554000)
            annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=344800)
            annotation (Placement(transformation(extent={{40,10},{60,30}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=327600)
            annotation (Placement(transformation(extent={{28,-50},{48,-30}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=1086000)
            annotation (Placement(transformation(extent={{20,-90},{40,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=1815000)
            annotation (Placement(transformation(extent={{-20,-50},{-40,-30}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
        equation
          connect(IPTurbine.flange_IP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{60,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, IPTurbine.vap_in) annotation (Line(
              points={{-40,20},{-22,20},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure.flange, IPTurbine.vap_out) annotation (Line(
              points={{40,20},{22,20},{22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, IPTurbine.SP5) annotation (Line(points=
                  {{-20,-40},{-6.8,-40},{-6.8,-22}}, color={0,0,255}));
          connect(sinkPressure2.flange, IPTurbine.SP4) annotation (Line(points=
                  {{20,-80},{14,-80},{2.4,-80},{2.4,-22}}, color={0,0,255}));
          connect(sinkPressure1.flange, IPTurbine.SP3) annotation (Line(points=
                  {{28,-40},{12,-40},{12,-22}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})));
        end test_IPT;

        model test_LPT "Test model of the low pressure turbine"
          extends Modelica.Icons.Example;
          Corps.LPT LPTurbine(w_seal_1=0.0182, w_seal_2=0.0076)
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{80,-10},{60,10}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=344800,
            h=2889e3)
            annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=12600)
            annotation (Placement(transformation(extent={{40,10},{60,30}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=55150)
            annotation (Placement(transformation(extent={{20,-70},{40,-50}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=189300)
            annotation (Placement(transformation(extent={{-20,-70},{-40,-50}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{80,80},{100,100}})));
        equation
          connect(LPTurbine.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{22,0},{60,0}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(sourcePressure.flange, LPTurbine.vap_in) annotation (Line(
              points={{-40,20},{-22,20},{-22,12}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.vap_out, sinkPressure.flange) annotation (Line(
              points={{22,12},{22,20},{40,20}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, LPTurbine.SP1) annotation (Line(
              points={{20,-60},{1.6,-60},{1.6,-22}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure3.flange, LPTurbine.SP2) annotation (Line(points=
                  {{-20,-60},{-10.8,-60},{-10.8,-22}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})));
        end test_LPT;

        model test_turbine "Global turbine model"
          extends Modelica.Icons.Example;
          Corps.HPT HPTurbine(w_seal=0.022)
            annotation (Placement(transformation(extent={{-102,0},{-62,40}})));
          Corps.IPT IPTurbine
            annotation (Placement(transformation(extent={{-30,0},{10,40}})));
          Corps.LPT LPTurbine(w_seal_1=0.0182, w_seal_2=0.0076)
            annotation (Placement(transformation(extent={{38,0},{78,40}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{140,10},{120,30}})));
          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=55150)
            annotation (Placement(transformation(extent={{68,-40},{88,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=189300)
            annotation (Placement(transformation(extent={{40,-30},{20,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=12600)
            annotation (Placement(transformation(extent={{120,70},{140,90}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=4732000,
            h=3554000)
            annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
          ThermoPower.Water.SinkPressure sinkPressure4(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=1815000)
            annotation (Placement(transformation(extent={{-30,-30},{-50,-10}})));
          ThermoPower.Water.SinkPressure sinkPressure5(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=1086000)
            annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
          ThermoPower.Water.SinkPressure sinkPressure6(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=327600)
            annotation (Placement(transformation(extent={{20,-60},{40,-40}})));
          ThermoPower.Water.SourcePressure sourcePressure1(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=17000000,
            h=3427000)
            annotation (Placement(transformation(extent={{-170,22},{-150,42}})));
          ThermoPower.Water.SinkPressure sinkPressure7(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=4782000)
            annotation (Placement(transformation(extent={{-152,-6},{-172,14}})));
          ThermoPower.Water.SinkMassFlow sinkMassFlow(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, w0=4.449)
            annotation (Placement(transformation(extent={{-100,-50},{-120,-30}})));
          inner ThermoPower.System system annotation (Placement(transformation(
                  extent={{-180,80},{-160,100}})));
        equation
          connect(HPTurbine.flange_HP_out, IPTurbine.flange_IP_in) annotation (Line(
              points={{-60,20},{-32,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.flange_IP_out, LPTurbine.flange_LP_in) annotation (Line(
              points={{12,20},{36,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(LPTurbine.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{80,20},{120,20}},
              color={0,0,0},
              smooth=Smooth.None));
          connect(IPTurbine.vap_out, LPTurbine.vap_in) annotation (Line(
              points={{12,32},{36,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(LPTurbine.vap_out, sinkPressure.flange) annotation (Line(
              points={{80,32},{80,80},{120,80}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure1.flange, LPTurbine.SP1) annotation (Line(
              points={{68,-30},{60,-30},{60,-2},{59.6,-2}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure.flange, IPTurbine.vap_in) annotation (Line(
              points={{-40,60},{-32,60},{-32,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sourcePressure1.flange, HPTurbine.vap_in) annotation (Line(
              points={{-150,32},{-104,32}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure7.flange, HPTurbine.vap_out) annotation (Line(
              points={{-152,4},{-104,4}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(sinkPressure4.flange, IPTurbine.SP5) annotation (Line(points=
                  {{-30,-20},{-16.8,-20},{-16.8,-2}}, color={0,0,255}));
          connect(sinkPressure5.flange, IPTurbine.SP4) annotation (Line(points=
                  {{0,-80},{-7.6,-80},{-7.6,-2}}, color={0,0,255}));
          connect(sinkPressure6.flange, IPTurbine.SP3) annotation (Line(points=
                  {{20,-50},{2,-50},{2,-2}}, color={0,0,255}));
          connect(sinkPressure3.flange, LPTurbine.SP2) annotation (Line(points=
                  {{40,-20},{47.2,-20},{47.2,-2}}, color={0,0,255}));
          connect(HPTurbine.SP6, sinkMassFlow.flange) annotation (Line(points={
                  {-82,-2},{-82,-40},{-100,-40}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -100},{140,100}})),                Icon(coordinateSystem(extent=
                   {{-180,-100},{140,100}})));
        end test_turbine;

        model test_stressesCalculator
          "Test model of the turbine stresses calculator"
          extends Modelica.Icons.Example;
          ThermalStress.turbineStressCalculator turbineStressCalculator(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            redeclare model HeatTransfer =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.8),
            Nr=10,
            V_steam=0.01,
            L_steam=0.1,
            D_ext_rotor=0.7,
            D_int_rotor=0.4,
            cm=576,
            km=21.5,
            rhom=7950,
            E=18.28e10,
            alpha=0.13138,
            ni=0.3,
            nominalColdFlow=91.3,
            nominalColdDeltaP=0,
            nominalColdPressure=17100000,
            nominalColdInletTemperature=823.15,
            nominalColdOutletTemperature=822.15)
            annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=91.3,
            h=3427000)
            annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=17100000)
            annotation (Placement(transformation(extent={{40,-10},{60,10}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(
              w_fixed=314.15) annotation (Placement(transformation(extent={{-60,
                    -60},{-40,-40}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
            annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
        equation
          connect(sourceMassFlow.flange, turbineStressCalculator.flangeA)
            annotation (Line(points={{-40,0},{-30,0},{-20,0}}, color={0,0,255}));
          connect(turbineStressCalculator.flangeB, sinkPressure.flange)
            annotation (Line(points={{20,0},{40,0}}, color={0,0,255}));
          connect(constantSpeed.flange, turbineStressCalculator.turb_shaft)
            annotation (Line(points={{-40,-50},{-28,-50},{-14,-50},{-14,-20}},
                color={0,0,0}));
        end test_stressesCalculator;

        model test_stressesCalculator_naked
          "Test model of the turbine stresses calculator, with "
          extends Modelica.Icons.Example;
          ThermoPower.Water.SourceMassFlow FROM_SH(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=91.3,
            h=3427000,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-100,10},{-80,30}})));
          ThermoPower.Water.SinkPressure TO_TURBINE(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            use_in_p0=true,
            p0=17000000) annotation (Placement(transformation(extent={{140,-30},
                    {160,-10}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(
              w_fixed=314.15) annotation (Placement(transformation(extent={{40,60},
                    {60,80}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
            annotation (Placement(transformation(extent={{-200,140},{-180,160}})));
          ThermalStress.TurbineStresses turbine_rotor(
            cm=576,
            km=21.5,
            Kt=2,
            ni=0.3,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickExternal,
            Nr=10,
            L=0.1,
            rint=0.1,
            rext=0.3175,
            rhom=7750,
            alpha=12e-6,
            Tstartint=773.15,
            Tstartext=773.15,
            E=182e9)
            annotation (Placement(transformation(extent={{84,54},{116,86}})));

          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in
            annotation (Placement(transformation(extent={{90,80},{110,100}})));
          Modelica.Blocks.Sources.Constant internal_flux(k=0)
            annotation (Placement(transformation(extent={{60,100},{80,120}})));
          ThermoPower.Water.Flow1DFV HP_inlet_section(
            noInitialPressure=true,
            N=2,
            L=0.1,
            dpnom=0,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            A=0.1995,
            omega=1.995,
            wnom=91.3,
            pstart=17000000,
            redeclare model HeatTransfer =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=2, gamma_nom=800))
            annotation (Placement(transformation(extent={{90,-30},{110,-10}})));
          ThermoPower.Water.SourcePressure FROM_FW(
            use_in_p0=true,
            use_in_h=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{-120,-70},{-100,-50}})));
          Modelica.Blocks.Tables.CombiTable1D p_pumpFW_outlet(smoothness=
                Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                86.44e5; 30,89.06e5; 40,92.25e5; 50,99.52e5; 60,120e5; 70,
                132.8e5; 80,148.8e5; 90,164.2e5; 100,178.7e5]) annotation (
              Placement(transformation(extent={{-140,-50},{-120,-30}})));
          Modelica.Blocks.Tables.CombiTable1D h_pumpFW_outlet(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{-140,-20},{-120,0}})));
          ThermoPower.Water.ValveLiq valveSH(
            wnom=2.2,
            CheckValve=true,
            Av=2.32e-4,
            pnom=8700000,
            dpnom=200000,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                          annotation (Placement(transformation(extent={{-80,-50},
                    {-60,-70}})));
          Modelica.Blocks.Continuous.FirstOrder valveSH_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=1,
            T=0.3) annotation (Placement(transformation(extent={{-40,-100},{-60,
                    -80}})));
          IndustrialControlSystems.Controllers.PI_steadyState
                                                  PI_valveSH(
            AntiWindup=true,
            Kp=-0.01,
            Ti=0.5,
            CSmin=0,
            CSmax=1,
            CS_start=0.5,
            useTS=false,
            steadyStateInit=true)
                      annotation (Placement(transformation(extent={{0,-80},{-20,
                    -100}})));
          ThermoPower.Water.SensT sensT_SH(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                transformation(extent={{-10,-14},{10,-34}})));
          ThermoPower.Water.Mixer desSH(
            noInitialPressure=true,
            FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
            V=0.5,
            hstart=3542000,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            pstart=8508000) annotation (Placement(transformation(extent={{-42,-30},
                    {-22,-10}})));
          Modelica.Blocks.Sources.Ramp T_sh_SP(
            height=50,
            offset=773.15,
            startTime=180,
            duration=2220)
            annotation (Placement(transformation(extent={{60,-106},{40,-86}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=80,
            offset=20,
            startTime=0,
            duration=540)
            annotation (Placement(transformation(extent={{-188,0},{-168,20}})));
          Modelica.Blocks.Sources.Ramp p_turb_inlet(
            height=85e5,
            offset=85e5,
            duration=270,
            startTime=270)   annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={170,10})));
          Modelica.Blocks.Tables.CombiTable1D h_SH_outlet(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,3542e3; 30,3535e3; 40,3529e3; 50,3518e3; 60,3499e3; 70,
                3476e3; 80,3453e3; 90,3429e3; 100,3428e3]) annotation (
              Placement(transformation(extent={{-140,60},{-120,80}})));
          Modelica.Blocks.Tables.CombiTable1D w_SH_outlet(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,17.67; 30,26.99; 40,36.63; 50,46.95; 60,57.44; 70,66.02;
                80,74.71; 90,83.33; 100,91.3]) annotation (Placement(
                transformation(extent={{-140,30},{-120,50}})));
        equation

          when time > 0 then
            reinit(turbine_rotor.T,linspace(turbine_rotor.Tstartint,turbine_rotor.Tstartext,turbine_rotor.Nr));
          end when;
          connect(internal_flux.y, heatSource1DFV_in.power)
            annotation (Line(points={{81,110},{100,110},{100,94}},
                                                               color={0,0,127},
              thickness=0.5));

          connect(heatSource1DFV_in.wall,turbine_rotor. internalBoundary)
            annotation (Line(
              points={{100,87},{100,74.8}},
              color={255,127,0},
              thickness=1));
          connect(constantSpeed.flange,turbine_rotor. shaft) annotation (Line(
              points={{60,70},{84,70}},
              color={0,0,0},
              thickness=0.5));
          connect(turbine_rotor.externalBoundary, HP_inlet_section.wall)
            annotation (Line(
              points={{100,65.2},{100,38},{100,-15}},
              color={255,127,0},
              thickness=1));
          connect(HP_inlet_section.outfl, TO_TURBINE.flange) annotation (Line(
              points={{110,-20},{140,-20}},
              color={0,0,255},
              thickness=1));
          connect(h_pumpFW_outlet.y[1], FROM_FW.in_h) annotation (Line(
              points={{-119,-10},{-106,-10},{-106,-51}},
              color={0,0,127},
              thickness=0.5));
          connect(p_pumpFW_outlet.y[1], FROM_FW.in_p0) annotation (Line(
              points={{-119,-40},{-114,-40},{-114,-50.8}},
              color={0,0,127},
              thickness=0.5));
          connect(valveSH_dynamic.y, valveSH.theta)
            annotation (Line(points={{-61,-90},{-70,-90},{-70,-68}}, color={0,0,127},
              thickness=0.5));

          connect(FROM_FW.flange, valveSH.inlet) annotation (Line(
              points={{-100,-60},{-90,-60},{-80,-60}},
              color={0,0,255},
              thickness=1));
          connect(FROM_SH.flange, desSH.in1) annotation (Line(
              points={{-80,20},{-80,20},{-40,20},{-40,-14}},
              color={0,0,255},
              thickness=1,
              arrow={Arrow.None,Arrow.Filled}));
          connect(valveSH.outlet, desSH.in2)
            annotation (Line(points={{-60,-60},{-40,-60},{-40,-26}},
                                                                 color={0,0,255},
              thickness=1,
              arrow={Arrow.None,Arrow.Filled}));

          connect(desSH.out, sensT_SH.inlet)
            annotation (Line(points={{-22,-20},{-22,-20},{-6,-20}},
                                                         color={0,0,255},
              thickness=1));
          connect(sensT_SH.outlet, HP_inlet_section.infl) annotation (Line(
              points={{6,-20},{6,-20},{90,-20}},
              color={0,0,255},
              thickness=1,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_SH.T, PI_valveSH.PV) annotation (Line(points={{8,-30},{
                  20,-30},{20,-89},{-2,-89}},
                                      color={0,0,127},
              thickness=0.5));
          connect(valveSH_dynamic.u, PI_valveSH.CS)
            annotation (Line(points={{-38,-90},{-38,-90},{-19,-90}},
                                                        color={0,0,127},
              thickness=0.5));
          connect(PI_valveSH.SP, T_sh_SP.y)
            annotation (Line(points={{-2,-96},{39,-96}}, color={0,0,127},
              thickness=0.5));
          connect(p_turb_inlet.y, TO_TURBINE.in_p0) annotation (Line(
              points={{159,10},{152,10},{146,10},{146,-11.2}},
              color={0,0,127},
              thickness=0.5));
          connect(w_SH_outlet.y[1], FROM_SH.in_w0) annotation (Line(
              points={{-119,40},{-94,40},{-94,26}},
              color={0,0,127},
              thickness=0.5));
          connect(h_SH_outlet.y[1], FROM_SH.in_h) annotation (Line(
              points={{-119,70},{-86,70},{-86,26}},
              color={0,0,127},
              thickness=0.5));
          connect(LOAD.y, h_SH_outlet.u[1]) annotation (Line(
              points={{-167,10},{-168,10},{-166,10},{-160,10},{-160,70},{-142,
                  70}},
              color={0,0,127},
              thickness=0.5));
          connect(LOAD.y, w_SH_outlet.u[1]) annotation (Line(
              points={{-167,10},{-160,10},{-160,40},{-142,40}},
              color={0,0,127},
              thickness=0.5));
          connect(LOAD.y, h_pumpFW_outlet.u[1]) annotation (Line(
              points={{-167,10},{-160,10},{-160,-10},{-142,-10}},
              color={0,0,127},
              thickness=0.5));
          connect(LOAD.y, p_pumpFW_outlet.u[1]) annotation (Line(
              points={{-167,10},{-160,10},{-160,-40},{-142,-40}},
              color={0,0,127},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-200,-160},{200,160}}),
                graphics={
                Polygon(
                  points={{240,-386},{212,-372},{202,-352},{160,-302},{68,-274},
                      {42,-302},{24,-356},{26,-432},{68,-486},{156,-516},{264,
                      -528},{298,-498},{298,-446},{282,-418},{240,-386}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  pattern=LinePattern.Dash,
                  smooth=Smooth.Bezier),
                Text(
                  extent={{-160,124},{-100,104}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5,
                  textString="SH OUTLET"),
                Text(
                  extent={{108,-42},{188,-68}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5,
                  textString="STEAM PATH"),
                Polygon(
                  points={{72,-10},{78,-12},{72,-14},{72,-10}},
                  lineColor={0,0,255},
                  lineThickness=1,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{72,-12},{60,-12}},
                  color={0,0,255},
                  thickness=1),
                Polygon(
                  points={{-56,-46},{-50,-48},{-56,-50},{-56,-46}},
                  lineColor={0,0,255},
                  lineThickness=1,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-56,-48},{-68,-48}},
                  color={0,0,255},
                  thickness=1),
                Polygon(
                  points={{-56,30},{-50,28},{-56,26},{-56,30}},
                  lineColor={0,0,255},
                  lineThickness=1,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-56,28},{-68,28}},
                  color={0,0,255},
                  thickness=1),
                Line(
                  points={{-58,-270},{-64,-278},{-76,-284},{-98,-290},{-132,
                      -290},{-154,-298},{-160,-308},{-156,-326},{-136,-338},{
                      -94,-350},{-62,-348},{-30,-338},{-18,-318},{-14,-292},{
                      -20,-266},{-34,-262},{-48,-264},{-58,-270}},
                  color={0,0,0},
                  thickness=0.5,
                  pattern=LinePattern.Dash,
                  smooth=Smooth.Bezier),
                Polygon(
                  points={{322,-302},{326,-298},{328,-284},{330,-264},{320,-246},
                      {308,-234},{288,-224},{284,-224},{258,-222},{256,-222},{
                      242,-224},{232,-228},{230,-232},{224,-242},{222,-248},{
                      214,-260},{212,-264},{210,-280},{210,-284},{210,-294},{
                      214,-302},{218,-308},{222,-310},{228,-312},{236,-312},{
                      244,-312},{248,-312},{258,-310},{264,-310},{280,-308},{
                      308,-306},{320,-304},{326,-298},{322,-302}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5,
                  smooth=Smooth.Bezier),
                Text(
                  extent={{126,116},{188,102}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5,
                  textString="ROTOR"),
                Polygon(
                  points={{-198,100},{-78,100},{82,-80},{82,-126},{-198,-126},{
                      -198,100}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5),
                Polygon(
                  points={{20,132},{128,132},{128,38},{20,38},{20,132}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5),
                Rectangle(
                  extent={{54,30},{192,-38}},
                  lineColor={0,0,0},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5)}),                                          Icon(
                coordinateSystem(extent={{-200,-160},{200,160}})),
            experiment(StopTime=10000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput);
        end test_stressesCalculator_naked;
      end Test;

    end SteamTurbine;

    package Control "Package containing control schemes of the power plant"
      package Schemes
        "Package containing the control models for the OTSG and power plant"
        package BaseClasses
          "Package containing base classes for control models/schemes"
          partial model BasePlantController
            "Base model of the plant control system"

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{160,-20},{200,20}}),iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={240,0})));
            Modelica.Blocks.Interfaces.RealInput load annotation (Placement(
                  transformation(extent={{-220,-20},{-180,20}}),
                  iconTransformation(extent={{-260,-20},{-220,20}})));
          equation

            connect(signalBus.load, load) annotation (Line(
                points={{180,0},{-10,0},{-200,0}},
                color={255,255,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-220,
                      -300},{220,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-220,-300},{220,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-220,140},{220,-120}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-220,300},{220,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end BasePlantController;

          partial model BasePowerPressureController
            "Base model of the power/pressure/FW control system"

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{300,-60},{340,-20}}),
                                                 iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={422,0})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-350,-20},{-310,20}}),
                  iconTransformation(extent={{-440,-20},{-400,20}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-220,370},{-180,410}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-320,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBhigh_bool
              annotation (Placement(transformation(extent={{-220,-190},{-180,
                      -150}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-160,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWlow_bool annotation (
                Placement(transformation(extent={{-220,-50},{-180,-10}}),
                                                                       iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={320,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-220,10},{-180,50}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={160,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBlow_bool
              annotation (Placement(transformation(extent={{-220,-310},{-180,
                      -270}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,460})));
          equation

            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -440},{400,440}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-440},{400,440}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="Power-pressure-FW
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-398,438},{402,-440}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end BasePowerPressureController;
        end BaseClasses;

        package SingleControllers
          "Package containing the models of the single controllers"

          model control_wMS_high "Model of the mechanical power controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            IndustrialControlSystems.Controllers.PI  PID_pumpMS_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpMS_high,
              CSmax=CSmax_pumpMS_high,
              CS_start=CSstart_pumpMS_high,
              Kp=Kp_pumpMS_high,
              Ti=Ti_pumpMS_high)
                                annotation (Placement(transformation(extent={{-80,
                      -120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_high
              annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,
                      -68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-200,120},{-160,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6]) annotation (Placement(transformation(extent={{-140,
                      -98},{-120,-78}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                  [20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Math.Add add_dec annotation (Placement(
                  transformation(extent={{20,-92},{40,-72}})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={32,-20}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={120,-220})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={0,-50})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{-32,-30},{-12,-10}})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{40,-140},{0,-100}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-120,-210})));
          equation

            connect(table_P_MEC_high.y[1], PID_pumpMS_high.SP) annotation (Line(
                  points={{-119,-88},{-119,-88},{-76,-88}},            color={0,
                    0,127}));
            connect(load, table_P_MEC_high.u[1]) annotation (Line(points={{-180,
                    -88},{-142,-88}},                   color={0,0,127}));
            connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-180,
                    -88},{-160,-88},{-160,-150},{-82,-150}},  color={0,0,127}));
            connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points={{-59,
                    -150},{78,-150}},                      color={0,0,127}));
            connect(PV, PID_pumpMS_high.PV) annotation (Line(points={{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}},
                                                       color={0,0,127}));
            connect(add_dec.y, add_high.u1) annotation (Line(points={{41,-82},{
                    60,-82},{60,-138},{78,-138}},
                                         color={0,0,127}));
            connect(PID_pumpMS_high.CS, add_dec.u2) annotation (Line(points={{-42,
                    -100},{0,-100},{0,-88},{18,-88}},      color={0,0,127}));
            connect(switch_dec.y, add_dec.u1) annotation (Line(points={{0,-61},
                    {0,-76},{18,-76}},  color={0,0,127}));
            connect(const.y, switch_dec.u1) annotation (Line(points={{-11,-20},
                    {-8,-20},{-8,-38}},color={0,0,127}));
            connect(dec_in, switch_dec.u3) annotation (Line(points={{32,-20},{8,
                    -20},{8,-38}},     color={0,0,127}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},
                    {-160,-88},{-160,40},{-122,40}},  color={0,0,127}));
            connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-180,140},
                    {-90,140},{-90,70},{-82,70}},   color={255,0,255}));
            connect(or1.y, PID_pumpMS_high.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}},       color={255,0,255}));
            connect(or1.y, switch_dec.u2) annotation (Line(points={{-59,70},{0,
                    70},{0,-38}},      color={255,0,255}));
            connect(not1.y, or2.u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},    color={255,0,255}));
            connect(add_dec.y, dec_out) annotation (Line(points={{41,-82},{60,
                    -82},{60,-120},{20,-120}}, color={0,0,127}));
            connect(pumpMS_TS_high.y, PID_pumpMS_high.TR) annotation (Line(
                  points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(add_high.y, switch_ts.u3) annotation (Line(points={{101,
                    -144},{120,-144},{120,-88},{138,-88}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80}},           color={0,0,127}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {40,40},{38,40}}, color={255,0,255}));
            connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-180,140},
                    {-82,140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,
                    -40},{120,-72},{138,-72}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_MS_high

controller")}));
          end control_wMS_high;

          model control_wMS_low "Model of the mechanical power controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-200,120},{-160,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            IndustrialControlSystems.Controllers.PI  PID_pumpMS_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpMS_low,
              CSmax=CSmax_pumpMS_low,
              CS_start=CSstart_pumpMS_low,
              Kp=Kp_pumpMS_low,
              Ti=Ti_pumpMS_low)
                               annotation (Placement(transformation(extent={{-80,
                      -120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_low annotation (Placement(
                  transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6]) annotation (Placement(transformation(extent={{-140,
                      -98},{-120,-78}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=
                  Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                  [20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.GreaterThreshold lessThreshold(threshold=load_switch)
              annotation (Placement(transformation(extent={{-120,30},{-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(transformation(
                    extent={{70,-60},{110,-20}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(transformation(
                    extent={{-160,-140},{-120,-100}}),iconTransformation(extent={{-240,
                      -20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(transformation(
                    extent={{180,-100},{220,-60}}), iconTransformation(extent={{200,-10},{
                      220,10}})));
          equation

            connect(table_P_MEC_low.y[1], PID_pumpMS_low.SP) annotation (Line(
                  points={{-119,-88},{-119,-88},{-76,-88}},            color={0,
                    0,127}));
            connect(lessThreshold.y, or1.u2)
              annotation (Line(points={{-99,40},{-90,40},{-90,62},{-82,62}},
                                                             color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},
                    {-160,-88},{-160,40},{-122,40}},
                                            color={0,0,127}));
            connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-180,140},
                    {-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));

            connect(not1.y, or2.u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},
                  color={255,0,255}));
            connect(load, table_P_MEC_low.u[1]) annotation (Line(points={{-180,
                    -88},{-142,-88}}, color={0,0,127}));
            connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-180,
                    -88},{-160,-88},{-160,-150},{-82,-150}},
                                             color={0,0,127}));
            connect(PV, PID_pumpMS_low.PV) annotation (Line(points={{-140,-120},
                    {-120,-120},{-100,-120},{-100,-102},{-76,-102}},
                                                       color={0,0,127}));
            connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points=
                   {{-79,-50},{-72,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(or1.y, PID_pumpMS_low.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}}, color={255,0,255}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80},{200,-80}}, color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,
                    -40},{120,-72},{138,-72}}, color={0,0,127}));
            connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-180,140},
                    {-82,140},{20,140},{20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {38,40},{38,40}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            connect(add_low.y, switch_ts.u3) annotation (Line(points={{41,-106},
                    {82,-106},{120,-106},{120,-88},{138,-88}}, color={0,0,127}));
            connect(PID_pumpMS_low.CS, add_low.u1) annotation (Line(points={{
                    -42,-100},{18,-100},{18,-100}}, color={0,0,127}));
            connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{
                    -59,-150},{0,-150},{0,-112},{18,-112}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-186,170},{174,-190}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_MS low

controller")}));
          end control_wMS_low;

          model control_Yt_high "Model of the pressure controller at high load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            IndustrialControlSystems.Controllers.PI PID_valveTURB_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveTURB_high,
              CSmax=CSmax_valveTURB_high,
              CS_start=CSstart_valveTURB_high,
              Kp=Kp_valveTURB_high,
              Ti=Ti_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS_high(k=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_high
              annotation (Placement(transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBhigh_bool
              annotation (Placement(transformation(extent={{-200,120},{-160,160}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Tables.CombiTable1D table_P_high(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt_high(
                table=[20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6; 60,5.01396e-6;
                  70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,4.98849e-6],
                smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},{-100,
                      50}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
          equation
            connect(valveTURB_TS_high.y, PID_valveTURB_high.TR)
              annotation (Line(points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(PID_valveTURB_high.CS, add_high.u1) annotation (Line(points={{-42,-100},
                    {18,-100}},                     color={0,0,127}));
            connect(table_P_high.y[1], PID_valveTURB_high.SP) annotation (Line(points={{-119,
                    -88},{-119,-88},{-76,-88}},            color={0,0,127}));
            connect(table_Yt_high.y[1], add_high.u2) annotation (Line(points={{-59,-150},{
                    -10,-150},{-10,-112},{18,-112}},
                                            color={0,0,127}));
            connect(load, table_P_high.u[1])
              annotation (Line(points={{-180,-88},{-142,-88}}, color={0,0,127}));
            connect(load, table_Yt_high.u[1]) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,-150},{-82,-150}}, color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,-40},{120,-72},
                    {138,-72}}, color={0,0,127}));
            connect(switch_ts.y, CS)
              annotation (Line(points={{161,-80},{200,-80}}, color={0,0,127}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,40},{-122,40}}, color={0,0,127}));
            connect(lessThreshold.y, or2.u2)
              annotation (Line(points={{-99,40},{-30,40},{38,40}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, not1.u) annotation (Line(points={{-180,140},{-80,
                    140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, or1.u1) annotation (Line(points={{-180,140},{-90,
                    140},{-90,70},{-82,70}}, color={255,0,255}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},{-90,40},{-90,
                    62},{-82,62}}, color={255,0,255}));
            connect(not1.y, or2.u1)
              annotation (Line(points={{20,99},{20,48},{38,48}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{70,48},{80,48},
                    {80,-80},{138,-80}}, color={255,0,255}));
            connect(or1.y, PID_valveTURB_high.TS)
              annotation (Line(points={{-59,70},{-52,70},{-52,-84}}, color={255,0,255}));
            connect(add_high.y, switch_ts.u3) annotation (Line(points={{41,-106},{120,-106},
                    {120,-88},{138,-88}}, color={0,0,127}));
            connect(PV, PID_valveTURB_high.PV) annotation (Line(points={{-140,-120},{-100,
                    -120},{-100,-102},{-76,-102}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,182},{180,-178}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="p_eva_high

controller")}));
          end control_Yt_high;

          model control_Yt_low "Model of the pressure controller for low load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            IndustrialControlSystems.Controllers.PI PID_valveTURB_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveTURB_low,
              CSmax=CSmax_valveTURB_low,
              CS_start=CSstart_valveTURB_low,
              Kp=Kp_valveTURB_low,
              Ti=Ti_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS_low(k=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_low
              annotation (Placement(transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_low(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt_low(
                table=[20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6; 60,5.01396e-6;
                  70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,4.98849e-6],
                smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBlow_bool
              annotation (Placement(transformation(extent={{-200,120},{-160,160}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Logical.GreaterThreshold
                                                  lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},{-100,
                      50}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
          equation
            connect(valveTURB_TS_low.y, PID_valveTURB_low.TR)
              annotation (Line(points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(PID_valveTURB_low.CS, add_low.u1) annotation (Line(points={{-42,-100},
                    {18,-100}},                      color={0,0,127}));
            connect(table_P_low.y[1], PID_valveTURB_low.SP) annotation (Line(points={{-119,
                    -88},{-110,-88},{-76,-88}},            color={0,0,127}));
            connect(table_Yt_low.y[1], add_low.u2) annotation (Line(points={{-59,-150},{-10,
                    -150},{-10,-112},{18,-112}},  color={0,0,127}));
            connect(load, table_P_low.u[1]) annotation (Line(points={{-180,-88},{-162,-88},
                    {-162,-88},{-142,-88}}, color={0,0,127}));
            connect(load, table_Yt_low.u[1]) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,-150},{-82,-150}}, color={0,0,127}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},{-90,40},{-90,
                    62},{-82,62}}, color={255,0,255}));
            connect(not1.y, or2.u1)
              annotation (Line(points={{20,99},{20,48},{38,48}}, color={255,0,255}));
            connect(TS_valveTURBlow_bool, not1.u) annotation (Line(points={{-180,140},{-80,
                    140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS_valveTURBlow_bool, or1.u1) annotation (Line(points={{-180,140},{-136,
                    140},{-90,140},{-90,70},{-82,70}}, color={255,0,255}));
            connect(or1.y, PID_valveTURB_low.TS)
              annotation (Line(points={{-59,70},{-52,70},{-52,-84}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2)
              annotation (Line(points={{-99,40},{38,40},{38,40}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{72,48},{80,48},
                    {80,-80},{138,-80}}, color={255,0,255}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,-40},{120,-72},
                    {138,-72}}, color={0,0,127}));
            connect(add_low.y, switch_ts.u3) annotation (Line(points={{41,-106},{80,-106},
                    {120,-106},{120,-88},{138,-88}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{180,-80},{180,-80},
                    {200,-80}}, color={0,0,127}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,40},{-122,40}}, color={0,0,127}));
            connect(PV, PID_valveTURB_low.PV) annotation (Line(points={{-140,-120},{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="p_eva_low

controller")}));
          end control_Yt_low;

          model control_wFW_high_PI
            "Model of the w_FW control for high load with PI controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_high,
              CSmax=CSmax_pumpFW_high,
              CS_start=CSstart_pumpFW_high,
              Kp=Kp_pumpFW_high,
              Ti=Ti_pumpFW_high)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{70,-120},{90,-100}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{108,-154},{128,-134}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                  70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
                Placement(transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={0,-50})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{-32,-30},{-12,-10}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={32,-20}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{84,-60},{124,-20}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{40,-140},{0,-100}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{20,-92},{40,-72}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-142},{-120,-102}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-140,-96},{-120,-76}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{91,-110},{91,
                    -110},{90,-110},{100,-110},{100,-138},{106,-138}},
                                          color={0,0,127}));

            connect(table_w_FW.y[1], add.u2)
              annotation (Line(points={{-59,-150},{-59,-150},{106,-150}},
                                                          color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-59,
                    -150},{60,-150},{60,-116},{68,-116}},
                                                     color={0,0,127}));
            connect(load, table_w_FW.u[1]) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,-150},{-82,-150}},
                                             color={0,0,127}));
            connect(const.y,switch_dec. u1) annotation (Line(points={{-11,-20},
                    {-8,-20},{-8,-38}},color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{32,-20},{8,
                    -20},{8,-38}},     color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{0,
                    70},{0,-38}},      color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(PID_pumpFW_high.CS, add_dec_FW.u2)
              annotation (Line(points={{-42,-100},{0,-100},{0,-88},{18,-88}},
                                                                    color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{
                    -2.22045e-015,-61},{0,-61},{0,-76},{18,-76}},
                                                 color={0,0,127}));
            connect(or1.y, PID_pumpFW_high.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}},
                                color={255,0,255}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{41,-82},{50,-82},{50,-104},{68,-104}},
                                                                    color={0,0,127}));
            connect(PV, PID_pumpFW_high.PV) annotation (Line(points={{-140,-122},
                    {-100,-122},{-100,-102},{-76,-102}},
                                            color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(pumpFW_TS_high.y, PID_pumpFW_high.TR) annotation (Line(
                  points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{41,-82},{
                    40,-82},{50,-82},{50,-104},{50,-120},{20,-120}}, color={0,0,
                    127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{174,
                    -80},{174,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{129,-144},{
                    132,-144},{132,-88},{138,-88}}, color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{104,-40},{132,
                    -40},{132,-72},{138,-72}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-80,140},{20,140},{20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-30,40},{38,40}}, color={255,0,255}));
            connect(table_DT_sh_sp.y[1], PID_pumpFW_high.SP) annotation (Line(
                  points={{-119,-86},{-100,-86},{-100,-88},{-76,-88}}, color={0,
                    0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-161,-86},{-142,-86}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_PI;

          model control_wFW_high_4th
            "Model of the w_FW controller for high load with 4th order controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-10,-40},{10,-20}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{88,-130},{108,-110}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{120,-150},{140,-130}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-150,-70},{-130,-50}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                  70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
                Placement(transformation(extent={{-60,-156},{-40,-136}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={40,-10})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,10},{28,30}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={160,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={80,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={60,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={72,20}),  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{100,-70},{140,-30}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{60,-100},{20,-60}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{52,-50},{72,-30}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-170,-152},{-130,-112}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
              annotation (Placement(transformation(extent={{-110,-120},{-90,
                      -100}})));
            Modelica.Blocks.Continuous.StateSpace controller4th_pumpFW_high(
              A=A,
              B=B,
              C=C,
              D=D)
              annotation (Placement(transformation(extent={{-56,-120},{-16,-80}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
                uMin=CSmin_pumpFW_high)
              annotation (Placement(transformation(extent={{-6,-110},{14,-90}})));
            Modelica.Blocks.Logical.Switch switch_TS
              annotation (Placement(transformation(extent={{28,-52},{40,-40}})));
            Modelica.Blocks.Logical.Switch switch_err annotation (Placement(
                  transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=0,
                  origin={-76,-80})));
            Modelica.Blocks.Sources.Constant const1(
                                                   k=0)
              annotation (Placement(transformation(extent={{-110,-60},{-90,-40}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-150,-114},{-130,
                      -94}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{109,-120},{109,
                    -120},{104,-120},{114,-120},{114,-134},{118,-134}},
                                          color={0,0,127}));

            connect(table_w_FW.y[1], add.u2)
              annotation (Line(points={{-39,-146},{-39,-146},{28,-146},{80,-146},
                    {118,-146}},                          color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-39,
                    -146},{80,-146},{80,-126},{86,-126}},
                                                     color={0,0,127}));
            connect(load, table_w_FW.u[1]) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,-146},{-62,-146}},
                                             color={0,0,127}));
            connect(const.y,switch_dec. u1) annotation (Line(points={{29,20},{
                    32,20},{32,2}},    color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{72,20},{48,
                    20},{48,2}},       color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{40,
                    70},{40,2}},       color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{60,99},{60,48},{
                    68,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{40,-21},
                    {40,-21},{40,-34},{50,-34}}, color={0,0,127}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{73,-40},{80,-40},{80,-114},{86,-114}},
                                                                    color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(PV, DT_sh_error.u2) annotation (Line(points={{-150,-132},{
                    -120,-132},{-120,-116},{-112,-116}},
                                             color={0,0,127}));
            connect(controller4th_pumpFW_high.y[1], pumpFW_lim_adim.u)
              annotation (Line(points={{-14,-100},{-14,-100},{-8,-100}},
                                                                      color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{73,-40},{
                    80,-40},{80,-80},{40,-80}},
                                     color={0,0,127}));
            connect(switch_TS.y, add_dec_FW.u2)
              annotation (Line(points={{40.6,-46},{50,-46},{50,-46}}, color={0,0,127}));
            connect(pumpFW_lim_adim.y, switch_TS.u3) annotation (Line(points={{15,-100},
                    {20,-100},{20,-50.8},{26.8,-50.8}},
                                                   color={0,0,127}));
            connect(or1.y, switch_TS.u2) annotation (Line(points={{-59,70},{-40,
                    70},{-40,-46},{26.8,-46}},
                                 color={255,0,255}));
            connect(pumpFW_TS_high.y, switch_TS.u1) annotation (Line(points={{
                    11,-30},{20,-30},{20,-41.2},{26.8,-41.2}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{171,-80},{175.5,
                    -80},{175.5,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{141,-140},{
                    144,-140},{144,-88},{148,-88}}, color={0,0,127}));
            connect(switch_ts.u1, TS) annotation (Line(points={{148,-72},{148,
                    -72},{146,-72},{146,-72},{144,-72},{144,-50},{120,-50},{120,
                    -50}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{91,48},{100,
                    48},{100,-80},{148,-80}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-15.5,40},{68,40}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-60,140},{60,140},{60,122}}, color={255,0,255}));
            connect(DT_sh_error.y, switch_err.u3) annotation (Line(points={{-89,
                    -110},{-84,-110},{-84,-83.2},{-80.8,-83.2}}, color={0,0,127}));
            connect(const1.y, switch_err.u1) annotation (Line(points={{-89,-50},
                    {-84,-50},{-84,-76.8},{-80.8,-76.8}}, color={0,0,127}));
            connect(lessThreshold.y, switch_err.u2) annotation (Line(points={{
                    -99,40},{-90,40},{-90,0},{-120,0},{-120,-80},{-80.8,-80}},
                  color={255,0,255}));
            connect(switch_err.y, controller4th_pumpFW_high.u[1]) annotation (
                Line(points={{-71.6,-80},{-68,-80},{-68,-100},{-60,-100}},
                  color={0,0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-166,-86},{-160,-86},{-160,-104},{-152,-104}}, color=
                    {0,0,127}));
            connect(table_DT_sh_sp.y[1], DT_sh_error.u1) annotation (Line(
                  points={{-129,-104},{-120,-104},{-112,-104}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_4th;

          model control_wFW_high_10th
            "Model of the w_FW controller for high load with 10th order controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-10,-40},{10,-20}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{88,-130},{108,-110}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{120,-150},{140,-130}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-150,-80},{-130,-60}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                  70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
                Placement(transformation(extent={{-60,-156},{-40,-136}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={40,-10})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,10},{28,30}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={160,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={80,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={60,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={72,20}),  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{100,-70},{140,-30}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{60,-100},{20,-60}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{52,-50},{72,-30}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-170,-152},{-130,-112}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
              annotation (Placement(transformation(extent={{-110,-120},{-90,-100}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
                uMin=CSmin_pumpFW_high)
              annotation (Placement(transformation(extent={{-6,-110},{14,-90}})));
            Modelica.Blocks.Logical.Switch switch_TS
              annotation (Placement(transformation(extent={{28,-52},{40,-40}})));
            Modelica.Blocks.Logical.Switch switch_err annotation (Placement(
                  transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=0,
                  origin={-76,-80})));
            Modelica.Blocks.Sources.Constant const1(
                                                   k=0)
              annotation (Placement(transformation(extent={{-110,-60},{-90,-40}})));
            Modelica.Blocks.Continuous.StateSpace controller10th_pumpFW_high(
              A=A,
              B=B,
              C=C,
              D=D)
              annotation (Placement(transformation(extent={{-56,-120},{-16,-80}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-150,-112},{-130,
                      -92}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{109,-120},{109,-120},{104,
                    -120},{114,-120},{114,-134},{118,-134}},
                                          color={0,0,127}));

            connect(table_w_FW.y[1], add.u2)
              annotation (Line(points={{-39,-146},{-39,-146},{28,-146},{80,-146},{118,-146}},
                                                          color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-39,
                    -146},{80,-146},{80,-126},{86,-126}},
                                                     color={0,0,127}));
            connect(load, table_w_FW.u[1]) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,-146},{-62,-146}},
                                             color={0,0,127}));
            connect(const.y,switch_dec. u1) annotation (Line(points={{29,20},{
                    32,20},{32,2}},    color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{72,20},{48,
                    20},{48,2}},       color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{40,
                    70},{40,2}},       color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{60,99},{60,48},{
                    68,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{40,-21},
                    {40,-21},{40,-34},{50,-34}}, color={0,0,127}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{73,-40},{80,-40},{80,-114},{86,-114}},
                                                                    color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(PV, DT_sh_error.u2) annotation (Line(points={{-150,-132},{-120,-132},{
                    -120,-116},{-112,-116}}, color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{73,-40},{
                    80,-40},{80,-80},{40,-80}},
                                     color={0,0,127}));
            connect(switch_TS.y, add_dec_FW.u2)
              annotation (Line(points={{40.6,-46},{50,-46},{50,-46}}, color={0,0,127}));
            connect(pumpFW_lim_adim.y, switch_TS.u3) annotation (Line(points={{15,-100},{20,
                    -100},{20,-50.8},{26.8,-50.8}},color={0,0,127}));
            connect(or1.y, switch_TS.u2) annotation (Line(points={{-59,70},{-40,
                    70},{-40,-46},{26.8,-46}},
                                 color={255,0,255}));
            connect(pumpFW_TS_high.y, switch_TS.u1) annotation (Line(points={{
                    11,-30},{20,-30},{20,-41.2},{26.8,-41.2}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{171,-80},{175.5,
                    -80},{175.5,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{141,-140},{144,-140},{144,
                    -88},{148,-88}},                color={0,0,127}));
            connect(switch_ts.u1, TS) annotation (Line(points={{148,-72},{148,
                    -72},{146,-72},{146,-72},{144,-72},{144,-50},{120,-50},{120,
                    -50}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{91,48},{100,
                    48},{100,-80},{148,-80}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-15.5,40},{68,40}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-60,140},{60,140},{60,122}}, color={255,0,255}));
            connect(DT_sh_error.y, switch_err.u3) annotation (Line(points={{-89,-110},{-84,
                    -110},{-84,-83.2},{-80.8,-83.2}}, color={0,0,127}));
            connect(const1.y, switch_err.u1) annotation (Line(points={{-89,-50},{-84,-50},
                    {-84,-76.8},{-80.8,-76.8}}, color={0,0,127}));
            connect(lessThreshold.y, switch_err.u2) annotation (Line(points={{-99,40},{-90,
                    40},{-90,0},{-120,0},{-120,-80},{-80.8,-80}}, color={255,0,255}));
            connect(pumpFW_lim_adim.u, controller10th_pumpFW_high.y[1]) annotation (Line(
                  points={{-8,-100},{-12,-100},{-14,-100}}, color={0,0,127}));
            connect(switch_err.y, controller10th_pumpFW_high.u[1]) annotation (Line(
                  points={{-71.6,-80},{-68,-80},{-68,-100},{-60,-100}}, color={0,0,127}));
            connect(table_DT_sh_sp.y[1], DT_sh_error.u1) annotation (Line(
                  points={{-129,-102},{-124,-102},{-120,-102},{-120,-104},{-112,
                    -104}}, color={0,0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-160,-86},{-160,-102},{-152,-102}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_10th;

          model control_wFW_low "Model of the w_FW for low load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,100},{-200,140}})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_low,
              CSmax=CSmax_pumpFW_low,
              CS_start=CSstart_pumpFW_low,
              Kp=Kp_pumpFW_low,
              Ti=Ti_pumpFW_low)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                       k=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWlow_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                       iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(transformation(
                    extent={{-160,-140},{-120,-100}}),iconTransformation(extent={{-240,
                      -20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(transformation(
                    extent={{180,-100},{220,-60}}), iconTransformation(extent={{200,-10},{
                      220,10}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.GreaterThreshold lessThreshold(threshold=load_switch)
              annotation (Placement(transformation(extent={{-120,30},{-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-20,110})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(transformation(
                    extent={{60,-50},{100,-10}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Tables.CombiTable1D table_l_sp(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,l_sp; 30,l_sp; 40,l_sp; 50,l_sp; 55,1; 60,0; 70,0; 80,0;
                  90,0; 100,0])
                             annotation (Placement(transformation(extent={{-140,
                      -98},{-120,-78}})));
          equation

            connect(lessThreshold.y,or1. u2)
              annotation (Line(points={{-99,40},{-90,40},{-90,62},{-82,62}},
                                                             color={255,0,255}));
            connect(or2.y,switch_ts. u2) annotation (Line(points={{21,48},{40,
                    48},{40,-80},{58,-80},{58,-80},{138,-80},{138,-80}},
                          color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{-20,99},{-20,48},
                    {-2,48}},
                  color={255,0,255}));
            connect(TS,switch_ts. u1) annotation (Line(points={{80,-30},{120,
                    -30},{120,-72},{138,-72}},
                               color={0,0,127}));
            connect(PV, PID_pumpFW_low.PV) annotation (Line(points={{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}}, color={0,0,127}));
            connect(TS_pumpFWlow_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-180,140},{-90,140},{-90,70},{-82,70}}, color={255,0,
                    255}));
            connect(or1.y, PID_pumpFW_low.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}}, color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}}, color={0,0,127}));
            connect(pumpFW_TS_low.y, PID_pumpFW_low.TR) annotation (Line(points=
                   {{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80},{200,-80}}, color={0,0,127}));
            connect(TS_pumpFWlow_bool, not1.u) annotation (Line(points={{-180,
                    140},{-20,140},{-20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-50.5,40},{-2,40}}, color={255,0,255}));
            connect(table_l_sp.y[1], PID_pumpFW_low.SP) annotation (Line(points=
                   {{-119,-88},{-76,-88}}, color={0,0,127}));
            connect(load, table_l_sp.u[1]) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,-88},{-142,-88}}, color={0,0,127}));
            connect(PID_pumpFW_low.CS, switch_ts.u3) annotation (Line(points={{
                    -42,-100},{40,-100},{120,-100},{120,-88},{138,-88}}, color=
                    {0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_low

controller")}));
          end control_wFW_low;

          model control_wBP "Model of the w_BP controller"

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-30},{-160,10}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-20}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              k=actuatorGain_valveBP,
              T=Ta_valveBP,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,20},{140,60}})));
            IndustrialControlSystems.Controllers.PI PI_valveBP(
              AntiWindup=true,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{-10,36},{10,56}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,30},{40,50}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveBP_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            Graphics.Label_input valveBP_PV
              annotation (Placement(transformation(extent={{-122,44},{-90,32}})));
            Graphics.Label_output valveBP_CS
              annotation (Placement(transformation(extent={{156,34},{188,46}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85;
                  70,518.15; 80,518.15; 90,518.15; 100,518.15]) annotation (
                Placement(transformation(extent={{-152,42},{-132,62}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0.01; 70,0.145652; 80,0.208685;
                  90,0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{56,30},{76,50}})));
          equation
            connect(add.u1, product.y) annotation (Line(points={{18,46},{18,46},
                    {11,46}}, color={0,0,127}));
            connect(product.u1, PI_valveBP.CS) annotation (Line(points={{-12,52},
                    {-30,52},{-30,40},{-42,40}},
                                   color={0,0,127}));
            connect(TS_valveBP_bool, PI_valveBP.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveBP_TS.y, PI_valveBP.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{140,-20},{144,-20},{144,18},{142,18},{142,40}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PI_valveBP.PV) annotation (Line(
                points={{140,-20},{178,-20},{178,-134},{-84,-134},{-84,36},{-78,36},{-78,38},
                    {-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(table_T_FW.y[1], PI_valveBP.SP) annotation (Line(points={{-131,52},
                    {-76,52}},                   color={0,0,127}));
            connect(load, table_thetaBP.u[1]) annotation (Line(points={{-180,
                    -10},{-62,-10}},           color={0,0,127}));
            connect(load, table_T_FW.u[1]) annotation (Line(points={{-180,-10},
                    {-160,-10},{-160,52},{-154,52}}, color={0,0,127}));
            connect(table_thetaBP.y[1], product.u2) annotation (Line(points={{
                    -39,-10},{-20,-10},{-20,40},{-12,40}}, color={0,0,127}));
            connect(table_thetaBP.y[1], add.u2) annotation (Line(points={{-39,
                    -10},{-39,-10},{14,-10},{14,34},{18,34}}, color={0,0,127}));
            connect(add.y, valveBP_lim.u) annotation (Line(points={{41,40},{54,
                    40}},         color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u) annotation (Line(points={{77,40},
                    {96,40}},                 color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_BP

controller")}));
          end control_wBP;

          model control_wHPH "Model of the w_HPH controller"

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-20},{120,20}})));
            Graphics.Label_output pumpHPH_CS
              annotation (Placement(transformation(extent={{140,-6},{178,6}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])    annotation (Placement(transformation(
                    extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=0)
              annotation (Placement(transformation(extent={{-20,-10},{0,10}})));
          equation
            connect(signalBus.pumpHPH_CS,pumpHPH_dynamic. y) annotation (Line(
                points={{140,-60},{140,-38},{142,-38},{142,-16},{122,-16},{122,
                    0}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpHPH_lim.u, table_w_HPH.y[1]) annotation (Line(points={{
                    -22,0},{-22,0},{-59,0}}, color={0,0,127}));
            connect(pumpHPH_lim.y, pumpHPH_dynamic.u) annotation (Line(points={
                    {1,0},{38.5,0},{76,0}}, color={0,0,127}));
            connect(load, table_w_HPH.u[1]) annotation (Line(points={{-180,0},{
                    -131,0},{-82,0}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_HPH

controller")}));
          end control_wHPH;

          model control_wSEP "Model of the w_SEP controller"

            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration";

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-212,-90},{-172,-50}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={128,-132}),
                                    iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-92,100})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={124,-70})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-132,130},{-112,150}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_SEP(                                                            table=[4,
                  55.97; 20,55.97; 30,85.48; 40,104.3; 50,79.95; 60,0; 70,0; 80,
                  0; 90,0; 100,0], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-92,40},{-72,60}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpSEP_bool annotation (Placement(
                  transformation(extent={{-32,120},{-72,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Logical.Switch switch_SEP
              annotation (Placement(transformation(extent={{42,-80},{62,-60}})));
            Modelica.Blocks.Logical.LessEqualThreshold    greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-92,-80},{-72,-60}})));
            Modelica.Blocks.Math.Product product2 annotation (Placement(
                  transformation(extent={{-58,96},{-38,116}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{-22,90},{-2,110}})));
            Graphics.Label_input pumpSEP_PV
              annotation (Placement(transformation(extent={{-166,104},{-126,92}})));
            Graphics.Label_output pumpSEP_CS
              annotation (Placement(transformation(extent={{164,-76},{202,-64}})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,-120},{28,-100}})));
            Modelica.Blocks.Nonlinear.Limiter pumpSEP_lim(uMax=120, uMin=0)
              annotation (Placement(transformation(extent={{72,-80},{92,-60}})));
            Modelica.Blocks.Math.Division division
              annotation (Placement(transformation(extent={{-28,-26},{-8,-6}})));
            Modelica.Blocks.Math.Product product1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={18,-10})));
            Modelica.Blocks.Sources.Constant const1(k=3.75)
              annotation (Placement(transformation(extent={{-62,-40},{-42,-20}})));
            Modelica.Blocks.Math.Add add1(k1=-1)
              annotation (Placement(transformation(extent={{-62,-14},{-42,6}})));
            Modelica.Blocks.Sources.Constant const2(k=0.25) annotation (
                Placement(transformation(extent={{-92,10},{-72,30}})));
            Graphics.Label_input pumpFW_PV_low annotation (Placement(
                  transformation(extent={{-132,-4},{-86,-16}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85;
                  70,518.15; 80,518.15; 90,518.15; 100,518.15]) annotation (
                Placement(transformation(extent={{-170,110},{-150,130}})));
          equation
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{128,-132},{128,-110},{168,-110},{168,-82},{146,-82},{
                    146,-70}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{128,-132},{128,-174},{-206,-174},{-206,-54},{-140,-54},
                    {-140,-40},{-138,-40},{-138,18},{-114,18},{-114,96},{-112,
                    96},{-112,98},{-108,98}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpSEP_TS.y, PID_pumpSEP.TR)
              annotation (Line(points={{-111,140},{-92,140},{-92,116}},
                                                                    color={0,0,127}));
            connect(TS_pumpSEP_bool, PID_pumpSEP.TS)
              annotation (Line(points={{-52,140},{-52,140},{-84,140},{-84,138},
                    {-84,116}},                                     color={255,0,255}));

            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-192,-70},{-192,-70},{-94,-70}},
                                                                   color={0,0,127}));
            connect(load, table_w_SEP.u[1]) annotation (Line(points={{-192,-70},
                    {-152,-70},{-152,50},{-94,50}},
                                   color={0,0,127}));
            connect(table_w_SEP.y[1], product2.u2) annotation (Line(points={{
                    -71,50},{-64,50},{-64,100},{-60,100}}, color={0,0,127}));
            connect(PID_pumpSEP.CS, product2.u1) annotation (Line(points={{-74,
                    100},{-68,100},{-68,112},{-60,112}}, color={0,0,127}));
            connect(product2.y, add2.u1)
              annotation (Line(points={{-37,106},{-24,106}}, color={0,0,127}));
            connect(table_w_SEP.y[1], add2.u2) annotation (Line(points={{-71,50},
                    {-32,50},{-32,94},{-24,94}}, color={0,0,127}));
            connect(switch_SEP.y, pumpSEP_lim.u) annotation (Line(points={{63,-70},
                    {64,-70},{66,-70},{70,-70}},
                                      color={0,0,127}));
            connect(pumpSEP_lim.y, pumpSEP_dynamic.u)
              annotation (Line(points={{93,-70},{94,-70},{96,-70},{100,-70}},
                                                        color={0,0,127}));
            connect(const.y, switch_SEP.u3) annotation (Line(points={{29,-110},
                    {29,-110},{32,-110},{32,-78},{40,-78}},              color=
                    {0,0,127}));
            connect(division.y, product1.u2) annotation (Line(points={{-7,-16},
                    {6,-16}},         color={0,0,127}));
            connect(add2.y, product1.u1) annotation (Line(points={{-1,100},{2,
                    100},{2,-4},{6,-4}}, color={0,0,127}));
            connect(const1.y, division.u2)
              annotation (Line(points={{-41,-30},{-36,-30},{-36,-22},{-30,-22}},
                                                          color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_SEP.u2) annotation (Line(
                  points={{-71,-70},{-44,-70},{-16,-70},{40,-70}},
                                                  color={255,0,255}));
            connect(const2.y, add1.u1) annotation (Line(points={{-71,20},{-68,
                    20},{-68,2},{-64,2}},         color={0,0,127}));
            connect(add1.y, division.u1) annotation (Line(points={{-41,-4},{-40,
                    -4},{-36,-4},{-36,-10},{-30,-10}},
                                          color={0,0,127}));
            connect(product1.y, switch_SEP.u1) annotation (Line(points={{29,-10},
                    {32,-10},{32,-62},{40,-62}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, add1.u2) annotation (Line(
                points={{128,-132},{128,-132},{128,-174},{-206,-174},{-206,-54},
                    {-126,-54},{-126,-40},{-64,-40},{-64,-10}},
                thickness=0.5,
                color={255,255,255}));
            connect(table_T_FW.y[1], PID_pumpSEP.SP) annotation (Line(points={{
                    -149,120},{-140,120},{-140,112},{-108,112}}, color={0,0,127}));
            connect(load, table_T_FW.u[1]) annotation (Line(points={{-192,-70},
                    {-180,-70},{-180,-68},{-180,120},{-172,120}}, color={0,0,
                    127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_SEP

controller")}));
          end control_wSEP;

          model control_valveSEP "Model of the on/off separator drain valve"

            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-60},{-160,-20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={160,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Logical.Switch switch annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,-80})));
            Modelica.Blocks.Sources.Constant const(k=1)
              annotation (Placement(transformation(extent={{-80,-40},{-60,-20}})));
            Modelica.Blocks.Sources.Constant const1(k=0)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,-130})));
            Modelica.Blocks.Continuous.FirstOrder valveSEP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSEP,
              T=Ta_valveSEP)
                   annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={100,0})));
            Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=load_min)
              annotation (Placement(transformation(extent={{-120,-70},{-100,-50}})));
            Modelica.Blocks.Logical.Hysteresis hysteresis(uLow=l_min, uHigh=l_max)
              annotation (Placement(transformation(extent={{-120,-110},{-100,
                      -90}})));
            Modelica.Blocks.Logical.And and1
              annotation (Placement(transformation(extent={{-80,-90},{-60,-70}})));
            Modelica.Blocks.Logical.Switch switch_IO annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=0,
                  origin={30,0})));
            Modelica.Blocks.Interfaces.BooleanInput useValveSEP annotation (
                Placement(transformation(extent={{-40,-20},{0,20}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Sources.Constant const2(k=0)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,40})));
            Graphics.Label_input pumpFW_PV_low annotation (Placement(
                  transformation(extent={{-188,-94},{-142,-106}})));
            Graphics.Label_output valveSEP_CS
              annotation (Placement(transformation(extent={{142,-6},{180,6}})));
          equation

            connect(greaterThreshold.y,and1. u1) annotation (Line(points={{-99,-60},
                    {-88,-60},{-88,-80},{-82,-80}}, color={255,0,255}));
            connect(hysteresis.y, and1.u2) annotation (Line(points={{-99,-100},
                    {-88,-100},{-88,-88},{-82,-88}},
                                     color={255,0,255}));
            connect(and1.y, switch.u2)
              annotation (Line(points={{-59,-80},{-59,-80},{-22,-80}},
                                                        color={255,0,255}));
            connect(load, greaterThreshold.u) annotation (Line(points={{-180,
                    -40},{-180,-40},{-142,-40},{-140,-40},{-140,-60},{-122,-60}},
                                                 color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_dynamic.y) annotation (Line(
                points={{160,-60},{126,-60},{126,-10},{124,-10},{124,0},{122,0}},
                color={255,255,255},
                thickness=0.5));
            connect(const.y, switch.u1)
              annotation (Line(points={{-59,-30},{-40,-30},{-40,-72},{-22,-72}},
                                                                      color={0,0,127}));
            connect(const1.y, switch.u3) annotation (Line(points={{-59,-130},{
                    -40,-130},{-40,-88},{-22,-88}},
                              color={0,0,127}));
            connect(useValveSEP, switch_IO.u2) annotation (Line(points={{-20,0},
                    {18,0}},        color={255,0,255}));
            connect(switch.y, switch_IO.u1) annotation (Line(points={{1,-80},{
                    10,-80},{10,-8},{18,-8}}, color={0,0,127}));
            connect(const2.y, switch_IO.u3) annotation (Line(points={{1,40},{10,
                    40},{10,8},{18,8}}, color={0,0,127}));
            connect(switch_IO.y, valveSEP_dynamic.u) annotation (Line(points={{
                    41,0},{58,0},{76,0}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, hysteresis.u) annotation (Line(
                points={{160,-60},{160,-60},{160,-180},{-124,-180},{-124,-114},
                    {-124,-100},{-122,-100}},
                color={255,255,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valve_SEP

controller")}));
          end control_valveSEP;

          model control_valveDEA
            "Model of the deaerator steam valve controller"

            //-- valveDEA --
            parameter Real Kp_valveDEA "Controller proportional gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ti_valveDEA
              "Controller integral time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Td_valveDEA
              "Controller derivative time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real Nd_valveDEA
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="valveDEA"));
            parameter Real CSmin_valveDEA
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSmax_valveDEA
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSstart_valveDEA "Start value of CS" annotation (Dialog(tab="valveDEA"));
            parameter Real actuatorGain_valveDEA "Actuator gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ta_valveDEA
              "Actuator time constant"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real TS_valveDEA "Tracking signal" annotation (Dialog(tab="valveDEA"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-30},{-160,10}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-20}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_dynamic(
              k=actuatorGain_valveDEA,
              T=Ta_valveDEA,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,20},{140,60}})));
            IndustrialControlSystems.Controllers.PI PI_valveDEA(
              AntiWindup=true,
              CSmin=CSmin_valveDEA,
              CSmax=CSmax_valveDEA,
              CS_start=CSstart_valveDEA,
              Kp=Kp_valveDEA,
              Ti=Ti_valveDEA,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveDEA_TS(k=TS_valveDEA)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveDEA_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            Graphics.Label_input valveDEA_PV
              annotation (Placement(transformation(extent={{-122,44},{-90,32}})));
            Graphics.Label_output valveDEA_CS
              annotation (Placement(transformation(extent={{156,34},{188,46}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_DEA(table=[20,2.234e5;
                  30,3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595E5; 70,7.754e5;
                  80,8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-152,42},{-132,62}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{40,30},{60,50}})));
          equation
            connect(TS_valveDEA_bool, PI_valveDEA.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveDEA_TS.y, PI_valveDEA.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveDEA_CS, valveDEA_dynamic.y) annotation (Line(
                points={{140,-20},{144,-20},{144,18},{142,18},{142,40}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveDEA_PV, PI_valveDEA.PV) annotation (Line(
                points={{140,-20},{178,-20},{178,-134},{-84,-134},{-84,36},{-78,36},{-78,38},
                    {-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(table_p_DEA.y[1], PI_valveDEA.SP)
              annotation (Line(points={{-131,52},{-76,52}}, color={0,0,127}));
            connect(load, table_p_DEA.u[1]) annotation (Line(points={{-180,-10},
                    {-160,-10},{-160,52},{-154,52}}, color={0,0,127}));
            connect(valveDEA_lim.y, valveDEA_dynamic.u) annotation (Line(points={{61,40},
                    {96,40}},                 color={0,0,127}));
            connect(PI_valveDEA.CS, valveDEA_lim.u) annotation (Line(points={{
                    -42,40},{-2,40},{38,40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="p_DEA

controller")}));
          end control_valveDEA;

          model control_wCOND "Model of the wCOND"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet Deaerator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpCOND --
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmin_pumpCOND "Minimum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmax_pumpCOND "Maximum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-140,-6},{-100,34}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Sources.Constant l_SP(k=2.0559)
              annotation (Placement(transformation(extent={{-80,40},{-60,60}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpCOND(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpCOND,
              CSmax=CSmax_pumpCOND,
              CS_start=CSstart_pumpCOND,
              Kp=Kp_pumpCOND,
              Ti=Ti_pumpCOND)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
            Modelica.Blocks.Sources.Constant pumpCOND_TS(
                                                       k=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-40,40},{-20,60}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpCONDlow_bool annotation (
                Placement(transformation(extent={{-80,120},{-40,160}}),iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Tables.CombiTable1D table_l_sp(table=[20,2.0559; 30,2.0559; 40,
                  2.0559; 50,2.0559; 55,2.0559; 60,2.0559; 70,2.0559; 80,2.0559; 90,2.0559;
                  100,2.0559], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                             annotation (Placement(transformation(extent={{-80,2},{-60,22}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={160,0}),  iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder pumpCOND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpCOND,
              T=Ta_pumpCOND)
              annotation (Placement(transformation(extent={{100,-20},{140,20}})));
            Modelica.Blocks.Nonlinear.Limiter pumpCOND_lim(uMin=0, uMax=100)
              annotation (Placement(transformation(extent={{50,-10},{70,10}})));
          equation

            connect(pumpCOND_TS.y, PID_pumpCOND.TR) annotation (Line(points={{-19,50},
                    {0,50},{0,16}},                 color={0,0,127}));
            connect(table_l_sp.y[1], PID_pumpCOND.SP) annotation (Line(points={{-59,12},
                    {-16,12}},             color={0,0,127}));
            connect(load, table_l_sp.u[1]) annotation (Line(points={{-120,14},{-100,14},{-100,
                    12},{-82,12}},                     color={0,0,127}));
            connect(TS_pumpCONDlow_bool, PID_pumpCOND.TS)
              annotation (Line(points={{-60,140},{8,140},{8,16}}, color={255,0,255}));
            connect(pumpCOND_lim.y, pumpCOND_dynamic.u)
              annotation (Line(points={{71,0},{71,0},{96,0}}, color={0,0,127}));
            connect(signalBus.pumpCOND_CS, pumpCOND_dynamic.y) annotation (Line(
                points={{160,0},{151,0},{142,0}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_pumpCOND.CS, pumpCOND_lim.u)
              annotation (Line(points={{18,0},{48,0}}, color={0,0,127}));
            connect(signalBus.pumpCOND_PV, PID_pumpCOND.PV) annotation (Line(
                points={{160,0},{160,0},{160,-60},{-40,-60},{-40,-2},{-16,-2}},
                color={255,204,51},
                thickness=0.5));

            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_COND

controller")}));
          end control_wCOND;

          model control_wBP_hotStart "Model of the w_BP controller"

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-30},{-160,10}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-20}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              k=actuatorGain_valveBP,
              T=Ta_valveBP,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,20},{140,60}})));
            IndustrialControlSystems.Controllers.PI PI_valveBP(
              AntiWindup=true,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{-10,36},{10,56}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,30},{40,50}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveBP_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            Graphics.Label_input valveBP_PV
              annotation (Placement(transformation(extent={{-122,44},{-90,32}})));
            Graphics.Label_output valveBP_CS
              annotation (Placement(transformation(extent={{156,34},{188,46}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0.01; 70,0.145652; 80,0.208685;
                  90,0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{56,30},{76,50}})));
            Auxiliaries.Components.Ramp_smooth T_FW_SP(
              height=-40,
              duration=100,
              offset=558.15,
              sigType=2,
              startTime=5160)
                           annotation (Placement(transformation(extent={{-160,42},
                      {-140,62}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-200,42},{-180,62}})));
          equation
            connect(add.u1, product.y) annotation (Line(points={{18,46},{18,46},
                    {11,46}}, color={0,0,127}));
            connect(product.u1, PI_valveBP.CS) annotation (Line(points={{-12,52},
                    {-30,52},{-30,40},{-42,40}},
                                   color={0,0,127}));
            connect(TS_valveBP_bool, PI_valveBP.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveBP_TS.y, PI_valveBP.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{140,-20},{144,-20},{144,18},{142,18},{142,40}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PI_valveBP.PV) annotation (Line(
                points={{140,-20},{178,-20},{178,-134},{-84,-134},{-84,36},{-78,36},{-78,38},
                    {-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(load, table_thetaBP.u[1]) annotation (Line(points={{-180,
                    -10},{-62,-10},{-62,-10}}, color={0,0,127}));
            connect(table_thetaBP.y[1], product.u2) annotation (Line(points={{
                    -39,-10},{-20,-10},{-20,40},{-12,40}}, color={0,0,127}));
            connect(table_thetaBP.y[1], add.u2) annotation (Line(points={{-39,
                    -10},{-39,-10},{14,-10},{14,34},{18,34}}, color={0,0,127}));
            connect(add.y, valveBP_lim.u) annotation (Line(points={{41,40},{54,
                    40}},         color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u) annotation (Line(points={{77,40},
                    {96,40}},                 color={0,0,127}));
            connect(realExpression.y, T_FW_SP.u)
              annotation (Line(points={{-179,52},{-162,52}}, color={0,0,127}));
            connect(T_FW_SP.y, PI_valveBP.SP) annotation (Line(points={{-139,52},
                    {-139,52},{-76,52}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_BP

controller")}));
          end control_wBP_hotStart;

          model control_wBP_hotStart_FF "Model of the w_BP controller"

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            parameter Integer n "Number of elements fro optimization vector";
            parameter Modelica.SIunits.Time time_high[n] = time_high
              "Time vector";
            parameter Real thetaBP_vec[n] "HPH2 bypass valve position vector";

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-20}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              k=actuatorGain_valveBP,
              T=Ta_valveBP,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,20},{140,60}})));
            IndustrialControlSystems.Controllers.PI PI_valveBP(
              AntiWindup=true,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{-10,36},{10,56}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,30},{40,50}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveBP_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            Graphics.Label_input valveBP_PV
              annotation (Placement(transformation(extent={{-122,44},{-90,32}})));
            Graphics.Label_output valveBP_CS
              annotation (Placement(transformation(extent={{156,34},{188,46}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_thetaBP(table=[time_high,thetaBP_vec])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{56,30},{76,50}})));
            Auxiliaries.Components.Ramp_smooth T_FW_SP(
              height=-40,
              duration=100,
              offset=558.15,
              sigType=2,
              startTime=5160)
                           annotation (Placement(transformation(extent={{-160,42},
                      {-140,62}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-200,-10},{-180,10}})));
          equation
            connect(add.u1, product.y) annotation (Line(points={{18,46},{18,46},
                    {11,46}}, color={0,0,127}));
            connect(product.u1, PI_valveBP.CS) annotation (Line(points={{-12,52},
                    {-30,52},{-30,40},{-42,40}},
                                   color={0,0,127}));
            connect(TS_valveBP_bool, PI_valveBP.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveBP_TS.y, PI_valveBP.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{140,-20},{144,-20},{144,18},{142,18},{142,40}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PI_valveBP.PV) annotation (Line(
                points={{140,-20},{178,-20},{178,-134},{-84,-134},{-84,36},{-78,36},{-78,38},
                    {-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(add.y, valveBP_lim.u) annotation (Line(points={{41,40},{54,
                    40}},         color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u) annotation (Line(points={{77,40},
                    {96,40}},                 color={0,0,127}));
            connect(realExpression.y, T_FW_SP.u)
              annotation (Line(points={{-179,0},{-170,0},{-170,52},{-162,52}},
                                                             color={0,0,127}));
            connect(T_FW_SP.y, PI_valveBP.SP) annotation (Line(points={{-139,52},
                    {-139,52},{-76,52}}, color={0,0,127}));
            connect(realExpression.y, table_thetaBP.u) annotation (Line(points={{-179,0},{
                    -170,0},{-170,-10},{-62,-10}}, color={0,0,127}));
            connect(table_thetaBP.y, add.u2) annotation (Line(points={{-39,-10},{-16,-10},
                    {14,-10},{14,34},{18,34}}, color={0,0,127}));
            connect(table_thetaBP.y, product.u2) annotation (Line(points={{-39,-10},{-20,-10},
                    {-20,40},{-12,40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_BP

controller")}));
          end control_wBP_hotStart_FF;

          model control_wSEP_hotStart "Model of the w_SEP controller"

            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration";

            //-- pumpSEP --
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-212,-90},{-172,-50}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={128,-132}),
                                    iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-92,100})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={124,-70})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-132,130},{-112,150}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_SEP(                                                            table=[4,
                  55.97; 20,55.97; 30,85.48; 40,104.3; 50,79.95; 60,0; 70,0; 80,
                  0; 90,0; 100,0], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-92,40},{-72,60}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpSEP_bool annotation (Placement(
                  transformation(extent={{-32,120},{-72,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Logical.Switch switch_SEP
              annotation (Placement(transformation(extent={{42,-80},{62,-60}})));
            Modelica.Blocks.Logical.LessEqualThreshold    greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-92,-80},{-72,-60}})));
            Modelica.Blocks.Math.Product product2 annotation (Placement(
                  transformation(extent={{-58,96},{-38,116}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{-22,90},{-2,110}})));
            Graphics.Label_input pumpSEP_PV
              annotation (Placement(transformation(extent={{-166,104},{-126,92}})));
            Graphics.Label_output pumpSEP_CS
              annotation (Placement(transformation(extent={{164,-76},{202,-64}})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,-120},{28,-100}})));
            Modelica.Blocks.Nonlinear.Limiter pumpSEP_lim(uMax=120, uMin=0)
              annotation (Placement(transformation(extent={{72,-80},{92,-60}})));
            Modelica.Blocks.Math.Division division
              annotation (Placement(transformation(extent={{-28,-26},{-8,-6}})));
            Modelica.Blocks.Math.Product product1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={18,-10})));
            Modelica.Blocks.Sources.Constant const1(k=3.75)
              annotation (Placement(transformation(extent={{-62,-40},{-42,-20}})));
            Modelica.Blocks.Math.Add add1(k1=-1)
              annotation (Placement(transformation(extent={{-62,-14},{-42,6}})));
            Modelica.Blocks.Sources.Constant const2(k=0.25) annotation (
                Placement(transformation(extent={{-92,10},{-72,30}})));
            Graphics.Label_input pumpFW_PV_low annotation (Placement(
                  transformation(extent={{-132,-4},{-86,-16}})));
            Auxiliaries.Components.Ramp_smooth T_FW_SP(
              height=-40,
              duration=100,
              offset=558.15,
              sigType=2,
              startTime=5160)
                           annotation (Placement(transformation(extent={{-160,
                      110},{-140,130}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-200,110},{-180,130}})));
          equation
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{128,-132},{128,-110},{168,-110},{168,-82},{146,-82},{
                    146,-70}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{128,-132},{128,-174},{-206,-174},{-206,-54},{-140,-54},
                    {-140,-40},{-138,-40},{-138,18},{-114,18},{-114,96},{-112,
                    96},{-112,98},{-108,98}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpSEP_TS.y, PID_pumpSEP.TR)
              annotation (Line(points={{-111,140},{-92,140},{-92,116}},
                                                                    color={0,0,127}));
            connect(TS_pumpSEP_bool, PID_pumpSEP.TS)
              annotation (Line(points={{-52,140},{-52,140},{-84,140},{-84,138},
                    {-84,116}},                                     color={255,0,255}));

            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-192,-70},{-192,-70},{-94,-70}},
                                                                   color={0,0,127}));
            connect(load, table_w_SEP.u[1]) annotation (Line(points={{-192,-70},
                    {-152,-70},{-152,50},{-94,50}},
                                   color={0,0,127}));
            connect(table_w_SEP.y[1], product2.u2) annotation (Line(points={{
                    -71,50},{-64,50},{-64,100},{-60,100}}, color={0,0,127}));
            connect(PID_pumpSEP.CS, product2.u1) annotation (Line(points={{-74,
                    100},{-68,100},{-68,112},{-60,112}}, color={0,0,127}));
            connect(product2.y, add2.u1)
              annotation (Line(points={{-37,106},{-24,106}}, color={0,0,127}));
            connect(table_w_SEP.y[1], add2.u2) annotation (Line(points={{-71,50},
                    {-32,50},{-32,94},{-24,94}}, color={0,0,127}));
            connect(switch_SEP.y, pumpSEP_lim.u) annotation (Line(points={{63,-70},
                    {64,-70},{66,-70},{70,-70}},
                                      color={0,0,127}));
            connect(pumpSEP_lim.y, pumpSEP_dynamic.u)
              annotation (Line(points={{93,-70},{94,-70},{96,-70},{100,-70}},
                                                        color={0,0,127}));
            connect(const.y, switch_SEP.u3) annotation (Line(points={{29,-110},
                    {29,-110},{32,-110},{32,-78},{40,-78}},              color=
                    {0,0,127}));
            connect(division.y, product1.u2) annotation (Line(points={{-7,-16},
                    {6,-16}},         color={0,0,127}));
            connect(add2.y, product1.u1) annotation (Line(points={{-1,100},{2,
                    100},{2,-4},{6,-4}}, color={0,0,127}));
            connect(const1.y, division.u2)
              annotation (Line(points={{-41,-30},{-36,-30},{-36,-22},{-30,-22}},
                                                          color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_SEP.u2) annotation (Line(
                  points={{-71,-70},{-44,-70},{-16,-70},{40,-70}},
                                                  color={255,0,255}));
            connect(const2.y, add1.u1) annotation (Line(points={{-71,20},{-68,
                    20},{-68,2},{-64,2}},         color={0,0,127}));
            connect(add1.y, division.u1) annotation (Line(points={{-41,-4},{-40,
                    -4},{-36,-4},{-36,-10},{-30,-10}},
                                          color={0,0,127}));
            connect(product1.y, switch_SEP.u1) annotation (Line(points={{29,-10},
                    {32,-10},{32,-62},{40,-62}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, add1.u2) annotation (Line(
                points={{128,-132},{128,-132},{128,-174},{-206,-174},{-206,-54},
                    {-126,-54},{-126,-40},{-64,-40},{-64,-10}},
                thickness=0.5,
                color={255,255,255}));
            connect(realExpression.y, T_FW_SP.u) annotation (Line(points={{-179,
                    120},{-162,120}}, color={0,0,127}));
            connect(T_FW_SP.y, PID_pumpSEP.SP) annotation (Line(points={{-139,
                    120},{-128,120},{-128,112},{-108,112}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_SEP

controller")}));
          end control_wSEP_hotStart;

          model control_valveSEP_hotStart
            "Model of the controlled separator drain valve"

            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={160,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveSEP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSEP,
              T=Ta_valveSEP)
                   annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={100,0})));
            Modelica.Blocks.Logical.Switch switch_IO annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={30,0})));
            Modelica.Blocks.Interfaces.BooleanInput useValveSEP annotation (
                Placement(transformation(extent={{-100,10},{-60,50}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Sources.Constant const2(k=0)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,-30})));
            Graphics.Label_output valveSEP_CS
              annotation (Placement(transformation(extent={{142,-6},{180,6}})));
            IndustrialControlSystems.Controllers.PI PI_valveSEP(
              AntiWindup=true,
              CSmin=0,
              CSmax=1,
              CS_start=0,
              useTS=false,
              Kp=-50,
              Ti=2) annotation (Placement(transformation(extent={{-60,60},{-20,
                      100}})));
            Modelica.Blocks.Sources.Constant   T_FW_SP(k=l_min)
                           annotation (Placement(transformation(extent={{-140,82},
                      {-120,102}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-180,-40},{-140,0}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=load_min)
              annotation (Placement(transformation(extent={{-80,-30},{-60,-10}})));
            Modelica.Blocks.Logical.And and1
              annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
          equation

            connect(signalBus.valveSEP_CS, valveSEP_dynamic.y) annotation (Line(
                points={{160,-60},{126,-60},{126,-10},{124,-10},{124,0},{122,0}},
                color={255,255,255},
                thickness=0.5));
            connect(const2.y, switch_IO.u3) annotation (Line(points={{1,-30},{
                    10,-30},{10,-8},{18,-8}},
                                        color={0,0,127}));
            connect(switch_IO.y, valveSEP_dynamic.u) annotation (Line(points={{
                    41,0},{58,0},{76,0}}, color={0,0,127}));
            connect(T_FW_SP.y, PI_valveSEP.SP) annotation (Line(points={{-119,
                    92},{-88,92},{-56,92}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, PI_valveSEP.PV) annotation (Line(
                points={{160,-60},{160,-60},{-174,-60},{-174,78},{-56,78}},
                color={255,204,51},
                thickness=0.5));
            connect(PI_valveSEP.CS, switch_IO.u1) annotation (Line(points={{-22,
                    80},{10,80},{10,8},{18,8}}, color={0,0,127}));
            connect(load, greaterThreshold.u) annotation (Line(points={{-160,
                    -20},{-82,-20},{-82,-20}}, color={0,0,127}));
            connect(greaterThreshold.y, and1.u2) annotation (Line(points={{-59,
                    -20},{-50,-20},{-50,-8},{-42,-8}}, color={255,0,255}));
            connect(useValveSEP, and1.u1) annotation (Line(points={{-80,30},{
                    -50,30},{-50,0},{-42,0}}, color={255,0,255}));
            connect(and1.y, switch_IO.u2) annotation (Line(points={{-19,0},{18,
                    0},{18,0}}, color={255,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valve_SEP

controller")}));
          end control_valveSEP_hotStart;
        end SingleControllers;

        package PowerPressureFWcontrollers
          "Package containing power/pressure/FW control schemes"

          model fullyDecentralized
            "Control schemes with fully decentralized control logic"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"
                                   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              table_Yt_low(table=[20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6;
                    50,4.99271e-6; 60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6;
                    90,5.0123e-6; 100,4.98849e-6]))
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_PI control_wFW_high_PI(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_PI.dec_out, gamma_FW_MS.u) annotation (Line(points={{
                    -112,111.5},{-112,117.75},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_PI.dec_in) annotation (Line(points={{-148,
                    151},{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_PI.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{61,-260},{98,-260}}, color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_PI.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_PI.load) annotation (Line(points={{-330,0},{-260,
                    0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,220},{
                    -163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_PI.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,80},{
                    -163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-80},{
                    -163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-220},
                    {-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_PI.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end fullyDecentralized;

          model staticDecoupled
            "Control schemes with a static decoupler between molten salt and water mass flow rate"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"
                                   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_PI control_wFW_high_PI(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_PI.dec_out, gamma_FW_MS.u) annotation (Line(points={{
                    -112,111.5},{-112,117.75},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_PI.dec_in) annotation (Line(points={{-148,
                    151},{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_PI.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{61,-260},{98,-260}}, color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_PI.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_PI.load) annotation (Line(points={{-330,0},{-260,
                    0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,220},{
                    -163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_PI.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,80},{
                    -163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-80},{
                    -163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-220},
                    {-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_PI.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled;

          model staticDecoupled_4th
            "Control schemes with a static decoupler between molten salt and water mass flow rate and a 4th order controller on wFW"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_4th control_wFW_high_4th(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              A=A,
              B=B,
              C=C,
              D=D) annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-84,-14},{-56,14}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{36,314},{64,286}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{36,-14},{64,14}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{38,-274},{64,-248}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,
                    340},{0,340},{0,311.2},{33.2,311.2}},
                                               color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,
                    220},{-50,220},{0,220},{0,288.8},{33.2,288.8}},
                                                         color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{65.4,300},{65.4,300},{118,300}},
                                                                     color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_4th.dec_out, gamma_FW_MS.u) annotation (Line(points={
                    {-112,111.5},{-112,111.5},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_4th.dec_in)
              annotation (Line(points={{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{65.4,1.77636e-015},{90,0},{118,0}},
                                                        color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_4th.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-54.6,
                    1.77636e-015},{-40,1.77636e-015},{-40,300},{33.2,300}},
                                                 color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-54.6,1.77636e-015},{33.2,1.77636e-015}},
                                                        color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{65.3,-261},{80,-261},{80,-260},{98,-260}},
                                                             color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_4th.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,11.2},{33.2,11.2}},
                                              color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,
                    -80},{0,-80},{0,-11.2},{33.2,-11.2}},
                                             color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,
                    -220},{-50,-220},{0,-220},{0,-250.6},{35.4,-250.6}},
                                                             color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,
                    -340},{-48,-340},{0,-340},{0,-271.4},{35.4,-271.4}},
                                                             color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-54.6,
                    1.77636e-015},{-40,1.77636e-015},{-40,-261},{35.4,-261}},
                                                   color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{65.3,
                    -261},{80,-261},{80,-170},{-115,-170},{-115,-187}},
                                                              color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{65.3,
                    -261},{80,-261},{80,-290},{-115,-290},{-115,-307}},
                                                              color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-228,0},{-228,1.77636e-015},{
                    -86.8,1.77636e-015}},                 color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,361},{-163,361}},
                                            color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,241},{-163,241}},
                                            color={0,0,127}));
            connect(load, control_wFW_high_4th.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,59},{-163,59}},
                                             color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-62},{-163,-62}},
                                            color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-199},{-163,-199}},
                                              color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-319},{-163,-319}},
                                              color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-250,-400},{-250,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-34},{320,-34},{320,-400},{
                    -250,-400},{-250,220},{-163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_4th.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-250,-400},{-250,80},{
                    -163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-26},{320,-26},{320,-400},{
                    -250,-400},{-250,-80},{-163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-118},{320,-118},{320,-400},{
                    -250,-400},{-250,-220},{-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled_4th;

          model staticDecoupled_10th
            "Control schemes with a static decoupler between molten salt and water mass flow rate and a 10th order controller on wFW"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_10th control_wFW_high_10th(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              A=A,
              B=B,
              C=C,
              D=D) annotation (Placement(transformation(extent={{-160,110},{-100,
                      50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_10th.dec_out, gamma_FW_MS.u) annotation (
                Line(points={{-112,111.5},{-112,111.5},{-112,128}}, color={0,0,
                    127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_10th.dec_in) annotation (
                Line(points={{-148,151},{-148,132},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_10th.TS) annotation (Line(
                  points={{141,0},{160,0},{160,30},{-115,30},{-115,47}}, color=
                    {0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{61,-260},{98,-260}}, color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_10th.CS, switch_FW.u1) annotation (Line(
                  points={{-98.5,80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_10th.load) annotation (Line(points={
                    {-330,0},{-260,0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,220},{
                    -163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_10th.PV)
              annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,80},{
                    -163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-80},{
                    -163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-220},
                    {-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_10th.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={
                    255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled_10th;

          model startUpOptim_FF
            "Control schemes with a FF signal on MS and FW (@high load) and other loops closed"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Integer n "Number of elements fro optimization vector";
            parameter Modelica.SIunits.Time time_vec[n] = time_vec
              "Time vector";
            parameter Modelica.SIunits.Time time_high[n]
              "Time vector for FW signal";

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.MassFlowRate wMS_vec[n]
              "MS mass flow vector";

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.MassFlowRate wFW_vec[n]
              "FW mass flow vector";

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-84,-14},{-56,14}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=700)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{36,-14},{64,14}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=5)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{38,-274},{64,-248}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-330,140},{-310,160}})));
            Auxiliaries.Components.Spline.SplineFunction table_wMS(table=[time_vec,wMS_vec],n=n)
              annotation (Placement(transformation(extent={{-200,296},{-180,316}})));
            Auxiliaries.Components.Spline.SplineFunction table_wFW(                         n=n, table=[
                  time_high,wFW_vec])
              annotation (Placement(transformation(extent={{-200,140},{-180,160}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
                  40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
                  100,171e5])
              annotation (Placement(transformation(extent={{-160,-270},{-140,-250}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,17.67; 30,26.99;
                  40,36.63; 50,46.95; 60,57.44; 70,66.02; 80,74.71; 90,83.33; 100,91.3])
                                               annotation (Placement(
                  transformation(extent={{-160,-230},{-140,-210}})));
            Modelica.Blocks.Math.Division division1 annotation (Placement(
                  transformation(extent={{-120,-250},{-100,-230}})));
            Modelica.Blocks.Sources.Ramp ramp(
              height=-61.9,
              duration=2000,
              offset=61.9,
              startTime=100)
              annotation (Placement(transformation(extent={{-200,242},{-180,262}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-120,290},{-100,310}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW1(table=[20,5.03762657899642e-06;
                  30,5.03762657899642e-06; 40,5.03762657899642e-06; 50,5.03762657899642e-06;
                  60,4.98310009788838e-06; 70,4.98310009788838e-06; 80,5.03762657899642e-06;
                  90,5.04553281643894e-06; 100,5.04553281643894e-06])
                                               annotation (Placement(
                  transformation(extent={{-82,-210},{-62,-190}})));
          equation
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{65.4,1.77636e-015},{90,0},{118,0}},
                                                        color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-54.6,1.77636e-015},{33.2,1.77636e-015}},
                                                        color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{65.3,-261},{80,-261},{80,-260},{98,-260}},
                                                             color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,
                    -80},{0,-80},{0,-11.2},{33.2,-11.2}},
                                             color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,
                    -340},{-48,-340},{0,-340},{0,-271.4},{35.4,-271.4}},
                                                             color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-54.6,
                    1.77636e-015},{-30,1.77636e-015},{-30,-261},{35.4,-261}},
                                                   color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{65.3,
                    -261},{80,-261},{80,-290},{-115,-290},{-115,-307}},
                                                              color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-228,0},{-228,1.77636e-015},{
                    -86.8,1.77636e-015}},                 color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-62},{-163,-62}},
                                            color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-319},{-163,-319}},
                                              color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-26},{320,-400},{-250,-400},{-250,-80},{-163,
                    -80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            connect(realExpression.y, table_wMS.u) annotation (Line(points={{-309,150},{-309,
                    150},{-280,150},{-280,306},{-202,306}}, color={0,0,127}));
            connect(realExpression.y, table_wFW.u) annotation (Line(points={{-309,150},{-300,
                    150},{-202,150}}, color={0,0,127}));
            connect(valveSH_RH_sourceP.y[1],division1. u2) annotation (Line(
                  points={{-139,-260},{-131,-260},{-131,-246},{-122,-246}},
                                                                    color={0,0,
                    127}));
            connect(valveSH_RH_sourceW.y[1],division1. u1) annotation (Line(
                  points={{-139,-220},{-131,-220},{-131,-234},{-122,-234}},
                                                                    color={0,0,
                    127}));
            connect(load,valveSH_RH_sourceW. u[1]) annotation (Line(points={{-330,0},{-280,
                    0},{-280,-148},{-280,-228},{-220,-228},{-220,-220},{-162,-220}},
                                            color={0,0,127}));
            connect(load,valveSH_RH_sourceP. u[1]) annotation (Line(points={{-330,0},{-280,
                    0},{-280,-228},{-220,-228},{-220,-260},{-162,-260}},
                                color={0,0,127}));
            connect(table_wFW.y, switch_FW.u1) annotation (Line(points={{-179,150},{-98,150},
                    {0,150},{0,11.2},{33.2,11.2}}, color={0,0,127}));
            connect(ramp.y, add.u2) annotation (Line(points={{-179,252},{-166,252},{-148,252},
                    {-148,294},{-122,294}}, color={0,0,127}));
            connect(table_wMS.y, add.u1) annotation (Line(points={{-179,306},{-150,306},{-122,
                    306}}, color={0,0,127}));
            connect(add.y, pumpMS_lim.u)
              annotation (Line(points={{-99,300},{118,300},{118,300}}, color={0,0,127}));
            connect(load, valveSH_RH_sourceW1.u[1]) annotation (Line(points={{-330,0},{-306,
                    0},{-280,0},{-280,-200},{-84,-200}}, color={0,0,127}));
            connect(valveSH_RH_sourceW1.y[1], switch_Yt.u1) annotation (Line(points={{-61,
                    -200},{0,-200},{0,-250.6},{35.4,-250.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end startUpOptim_FF;
          annotation ();
        end PowerPressureFWcontrollers;

        package LinearizationSchemes
          "Package containing the control schemes for linearization"

          model plant_controller_HPpart_lin_highLoad
            "Model of the HP plant control system"

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp_TS
              "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
              "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW,
              Td=Td_pumpFW,
              N=Nd_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanStep booleanStep2(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep6(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-190})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                      -150},{-120,-130}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-180,-144},{-160,-124}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={190,-140})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{150,50},{130,70}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                  transformation(extent={{-120,-120},{-160,-80}}),
                  iconTransformation(extent={{-440,-100},{-400,-60}})));
            Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                  transformation(extent={{100,260},{140,300}}),iconTransformation(
                    extent={{-440,220},{-400,260}})));
            Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                  transformation(extent={{100,80},{140,120}}),  iconTransformation(
                    extent={{-440,60},{-400,100}})));
            Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                     {{-220,-138},{-200,-118}})));
            Modelica.Blocks.Math.Add add10
              annotation (Placement(transformation(extent={{180,236},{160,256}})));
            Modelica.Blocks.Math.Add add3
              annotation (Placement(transformation(extent={{210,56},{190,76}})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{180,50},{160,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-156,50},
                      {-136,70}})));
            Modelica.Blocks.Math.Add add11
              annotation (Placement(transformation(extent={{-222,62},{-202,82}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                  transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                    extent={{-440,-260},{-400,-220}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={380,150}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep1(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,0;
                  20,0; 30,0; 40,0; 50,0; 60,0.01; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-260,-200},{-240,-180}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,244},{340,264}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,50},{-100,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{-112,-150},{-92,-130}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=1)
              annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,50},{100,70}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{-188,56},{-168,76}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(
                                                        k=0)
              annotation (Placement(transformation(extent={{-60,230},{-40,250}})));
            Modelica.Blocks.Sources.Constant pumpSEP_CS(k=0) annotation (
                Placement(transformation(extent={{-60,160},{-40,180}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(table_P.u[1], LOAD2.y)
              annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1])
              annotation (Line(points={{296,72},{296,72},{339,72}},
                                                           color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                                 color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                    240}},          color={0,0,127}));
            connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                    -128},{-182,-128}}, color={0,0,127}));
            connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                    -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
            connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,-100},{-230,
                    -100},{-230,-122},{-222,-122}},      color={0,0,127}));
            connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                    200,252},{182,252}}, color={0,0,127}));
            connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                    240},{182,240}},           color={0,0,127}));
            connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                    {220,72},{212,72}},          color={0,0,127}));
            connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                    60},{212,60}},                   color={0,0,127}));
            connect(add4.u1, add10.y)
              annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{152,60},{152,60},{159,60}},
                                                           color={0,0,127}));
            connect(add5.u1, add3.y) annotation (Line(points={{182,66},{189,66}},
                                   color={0,0,127}));
            connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-262,-140},{-254,
                    -140},{-254,-116},{-280,-116},{-280,-124}},             color={
                    0,0,127}));
            connect(PID_valveTURB.CS, PID_valveTURB.TR) annotation (Line(points={{
                    262,60},{252,60},{252,84},{280,84},{280,76}}, color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                    -128},{-296,-128}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{
                    -230,100},{-230,78},{-224,78}},
                                         color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                    238},{296,238}}, color={0,0,127}));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(table_w_HPH.u[1], LOAD5.y)
              annotation (Line(points={{162,-140},{179,-140}}, color={0,0,127}));
            connect(table_w_MS.u[1], LOAD7.y) annotation (Line(points={{242,190},
                    {242,190},{259,190}}, color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},
                    {140,190},{140,234},{122,234}}, color={0,0,127}));
            connect(booleanStep1.y, PID_valveBP.TS) annotation (Line(points={{
                    -261,100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(PID_valveBP.CS, PID_valveBP.TR) annotation (Line(points={{
                    -262,60},{-254,60},{-254,82},{-280,82},{-280,76}}, color={0,0,
                    127}));
            connect(LOAD1.y, table_T_FW.u[1])
              annotation (Line(points={{-379,72},{-362,72}}, color={0,0,127}));
            connect(table_T_FW.y[1], PID_valveBP.SP)
              annotation (Line(points={{-339,72},{-296,72}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,
                    10},{-270.5,10},{-262,10}}, color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-279,-190},
                    {-270,-190},{-262,-190}}, color={0,0,127}));
            connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},
                    {-239,10},{-162,10},{-162,54},{-158,54}},     color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                    {-196,-190},{-150,-190},{-150,-146},{-142,-146}}, color={0,0,
                    127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,
                    -190},{-216,-190},{-190,-190},{-190,-140},{-182,-140}}, color=
                   {0,0,127}));
            connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{242,10},{
                    259,10}},          color={0,0,127}));
            connect(table_Yt.y[1], add5.u2) annotation (Line(points={{219,10},{
                    219,10},{188,10},{188,54},{182,54}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,254},
                    {370,254},{370,252},{379,252}},
                                          color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{296,252},
                    {318,252},{318,254},{339,254}},color={0,0,127}));
            connect(add8.y, valveBP_lim.u)
              annotation (Line(points={{-135,60},{-122,60}}, color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u)
              annotation (Line(points={{-99,60},{-84,60}}, color={0,0,127}));
            connect(pumpFW_dynamic.u, pumpFW_lim.y) annotation (Line(points={{-84,
                    -140},{-88,-140},{-91,-140}}, color={0,0,127}));
            connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-119,-140},{
                    -116.5,-140},{-114,-140}}, color={0,0,127}));
            connect(pumpHPH_dynamic.u, pumpHPH_lim.y)
              annotation (Line(points={{84,-140},{99,-140}}, color={0,0,127}));
            connect(pumpHPH_lim.u, table_w_HPH.y[1])
              annotation (Line(points={{122,-140},{139,-140}}, color={0,0,127}));
            connect(valveTURB_dynamic.u, valveTURB_lim.y)
              annotation (Line(points={{84,60},{99,60}}, color={0,0,127}));
            connect(valveTURB_lim.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{122,60},{129,60}}, color={0,0,127}));
            connect(PID_valveBP.CS, add11.u2) annotation (Line(points={{-262,60},
                    {-244,60},{-244,66},{-224,66}}, color={0,0,127}));
            connect(add11.y, product1.u1) annotation (Line(points={{-201,72},{
                    -190,72},{-190,72}}, color={0,0,127}));
            connect(table_thetaBP.y[1], product1.u2) annotation (Line(points={{
                    -239,10},{-196,10},{-196,60},{-190,60}}, color={0,0,127}));
            connect(product1.y, add8.u1)
              annotation (Line(points={{-167,66},{-158,66}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,240},{-39,240}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, pumpSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,170},{-39,170}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_lin_highLoad;

          model plant_controller_HPpart_lin_lowLoad
            "Model of the HP plant control system"

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_TS
              "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Modelica.SIunits.AbsolutePressure p_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point"   annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
            Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
                Placement(transformation(extent={{400,200},{380,220}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanStep booleanStep2(
                startTime=t_start_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
              annotation (Placement(transformation(extent={{400,20},{380,40}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep6(
                startTime=t_start_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{130,50},{110,70}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                  transformation(extent={{-120,-120},{-160,-80}}),
                  iconTransformation(extent={{-440,-100},{-400,-60}})));
            Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                  transformation(extent={{100,260},{140,300}}),iconTransformation(
                    extent={{-440,220},{-400,260}})));
            Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                  transformation(extent={{100,80},{140,120}}),  iconTransformation(
                    extent={{-440,60},{-400,100}})));
            Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent={{-200,
                      -150},{-180,-130}})));
            Modelica.Blocks.Math.Add add10
              annotation (Placement(transformation(extent={{180,236},{160,256}})));
            Modelica.Blocks.Math.Add add3
              annotation (Placement(transformation(extent={{210,56},{190,76}})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{170,50},{150,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={380,150}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,268},{250,288}})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=useTS_pumpSEP,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-280,60})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              y_start=79)                                      annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,60})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Product product4
                                                 annotation (Placement(transformation(
                    extent={{-180,56},{-160,76}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{-140,50},
                      {-120,70}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Math.Add add8
              annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
            Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                  transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                    extent={{-440,-260},{-400,-220}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep3(startTime=t_start_TS,
                startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Constant valveBP_CS(k=0)
              annotation (Placement(transformation(extent={{100,-150},{80,-130}})));
            Modelica.Blocks.Sources.Constant pump_HPH_CS(k=0.1)
              annotation (Placement(transformation(extent={{100,-192},{80,-172}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS1(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(
                                                        k=0)
              annotation (Placement(transformation(extent={{100,-110},{80,-90}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_SEP(                                                            table=[4,
                  55.97; 20,55.97; 30,85.48; 40,104.3; 50,79.95; 60,0; 70,0; 80,
                  0; 90,0; 100,0], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(table_P.u[1], LOAD2.y)
              annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1])
              annotation (Line(points={{296,72},{296,72},{339,72}},
                                                           color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                    240}},          color={0,0,127}));
            connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{-220,-140},
                    {-220,-146},{-218,-146},{-202,-146}},color={0,0,127}));
            connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-140,-100},{-220,
                    -100},{-220,-134},{-202,-134}},      color={0,0,127}));
            connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                    200,252},{182,252}}, color={0,0,127}));
            connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                    240},{182,240}},           color={0,0,127}));
            connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
            connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                    {220,72},{212,72}},          color={0,0,127}));
            connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                    60},{212,60}},                   color={0,0,127}));
            connect(add4.u1, add10.y)
              annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
            connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                    66},{189,66}}, color={0,0,127}));
            connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-262,-140},{-254,
                    -140},{-254,-116},{-280,-116},{-280,-124}},             color={
                    0,0,127}));
            connect(l_SP.y, PID_pumpFW.SP)
              annotation (Line(points={{-339,-128},{-296,-128}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));

            connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                    238},{296,238}}, color={0,0,127}));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,278},
                    {272,278},{272,256}},
                                     color={255,0,255}));
            connect(product4.y,add2. u1) annotation (Line(points={{-159,66},{-142,66}},
                                color={0,0,127}));
            connect(add2.y,pumpSEP_dynamic. u) annotation (Line(points={{-119,60},{-101.5,
                    60},{-84,60}},        color={0,0,127}));
            connect(add8.y,product4. u1) annotation (Line(points={{-199,72},{-192,72},{-182,
                    72}},       color={0,0,127}));
            connect(du_w_SEP,add8. u1) annotation (Line(points={{-140,100},{-184,100},{-230,
                    100},{-230,78},{-222,78}},       color={0,0,127}));
            connect(PID_pumpSEP.CS,add8. u2) annotation (Line(points={{-262,60},{-230,60},
                    {-230,66},{-222,66}},     color={0,0,127}));
            connect(PID_pumpSEP.CS,PID_pumpSEP. TR) annotation (Line(points={{-262,60},{-256,
                    60},{-252,60},{-252,84},{-280,84},{-280,76}},       color={0,0,
                    127}));
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{0,60},{-20,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_CS, valveBP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{79,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_CS, pump_HPH_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,-182},{79,-182}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-222},{0,-220},{-320,-220},{-320,-142},{
                    -296,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(add9.y, pumpFW_dynamic.u) annotation (Line(points={{-179,
                    -140},{-84,-140}},
                                 color={0,0,127}));
            connect(PID_valveTURB.CS, PID_valveTURB.TR) annotation (Line(points={{
                    262,60},{258,60},{254,60},{254,82},{280,82},{280,76}}, color={0,
                    0,127}));
            connect(table_w_MS1.u[1], LOAD7.y) annotation (Line(points={{242,190},
                    {259,190}},          color={0,0,127}));
            connect(table_w_MS1.y[1], add4.u2) annotation (Line(points={{219,190},{
                    180,190},{140,190},{140,234},{122,234}}, color={0,0,127}));
            connect(T_MS_SP.y, PID_pumpSEP.SP) annotation (Line(points={{-339,72},
                    {-318,72},{-296,72}},           color={0,0,127}));
            connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{242,10},{
                    259,10},{259,10}}, color={0,0,127}));
            connect(table_Yt.y[1], add5.u2) annotation (Line(points={{219,10},{
                    200,10},{180,10},{180,54},{172,54}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,252},
                    {379,252},{379,252}}, color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{
                    296,252},{318,252},{318,252},{339,252}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,-100},{79,-100}},
                color={255,204,51},
                thickness=0.5));
            connect(LOAD8.y, table_w_SEP.u[1]) annotation (Line(points={{-279,
                    10},{-262,10},{-262,10}}, color={0,0,127}));
            connect(table_w_SEP.y[1], product4.u2) annotation (Line(points={{
                    -239,10},{-190,10},{-190,60},{-182,60}}, color={0,0,127}));
            connect(table_w_SEP.y[1], add2.u2) annotation (Line(points={{-239,
                    10},{-208,10},{-208,12},{-208,10},{-150,10},{-150,54},{-142,
                    54}}, color={0,0,127}));
            connect(booleanStep3.y, PID_pumpSEP.TS) annotation (Line(points={{
                    -261,100},{-272,100},{-272,76}}, color={255,0,255}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_lin_lowLoad;

          model preheaters_dea_controller_lin
            "Model of the feedwater train controller for linearization"

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp_TS
              "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Real step_wFW_height "Height of wFW step";
            parameter Modelica.SIunits.Time step_wFW_start "Step start time";
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpCOND --
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                              annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                              annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND "Minimum value of control signal"  annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND "Maximum value of control signal"  annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));
            parameter Real step_wCOND_height "Height of wFW step";
            parameter Modelica.SIunits.Time step_wCOND_start "Step start time";

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-120})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-20},{40,20}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,100},{40,140}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-250,-150})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-160,
                      -130},{-140,-110}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={190,0})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={170,240})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{200,110},{180,130}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-156,50},
                      {-136,70}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{140,230},{120,250}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{160,-10},{140,10}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep1
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[4,0;
                  20,0; 30,0; 40,0; 50,0; 60,0.01; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-220,-160},{-200,-140}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{160,110},{140,130}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,50},{-100,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{-120,-130},{-100,-110}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=1)
              annotation (Placement(transformation(extent={{120,-10},{100,10}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,110},{100,130}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{-188,56},{-168,76}})));
            Modelica.Blocks.Sources.Constant pumpSEP_CS(k=0) annotation (
                Placement(transformation(extent={{60,-130},{40,-110}})));
            Modelica.Blocks.Sources.Step step_wFW(height=step_wFW_height, startTime=
                  step_wFW_start)
              annotation (Placement(transformation(extent={{-220,-100},{-200,-80}})));
            Modelica.Blocks.Sources.Constant l_SP(k=2.0559)
              annotation (Placement(transformation(extent={{-360,182},{-340,202}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpCOND(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpCOND,
              CSmax=CSmax_pumpCOND,
              CS_start=CSstart_pumpCOND,
              Kp=Kp_pumpCOND,
              Ti=Ti_pumpCOND)
              annotation (Placement(transformation(extent={{-300,160},{-260,200}})));
            Modelica.Blocks.Sources.Constant pumpCOND_TS(
                                                       k=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-320,210},{-300,230}})));
            Modelica.Blocks.Continuous.FirstOrder pumpCOND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpCOND,
              T=Ta_pumpCOND)
              annotation (Placement(transformation(extent={{-80,180},{-40,220}})));
            Modelica.Blocks.Nonlinear.Limiter pumpCOND_lim(uMin=0, uMax=100)
              annotation (Placement(transformation(extent={{-120,190},{-100,210}})));
            Modelica.Blocks.Math.Add3 add2
                                          annotation (Placement(transformation(extent={{-160,
                      190},{-140,210}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep3(
                startValue=TS_start, startTime=t_start_ramp_TS)
              annotation (Placement(transformation(extent={{-240,210},{-260,230}})));
            Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                  transformation(extent={{-240,260},{-200,300}}), iconTransformation(
                    extent={{-440,-20},{-400,20}})));
            Modelica.Blocks.Sources.Step step_wCOND(height=step_wCOND_height, startTime=
                  step_wCOND_start)
              annotation (Placement(transformation(extent={{-220,210},{-200,230}})));
          equation
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-120},{0,0},{38,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,120},{38,120}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-120},{-38,-120}},
                color={255,204,51},
                thickness=0.5));

            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(table_w_HPH.u[1], LOAD5.y)
              annotation (Line(points={{162,0},{179,0}},       color={0,0,127}));
            connect(table_w_MS.u[1], LOAD7.y) annotation (Line(points={{142,240},{142,240},
                    {159,240}},           color={0,0,127}));
            connect(booleanStep1.y, PID_valveBP.TS) annotation (Line(points={{
                    -261,100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(LOAD1.y, table_T_FW.u[1])
              annotation (Line(points={{-379,72},{-362,72}}, color={0,0,127}));
            connect(table_T_FW.y[1], PID_valveBP.SP)
              annotation (Line(points={{-339,72},{-296,72}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,
                    10},{-270.5,10},{-262,10}}, color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-239,-150},{-230,-150},
                    {-222,-150}},             color={0,0,127}));
            connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},
                    {-239,10},{-162,10},{-162,54},{-158,54}},     color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-199,-150},{-199,-150},
                    {-180,-150},{-180,-126},{-162,-126}},             color={0,0,
                    127}));
            connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{162,120},{179,120}},
                                       color={0,0,127}));
            connect(add8.y, valveBP_lim.u)
              annotation (Line(points={{-135,60},{-122,60}}, color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u)
              annotation (Line(points={{-99,60},{-84,60}}, color={0,0,127}));
            connect(pumpFW_dynamic.u, pumpFW_lim.y) annotation (Line(points={{-84,-120},{-99,
                    -120}},                       color={0,0,127}));
            connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-139,-120},{-139,-120},
                    {-122,-120}},              color={0,0,127}));
            connect(pumpHPH_dynamic.u, pumpHPH_lim.y)
              annotation (Line(points={{84,0},{99,0}},       color={0,0,127}));
            connect(pumpHPH_lim.u, table_w_HPH.y[1])
              annotation (Line(points={{122,0},{139,0}},       color={0,0,127}));
            connect(valveTURB_dynamic.u, valveTURB_lim.y)
              annotation (Line(points={{84,120},{99,120}},
                                                         color={0,0,127}));
            connect(table_thetaBP.y[1], product1.u2) annotation (Line(points={{-239,10},{-200,
                    10},{-200,60},{-190,60}},                color={0,0,127}));
            connect(product1.y, add8.u1)
              annotation (Line(points={{-167,66},{-158,66}}, color={0,0,127}));
            connect(signalBus.pumpSEP_CS, pumpSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,-120},{39,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_valveBP.CS, product1.u1) annotation (Line(points={{-262,60},{-208,
                    60},{-208,72},{-190,72}}, color={0,0,127}));
            connect(table_w_MS.y[1], pumpMS_dynamic.u) annotation (Line(points={{119,240},
                    {101.5,240},{84,240}}, color={0,0,127}));
            connect(table_Yt.y[1], valveTURB_lim.u)
              annotation (Line(points={{139,120},{122,120}}, color={0,0,127}));
            connect(step_wFW.y, add1.u1) annotation (Line(points={{-199,-90},{-180,-90},{-180,
                    -114},{-162,-114}}, color={0,0,127}));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                    100},{-280,76}}, color={0,0,127}));
            connect(l_SP.y, PID_pumpCOND.SP)
              annotation (Line(points={{-339,192},{-296,192}}, color={0,0,127}));
            connect(booleanStep3.y, PID_pumpCOND.TS) annotation (Line(points={{-261,220},{
                    -272,220},{-272,196}}, color={255,0,255}));
            connect(PID_pumpCOND.CS, PID_pumpCOND.TR) annotation (Line(points={{-262,180},
                    {-254,180},{-254,204},{-280,204},{-280,196}}, color={0,0,127}));
            connect(du_w_COND, add2.u1) annotation (Line(points={{-220,280},{-220,280},{-180,
                    280},{-180,208},{-162,208}}, color={0,0,127}));
            connect(add2.y, pumpCOND_lim.u) annotation (Line(points={{-139,200},{-122,200},
                    {-122,200}}, color={0,0,127}));
            connect(pumpCOND_lim.y, pumpCOND_dynamic.u)
              annotation (Line(points={{-99,200},{-92,200},{-84,200}}, color={0,0,127}));
            connect(signalBus.pumpCOND_CS, pumpCOND_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,200},{-38,200}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_PV, PID_pumpCOND.PV) annotation (Line(
                points={{0,60},{0,140},{-320,140},{-320,178},{-296,178}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_pumpCOND.CS, add2.u3) annotation (Line(points={{-262,180},{-224,180},
                    {-200,180},{-180,180},{-180,192},{-162,192}}, color={0,0,127}));
            connect(step_wCOND.y, add2.u2) annotation (Line(points={{-199,220},{-190,220},
                    {-190,200},{-162,200}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end preheaters_dea_controller_lin;
        end LinearizationSchemes;

        package PlantControlSchemes "Package containing plant control schemes"

          model plantController_fullyDecentralized
            "Plant controller model with PI/PID controller and fully decentralized control logic"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            PowerPressureFWcontrollers.fullyDecentralized fullyDecentralized(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-36,120},{36,200}})));
            SingleControllers.control_wBP control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,20},{20,60}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-60},{20,-20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},{-60,
                      230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(k=useTS_pumpFW_high)
                                   annotation (Placement(transformation(extent={{60,260},{
                      40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},{60,
                      230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-40,80},{-20,
                      100}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-160},{20,-120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-40,
                      -100},{-20,-80}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-40,-200},{-20,
                      -180}})));
          equation
            connect(fullyDecentralized.signalBus, signalBus) annotation (Line(
                points={{37.98,160},{37.98,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,40},{180,40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,-40},{21,-40},{180,-40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, fullyDecentralized.TS_pumpMS_bool) annotation (Line(points={{-59,220},
                    {-28.8,220},{-28.8,201.818}},      color={255,0,255}));
            connect(TS_w_FW_high.y, fullyDecentralized.TS_pumpFWhigh_bool) annotation (
                Line(points={{39,270},{14.4,270},{14.4,201.818}},
                                                                color={255,0,255}));
            connect(TS_w_FW_low.y, fullyDecentralized.TS_pumpFWlow_bool) annotation (Line(
                  points={{59,220},{28.8,220},{28.8,201.818}},
                                                             color={255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-19,90},
                    {0,90},{0,62}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-200,0},{-166,0},{-160,0},{-160,40},{-22,
                    40}},                                           color={0,0,127}));
            connect(load, fullyDecentralized.load) annotation (Line(points={{-200,0},{-160,
                    0},{-160,160},{-37.8,160}},color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-160,
                    0},{-160,0},{-160,0},{-160,-40},{-22,-40}},
                                                 color={0,0,127}));
            connect(load, control_wSEP.load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -140},{-22,-140}},  color={0,0,127}));
            connect(signalBus, control_wSEP.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-140},{21,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y, control_wSEP.TS_pumpSEP_bool) annotation (Line(points={{-19,-90},
                    {0,-90},{0,-118}},              color={255,0,255}));
            connect(TS_Y_t_high.y, fullyDecentralized.TS_valveTURBhigh_bool) annotation (
                Line(points={{-59,250},{-44,250},{-14.4,250},{-14.4,201.818}},
                                                                           color={255,0,255}));
            connect(TS_Y_t_low.y, fullyDecentralized.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-32,280},{0,280},{0,201.818}},     color={255,0,255}));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-160,0},
                    {-160,-240},{-22,-240}},            color={0,0,127}));
            connect(signalBus, control_valveSEP.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-42},{180,-240},{21,-240}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (Line(points=
                   {{-19,-190},{0,-190},{0,-218}}, color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_fullyDecentralized;

          model plantController_staticDecoupled
            "Plant controller model with PI/PID controller and a static decoupler between wMS e wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            PowerPressureFWcontrollers.staticDecoupled
                                            staticDecoupled(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,20},{20,60}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-60},{20,-20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-40,80},
                      {-20,100}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-160},{20,-120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-40,
                      -100},{-20,-80}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-40,
                      -200},{-20,-180}})));
          equation
            connect(staticDecoupled.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,40},{180,40},{180,-4},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,-40},{22,-40},{22,-40},{22,-40},{180,-40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled.TS_pumpMS_bool) annotation (Line(
                  points={{-59,220},{-32,220},{-32,199.727}},color={255,0,255}));
            connect(TS_w_FW_high.y, staticDecoupled.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-19,90},
                    {0,90},{0,62}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,40},{-22,40}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},
                    {-200,0},{-162,0},{-162,0},{-160,0},{-160,-40},{-22,-40}},
                                                 color={0,0,127}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-140},{-22,-140}},
                                        color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-140},{21,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-19,-90},
                    {0,-90},{0,-118}},              color={255,0,255}));
            connect(TS_Y_t_high.y, staticDecoupled.TS_valveTURBhigh_bool)
              annotation (Line(points={{-59,250},{-16,250},{-16,199.727}},color=
                   {255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled.TS_valveTURBlow_bool)
              annotation (Line(points={{-59,280},{0,280},{0,199.727}},    color=
                   {255,0,255}));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-240},{-22,-240}},   color={0,0,127}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-240},{180,-240},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-19,-190},{0,-190},{0,-218}}, color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_staticDecoupled;

          model plantController_staticDecoupled_4thOrder
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));
            PowerPressureFWcontrollers.staticDecoupled_4th
                                                       staticDecoupled_4th(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              A=A,
              B=B,
              C=C,
              D=D,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,20},{20,60}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-60},{20,-20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-40,80},
                      {-20,100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-160},{20,-120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-40,
                      -100},{-20,-80}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-40,
                      -200},{-20,-180}})));
          equation
            connect(staticDecoupled_4th.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,40},{180,40},{180,6},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,-40},{21,-40},{180,-40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled_4th.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, staticDecoupled_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled_4th.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-19,90},
                    {0,90},{0,62}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,40},{-22,40}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled_4th.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},
                    {-200,0},{-186,0},{-160,0},{-160,-40},{-22,-40}},
                                                 color={0,0,127}));
            connect(TS_Y_t_high.y, staticDecoupled_4th.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled_4th.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-140},{-22,-140}},
                                        color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-140},{21,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-19,-90},
                    {0,-90},{0,-118}},              color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-240},{21,-240},{180,-240},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},
                    {-200,0},{-160,0},{-160,-240},{-22,-240}},   color={0,0,127}));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-19,-190},{0,-190},{0,-218}}, color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_staticDecoupled_4thOrder;

          model plantController_staticDecoupled_4thOrder_hotStart
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));
            PowerPressureFWcontrollers.staticDecoupled_4th
                                                       staticDecoupled_4th(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              A=A,
              B=B,
              C=C,
              D=D,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP_hotStart
                                          control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,20},{20,60}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-60},{20,-20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-40,80},
                      {-20,100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP_hotStart
                                           control_wSEP(
              load_switch=load_switch,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-160},{20,-120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-40,
                      -100},{-20,-80}})));
            SingleControllers.control_valveSEP_hotStart
                                               control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-40,
                      -200},{-20,-180}})));
          equation
            connect(staticDecoupled_4th.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,40},{180,40},{180,6},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,-40},{21,-40},{180,-40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled_4th.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, staticDecoupled_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled_4th.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-19,90},
                    {0,90},{0,62}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,40},{-22,40}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled_4th.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},
                    {-200,0},{-186,0},{-160,0},{-160,-40},{-22,-40}},
                                                 color={0,0,127}));
            connect(TS_Y_t_high.y, staticDecoupled_4th.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled_4th.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-140},{-22,-140}},
                                        color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-140},{21,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-19,-90},
                    {0,-90},{0,-118}},              color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-240},{21,-240},{180,-240},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},
                    {-200,0},{-160,0},{-160,-240},{-22,-240}},   color={0,0,127}));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-19,-190},{0,-190},{0,-218}}, color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_staticDecoupled_4thOrder_hotStart;

          model plantController_staticDecoupled_10thOrder
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 10th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            PowerPressureFWcontrollers.staticDecoupled_10th staticDecoupled_10th(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              A=A,
              B=B,
              C=C,
              D=D,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS,
              TS_pumpFW_high=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,20},{20,60}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-60},{20,-20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-40,80},
                      {-20,100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-160},{20,-120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-40,
                      -100},{-20,-80}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-40,
                      -200},{-20,-180}})));
          equation
            connect(staticDecoupled_10th.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,40},{180,40},{180,30},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,-40},{21,-40},{180,-40},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled_10th.TS_pumpMS_bool) annotation (
               Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,255}));
            connect(TS_w_FW_high.y, staticDecoupled_10th.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled_10th.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-19,90},
                    {0,90},{0,62}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,40},{-22,40}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled_10th.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},          color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,56},{-160,-40},{-22,-40}},
                                                 color={0,0,127}));
            connect(TS_Y_t_high.y, staticDecoupled_10th.TS_valveTURBhigh_bool)
              annotation (Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled_10th.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{0,280},{0,199.727}},    color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-140},{-22,-140}},
                                        color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-140},{21,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-19,-90},
                    {0,-90},{0,-118}},              color={255,0,255}));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,-240},{-22,-240}},   color={0,0,127}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-240},{180,-240},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-19,-190},{0,-190},{0,-218}}, color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_staticDecoupled_10thOrder;

          model plant_controller_HPpart_highLoad
            "Model of the HP plant control system "

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Real DT_SH_sp "Degree of superheating set point"   annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpHPH --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
            parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ti_pumpHPH
              "Controller integral time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmin_pumpHPH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmax_pumpHPH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));
            parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
            parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep2
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
              AntiWindup=true,
              useTS=useTS_pumpHPH,
              CSmin=CSmin_pumpHPH,
              CSmax=CSmax_pumpHPH,
              CS_start=CSstart_pumpHPH,
              Kp=Kp_pumpHPH,
              Ti=Ti_pumpHPH)
              annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep4
              annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
            Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
              annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PI  PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
              annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep6
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                  563.15; 80,563.15; 90,563.15; 100,563.15])
              annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-260,-200},{-240,-180}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-190})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-160,
                      -150},{-140,-130}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-200,-144},{-180,-124}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
            Modelica.Blocks.Math.Add add2
              annotation (Placement(transformation(extent={{146,-150},{126,-130}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{186,-144},{166,-124}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,-192})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 4.1407017192796e-07,0.00999999977648258;
                  8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                  0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                  2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                  0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                  3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                  0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                  3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                  0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                  4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                  0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                  4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                  0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                  4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                  0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                  4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                  0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                  5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                  0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                  5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                  0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                  5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                  0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                  5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                  0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                  5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                  0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                  5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                  0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                  5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                  0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                  5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                  0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                  5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                  0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                  5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                  0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                  5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                  0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                  5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                  0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                  5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                  0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                  5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                  0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                  5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                  0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                  5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                  0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                  5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                  0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                  5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                  0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                  5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                  0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                  5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                  0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                  5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                  0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                  5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                  0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                  5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                  0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                  5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                  0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                  5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                  0.989600002765656; 5.35380604560487e-06,0.999599993228912])
              annotation (Placement(transformation(extent={{150,50},{130,70}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{168,230},{148,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{190,50},{170,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep3
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-180,50},
                      {-160,70}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={360,160}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-390,72})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(k=0)
              annotation (Placement(transformation(extent={{-60,140},{-40,160}})));
            Modelica.Blocks.Sources.Constant pumpSEP_CS(k=0) annotation (
                Placement(transformation(extent={{-60,200},{-40,220}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-122,50},{-102,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{-114,-150},{-94,
                      -130}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=1)
              annotation (Placement(transformation(extent={{118,-150},{98,-130}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{118,50},{98,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(uMax=650, uMin=5)
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                    -100},{272,-124}}, color={255,0,255}));
            connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                    -100},{280,-100},{280,-124}}, color={0,0,127}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_pumpMS.SP, table_P_MEC.y[1])
              annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y)
              annotation (Line(points={{362,252},{368,252},{379,252}},
                                                             color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1])
              annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-179,-134},{-170,-134},{-162,-134}},
                                                                 color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,
                    -190},{-172,-190},{-172,-146},{-162,-146}},
                                                         color={0,0,127}));
            connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                    250,-192},{242,-192}}, color={0,0,127}));
            connect(product1.y, add2.u1) annotation (Line(points={{165,-134},{
                    165,-134},{148,-134}},
                                       color={0,0,127}));
            connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,
                    -192},{157,-192},{157,-146},{148,-146}},
                                                      color={0,0,127}));
            connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                    190},{242,190}}, color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},
                    {179,190},{179,234},{170,234}},
                                               color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,
                    -190},{-239,-190},{-210,-190},{-210,-140},{-202,-140}},
                                                                      color={0,0,127}));
            connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,
                    -192},{198,-192},{198,-140},{188,-140}},
                                                       color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{152,60},{169,60}}, color={0,0,127}));
            connect(table_Yt.u[1], LOAD6.y)
              annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
            connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{192,54},{
                    200,54},{200,10},{219,10}},
                                        color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                    10},{-262,10}}, color={0,0,127}));
            connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                    339,-128},{339,-128}}, color={0,0,127}));
            connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                    {379,-128}}, color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,-128}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},
                    {-239,10},{-192,10},{-192,54},{-182,54}},
                                                        color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                    100},{-280,76}}, color={0,0,127}));
            connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                    100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                    -100},{-280,-124}}, color={0,0,127}));
            connect(valveTURB_TS.y, PID_valveTURB.TR)
              annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
            connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{170,246},
                    {220,246},{220,246},{220,240},{262,240}},
                                                         color={0,0,127}));
            connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},
                    {-262,60},{-198,60},{-198,66},{-182,66}},color={0,0,127}));
            connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,
                    -140},{-244,-140},{-244,-128},{-202,-128}},
                                                          color={0,0,127}));
            connect(product1.u1, PID_pumpHPH.CS) annotation (Line(points={{188,
                    -128},{240,-128},{240,-140},{262,-140}},
                                                       color={0,0,127}));
            connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{192,66},
                    {236,66},{236,60},{262,60}},color={0,0,127}));
            connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                    238},{324,160},{360,160}}, color={0,0,127}));
            connect(table_P.u[1], LOAD2.y)
              annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1])
              annotation (Line(points={{296,72},{339,72}}, color={0,0,127}));
            connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},
                    {-362,72}},           color={0,0,127}));
            connect(table_T_FW.y[1], PID_valveBP.SP) annotation (Line(points={{
                    -339,72},{-318,72},{-296,72}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,150},{-39,150}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
                points={{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, pumpSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,212},{0,210},{-39,210}},
                color={255,204,51},
                thickness=0.5));
            connect(add8.y, valveBP_lim.u) annotation (Line(points={{-159,60},{
                    -141.5,60},{-124,60}}, color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u)
              annotation (Line(points={{-101,60},{-84,60}}, color={0,0,127}));
            connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-139,-140},
                    {-128,-140},{-116,-140}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u) annotation (Line(points={{
                    -93,-140},{-84,-140}}, color={0,0,127}));
            connect(pumpHPH_lim.y, pumpHPH_dynamic.u) annotation (Line(points={
                    {97,-140},{92.5,-140},{84,-140}}, color={0,0,127}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u)
              annotation (Line(points={{129,60},{120,60}}, color={0,0,127}));
            connect(valveTURB_dynamic.u, valveTURB_lim.y)
              annotation (Line(points={{84,60},{97,60}}, color={0,0,127}));
            connect(add4.y, pumpMS_lim.u)
              annotation (Line(points={{147,240},{122,240}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u) annotation (Line(points={{
                    99,240},{91.5,240},{84,240}}, color={0,0,127}));
            connect(pumpHPH_lim.u, add2.y) annotation (Line(points={{120,-140},
                    {125,-140},{125,-140}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller")}));
          end plant_controller_HPpart_highLoad;

          model plant_controller_HPpart_highLoad_wHPHsens
            "Model of the HP plant control system "

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Real DT_SH_sp "Degree of superheating set point"   annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpHPH --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
            parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ti_pumpHPH
              "Controller integral time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Td_pumpHPH
              "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Real Nd_pumpHPH
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmin_pumpHPH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmax_pumpHPH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));
            parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
            parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW,
              Td=Td_pumpFW,
              N=Nd_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep2
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep6
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-260,-200},{-240,-180}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-190})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                      -150},{-120,-130}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-180,-144},{-160,-124}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 4.1407017192796e-07,0.00999999977648258;
                  8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                  0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                  2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                  0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                  3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                  0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                  3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                  0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                  4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                  0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                  4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                  0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                  4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                  0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                  4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                  0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                  5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                  0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                  5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                  0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                  5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                  0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                  5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                  0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                  5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                  0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                  5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                  0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                  5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                  0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                  5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                  0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                  5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                  0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                  5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                  0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                  5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                  0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                  5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                  0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                  5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                  0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                  5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                  0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                  5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                  0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                  5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                  0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                  5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                  0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                  5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                  0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                  5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                  0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                  5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                  0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                  5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                  0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                  5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                  0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                  5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                  0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                  5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                  0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                  5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                  0.989600002765656; 5.35380604560487e-06,0.999599993228912])
              annotation (Placement(transformation(extent={{130,50},{110,70}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{170,50},{150,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep3
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                      {-120,70}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={360,160}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-390,72})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(k=0)
              annotation (Placement(transformation(extent={{-60,160},{-40,180}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-190})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{200,-200},{180,-180}})));
            Modelica.Blocks.Sources.Ramp rampPos(
              offset=0,
              duration=5000,
              height=0.15,
              startTime=5000)
                           annotation (Placement(transformation(extent={{240,
                      -124},{220,-104}})));
            Modelica.Blocks.Sources.Ramp rampNeg(
              duration=10000,
              offset=0,
              height=-1.1,
              startTime=15000)
                           annotation (Placement(transformation(extent={{240,
                      -164},{220,-144}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{200,-144},{180,-124}})));
            Modelica.Blocks.Math.Product product2 annotation (Placement(
                  transformation(extent={{150,-144},{130,-124}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{116,-150},{96,-130}})));
            Modelica.Blocks.Sources.Constant pumpSEP_CS(k=0) annotation (
                Placement(transformation(extent={{-60,200},{-40,220}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_pumpMS.SP, table_P_MEC.y[1])
              annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y)
              annotation (Line(points={{362,252},{368,252},{379,252}},
                                                             color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1])
              annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                                 color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                    {-152,-190},{-152,-146},{-142,-146}},color={0,0,127}));
            connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                    190},{242,190}}, color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                    190},{131,234},{122,234}}, color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                    240}},          color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                    {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
            connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
            connect(table_Yt.u[1], LOAD6.y)
              annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
            connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                    {180,10},{219,10}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                    10},{-262,10}}, color={0,0,127}));
            connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},
                    {-84,-140}}, color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,-128}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(add8.y, valveBP_dynamic.u)
              annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
            connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                    10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                    100},{-280,76}}, color={0,0,127}));
            connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                    100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                    -100},{-280,-124}}, color={0,0,127}));
            connect(valveTURB_TS.y, PID_valveTURB.TR)
              annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
            connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{122,246},{172,
                    246},{220,246},{220,240},{262,240}}, color={0,0,127}));
            connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},{
                    -210,60},{-158,60},{-158,66},{-142,66}}, color={0,0,127}));
            connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,-140},
                    {-224,-140},{-224,-128},{-182,-128}}, color={0,0,127}));
            connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{172,66},{
                    216,66},{216,60},{262,60}}, color={0,0,127}));
            connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                    238},{324,160},{360,160}}, color={0,0,127}));
            connect(table_P.u[1], LOAD2.y)
              annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1])
              annotation (Line(points={{296,72},{339,72}}, color={0,0,127}));
            connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},
                    {-362,72}},           color={0,0,127}));
            connect(table_T_FW.y[1], PID_valveBP.SP) annotation (Line(points={{
                    -339,72},{-318,72},{-296,72}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,170},{-39,170}},
                color={255,204,51},
                thickness=0.5));
            connect(table_w_HPH.u[1],LOAD5. y)
              annotation (Line(points={{202,-190},{219,-190}}, color={0,0,127}));
            connect(rampPos.y,add. u1) annotation (Line(points={{219,-114},{209,
                    -114},{209,-128},{202,-128}},color={0,0,127}));
            connect(rampNeg.y,add. u2) annotation (Line(points={{219,-154},{209,
                    -154},{209,-140},{202,-140}},               color={0,0,127}));
            connect(table_w_HPH.y[1],product2. u2) annotation (Line(points={{179,
                    -190},{160,-190},{160,-140},{152,-140}}, color={0,0,127}));
            connect(product2.u1,add. y) annotation (Line(points={{152,-128},{
                    168,-128},{168,-134},{179,-134}},
                                                  color={0,0,127}));
            connect(add2.u1,product2. y) annotation (Line(points={{118,-134},{
                    126,-134},{129,-134}},        color={0,0,127}));
            connect(pumpHPH_dynamic.u,add2. y) annotation (Line(points={{84,-140},
                    {95,-140}},           color={0,0,127}));
            connect(add2.u2,table_w_HPH. y[1]) annotation (Line(points={{118,
                    -146},{132,-146},{132,-150},{140,-150},{140,-190},{179,-190}},
                  color={0,0,127}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, pumpSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,212},{0,210},{-39,210}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_highLoad_wHPHsens;

          model plant_controller_HPpart_highLoad_steadyStateInit
            "Model of the HP plant control system "

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Real DT_SH_sp "Degree of superheating set point"   annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpHPH --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
            parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ti_pumpHPH
              "Controller integral time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmin_pumpHPH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmax_pumpHPH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));
            parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
            parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI_steadyState
                                                     PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW,
              steadyStateInit=false)
              annotation (Placement(transformation(extent={{-300,-160},{-260,
                      -120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep2
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
            IndustrialControlSystems.Controllers.PI_steadyState
                                                     PID_pumpHPH(
              AntiWindup=true,
              useTS=useTS_pumpHPH,
              CSmin=CSmin_pumpHPH,
              CSmax=CSmax_pumpHPH,
              CS_start=CSstart_pumpHPH,
              Kp=Kp_pumpHPH,
              Ti=Ti_pumpHPH,
              steadyStateInit=false)
              annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep4
              annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
            Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
              annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PI_steadyState
                                                     PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              steadyStateInit=false)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
              annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI_steadyState
                                                     PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB,
              steadyStateInit=false)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep6
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_P_MEC(                                                        table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_T_MS(                                                                    table=[4,
                  534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                  563.15; 80,563.15; 90,563.15; 100,563.15])
              annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_w_FW(                                                            table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-260,-200},{-240,-180}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-190})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-160,
                      -150},{-140,-130}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-200,-144},{-180,-124}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_w_HPH(                          table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
            Modelica.Blocks.Math.Add add2
              annotation (Placement(transformation(extent={{146,-150},{126,-130}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{186,-144},{166,-124}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,-192})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_Y_tTOtheta(                                                                  table=[0,
                  0; 4.1407017192796e-07,0.00999999977648258;
                  8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                  0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                  2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                  0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                  3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                  0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                  3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                  0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                  4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                  0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                  4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                  0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                  4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                  0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                  4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                  0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                  5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                  0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                  5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                  0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                  5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                  0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                  5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                  0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                  5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                  0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                  5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                  0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                  5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                  0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                  5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                  0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                  5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                  0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                  5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                  0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                  5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                  0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                  5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                  0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                  5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                  0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                  5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                  0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                  5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                  0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                  5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                  0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                  5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                  0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                  5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                  0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                  5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                  0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                  5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                  0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                  5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                  0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                  5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                  0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                  5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                  0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                  5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                  0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                  5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                  0.989600002765656; 5.35380604560487e-06,0.999599993228912])
              annotation (Placement(transformation(extent={{150,50},{130,70}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_w_MS(                                                      table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{168,230},{148,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{190,50},{170,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_Yt(                         table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_thetaBP(                                                                     table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI_steadyState
                                                    PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP,
              steadyStateInit=false)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep3
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-180,50},
                      {-160,70}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={360,160}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-390,72})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_P(                                                   table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Auxiliaries.Components.Spline.SplineFunction
                                                table_T_FW(                                              table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(k=0)
              annotation (Placement(transformation(extent={{-60,140},{-40,160}})));
            Modelica.Blocks.Sources.Constant pumpSEP_CS(k=0) annotation (
                Placement(transformation(extent={{-60,200},{-40,220}})));
            Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-122,50},{-102,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(          uMin=10, uMax=200)
              annotation (Placement(transformation(extent={{-114,-150},{-94,
                      -130}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=1)
              annotation (Placement(transformation(extent={{118,-150},{98,-130}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{118,50},{98,70}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(uMax=650, uMin=5)
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,
                    -124},{-272,-124},{-272,-112},{-272,-100},{-261,-100}},
                                                                color={255,0,255}));
            connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                    -100},{272,-124}}, color={255,0,255}));
            connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                    -100},{280,-100},{280,-124}}, color={0,0,127}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(product.y, add1.u1)
              annotation (Line(points={{-179,-134},{-170,-134},{-162,-134}},
                                                                 color={0,0,127}));
            connect(product1.y, add2.u1) annotation (Line(points={{165,-134},{
                    165,-134},{148,-134}},
                                       color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,
                    -128},{-318,-128},{-296,-128}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},
                    {-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                    100},{-280,76}}, color={0,0,127}));
            connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                    100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,
                    -100},{-280,-100},{-280,-124}},
                                        color={0,0,127}));
            connect(valveTURB_TS.y, PID_valveTURB.TR)
              annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
            connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{170,246},
                    {220,246},{220,240},{262,240}},      color={0,0,127}));
            connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},
                    {-262,60},{-198,60},{-198,66},{-182,66}},color={0,0,127}));
            connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,
                    -140},{-244,-140},{-244,-128},{-202,-128}},
                                                          color={0,0,127}));
            connect(product1.u1, PID_pumpHPH.CS) annotation (Line(points={{188,
                    -128},{240,-128},{240,-140},{262,-140}},
                                                       color={0,0,127}));
            connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{192,66},
                    {236,66},{236,60},{262,60}},color={0,0,127}));
            connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                    238},{324,160},{360,160}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,150},{-39,150}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
                points={{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, pumpSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,212},{0,210},{-39,210}},
                color={255,204,51},
                thickness=0.5));
            connect(add8.y, valveBP_lim.u) annotation (Line(points={{-159,60},{
                    -141.5,60},{-124,60}}, color={0,0,127}));
            connect(valveBP_lim.y, valveBP_dynamic.u)
              annotation (Line(points={{-101,60},{-84,60}}, color={0,0,127}));
            connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-139,-140},
                    {-128,-140},{-116,-140}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u) annotation (Line(points={{
                    -93,-140},{-84,-140}}, color={0,0,127}));
            connect(pumpHPH_lim.y, pumpHPH_dynamic.u) annotation (Line(points={
                    {97,-140},{92.5,-140},{84,-140}}, color={0,0,127}));
            connect(valveTURB_dynamic.u, valveTURB_lim.y)
              annotation (Line(points={{84,60},{97,60}}, color={0,0,127}));
            connect(add4.y, pumpMS_lim.u)
              annotation (Line(points={{147,240},{122,240}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u) annotation (Line(points={{
                    99,240},{91.5,240},{84,240}}, color={0,0,127}));
            connect(pumpHPH_lim.u, add2.y) annotation (Line(points={{120,-140},
                    {125,-140},{125,-140}}, color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u) annotation (Line(points={{-279,-190},
                    {-262,-190},{-262,-190}}, color={0,0,127}));
            connect(table_w_FW.y, product.u2) annotation (Line(points={{-239,
                    -190},{-220,-190},{-220,-140},{-202,-140}}, color={0,0,127}));
            connect(table_w_FW.y, add1.u2) annotation (Line(points={{-239,-190},
                    {-208,-190},{-172,-190},{-172,-146},{-162,-146}}, color={0,
                    0,127}));
            connect(table_thetaBP.y, add8.u2) annotation (Line(points={{-239,10},
                    {-190,10},{-190,54},{-182,54}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u) annotation (Line(points={{-279,
                    10},{-262,10},{-262,10}}, color={0,0,127}));
            connect(LOAD1.y, table_T_FW.u) annotation (Line(points={{-379,72},{
                    -362,72},{-362,72}}, color={0,0,127}));
            connect(table_T_FW.y, PID_valveBP.SP)
              annotation (Line(points={{-339,72},{-296,72}}, color={0,0,127}));
            connect(add4.u2, table_w_MS.y) annotation (Line(points={{170,234},{
                    190,234},{190,190},{219,190}}, color={0,0,127}));
            connect(table_w_MS.u, LOAD7.y) annotation (Line(points={{242,190},{
                    259,190},{259,190}}, color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y)
              annotation (Line(points={{296,252},{339,252}}, color={0,0,127}));
            connect(table_P_MEC.u, LOAD.y) annotation (Line(points={{362,252},{
                    379,252},{379,252}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y)
              annotation (Line(points={{296,72},{339,72}}, color={0,0,127}));
            connect(table_P.u, LOAD2.y) annotation (Line(points={{362,72},{379,
                    72},{379,72}}, color={0,0,127}));
            connect(add5.u2, table_Yt.y) annotation (Line(points={{192,54},{208,
                    54},{208,10},{219,10}}, color={0,0,127}));
            connect(table_Yt.u, LOAD6.y) annotation (Line(points={{242,10},{259,
                    10},{259,10}}, color={0,0,127}));
            connect(PID_pumpHPH.SP, table_T_MS.y) annotation (Line(points={{296,
                    -128},{339,-128}}, color={0,0,127}));
            connect(table_T_MS.u, LOAD3.y) annotation (Line(points={{362,-128},
                    {379,-128},{379,-128}}, color={0,0,127}));
            connect(add2.u2, table_w_HPH.y) annotation (Line(points={{148,-146},
                    {148,-146},{160,-146},{160,-192},{219,-192}}, color={0,0,
                    127}));
            connect(product1.u2, table_w_HPH.y) annotation (Line(points={{188,
                    -140},{200,-140},{200,-192},{219,-192}}, color={0,0,127}));
            connect(table_w_HPH.u, LOAD5.y) annotation (Line(points={{242,-192},
                    {259,-192},{259,-192}}, color={0,0,127}));
            connect(valveTURB_lim.u, table_Y_tTOtheta.y) annotation (Line(
                  points={{120,60},{129,60},{129,60}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u, add5.y) annotation (Line(points={{152,
                    60},{169,60},{169,60}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller")}));
          end plant_controller_HPpart_highLoad_steadyStateInit;

          model plant_controller_HPpart_lowLoad
            "Model of the HP plant control system "

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Modelica.SIunits.AbsolutePressure p_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpHPH --
            parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ti_pumpHPH
              "Controller integral time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmin_pumpHPH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmax_pumpHPH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));
            parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
            parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"   annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
            Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
                Placement(transformation(extent={{400,200},{380,220}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep2
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
              AntiWindup=true,
              useTS=useTS_pumpHPH,
              CSmin=CSmin_pumpHPH,
              CSmax=CSmax_pumpHPH,
              CS_start=CSstart_pumpHPH,
              Kp=Kp_pumpHPH,
              Ti=Ti_pumpHPH)
              annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep4
              annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
            Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
              annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PI  PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,40},{40,80}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,40},{260,80}})));
            Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
              annotation (Placement(transformation(extent={{400,20},{380,40}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep6
              annotation (Placement(transformation(extent={{242,90},{262,110}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,90},{300,110}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                  563.15; 80,563.15; 90,563.15; 100,563.15])
              annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,62},{380,82}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
            Modelica.Blocks.Math.Add add2
              annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
            Modelica.Blocks.Math.Product product1
              annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,-192})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 4.1407017192796e-07,0.00999999977648258;
                  8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                  0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                  2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                  0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                  3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                  0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                  3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                  0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                  4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                  0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                  4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                  0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                  4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                  0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                  4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                  0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                  5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                  0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                  5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                  0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                  5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                  0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                  5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                  0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                  5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                  0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                  5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                  0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                  5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                  0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                  5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                  0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                  5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                  0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                  5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                  0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                  5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                  0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                  5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                  0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                  5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                  0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                  5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                  0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                  5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                  0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                  5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                  0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                  5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                  0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                  5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                  0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                  5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                  0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                  5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                  0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                  5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                  0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                  5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                  0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                  5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                  0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                  5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                  0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                  5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                  0.989600002765656; 5.35380604560487e-06,0.999599993228912])
              annotation (Placement(transformation(extent={{130,50},{110,70}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{170,50},{150,70}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,0},{260,20}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP,
              T=Ta_valveBP)
              annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
            IndustrialControlSystems.Controllers.PI PID_valveBP(
              AntiWindup=true,
              useTS=useTS_valveBP,
              CSmin=CSmin_valveBP,
              CSmax=CSmax_valveBP,
              CS_start=CSstart_valveBP,
              Kp=Kp_valveBP,
              Ti=Ti_valveBP)
              annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep3
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                      {-120,70}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={360,160}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-390,72})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
              annotation (Placement(transformation(extent={{-380,242},{-360,262}})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=useTS_pumpSEP,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-280,240})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,240})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
            Modelica.Blocks.Math.Product product4
                                                 annotation (Placement(transformation(
                    extent={{-180,236},{-160,256}})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                      230},{-120,250}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,190})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep1
              annotation (Placement(transformation(extent={{-240,270},{-260,290}})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,62},{340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15])
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.145652; 80,0.208685; 90,
                  0.349201; 100,0.866205])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,0},{220,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_wSEP(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0; 20,75; 30,97.9512; 40,104.453; 50,87.2734; 60,0; 70,0;
                  80,0; 90,0; 100,0]) annotation (Placement(transformation(extent=
                     {{-260,180},{-240,200}})));
            Modelica.Blocks.Sources.Constant valveSEP_CS(k=0)
              annotation (Placement(transformation(extent={{-60,-40},{-40,-20}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                    -100},{272,-124}}, color={255,0,255}));
            connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                    -100},{280,-100},{280,-124}}, color={0,0,127}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
                points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                    {272,100},{272,76}}, color={255,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,60},{2,60},{38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                    250,-192},{242,-192}}, color={0,0,127}));
            connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                    -134},{122,-134}}, color={0,0,127}));
            connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                    131,-192},{131,-146},{122,-146}}, color={0,0,127}));
            connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},
                    {99,-140}},       color={0,0,127}));
            connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                    190},{242,190}}, color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                    190},{131,234},{122,234}}, color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                    240}},          color={0,0,127}));
            connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                    {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
            connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
            connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                    339,-128},{339,-128}}, color={0,0,127}));
            connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                    {379,-128}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));

            connect(add8.y, valveBP_dynamic.u)
              annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
            connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
                points={{0,60},{-19,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                    100},{-280,76}}, color={0,0,127}));
            connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                    100},{-272,100},{-272,76}}, color={255,0,255}));
            connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
                points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                    -100},{-280,-124}}, color={0,0,127}));
            connect(valveTURB_TS.y, PID_valveTURB.TR)
              annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
            connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{122,246},{172,
                    246},{220,246},{220,240},{262,240}}, color={0,0,127}));
            connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},{
                    -262,60},{-160,60},{-160,66},{-142,66}}, color={0,0,127}));
            connect(product1.u1, PID_pumpHPH.CS) annotation (Line(points={{162,-128},
                    {214,-128},{214,-140},{262,-140}}, color={0,0,127}));
            connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{172,66},{
                    216,66},{216,60},{262,60}}, color={0,0,127}));
            connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                    238},{324,160},{360,160}}, color={0,0,127}));
            connect(PID_pumpFW.CS, pumpFW_dynamic.u) annotation (Line(points={{-262,
                    -140},{-84,-140}},      color={0,0,127}));
            connect(l_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{
                    -318,-128},{-296,-128}},  color={0,0,127}));
            connect(product4.y,add1. u1) annotation (Line(points={{-159,246},{-142,246}},
                                color={0,0,127}));
            connect(add1.y,pumpSEP_dynamic. u) annotation (Line(points={{-119,240},{-101.5,
                    240},{-84,240}},      color={0,0,127}));
            connect(signalBus.pumpSEP_PV,PID_pumpSEP. PV) annotation (Line(
                points={{0,60},{0,160},{-20,160},{-320,160},{-320,238},{-296,238}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep1.y,PID_pumpSEP. TS) annotation (Line(points={{-261,280},{-272,
                    280},{-272,256}},color={255,0,255}));
            connect(T_FW_SP.y, PID_pumpSEP.SP) annotation (Line(points={{-359,252},{-296,252}},
                                 color={0,0,127}));
            connect(pumpSEP_TS.y, PID_pumpSEP.TR) annotation (Line(points={{-299,280},{-292,
                    280},{-280,280},{-280,256}}, color={0,0,127}));
            connect(PID_pumpSEP.CS, product4.u1) annotation (Line(points={{-262,240},{-220,
                    240},{-220,252},{-182,252}}, color={0,0,127}));
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{-38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(table_P.u[1], LOAD2.y) annotation (Line(points={{362,72},{379,
                    72},{379,72}}, color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1]) annotation (Line(points={{296,
                    72},{339,72},{339,72}}, color={0,0,127}));
            connect(table_T_FW.y[1], PID_valveBP.SP) annotation (Line(points={{
                    -339,72},{-296,72},{-296,72}}, color={0,0,127}));
            connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},
                    {-362,72},{-362,72}}, color={0,0,127}));
            connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{242,10},{
                    259,10},{259,10}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,252},
                    {370,252},{370,252},{379,252}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaBP.u[1])
              annotation (Line(points={{-279,10},{-262,10}}, color={0,0,127}));
            connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,
                    10},{-239,10},{-160,10},{-160,54},{-142,54}}, color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{
                    296,252},{318,252},{318,252},{339,252}}, color={0,0,127}));
            connect(table_Yt.y[1], add5.u2) annotation (Line(points={{219,10},{
                    200,10},{200,54},{172,54}}, color={0,0,127}));
            connect(LOAD8.y, table_wSEP.u[1]) annotation (Line(points={{-279,190},{-262,190}},
                                            color={0,0,127}));
            connect(table_wSEP.y[1], product4.u2) annotation (Line(points={{-239,
                    190},{-220,190},{-200,190},{-200,240},{-182,240}}, color={0,0,
                    127}));
            connect(signalBus.valveSEP_CS, valveSEP_CS.y) annotation (Line(
                points={{0,60},{0,60},{0,-30},{-39,-30}},
                color={255,204,51},
                thickness=0.5));
            connect(table_wSEP.y[1], add1.u2) annotation (Line(points={{-239,190},{-196,190},
                    {-150,190},{-150,234},{-142,234}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_lowLoad;

          model plant_controller_HPpart_drainage
            "Model of the HP plant control system with drainage procedure "

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_drain
              "Drainage procedure start time [s]"                                       annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));
            parameter Boolean useSEP = true
              "Use of separator pump during drainage"                               annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
              "Degree of superheating set point"     annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real CSmin_pumpFW_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real CSmax_pumpFW_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real CSstart_pumpFW_high "Start value of CS" annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW_high "Tracking reference mode" annotation (Dialog(tab="pumpFW",group="High load"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="High load"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Length l_sp
              "Degree of superheating set point"     annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real CSmin_pumpFW_low
              "Minimum value of control signal for scaling"                               annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real CSmax_pumpFW_low
              "Maximum value of control signal for scaling"                               annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Boolean useTS_pumpFW_low "Tracking reference mode" annotation (Dialog(tab="pumpFW",group="Low load"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Low load"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP_SH --
            parameter Modelica.SIunits.AbsolutePressure p_SH_sp
              "SH pressure set point during drainage"     annotation (Dialog(tab="valveBP_SH"));
            parameter Real Kp_valveBP_SH "Controller proportional gain" annotation (Dialog(tab="valveBP_SH"));
            parameter Modelica.SIunits.Time Ti_valveBP_SH
              "Controller integral time"                                             annotation (Dialog(tab="valveBP_SH"));
            parameter Modelica.SIunits.Time Td_valveBP_SH
              "Controller derivative time"                                             annotation (Dialog(tab="valveBP_SH"));
            parameter Real Nd_valveBP_SH
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="valveBP_SH"));
            parameter Real CSmin_valveBP_SH
              "Minimum value of control signal for scaling"                               annotation (Dialog(tab="valveBP_SH"));
            parameter Real CSmax_valveBP_SH
              "Maximum value of control signal for scaling"                               annotation (Dialog(tab="valveBP_SH"));
            parameter Real CSstart_valveBP_SH "Start value of CS" annotation (Dialog(tab="valveBP_SH"));
            parameter Real actuatorGain_valveBP_SH "Actuator gain" annotation (Dialog(tab="valveBP_SH"));
            parameter Modelica.SIunits.Time Ta_valveBP_SH
              "Actuator time constant"                                             annotation (Dialog(tab="valveBP_SH"));
            parameter Boolean useTS_valveBP_SH "Tracking reference mode" annotation (Dialog(tab="valveBP_SH"));
            parameter Real TS_valveBP_SH "Tracking signal" annotation (Dialog(tab="valveBP_SH"));

            //-- valveBP_RH --
            parameter Modelica.SIunits.AbsolutePressure p_RH_sp
              "RH pressure set point during drainage"     annotation (Dialog(tab="valveBP_RH"));
            parameter Real Kp_valveBP_RH "Controller proportional gain" annotation (Dialog(tab="valveBP_RH"));
            parameter Modelica.SIunits.Time Ti_valveBP_RH
              "Controller integral time"                                             annotation (Dialog(tab="valveBP_RH"));
            parameter Modelica.SIunits.Time Td_valveBP_RH
              "Controller derivative time"                                             annotation (Dialog(tab="valveBP_RH"));
            parameter Real Nd_valveBP_RH
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="valveBP_RH"));
            parameter Real CSmin_valveBP_RH
              "Minimum value of control signal for scaling"                               annotation (Dialog(tab="valveBP_RH"));
            parameter Real CSmax_valveBP_RH
              "Maximum value of control signal for scaling"                               annotation (Dialog(tab="valveBP_RH"));
            parameter Real CSstart_valveBP_RH "Start value of CS" annotation (Dialog(tab="valveBP_RH"));
            parameter Real actuatorGain_valveBP_RH "Actuator gain" annotation (Dialog(tab="valveBP_RH"));
            parameter Modelica.SIunits.Time Ta_valveBP_RH
              "Actuator time constant"                                             annotation (Dialog(tab="valveBP_RH"));
            parameter Boolean useTS_valveBP_RH "Tracking reference mode" annotation (Dialog(tab="valveBP_RH"));
            parameter Real TS_valveBP_RH "Tracking signal" annotation (Dialog(tab="valveBP_RH"));

            //-- valveINT_IPT --
            parameter Real actuatorGain_valveINT_IPT "Actuator gain" annotation (Dialog(tab="valveINT_IPT"));
            parameter Modelica.SIunits.Time Ta_valveINT_IPT
              "Actuator time constant"                                               annotation (Dialog(tab="valveINT_IPT"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Length l_sep_SP
              "Level set-point during drainage"                                          annotation (Dialog(tab="pumpSEP"));
              parameter Modelica.SIunits.MassFlowRate w_SEPmax
              "Maximum separator pump mass flow during drainage"                                                  annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,180},{20,220}}),iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW_high(
              AntiWindup=true,
              useTS=useTS_pumpFW_high,
              useBIAS=false,
              CSmin=CSmin_pumpFW_high,
              CSmax=CSmax_pumpFW_high,
              CS_start=CSstart_pumpFW_high,
              Kp=Kp_pumpFW_high,
              Ti=Ti_pumpFW_high,
              Td=Td_pumpFW_high,
              N=Nd_pumpFW_high)
              annotation (Placement(transformation(extent={{-300,-40},{-260,0}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-160})));
            Modelica.Blocks.Sources.BooleanStep booleanStep2(startTime=t_start_drain,
                startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,10},{-260,30}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-320,10},{-300,30}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,0},{40,40}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,360})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{80,180},{40,220}})));
            IndustrialControlSystems.Controllers.PI  PID_valveTURB(
              AntiWindup=true,
              useTS=useTS_valveTURB,
              CS_start=CSstart_valveTURB,
              CSmin=CSmin_valveTURB,
              CSmax=CSmax_valveTURB,
              Kp=Kp_valveTURB,
              Ti=Ti_valveTURB)
              annotation (Placement(transformation(extent={{300,180},{260,220}})));
            Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
              annotation (Placement(transformation(extent={{320,230},{300,250}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,202},{380,222}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                  65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                              annotation (Placement(transformation(
                    extent={{-260,-80},{-240,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-70})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-160,
                      -36},{-140,-16}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-200,-30},{-180,-10}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                  6.743; 100,24.51])
              annotation (Placement(transformation(extent={{180,-10},{160,10}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,0})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 4.1407017192796e-07,0.00999999977648258;
                  8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                  0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                  2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                  0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                  3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                  0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                  3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                  0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                  4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                  0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                  4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                  0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                  4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                  0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                  4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                  0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                  5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                  0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                  5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                  0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                  5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                  0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                  5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                  0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                  5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                  0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                  5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                  0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                  5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                  0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                  5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                  0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                  5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                  0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                  5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                  0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                  5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                  0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                  5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                  0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                  5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                  0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                  5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                  0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                  5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                  0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                  5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                  0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                  5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                  0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                  5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                  0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                  5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                  0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                  5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                  0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                  5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                  0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                  5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                  0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                  5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                  0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                  5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                  0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                  5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                  0.989600002765656; 5.35380604560487e-06,0.999599993228912])
              annotation (Placement(transformation(extent={{160,184},{140,204}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                  495.8; 90,557.8; 100,619.8])
              annotation (Placement(transformation(extent={{240,300},{220,320}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,310})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{190,184},{170,204}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,140},{260,160}})));
            Modelica.Blocks.Tables.CombiTable1D table_Yt(
                smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                  60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                  4.98849e-6])
              annotation (Placement(transformation(extent={{240,140},{220,160}})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-18},{-340,2}})));
            Modelica.Blocks.Tables.CombiTable1D table_P(
                                         smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                  124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,202},{340,222}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_SH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP_SH,
              T=Ta_valveBP_SH)
              annotation (Placement(transformation(extent={{-80,100},{-40,140}})));
            Modelica.Blocks.Continuous.FirstOrder valveBP_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveBP_RH,
              T=Ta_valveBP_RH)
              annotation (Placement(transformation(extent={{-80,240},{-40,280}})));
            Modelica.Blocks.Continuous.FirstOrder valveINT_IPT_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveINT_IPT,
              T=Ta_valveINT_IPT)
              annotation (Placement(transformation(extent={{-80,340},{-40,380}})));
            Modelica.Blocks.Sources.Step step(
              height=-1,
              offset=1,
              startTime=t_start_drain)
              annotation (Placement(transformation(extent={{-140,350},{-120,370}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep1(startTime=t_start_drain,
                startValue=TS_start)
              annotation (Placement(transformation(extent={{240,230},{260,250}})));
            IndustrialControlSystems.Controllers.PID PID_valveBP_SH(
              AntiWindup=true,
              useTS=useTS_valveBP_SH,
              useBIAS=false,
              CSmin=CSmin_valveBP_SH,
              CSmax=CSmax_valveBP_SH,
              CS_start=CSstart_valveBP_SH,
              Kp=Kp_valveBP_SH,
              Ti=Ti_valveBP_SH,
              Td=Td_valveBP_SH,
              N=Nd_valveBP_SH)
              annotation (Placement(transformation(extent={{-300,100},{-260,140}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep3(startTime=t_start_drain,
                startValue=true)
              annotation (Placement(transformation(extent={{-240,150},{-260,170}})));
            Modelica.Blocks.Sources.Constant valveBP_SH_TS(k=TS_valveBP_SH)
              annotation (Placement(transformation(extent={{-320,150},{-300,170}})));
            Modelica.Blocks.Sources.Constant p_SH_SP(k=p_SH_sp)
              annotation (Placement(transformation(extent={{-360,122},{-340,142}})));
            IndustrialControlSystems.Controllers.PID PID_valveBP_RH(
              AntiWindup=true,
              useTS=useTS_valveBP_RH,
              useBIAS=false,
              CSmin=CSmin_valveBP_RH,
              CSmax=CSmax_valveBP_RH,
              CS_start=CSstart_valveBP_RH,
              Kp=Kp_valveBP_RH,
              Ti=Ti_valveBP_RH,
              Td=Td_valveBP_RH,
              N=Nd_valveBP_RH)
              annotation (Placement(transformation(extent={{-300,240},{-260,280}})));
            Modelica.Blocks.Sources.Constant valveBP_RH_TS(k=TS_valveBP_RH)
              annotation (Placement(transformation(extent={{-320,290},{-300,310}})));
            Modelica.Blocks.Sources.Constant p_RH_SP(k=p_RH_sp)
              annotation (Placement(transformation(extent={{-360,262},{-340,282}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep4(startTime=t_start_drain,
                startValue=true)
              annotation (Placement(transformation(extent={{-240,290},{-260,310}})));
            Modelica.Blocks.Math.Product product1
                                                 annotation (Placement(transformation(
                    extent={{120,350},{100,370}})));
            Modelica.Blocks.Sources.Step step1(
              offset=1,
              startTime=t_start_drain,
              height=-0.99)
              annotation (Placement(transformation(extent={{180,370},{160,390}})));
            Modelica.Blocks.Math.Product product2
                                                 annotation (Placement(transformation(
                    extent={{120,190},{100,210}})));
            Modelica.Blocks.Sources.Step step2(
              offset=1,
              startTime=t_start_drain,
              height=-1)
              annotation (Placement(transformation(extent={{160,230},{140,250}})));
            Modelica.Blocks.Math.Product product3
                                                 annotation (Placement(transformation(
                    extent={{-120,-30},{-100,-10}})));
            Modelica.Blocks.Sources.Step step3(
              offset=1,
              startTime=t_start_drain,
              height=-0.99)
              annotation (Placement(transformation(extent={{-160,20},{-140,40}})));
            Modelica.Blocks.Math.Product product4
                                                 annotation (Placement(transformation(
                    extent={{120,10},{100,30}})));
            Modelica.Blocks.Sources.Step step4(
              offset=1,
              startTime=t_start_drain,
              height=-0.99)
              annotation (Placement(transformation(extent={{180,32},{160,52}})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,-80})));
            Modelica.Blocks.Math.Product product5
                                                 annotation (Placement(transformation(
                    extent={{300,-136},{280,-116}})));
            Modelica.Blocks.Math.Add add2(k1=-1)
                                          annotation (Placement(transformation(extent={{340,
                      -142},{320,-122}})));
            Modelica.Blocks.Math.Product product6
                                                 annotation (Placement(transformation(
                    extent={{260,-130},{240,-110}})));
            Modelica.Blocks.Logical.Switch switch1
              annotation (Placement(transformation(extent={{192,-98},{172,-78}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=t_start_drain,
                startValue=true)
              annotation (Placement(transformation(extent={{234,-98},{214,-78}})));
            Modelica.Blocks.Sources.Step     const(
              height=0,
              offset=0,
              startTime=t_start_drain)
              annotation (Placement(transformation(extent={{240,-50},{220,-30}})));
            Modelica.Blocks.Sources.Constant const1(k=l_sep_SP)
              annotation (Placement(transformation(extent={{380,-122},{360,-102}})));
            Modelica.Blocks.Math.Division division
              annotation (Placement(transformation(extent={{340,-106},{320,-86}})));
            Modelica.Blocks.Sources.Constant const2(k=1)
              annotation (Placement(transformation(extent={{380,-86},{360,-66}})));
            Modelica.Blocks.Sources.Constant const3(k=w_SEPmax)
              annotation (Placement(transformation(extent={{300,-96},{280,-76}})));
            Modelica.Blocks.Nonlinear.Limiter pumpSEP_lim(uMax=w_SEPmax, uMin=0)
              annotation (Placement(transformation(extent={{114,-90},{94,-70}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=useSEP)
              annotation (Placement(transformation(extent={{192,-68},{172,-48}})));
            Modelica.Blocks.Logical.Switch switch2
              annotation (Placement(transformation(extent={{146,-70},{126,-90}})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW_low(
              AntiWindup=true,
              useTS=useTS_pumpFW_low,
              useBIAS=false,
              CSmin=CSmin_pumpFW_low,
              CSmax=CSmax_pumpFW_low,
              CS_start=CSstart_pumpFW_low,
              Kp=Kp_pumpFW_low,
              Ti=Ti_pumpFW_low,
              Td=Td_pumpFW_low,
              N=Nd_pumpFW_low)
              annotation (Placement(transformation(extent={{-300,-264},{-260,-224}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_low(k=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-320,-214},{-300,-194}})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{-360,-242},{-340,-222}})));
            Modelica.Blocks.Logical.Switch switch3
              annotation (Placement(transformation(extent={{-120,-170},{-100,-150}})));
            Modelica.Blocks.Math.RealToBoolean realToBoolean(threshold=55)
              annotation (Placement(transformation(extent={{-208,-170},{-188,-150}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep5(startTime=t_start_drain,
                startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-214},{-260,-194}})));
            Modelica.Blocks.Sources.Step step5(
              offset=1,
              startTime=t_start_drain,
              height=-0.99)
              annotation (Placement(transformation(extent={{-240,-298},{-220,-278}})));
            Modelica.Blocks.Math.Product product7
                                                 annotation (Placement(transformation(
                    extent={{-200,-260},{-180,-240}})));
            Modelica.Blocks.Continuous.FirstOrder valveSPURG(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=2) annotation (Placement(transformation(extent={{80,-240},{40,
                      -200}})));
            Modelica.Blocks.Logical.Switch switch4
              annotation (Placement(transformation(extent={{120,-230},{100,-210}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep6(
                                                            startTime=t_start_drain,
                startValue=true)
              annotation (Placement(transformation(extent={{240,-230},{220,-210}})));
            Modelica.Blocks.Sources.Constant const4(
                                                   k=0)
              annotation (Placement(transformation(extent={{200,-200},{180,-180}})));
            Modelica.Blocks.Logical.Greater greater annotation (Placement(
                  transformation(extent={{200,-280},{180,-260}})));
            Modelica.Blocks.Logical.Switch switch5 annotation (Placement(
                  transformation(extent={{160,-260},{140,-280}})));
            Modelica.Blocks.Sources.Constant const5(k=1)
              annotation (Placement(transformation(extent={{200,-320},{180,-300}})));
            Modelica.Blocks.Sources.Constant l_SP1(k=l_sep_SP)
              annotation (Placement(transformation(extent={{260,-322},{240,-302}})));
            Modelica.Blocks.Nonlinear.FixedDelay fixedDelay(delayTime=1)
              annotation (Placement(transformation(
                  extent={{-5,-5},{5,5}},
                  rotation=90,
                  origin={131,-251})));
          equation
            connect(PID_pumpFW_high.TS, booleanStep2.y) annotation (Line(points={{-272,-4},
                    {-272,-4},{-272,8},{-272,20},{-261,20}}, color={255,0,255}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,20},{38,20}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,360},{38,360}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{38,200}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
                points={{0,200},{0,200},{0,60},{322,60},{322,198},{296,198}},
                color={255,204,51},
                thickness=0.5));
            connect(LOAD4.y, table_w_FW.u[1])
              annotation (Line(points={{-279,-70},{-262,-70}},   color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-179,-20},{-170,-20},{-162,-20}},
                                                                 color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-70},{-172,-70},
                    {-172,-32},{-162,-32}},              color={0,0,127}));
            connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{199,0},{190,0},{182,
                    0}},                   color={0,0,127}));
            connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,310},{250,310},
                    {242,310}},      color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-70},{-239,
                    -70},{-210,-70},{-210,-26},{-202,-26}},           color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y)
              annotation (Line(points={{162,194},{162,194},{169,194}},
                                                           color={0,0,127}));
            connect(table_Yt.u[1], LOAD6.y)
              annotation (Line(points={{242,150},{259,150}},
                                                           color={0,0,127}));
            connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{192,188},{200,188},{
                    200,150},{219,150}},color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW_high.SP)
              annotation (Line(points={{-339,-8},{-296,-8}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-160},{-38,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW_high.PV) annotation (Line(
                points={{0,200},{0,200},{0,-120},{2,-120},{-318,-120},{-318,-22},{-296,-22}},
                color={255,204,51},
                thickness=0.5));

            connect(pumpFW_TS_high.y, PID_pumpFW_high.TR)
              annotation (Line(points={{-299,20},{-280,20},{-280,-4}}, color={0,0,127}));
            connect(valveTURB_TS.y, PID_valveTURB.TR)
              annotation (Line(points={{299,240},{280,240},{280,216}},color={0,0,127}));
            connect(PID_pumpFW_high.CS, product.u1) annotation (Line(points={{-262,-20},{-244,
                    -20},{-244,-14},{-202,-14}}, color={0,0,127}));
            connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{192,200},{236,200},
                    {262,200}},                 color={0,0,127}));
            connect(table_P.u[1], LOAD2.y)
              annotation (Line(points={{362,212},{379,212}},
                                                           color={0,0,127}));
            connect(PID_valveTURB.SP, table_P.y[1])
              annotation (Line(points={{296,212},{339,212}},
                                                           color={0,0,127}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,120},{-38,120}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,260},{-38,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,360},{-38,360}},
                color={255,204,51},
                thickness=0.5));
            connect(step.y, valveINT_IPT_dynamic.u) annotation (Line(points={{-119,360},{-84,
                    360}},           color={0,0,127}));
            connect(booleanStep1.y, PID_valveTURB.TS) annotation (Line(points={{261,240},{
                    266,240},{272,240},{272,216}},color={255,0,255}));
            connect(PID_valveBP_SH.TS, booleanStep3.y) annotation (Line(points={{-272,136},
                    {-272,136},{-272,148},{-272,160},{-261,160}},
                                                              color={255,0,255}));
            connect(p_SH_SP.y, PID_valveBP_SH.SP)
              annotation (Line(points={{-339,132},{-296,132}},
                                                             color={0,0,127}));
            connect(valveBP_SH_TS.y, PID_valveBP_SH.TR)
              annotation (Line(points={{-299,160},{-280,160},{-280,136}},
                                                                       color={0,0,127}));
            connect(signalBus.valveTURB_PV, PID_valveBP_SH.PV) annotation (Line(
                points={{0,200},{0,200},{0,60},{-318,60},{-318,118},{-296,118}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_valveBP_SH.CS, valveBP_SH_dynamic.u)
              annotation (Line(points={{-262,120},{-84,120}},
                                                          color={0,0,127}));
            connect(p_RH_SP.y, PID_valveBP_RH.SP)
              annotation (Line(points={{-339,272},{-296,272}}, color={0,0,127}));
            connect(valveBP_RH_TS.y, PID_valveBP_RH.TR) annotation (Line(points={{-299,300},
                    {-280,300},{-280,276}}, color={0,0,127}));
            connect(signalBus.valveBP_RH_PV, PID_valveBP_RH.PV) annotation (Line(
                points={{0,200},{0,200},{-320,200},{-320,258},{-296,258}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_valveBP_RH.CS, valveBP_RH_dynamic.u)
              annotation (Line(points={{-262,260},{-84,260}}, color={0,0,127}));
            connect(booleanStep4.y, PID_valveBP_RH.TS) annotation (Line(points={{-261,300},
                    {-266,300},{-272,300},{-272,276}}, color={255,0,255}));
            connect(product1.u1, step1.y) annotation (Line(points={{122,366},{140,366},{140,
                    380},{159,380}}, color={0,0,127}));
            connect(table_w_MS.y[1], product1.u2) annotation (Line(points={{219,310},{180,
                    310},{140,310},{140,354},{122,354}},
                                                    color={0,0,127}));
            connect(pumpMS_dynamic.u, product1.y)
              annotation (Line(points={{84,360},{99,360}},          color={0,0,127}));
            connect(product2.u1,step2. y) annotation (Line(points={{122,206},{130,206},{130,
                    240},{139,240}}, color={0,0,127}));
            connect(product2.u2, table_Y_tTOtheta.y[1])
              annotation (Line(points={{122,194},{139,194}},        color={0,0,127}));
            connect(valveTURB_dynamic.u, product2.y)
              annotation (Line(points={{84,200},{91,200},{99,200}},      color={0,0,127}));
            connect(product3.u1,step3. y) annotation (Line(points={{-122,-14},{-132,-14},{
                    -132,30},{-139,30}},
                                     color={0,0,127}));
            connect(add1.y, product3.u2)
              annotation (Line(points={{-139,-26},{-122,-26}},               color={0,0,127}));
            connect(product4.u1,step4. y) annotation (Line(points={{122,26},{140,
                    26},{140,42},{159,42}},
                                     color={0,0,127}));
            connect(table_w_HPH.y[1], product4.u2) annotation (Line(points={{159,0},{140,0},
                    {140,14},{122,14}},    color={0,0,127}));
            connect(pumpHPH_dynamic.u, product4.y)
              annotation (Line(points={{84,20},{99,20}},               color={0,0,127}));
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-80},{38,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(const.y, switch1.u1) annotation (Line(points={{219,-40},{200,-40},{200,
                    -80},{194,-80}},   color={0,0,127}));
            connect(const1.y, add2.u1) annotation (Line(points={{359,-112},{350,-112},{350,
                    -126},{342,-126}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, add2.u2) annotation (Line(
                points={{0,200},{0,200},{0,198},{0,-120},{0,-160},{350,-160},{350,-138},{342,
                    -138}},
                color={255,204,51},
                thickness=0.5));
            connect(product5.u2, add2.y)
              annotation (Line(points={{302,-132},{284,-132},{284,-136},{290,-136},{290,-132},
                    {319,-132}},                               color={0,0,127}));
            connect(const2.y, division.u1) annotation (Line(points={{359,-76},{350,-76},{350,
                    -90},{342,-90}},        color={0,0,127}));
            connect(const1.y, division.u2) annotation (Line(points={{359,-112},{350,-112},
                    {350,-102},{342,-102}}, color={0,0,127}));
            connect(division.y, product5.u1) annotation (Line(points={{319,-96},{312,-96},
                    {312,-120},{302,-120}}, color={0,0,127}));
            connect(const3.y, product6.u1) annotation (Line(points={{279,-86},{270,-86},{270,
                    -114},{262,-114}},      color={0,0,127}));
            connect(product5.y, product6.u2)
              annotation (Line(points={{279,-126},{262,-126}}, color={0,0,127}));
            connect(switch1.u3, product6.y) annotation (Line(points={{194,-96},{200,-96},{
                    200,-120},{239,-120}},  color={0,0,127}));
            connect(const.y, switch2.u3) annotation (Line(points={{219,-40},{188,-40},{154,
                    -40},{154,-72},{148,-72}},               color={0,0,127}));
            connect(switch2.u1, switch1.y) annotation (Line(points={{148,-88},{171,-88}},
                                           color={0,0,127}));
            connect(switch1.u2, booleanStep.y) annotation (Line(points={{194,-88},{213,-88}},
                                 color={255,0,255}));
            connect(switch2.u2, booleanConstant.y) annotation (Line(points={{148,-80},{156,
                    -80},{164,-80},{164,-58},{171,-58}},                color={
                    255,0,255}));
            connect(pumpFW_TS_low.y, PID_pumpFW_low.TR) annotation (Line(points={{-299,-204},
                    {-280,-204},{-280,-228}}, color={0,0,127}));
            connect(l_SP.y, PID_pumpFW_low.SP) annotation (Line(points={{-339,-232},{-318,
                    -232},{-296,-232}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
                points={{0,200},{0,200},{0,-344},{-320,-344},{-320,-246},{-296,-246}},
                color={255,204,51},
                thickness=0.5));
            connect(switch3.y, pumpFW_dynamic.u) annotation (Line(points={{-99,-160},{-91.5,
                    -160},{-84,-160}}, color={0,0,127}));
            connect(product3.y, switch3.u1) annotation (Line(points={{-99,-20},{-80,-20},{
                    -80,-106},{-146,-106},{-146,-152},{-122,-152}}, color={0,0,127}));
            connect(LOAD4.y, realToBoolean.u) annotation (Line(points={{-279,-70},{-266,-70},
                    {-266,-160},{-210,-160}}, color={0,0,127}));
            connect(realToBoolean.y, switch3.u2)
              annotation (Line(points={{-187,-160},{-122,-160}}, color={255,0,255}));
            connect(booleanStep5.y, PID_pumpFW_low.TS) annotation (Line(points={{
                    -261,-204},{-264,-204},{-272,-204},{-272,-228}}, color={255,0,
                    255}));
            connect(step5.y, product7.u2) annotation (Line(points={{-219,-288},{
                    -212,-288},{-212,-256},{-202,-256}}, color={0,0,127}));
            connect(PID_pumpFW_low.CS, product7.u1) annotation (Line(points={{
                    -262,-244},{-202,-244}}, color={0,0,127}));
            connect(product7.y, switch3.u3) annotation (Line(points={{-179,-250},
                    {-179,-250},{-142,-250},{-142,-168},{-122,-168}}, color={0,0,
                    127}));
            connect(pumpSEP_dynamic.u,pumpSEP_lim. y)
              annotation (Line(points={{84,-80},{93,-80}}, color={0,0,127}));
            connect(pumpSEP_lim.u, switch2.y)
              annotation (Line(points={{116,-80},{125,-80}}, color={0,0,127}));
            connect(switch4.u2, booleanStep6.y) annotation (Line(points={{122,
                    -220},{122,-220},{219,-220}}, color={255,0,255}));
            connect(valveSPURG.u, switch4.y)
              annotation (Line(points={{84,-220},{99,-220}}, color={0,0,127}));
            connect(switch4.u1, const4.y) annotation (Line(points={{122,-212},{
                    160,-212},{160,-190},{179,-190}}, color={0,0,127}));
            connect(switch5.u2, greater.y) annotation (Line(points={{162,-270},{
                    179,-270}}, color={255,0,255}));
            connect(const4.y, switch5.u3) annotation (Line(points={{179,-190},{
                    172,-190},{172,-262},{162,-262}}, color={0,0,127}));
            connect(const5.y, switch5.u1) annotation (Line(points={{179,-310},{
                    170,-310},{170,-278},{162,-278}}, color={0,0,127}));
            connect(l_SP1.y, greater.u2) annotation (Line(points={{239,-312},{220,
                    -312},{220,-278},{202,-278}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, greater.u1) annotation (Line(
                points={{0,200},{0,200},{0,-344},{300,-344},{300,-270},{202,-270}},
                color={255,204,51},
                thickness=0.5));

            connect(switch4.u3, fixedDelay.y) annotation (Line(points={{122,-228},
                    {131,-228},{131,-245.5}}, color={0,0,127}));
            connect(fixedDelay.u, switch5.y) annotation (Line(points={{131,-257},
                    {131,-270},{139,-270}}, color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSPURG.y) annotation (Line(
                points={{0,200},{0,200},{0,-220},{38,-220}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -400},{400,400}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-400},{400,400}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_drainage;

          model plantController
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpCOND "FF only on COND pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveDEA "FF only on DEA valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            //-- pumpCOND --
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmin_pumpCOND "Minimum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmax_pumpCOND "Maximum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));

            //-- valveDEA --
            parameter Real Kp_valveDEA "Controller proportional gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ti_valveDEA
              "Controller integral time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Td_valveDEA
              "Controller derivative time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real Nd_valveDEA
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="valveDEA"));
            parameter Real CSmin_valveDEA
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSmax_valveDEA
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSstart_valveDEA "Start value of CS" annotation (Dialog(tab="valveDEA"));
            parameter Real actuatorGain_valveDEA "Actuator gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ta_valveDEA
              "Actuator time constant"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real TS_valveDEA "Tracking signal" annotation (Dialog(tab="valveDEA"));

            PowerPressureFWcontrollers.staticDecoupled_4th
                                                       staticDecoupled_4th(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              A=A,
              B=B,
              C=C,
              D=D,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,40},{20,80}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-58,78},{-38,
                      98}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=
                  useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-80},{20,-40}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-60,-42},{-40,
                      -22}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-140},{20,-100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-60,-100},{-40,
                      -80}})));
            SingleControllers.control_wCOND control_wCOND(
              load_switch=load_switch,
              Kp_pumpCOND=Kp_pumpCOND,
              Ti_pumpCOND=Ti_pumpCOND,
              Td_pumpCOND=Td_pumpCOND,
              Nd_pumpCOND=Nd_pumpCOND,
              CSmin_pumpCOND=CSmin_pumpCOND,
              CSmax_pumpCOND=CSmax_pumpCOND,
              CSstart_pumpCOND=CSstart_pumpCOND,
              TS_pumpCOND=TS_pumpCOND,
              actuatorGain_pumpCOND=actuatorGain_pumpCOND,
              Ta_pumpCOND=Ta_pumpCOND)
              annotation (Placement(transformation(extent={{-20,-200},{20,-160}})));
            Modelica.Blocks.Sources.BooleanConstant TS_pump_COND(k=
                  useTS_pumpCOND)
              annotation (Placement(transformation(extent={{-60,-162},{-40,-142}})));
            SingleControllers.control_valveDEA control_valveDEA(
              Kp_valveDEA=Kp_valveDEA,
              Ti_valveDEA=Ti_valveDEA,
              Td_valveDEA=Td_valveDEA,
              Nd_valveDEA=Nd_valveDEA,
              CSmin_valveDEA=CSmin_valveDEA,
              CSmax_valveDEA=CSmax_valveDEA,
              CSstart_valveDEA=CSstart_valveDEA,
              actuatorGain_valveDEA=actuatorGain_valveDEA,
              Ta_valveDEA=Ta_valveDEA,
              TS_valveDEA=TS_valveDEA)
              annotation (Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_DEA(k=useTS_valveDEA)
              annotation (Placement(transformation(extent={{-60,-220},{-40,-200}})));
          equation
            connect(staticDecoupled_4th.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,60},{180,60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,0},{21,0},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled_4th.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, staticDecoupled_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled_4th.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-37,88},
                    {0,88},{0,82}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,60},{-22,60}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled_4th.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-186,
                    0},{-160,0},{-22,0}},        color={0,0,127}));
            connect(TS_Y_t_high.y, staticDecoupled_4th.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled_4th.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -60},{-22,-60}},    color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-60},{21,-60}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-39,-32},
                    {0,-32},{0,-38}},               color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-120},{21,-120},{180,-120},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-200,0},
                    {-160,0},{-160,-120},{-22,-120}},            color={0,0,127}));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-39,-90},{0,-90},{0,-98}},    color={255,0,255}));
            connect(TS_pump_COND.y, control_wCOND.TS_pumpCONDlow_bool) annotation (Line(
                  points={{-39,-152},{-10,-152},{-10,-158}}, color={255,0,255}));
            connect(load, control_wCOND.load) annotation (Line(points={{-200,0},{-160,0},{
                    -160,-180},{-22,-180}}, color={0,0,127}));
            connect(control_wCOND.signalBus, signalBus) annotation (Line(
                points={{21,-180},{102,-180},{180,-180},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveDEA.load) annotation (Line(points={{-200,0},{-180,0},
                    {-160,0},{-160,-240},{-22,-240}}, color={0,0,127}));
            connect(signalBus, control_valveDEA.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-240},{21,-240}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_DEA.y, control_valveDEA.TS_valveDEA_bool)
              annotation (Line(points={{-39,-210},{-20,-210},{0,-210},{0,-218}},
                  color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController;

          model plantController_hotStart
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpCOND "FF only on COND pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveDEA "FF only on DEA valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            //-- pumpCOND --
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmin_pumpCOND "Minimum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmax_pumpCOND "Maximum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));

            //-- valveDEA --
            parameter Real Kp_valveDEA "Controller proportional gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ti_valveDEA
              "Controller integral time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Td_valveDEA
              "Controller derivative time"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real Nd_valveDEA
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="valveDEA"));
            parameter Real CSmin_valveDEA
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSmax_valveDEA
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="valveDEA"));
            parameter Real CSstart_valveDEA "Start value of CS" annotation (Dialog(tab="valveDEA"));
            parameter Real actuatorGain_valveDEA "Actuator gain" annotation (Dialog(tab="valveDEA"));
            parameter Modelica.SIunits.Time Ta_valveDEA
              "Actuator time constant"                                           annotation (Dialog(tab="valveDEA"));
            parameter Real TS_valveDEA "Tracking signal" annotation (Dialog(tab="valveDEA"));

            PowerPressureFWcontrollers.staticDecoupled_4th
                                                       staticDecoupled_4th(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              A=A,
              B=B,
              C=C,
              D=D,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP_hotStart
                                          control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP)
              annotation (Placement(transformation(extent={{-20,40},{20,80}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=useTS_pumpFW_high) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-58,78},{-38,
                      98}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveTURB_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP_hotStart
                                           control_wSEP(
              load_switch=load_switch,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-80},{20,-40}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-60,-42},{-40,
                      -22}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-140},{20,-100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-60,-100},{-40,
                      -80}})));
            SingleControllers.control_wCOND control_wCOND(
              load_switch=load_switch,
              Kp_pumpCOND=Kp_pumpCOND,
              Ti_pumpCOND=Ti_pumpCOND,
              Td_pumpCOND=Td_pumpCOND,
              Nd_pumpCOND=Nd_pumpCOND,
              CSmin_pumpCOND=CSmin_pumpCOND,
              CSmax_pumpCOND=CSmax_pumpCOND,
              CSstart_pumpCOND=CSstart_pumpCOND,
              TS_pumpCOND=TS_pumpCOND,
              actuatorGain_pumpCOND=actuatorGain_pumpCOND,
              Ta_pumpCOND=Ta_pumpCOND)
              annotation (Placement(transformation(extent={{-20,-200},{20,-160}})));
            Modelica.Blocks.Sources.BooleanConstant TS_pump_COND(k=
                  useTS_pumpCOND)
              annotation (Placement(transformation(extent={{-60,-162},{-40,-142}})));
            SingleControllers.control_valveDEA control_valveDEA(
              Kp_valveDEA=Kp_valveDEA,
              Ti_valveDEA=Ti_valveDEA,
              Td_valveDEA=Td_valveDEA,
              Nd_valveDEA=Nd_valveDEA,
              CSmin_valveDEA=CSmin_valveDEA,
              CSmax_valveDEA=CSmax_valveDEA,
              CSstart_valveDEA=CSstart_valveDEA,
              actuatorGain_valveDEA=actuatorGain_valveDEA,
              Ta_valveDEA=Ta_valveDEA,
              TS_valveDEA=TS_valveDEA)
              annotation (Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_DEA(k=useTS_valveDEA)
              annotation (Placement(transformation(extent={{-60,-220},{-40,-200}})));
          equation
            connect(staticDecoupled_4th.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,60},{180,60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,0},{21,0},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, staticDecoupled_4th.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, staticDecoupled_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, staticDecoupled_4th.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-37,88},
                    {0,88},{0,82}},                color={255,0,255}));
            connect(load, control_wBP.load)
              annotation (Line(points={{-200,0},{-160,0},{-160,60},{-22,60}},
                                                                    color={0,0,127}));
            connect(load, staticDecoupled_4th.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-186,
                    0},{-160,0},{-22,0}},        color={0,0,127}));
            connect(TS_Y_t_high.y, staticDecoupled_4th.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, staticDecoupled_4th.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -60},{-22,-60}},    color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-60},{21,-60}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-39,-32},
                    {0,-32},{0,-38}},               color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-120},{21,-120},{180,-120},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-200,0},
                    {-160,0},{-160,-120},{-22,-120}},            color={0,0,127}));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-39,-90},{0,-90},{0,-98}},    color={255,0,255}));
            connect(TS_pump_COND.y, control_wCOND.TS_pumpCONDlow_bool) annotation (Line(
                  points={{-39,-152},{-10,-152},{-10,-158}}, color={255,0,255}));
            connect(load, control_wCOND.load) annotation (Line(points={{-200,0},{-160,0},{
                    -160,-180},{-22,-180}}, color={0,0,127}));
            connect(control_wCOND.signalBus, signalBus) annotation (Line(
                points={{21,-180},{102,-180},{180,-180},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveDEA.load) annotation (Line(points={{-200,0},{-180,0},
                    {-160,0},{-160,-240},{-22,-240}}, color={0,0,127}));
            connect(signalBus, control_valveDEA.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-240},{21,-240}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_DEA.y, control_valveDEA.TS_valveDEA_bool)
              annotation (Line(points={{-39,-210},{-20,-210},{0,-210},{0,-218}},
                  color={255,0,255}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_hotStart;

          model plantController_hotStart_FF
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpCOND "FF only on COND pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Integer n=10 "Number of elements fro optimization vector";
            parameter Modelica.SIunits.Time time_vec[n] "Time vector";

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.MassFlowRate wMS_vec[n]
              "MS mass flow vector";

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.MassFlowRate wFW_vec[n]
              "FW mass flow vector";

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));
            parameter Real thetaBP_vec[n] "HPH2 bypass valve position vector";

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            //-- pumpCOND --
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                              annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmin_pumpCOND "Minimum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSmax_pumpCOND "Maximum value of control signal"  annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND",group="Deaerator level control"));

            PowerPressureFWcontrollers.startUpOptim_FF startUpOptim_FF(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              n=n,
              time_vec=time_vec,
              wMS_vec=wMS_vec,
              wFW_vec=wFW_vec)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP_hotStart_FF
                                          control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP,
              n=n,
              time_vec=time_vec,
              thetaBP_vec=thetaBP_vec)
              annotation (Placement(transformation(extent={{-20,40},{20,80}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=true) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=true) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-60,80},{-40,
                      100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=true)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP_hotStart
                                           control_wSEP(
              load_switch=load_switch,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-100},{20,-60}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-60,-62},{-40,
                      -42}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-20,-180},{20,-140}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-60,-140},{-40,
                      -120}})));
            SingleControllers.control_wCOND control_wCOND(
              load_switch=load_switch,
              Kp_pumpCOND=Kp_pumpCOND,
              Ti_pumpCOND=Ti_pumpCOND,
              Td_pumpCOND=Td_pumpCOND,
              Nd_pumpCOND=Nd_pumpCOND,
              CSmin_pumpCOND=CSmin_pumpCOND,
              CSmax_pumpCOND=CSmax_pumpCOND,
              CSstart_pumpCOND=CSstart_pumpCOND,
              TS_pumpCOND=TS_pumpCOND,
              actuatorGain_pumpCOND=actuatorGain_pumpCOND,
              Ta_pumpCOND=Ta_pumpCOND)
              annotation (Placement(transformation(extent={{-20,-260},{20,-220}})));
            Modelica.Blocks.Sources.BooleanConstant TS_pump_COND(k=
                  useTS_pumpCOND)
              annotation (Placement(transformation(extent={{-60,-222},{-40,-202}})));
            Modelica.Blocks.Sources.Constant valveDEA_CS(k=0)
              annotation (Placement(transformation(extent={{-10,-300},{10,-280}})));
          equation
            connect(startUpOptim_FF.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,60},{180,60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,0},{21,0},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, startUpOptim_FF.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, startUpOptim_FF.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, startUpOptim_FF.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-39,90},
                    {0,90},{0,82}},                color={255,0,255}));
            connect(load, startUpOptim_FF.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-186,
                    0},{-160,0},{-22,0}},        color={0,0,127}));
            connect(TS_Y_t_high.y, startUpOptim_FF.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, startUpOptim_FF.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -80},{-22,-80}},    color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-80},{21,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-39,-52},
                    {0,-52},{0,-58}},               color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-160},{21,-160},{180,-160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-200,0},
                    {-160,0},{-160,-160},{-22,-160}},            color={0,0,127}));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-39,-130},{0,-130},{0,-138}}, color={255,0,255}));
            connect(TS_pump_COND.y, control_wCOND.TS_pumpCONDlow_bool) annotation (Line(
                  points={{-39,-212},{-10,-212},{-10,-218}}, color={255,0,255}));
            connect(load, control_wCOND.load) annotation (Line(points={{-200,0},{-160,0},{
                    -160,-240},{-22,-240}}, color={0,0,127}));
            connect(control_wCOND.signalBus, signalBus) annotation (Line(
                points={{21,-240},{21,-240},{180,-240},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_CS, valveDEA_CS.y) annotation (Line(
                points={{180,0},{180,0},{180,-288},{180,-290},{11,-290}},
                color={255,204,51},
                thickness=0.5));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_hotStart_FF;

          model plantController_HPpart_hotStart_FF
            "Plant controller model with PI/PID controller, a static decoupler between wMS e wFW and a 4th order controller on wFW"

          extends
              PreFlexMS.FullScale_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_valveTURB_low
              "FF only on turbine valve (@low load)"                                     annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveBP "FF only on by-pass valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpCOND "FF only on COND pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Integer n=10 "Number of elements fro optimization vector";
            parameter Modelica.SIunits.Time time_vec[n] "Time vector";
            parameter Modelica.SIunits.Time time_high[n]
              "Time vector for FW signal";

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.MassFlowRate wMS_vec[n]
              "MS mass flow vector";

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.MassFlowRate wFW_vec[n]
              "FW mass flow vector";

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveBP --
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));
            parameter Real thetaBP_vec[n] "HPH2 bypass valve position vector";

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            PowerPressureFWcontrollers.startUpOptim_FF startUpOptim_FF(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveTURB=actuatorGain_valveTURB,
              Ta_valveTURB=Ta_valveTURB,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low,
              load_switch=load_switch,
              n=n,
              time_vec=time_vec,
              wMS_vec=wMS_vec,
              wFW_vec=wFW_vec,
              time_high=time_high)
              annotation (Placement(transformation(extent={{-40,122},{40,198}})));
            SingleControllers.control_wBP_hotStart_FF
                                          control_wBP(
              Kp_valveBP=Kp_valveBP,
              Ti_valveBP=Ti_valveBP,
              Td_valveBP=Td_valveBP,
              Nd_valveBP=Nd_valveBP,
              CSmin_valveBP=CSmin_valveBP,
              CSmax_valveBP=CSmax_valveBP,
              CSstart_valveBP=CSstart_valveBP,
              actuatorGain_valveBP=actuatorGain_valveBP,
              Ta_valveBP=Ta_valveBP,
              TS_valveBP=TS_valveBP,
              n=n,
              time_high=time_high,
              thetaBP_vec=thetaBP_vec)
              annotation (Placement(transformation(extent={{-20,40},{20,80}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=true) annotation (Placement(transformation(extent={{-80,210},
                      {-60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(
              k=true) annotation (Placement(transformation(extent={{60,260},
                      {40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{80,210},
                      {60,230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_theta_BP(
              k=useTS_valveBP) annotation (Placement(transformation(extent={{-60,80},{-40,
                      100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=true)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveTURB_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_wSEP_hotStart
                                           control_wSEP(
              load_switch=load_switch,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-20,-100},{20,-60}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-60,-62},{-40,
                      -42}})));
            SingleControllers.control_valveSEP_hotStart
                                               control_valveSEP(
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max,
              load_min=load_switch)                             annotation (
                Placement(transformation(extent={{-20,-180},{20,-140}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-60,-140},{-40,
                      -120}})));
          equation
            connect(startUpOptim_FF.signalBus, signalBus) annotation (Line(
                points={{42.2,160},{42.2,160},{180,160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wBP.signalBus, signalBus) annotation (Line(
                points={{21,60},{180,60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{21,0},{21,0},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, startUpOptim_FF.TS_pumpMS_bool) annotation (
                Line(points={{-59,220},{-32,220},{-32,199.727}},color={255,0,
                    255}));
            connect(TS_w_FW_high.y, startUpOptim_FF.TS_pumpFWhigh_bool)
              annotation (Line(points={{39,270},{16,270},{16,199.727}},   color=
                   {255,0,255}));
            connect(TS_w_FW_low.y, startUpOptim_FF.TS_pumpFWlow_bool)
              annotation (Line(points={{59,220},{32,220},{32,199.727}},   color=
                   {255,0,255}));
            connect(TS_theta_BP.y, control_wBP.TS_valveBP_bool) annotation (Line(points={{-39,90},
                    {0,90},{0,82}},                color={255,0,255}));
            connect(load, startUpOptim_FF.load) annotation (Line(points={{-200,0},
                    {-160,0},{-160,160},{-42,160}},     color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-186,
                    0},{-160,0},{-22,0}},        color={0,0,127}));
            connect(TS_Y_t_high.y, startUpOptim_FF.TS_valveTURBhigh_bool) annotation (
               Line(points={{-59,250},{-16,250},{-16,199.727}},color={255,0,255}));
            connect(TS_Y_t_low.y, startUpOptim_FF.TS_valveTURBlow_bool) annotation (
                Line(points={{-59,280},{-30,280},{0,280},{0,199.727}},     color={255,0,255}));
            connect(load,control_wSEP. load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -80},{-22,-80}},    color={0,0,127}));
            connect(signalBus,control_wSEP. signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-80},{21,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y,control_wSEP. TS_pumpSEP_bool) annotation (Line(points={{-39,-52},
                    {0,-52},{0,-58}},               color={255,0,255}));
            connect(control_valveSEP.signalBus, signalBus) annotation (Line(
                points={{21,-160},{21,-160},{180,-160},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (
                Line(points={{-39,-130},{0,-130},{0,-138}}, color={255,0,255}));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-160,0},
                    {-160,-160},{-22,-160}}, color={0,0,127}));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end plantController_HPpart_hotStart_FF;
        end PlantControlSchemes;

      end Schemes;

      package Linearization "Test for process linearization and PID tuning"

        model Plant_HP_IO_100
          "Model of the high pressure parto of the OTSG for linearization at 100% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                               annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
            controllers(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_start=100,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            load_end=100,
            t_ramp=0,
            t_start_ramp=0,
            t_start_ramp_TS=15000,
            Kp_pumpMS=4.57e-4,
            Ti_pumpMS=98.66,
            Td_pumpMS=1.128,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.08e-11,
            Ti_valveTURB=2.164,
            CSmax_pumpFW=0.3,
            Kp_valveBP=-7.93e-6,
            Ti_valveBP=0.001,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=50,
            TS_start=false,
            T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100])
                                     annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                                                                iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}),
                                                            iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},
                  {-270,80},{-270,-24},{-261.5,-24}},   color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -160},{-270,-160},{-270,-56},{-261.5,-56}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                  100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
          connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
          connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80},{219,-80}}, color={0,0,127}));
          connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                  -120},{219,-120},{219,-120}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_100;

        model Plant_HP_IO_90
          "Model of the high pressure parto of the OTSG for linearization at 90% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                               annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
            controllers(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_start=100,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            TS_start=false,
            Kp_pumpMS=4.57e-4,
            Ti_pumpMS=98.66,
            Td_pumpMS=1.128,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.08e-11,
            Ti_valveTURB=2.164,
            CSmax_pumpFW=0.3,
            Kp_valveBP=-7.93e-6,
            Ti_valveBP=0.001,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=50,
            t_ramp=10000,
            t_start_ramp=5000,
            t_start_ramp_TS=20000,
            load_end=90,
            T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100])
                                     annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                                                                iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}),
                                                            iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},
                  {-270,80},{-270,-24},{-261.5,-24}},   color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -160},{-270,-160},{-270,-56},{-261.5,-56}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                  100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
          connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
          connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80},{219,-80}}, color={0,0,127}));
          connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                  -120},{219,-120},{219,-120}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=25000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_90;

        model Plant_HP_IO_80
          "Model of the high pressure parto of the OTSG for linearization at 80% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                               annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
            controllers(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_start=100,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            TS_start=false,
            Kp_pumpMS=4.57e-4,
            Ti_pumpMS=98.66,
            Td_pumpMS=1.128,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.08e-11,
            Ti_valveTURB=2.164,
            CSmax_pumpFW=0.3,
            Kp_valveBP=-7.93e-6,
            Ti_valveBP=0.001,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=50,
            load_end=80,
            t_ramp=20000,
            t_start_ramp=5000,
            t_start_ramp_TS=35000,
            T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100])
                                     annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                                                                iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}),
                                                            iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},
                  {-270,80},{-270,-24},{-261.5,-24}},   color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -160},{-270,-160},{-270,-56},{-261.5,-56}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                  100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
          connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
          connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80},{219,-80}}, color={0,0,127}));
          connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                  -120},{219,-120},{219,-120}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_80;

        model Plant_HP_IO_70
          "Model of the high pressure parto of the OTSG for linearization at 70% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                               annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
            controllers(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_start=100,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            TS_start=false,
            Kp_pumpMS=4.57e-4,
            Ti_pumpMS=98.66,
            Td_pumpMS=1.128,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.08e-11,
            Ti_valveTURB=2.164,
            CSmax_pumpFW=0.3,
            Kp_valveBP=-7.93e-6,
            Ti_valveBP=0.001,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=50,
            load_end=70,
            t_ramp=30000,
            t_start_ramp=5000,
            t_start_ramp_TS=45000,
            T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100])
                                     annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                                                                iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}),
                                                            iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},
                  {-270,80},{-270,-24},{-261.5,-24}},   color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -160},{-270,-160},{-270,-56},{-261.5,-56}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                  100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
          connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
          connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80},{219,-80}}, color={0,0,127}));
          connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                  -120},{219,-120},{219,-120}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_70;

        model Plant_HP_IO_60
          "Model of the high pressure parto of the OTSG for linearization at 60% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                               annotation (Placement(
                transformation(extent={{-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
            controllers(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            load_start=100,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            CSmax_valveTURB=0.04e-6,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSstart_valveBP=1,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            useTS_valveBP=true,
            TS_valveBP=0,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            TS_start=false,
            Kp_pumpMS=4.57e-4,
            Ti_pumpMS=98.66,
            Td_pumpMS=1.128,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.08e-11,
            Ti_valveTURB=2.164,
            CSmax_pumpFW=0.3,
            Kp_valveBP=-7.93e-6,
            Ti_valveBP=0.001,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            DT_SH_sp=20,
            Kp_pumpFW=-0.01,
            Ti_pumpFW=50,
            load_end=60,
            t_ramp=40000,
            t_start_ramp=5000,
            t_start_ramp_TS=55000,
            T_FW_sp=518.15,
            table_thetaBP(table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0.1; 70,
                  0.145652; 80,0.208685; 90,0.349201; 100,0.866205]))
                            annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            p0=18380000,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100])
                                     annotation (Placement(transformation(extent={{200,
                    -130},{180,-110}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_BP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                                                                iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}),
                                                            iconTransformation(extent={{
                    320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},
                  {-270,80},{-270,-24},{-261.5,-24}},   color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(du_theta_BP, controllers.du_thetaBP) annotation (Line(points={{-340,
                  -160},{-270,-160},{-270,-56},{-261.5,-56}},
                                                       color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                  100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
          connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
          connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80},{219,-80}}, color={0,0,127}));
          connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                  -120},{219,-120},{219,-120}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=60000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_60;

        model Plant_HP_IO_50
          "Model of the high pressure parto of the OTSG for linearization at 50% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                  annotation (Placement(transformation(extent={
                    {-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_lowLoad
            controllers(
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-0.9,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            CSmin_pumpFW=1,
            CSmax_pumpFW=100,
            CSstart_pumpFW=46.95,
            Ti_pumpFW=50,
            CSmax_pumpSEP=1,
            load_end=50,
            t_ramp=0,
            t_start_ramp=0,
            CSstart_pumpSEP=0,
            TS_start=false,
            load_start=50,
            Kp_pumpMS=1.47e-4,
            Ti_pumpMS=29.12,
            Td_pumpMS=4.255,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.52e-11,
            Ti_valveTURB=3.626,
            Kp_pumpFW=17.6,
            Kp_pumpSEP=0.0152,
            Ti_pumpSEP=2.267,
            CSmin_valveTURB=-1e-6,
            CSmax_valveTURB=1e-6,
            t_start_TS=15000,
            P_mec_sp=79725800,
            p_sp=17611000,
            T_MS_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100]) annotation (Placement(
                transformation(extent={{200,-130},{180,-110}})));

          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}), iconTransformation(extent=
                   {{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(LOAD5.y, HPH1_P_source.u[1]) annotation (Line(points={{219,-120},
                  {219,-120},{202,-120}}, color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},{-270,
                  80},{-270,-24},{-261.5,-24}},         color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-190,-40},{-180,-40},{-180,-200},{100.556,
                  -200},{100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{
                  -340,-160},{-306,-160},{-270,-160},{-270,-56},{-261.5,-56}},
                color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80}},           color={0,0,127}));
          connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                  127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=20000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_50;

        model Plant_HP_IO_40
          "Model of the high pressure parto of the OTSG for linearization at 40% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                  annotation (Placement(transformation(extent={
                    {-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_lowLoad
            controllers(
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-0.9,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            CSmin_pumpFW=1,
            CSmax_pumpFW=100,
            CSstart_pumpFW=46.95,
            Ti_pumpFW=50,
            CSmax_pumpSEP=1,
            CSstart_pumpSEP=0,
            TS_start=false,
            load_start=50,
            Kp_pumpMS=1.47e-4,
            Ti_pumpMS=29.12,
            Td_pumpMS=4.255,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.52e-11,
            Ti_valveTURB=3.626,
            Kp_pumpFW=17.6,
            Kp_pumpSEP=0.0152,
            Ti_pumpSEP=2.267,
            CSmin_valveTURB=-1e-6,
            CSmax_valveTURB=1e-6,
            P_mec_sp=79725800,
            load_end=40,
            t_start_ramp=2500,
            t_ramp=20000,
            t_start_TS=45000,
            p_sp=17611000,
            T_MS_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100]) annotation (Placement(
                transformation(extent={{200,-130},{180,-110}})));

          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}), iconTransformation(extent=
                   {{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(LOAD5.y, HPH1_P_source.u[1]) annotation (Line(points={{219,-120},
                  {219,-120},{202,-120}}, color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},{-270,
                  80},{-270,-24},{-261.5,-24}},         color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-190,-40},{-180,-40},{-180,-200},{100.556,
                  -200},{100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{
                  -340,-160},{-306,-160},{-270,-160},{-270,-56},{-261.5,-56}},
                color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80}},           color={0,0,127}));
          connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                  127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_40;

        model Plant_HP_IO_30
          "Model of the high pressure parto of the OTSG for linearization at 40% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                  annotation (Placement(transformation(extent={
                    {-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_lowLoad
            controllers(
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-0.9,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            CSmin_pumpFW=1,
            CSmax_pumpFW=100,
            CSstart_pumpFW=46.95,
            Ti_pumpFW=50,
            CSmax_pumpSEP=1,
            CSstart_pumpSEP=0,
            TS_start=false,
            load_start=50,
            Kp_pumpMS=1.47e-4,
            Ti_pumpMS=29.12,
            Td_pumpMS=4.255,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.52e-11,
            Ti_valveTURB=3.626,
            Kp_pumpFW=17.6,
            Kp_pumpSEP=0.0152,
            Ti_pumpSEP=2.267,
            CSmin_valveTURB=-1e-6,
            CSmax_valveTURB=1e-6,
            P_mec_sp=79725800,
            t_ramp=10000,
            t_start_ramp=2500,
            load_end=30,
            t_start_TS=45000,
            p_sp=17611000,
            T_MS_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100]) annotation (Placement(
                transformation(extent={{200,-130},{180,-110}})));

          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}), iconTransformation(extent=
                   {{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(LOAD5.y, HPH1_P_source.u[1]) annotation (Line(points={{219,-120},
                  {219,-120},{202,-120}}, color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},{-270,
                  80},{-270,-24},{-261.5,-24}},         color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-190,-40},{-180,-40},{-180,-200},{100.556,
                  -200},{100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{
                  -340,-160},{-306,-160},{-270,-160},{-270,-56},{-261.5,-56}},
                color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80}},           color={0,0,127}));
          connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                  127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_30;

        model Plant_HP_IO_20
          "Model of the high pressure parto of the OTSG for linearization at 40% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                  extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                  annotation (Placement(transformation(extent={
                    {-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
            HPHs annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_lowLoad
            controllers(
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            l_sp=4,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-0.9,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            CSmin_pumpFW=1,
            CSmax_pumpFW=100,
            CSstart_pumpFW=46.95,
            Ti_pumpFW=50,
            CSmax_pumpSEP=1,
            CSstart_pumpSEP=0,
            TS_start=false,
            load_start=50,
            Kp_pumpMS=1.47e-4,
            Ti_pumpMS=29.12,
            Td_pumpMS=4.255,
            CSmin_pumpMS=-0.5,
            CSmax_pumpMS=0.5,
            Kp_valveTURB=-1.52e-11,
            Ti_valveTURB=3.626,
            Kp_pumpFW=17.6,
            Kp_pumpSEP=0.0152,
            Ti_pumpSEP=2.267,
            CSmin_valveTURB=-1e-6,
            CSmax_valveTURB=1e-6,
            P_mec_sp=79725800,
            t_ramp=10000,
            t_start_ramp=2500,
            load_end=20,
            t_start_TS=45000,
            p_sp=17611000,
            T_MS_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100]) annotation (Placement(
                transformation(extent={{200,-130},{180,-110}})));

          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,-100},{-320,-60}}),  iconTransformation(
                  extent={{-360,-100},{-320,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}), iconTransformation(extent=
                   {{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(LOAD5.y, HPH1_P_source.u[1]) annotation (Line(points={{219,-120},
                  {219,-120},{202,-120}}, color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},{-270,
                  80},{-270,-24},{-261.5,-24}},         color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(du_w_FW, controllers.du_w_FW) annotation (Line(points={{-340,
                  -80},{-340,-80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}},
                                                                color={0,0,127}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-190,-40},{-180,-40},{-180,-200},{100.556,
                  -200},{100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{
                  -340,-160},{-306,-160},{-270,-160},{-270,-56},{-261.5,-56}},
                color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80}},           color={0,0,127}));
          connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                  127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=50000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_20;

        model Feedwater_train_IO_100
          "Test model of the HPHs, LPHs, DEA and turbine for levels control tuning"
          import PreFlexMS;

          PreFlexMS.FullScale_245degC.HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_lin
            HPHs(
            t_start_TS=preheaters_dea_controller_lin.t_start_ramp_TS,
            HPH2(
              NusseltCondenser(ws_in(start=1, fixed=true)),
              CSstart=0.2,
              Kp=-9.298,
              Ti=228.5),
            HPH1(
              NusseltCondenser(ws_in(start=3, fixed=true)),
              CSstart=0.2,
              Kp=-2.52,
              Ti=571.4)) annotation (Placement(transformation(extent={{-232,-120},
                    {-92,-40}})));
          ThermoPower.Water.SourcePressure sourcePressure(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=1384500,
            p0=18140000,
            use_in_p0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-268,-230},{-248,-210}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=17910000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{-300,-70},{-320,-90}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-480,300},{-460,320}})));
          Modelica.Blocks.Sources.Constant pumpFW_PV(k=0) annotation (Placement(
                transformation(extent={{-62,-266},{-54,-258}})));
          Modelica.Blocks.Sources.Constant pumpHPH_PV(k=0) annotation (
              Placement(transformation(extent={{-62,-280},{-54,-272}})));
          Modelica.Blocks.Sources.Constant pumpMS_PV(k=0) annotation (Placement(
                transformation(extent={{-62,-298},{-54,-290}})));
          Modelica.Blocks.Sources.Constant pumpSEP_PV(k=0) annotation (
              Placement(transformation(extent={{-62,-314},{-54,-306}})));
          Modelica.Blocks.Sources.Constant valveRH_PV(k=0)
            annotation (Placement(transformation(extent={{-44,-306},{-36,-298}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{26,-226},{38,-214}}),
                iconTransformation(extent={{-12,-146},{0,-134}})));
          Modelica.Blocks.Sources.Constant valveTURB_PV(k=0)
            annotation (Placement(transformation(extent={{-44,-288},{-36,-280}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-370,-160})));
          Modelica.Blocks.Tables.CombiTable1D HPH_sourceH(table=[20,1232.1e3;
                30,1252.4e3; 40,1262e3; 50,1256.5e3; 60,1118.1e3; 70,1062.2e3;
                80,1062.4e3; 90,1293.5e3; 100,1289e3])   annotation (Placement(
                transformation(extent={{-340,-170},{-320,-150}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-370,-190})));
          Modelica.Blocks.Tables.CombiTable1D HPH_sourceP(table=[20,86.35e5;
                30,88.66e5; 40,91.88e5; 50,98.91e5; 60,119.1e5; 70,131.6e5;
                80,147.2e5; 90,162.3e5; 100,176.3e5])
                                          annotation (Placement(transformation(
                  extent={{-340,-200},{-320,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-372,-110})));
          Modelica.Blocks.Tables.CombiTable1D FW_sinkP(table=[20,85.44e5; 30,
                86.74e5; 40,87.97e5; 50,92.49e5; 60,109.5e5; 70,126.1e5; 80,
                142e5; 90,157.8e5; 100,174e5])   annotation (Placement(
                transformation(extent={{-342,-120},{-322,-100}})));
          ThermoPower.Water.SensT sensT(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{-262,-86},{-282,-66}})));
          PreFlexMS.FullScale_245degC.SteamTurbine.Corps.HPT HPTurb(w_seal=
                0.022) annotation (Placement(transformation(extent={{-220,122},
                    {-144,198}})));
          PreFlexMS.FullScale_245degC.SteamTurbine.Corps.IPT IPTurb
            annotation (Placement(transformation(extent={{-86,122},{-4,198}})));
          PreFlexMS.FullScale_245degC.SteamTurbine.Corps.LPT LPTurb(w_seal_1=
                0.0182, w_seal_2=0.0076) annotation (Placement(transformation(
                  extent={{170,122},{254,198}})));
          PreFlexMS.FullScale_245degC.HeatExchangers.Components.Deaerator
                                              deaerator(
            L=12,
            H=2.677,
            zl_start=2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            h_start=1e6,
            w_small=100,
            p_start=1086000)
            annotation (Placement(transformation(extent={{-54,-84},{56,26}})));
          PreFlexMS.FullScale_245degC.HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_lin
            LPHs(
            t_start_TS=preheaters_dea_controller_lin.t_start_ramp_TS,
            LPH2(
              NusseltCondenser(p(start=1.893e5, fixed=true)),
              Kp=-16.77,
              Ti=228.5),
            LPH1(
              NusseltCondenser(p(start=0.5515e5, fixed=true)),
              Scold_cond=400,
              Kp=-4.432,
              Ti=571.4),
            LPH3(
              NusseltCondenser(p(start=280000, fixed=true)),
              Kp=-100.8,
              Ti=114.3))
            annotation (Placement(transformation(extent={{100,-38},{280,44}})));
          ThermoPower.Water.SinkPressure sinkPressure_LPTurb(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            use_in_p0=true,
            p0=900000)
            annotation (Placement(transformation(extent={{320,174},{340,194}})));
          Modelica.Blocks.Tables.CombiTable1D LPTurb_sinkP(table=[20,0.051e5; 30,0.0579e5;
                40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,0.1028e5; 90,0.1137e5;
                100,0.126e5])
            annotation (Placement(transformation(extent={{360,210},{340,230}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph,
            p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{320,30},{340,50}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=742500,
            use_in_h=true,
            p0=900000)
            annotation (Placement(transformation(extent={{340,12},{320,-8}})));
          Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                transformation(extent={{360,-80},{340,-60}})));
          Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
             Placement(transformation(extent={{360,60},{340,80}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                            w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{-280,150},{-260,170}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph, w0=0,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-260,-30},{-240,-10}})));
          Modelica.Blocks.Sources.Ramp LOAD11(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-310,40})));
          Modelica.Blocks.Tables.CombiTable1D sep_sourceH(table=[20,1342e3;
                30,1343.3e3; 40,1344.8e3; 50,1361.9e3; 60,1444.4e3; 70,
                1511.3e3; 80,1573.6e3; 90,1634.9e3; 100,1700.4e3])
                                                         annotation (Placement(
                transformation(extent={{-280,30},{-260,50}})));
          Modelica.Blocks.Sources.Ramp LOAD12(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-310,10})));
          Modelica.Blocks.Tables.CombiTable1D sep_sourceW(table=[20,55.97; 30,
                85.48; 40,104.3; 50,79.95; 60,0; 70,0; 80,0; 90,0; 100,0])
            annotation (Placement(transformation(extent={{-280,0},{-260,20}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={390,220})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={390,70})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={390,-70})));
          ThermoPower.Water.SourcePressure sourcePressure_HPTurb(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=1384500,
            use_in_p0=true,
            use_in_h=true,
            p0=18140000)
            annotation (Placement(transformation(extent={{-280,210},{-260,230}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-350,280})));
          Modelica.Blocks.Tables.CombiTable1D HPTurb_sourceH(table=[20,3540e3; 30,3534e3;
                40,3528e3; 50,3516e3; 60,3498e3; 70,3475e3; 80,3452e3; 90,3428e3; 100,3427e3])
            annotation (Placement(transformation(extent={{-320,270},{-300,290}})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-350,250})));
          Modelica.Blocks.Tables.CombiTable1D HPTurb_sourceP(table=[20,34.2e5; 30,51.8e5;
                40,69.6e5; 50,88.3e5; 60,107.2e5; 70,123.4e5; 80,138.9e5; 90,154.3e5; 100,
                170.1e5])
            annotation (Placement(transformation(extent={{-320,240},{-300,260}})));
          ThermoPower.Water.SourcePressure sourcePressure_IPTurb(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=1384500,
            use_in_p0=true,
            use_in_h=true,
            p0=18140000)
            annotation (Placement(transformation(extent={{-120,210},{-100,230}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-190,280})));
          Modelica.Blocks.Tables.CombiTable1D IPH_sourceH(table=[20,3617e3; 30,3611e3; 40,
                3604e3; 50,3597e3; 60,3589e3; 70,3579e3; 80,3571e3; 90,3562e3; 100,3552e3])
            annotation (Placement(transformation(extent={{-160,270},{-140,290}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-190,250})));
          Modelica.Blocks.Tables.CombiTable1D IPH_sourceP(table=[20,8.641e5; 30,13.02e5;
                40,17.46e5; 50,22.15e5; 60,26.83e5; 70,31.95e5; 80,36.38e5; 90,41.13e5;
                100,46.24e5])
            annotation (Placement(transformation(extent={{-160,240},{-140,260}})));
          ThermoPower.Water.SinkPressure sinkPressure_IPTurb(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            use_in_p0=true,
            p0=17910000)
            annotation (Placement(transformation(extent={{-260,70},{-280,90}})));
          Modelica.Blocks.Sources.Ramp LOAD13(
            height=preheaters_dea_controller_lin.load_end - preheaters_dea_controller_lin.load_start,
            duration=preheaters_dea_controller_lin.t_ramp,
            offset=preheaters_dea_controller_lin.load_start,
            startTime=preheaters_dea_controller_lin.load_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-330,110})));
          Modelica.Blocks.Tables.CombiTable1D HPTurb_sinkP(table=[20,8.932e5; 30,13.46e5;
                40,18.05e5; 50,22.9e5; 60,27.74e5; 70,33.04e5; 80,37.62e5; 90,42.53e5; 100,
                47.82e5])
            annotation (Placement(transformation(extent={{-300,100},{-280,120}})));
          PreFlexMS.FullScale_245degC.Control.Schemes.LinearizationSchemes.preheaters_dea_controller_lin
            preheaters_dea_controller_lin(
            load_start=100,
            t_ramp=80000,
            t_start_ramp=5000,
            t_start_ramp_TS=95000,
            TS_start=false,
            actuatorGain_pumpMS=1,
            Ta_pumpMS=2,
            actuatorGain_valveTURB=1,
            Ta_valveTURB=0.3,
            step_wFW_height=0,
            step_wFW_start=0,
            actuatorGain_pumpFW=1,
            Ta_pumpFW=2,
            actuatorGain_pumpHPH=1,
            Ta_pumpHPH=2,
            Kp_valveBP=-7.925e-6,
            Ti_valveBP=0.001,
            Td_valveBP=0,
            Nd_valveBP=20,
            CSmin_valveBP=-1,
            CSmax_valveBP=1,
            CSstart_valveBP=0,
            actuatorGain_valveBP=1,
            Ta_valveBP=0.3,
            TS_valveBP=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=20,
            CSmin_pumpCOND=5,
            CSmax_pumpCOND=100,
            CSstart_pumpCOND=77,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            step_wCOND_height=0,
            step_wCOND_start=0,
            useTS_valveBP=false,
            load_end=20,
            T_FW_sp=518.15,
            Kp_pumpCOND=1539,
            Ti_pumpCOND=1143)
            annotation (Placement(transformation(extent={{160,-250},{80,-190}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{220,-240},{180,-200}}), iconTransformation(
                  extent={{-454,170},{-414,210}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_HPH2 annotation (Placement(
                transformation(extent={{-300,-130},{-260,-90}}), iconTransformation(
                  extent={{-508,232},{-468,272}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_HPH1 annotation (Placement(
                transformation(extent={{-300,-160},{-260,-120}}), iconTransformation(
                  extent={{-488,118},{-448,158}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_LPH3 annotation (Placement(
                transformation(extent={{36,-34},{76,6}}), iconTransformation(extent={{-484,
                    214},{-444,254}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_LPH2 annotation (Placement(
                transformation(extent={{36,-66},{76,-26}}), iconTransformation(extent={{
                    -508,186},{-468,226}})));
          Modelica.Blocks.Interfaces.RealInput du_theta_LPH1 annotation (Placement(
                transformation(extent={{40,-120},{80,-80}}),iconTransformation(extent={{
                    -506,200},{-466,240}})));
          Modelica.Blocks.Interfaces.RealOutput l_dea = deaerator.zl annotation (Placement(
                transformation(extent={{460,190},{480,210}}), iconTransformation(extent=
                   {{-672,342},{-652,362}})));
          Modelica.Blocks.Interfaces.RealOutput l_HPH2 = HPHs.HPH2.NusseltCondenser.zl annotation (Placement(
                transformation(extent={{460,110},{480,130}}), iconTransformation(extent=
                   {{-672,342},{-652,362}})));
          Modelica.Blocks.Interfaces.RealOutput l_HPH1 = HPHs.HPH1.NusseltCondenser.zl annotation (Placement(
                transformation(extent={{460,30},{480,50}}), iconTransformation(extent={{
                    -672,342},{-652,362}})));
          Modelica.Blocks.Interfaces.RealOutput l_LPH3 = LPHs.LPH3.NusseltCondenser.zl annotation (Placement(
                transformation(extent={{460,-50},{480,-30}}), iconTransformation(extent=
                   {{-672,342},{-652,362}})));
          Modelica.Blocks.Interfaces.RealOutput l_LPH2 = LPHs.LPH2.NusseltCondenser.zl annotation (Placement(
                transformation(extent={{460,-130},{480,-110}}), iconTransformation(
                  extent={{-672,342},{-652,362}})));
          Modelica.Blocks.Interfaces.RealOutput l_LPH1 = LPHs.LPH1.NusseltCondenser.zl annotation (Placement(
                transformation(extent={{460,-210},{480,-190}}), iconTransformation(
                  extent={{-672,342},{-652,362}})));
        equation
          connect(sourcePressure.flange, HPHs.MS_HPH_in) annotation (Line(
              points={{-248,-220},{-146.444,-220},{-146.444,-124}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(signalBus.pumpFW_PV, pumpFW_PV.y) annotation (Line(
              points={{32,-220},{32,-220},{32,-262},{-53.6,-262}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, pumpHPH_PV.y) annotation (Line(
              points={{32,-220},{32,-220},{32,-276},{-53.6,-276}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, valveTURB_PV.y) annotation (Line(
              points={{32,-220},{32,-284},{-35.6,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_PV, valveRH_PV.y) annotation (Line(
              points={{32,-220},{32,-220},{32,-302},{-35.6,-302}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, pumpMS_PV.y) annotation (Line(
              points={{32,-220},{32,-220},{32,-294},{-53.6,-294}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, pumpSEP_PV.y) annotation (Line(
              points={{32,-220},{32,-220},{32,-310},{-53.6,-310}},
              color={255,204,51},
              thickness=0.5));
          connect(HPH_sourceH.y[1], sourcePressure.in_h) annotation (Line(
                points={{-319,-160},{-304,-160},{-254,-160},{-254,-211}},
                                                                    color={0,0,
                  127}));
          connect(LOAD1.y, HPH_sourceH.u[1]) annotation (Line(points={{-359,-160},{-350,
                  -160},{-342,-160}},     color={0,0,127}));
          connect(LOAD2.y, HPH_sourceP.u[1]) annotation (Line(points={{-359,-190},{-350,
                  -190},{-342,-190}},     color={0,0,127}));
          connect(HPH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
                points={{-319,-190},{-306,-190},{-262,-190},{-262,-210.8}},
                                                                      color={0,
                  0,127}));
          connect(LOAD3.y, FW_sinkP.u[1]) annotation (Line(points={{-361,-110},{-352,-110},
                  {-344,-110}},        color={0,0,127}));
          connect(FW_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{-321,-110},
                  {-306,-110},{-306,-88.8}},                color={0,0,127}));
          connect(sensT.inlet, HPHs.FW_out)
            annotation (Line(points={{-266,-80},{-235.889,-80}},
                                                            color={0,0,255}));
          connect(sinkPressure.flange, sensT.outlet)
            annotation (Line(points={{-300,-80},{-296,-80},{-278,-80}},
                                                         color={0,0,255}));
          connect(LPTurb_sinkP.y[1], sinkPressure_LPTurb.in_p0) annotation (Line(points=
                 {{339,220},{326,220},{326,192.8}}, color={0,0,127}));
          connect(LPTurb.vap_out, sinkPressure_LPTurb.flange) annotation (Line(
              points={{258.2,182.8},{320,182.8},{320,184}},
              color={0,0,255},
              thickness=0.5));
          connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                points={{339,-70},{326,-70},{326,-7}}, color={0,0,127}));
          connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                points={{339,70},{326,70},{326,48.8}}, color={0,0,127}));
          connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(points={{1,
                  -72.2143},{1,-80},{-88.1111,-80}},
                                           color={0,0,255}));
          connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(points={{
                  -88.1111,-56},{-88.1111,-56.5},{-50.0714,-56.5}},
                                                           color={0,0,255}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(points={{-182,118.2},{
                  -182,-36},{-181.444,-36}},
                                   color={0,0,255}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(points={{-58.94,118.2},
                  {-58.94,80},{-130.889,80},{-130.889,-36}},
                                                     color={0,0,255}));
          connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(points={{-40.08,
                  118.2},{-40.08,-21.1429},{-13.9286,-21.1429}},
                                                          color={0,0,255}));
          connect(deaerator.water_in, LPHs.FW_out) annotation (Line(points={{15.1429,
                  2.42857},{54.5714,2.42857},{54.5714,3},{96.25,3}},
                                                            color={0,0,255}));
          connect(LPHs.FW_in, sourcePressure1.flange)
            annotation (Line(points={{283.75,3},{283.75,2},{320,2}}, color={0,0,255}));
          connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(points={{283.75,
                  27.6},{300,27.6},{300,40},{320,40}}, color={0,0,255}));
          connect(IPTurb.SP3, LPHs.SP4) annotation (Line(points={{-20.4,118.2},{-20.4,80},
                  {137.5,80},{137.5,48.1}}, color={0,0,255}));
          connect(LPTurb.SP2, LPHs.SP5) annotation (Line(points={{189.32,118.2},{189.32,
                  84.1},{190,84.1},{190,48.1}}, color={0,0,255}));
          connect(LPTurb.SP1, LPHs.SP6) annotation (Line(points={{215.36,118.2},{215.36,
                  80},{242.5,80},{242.5,48.1}}, color={0,0,255}));
          connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(points={{0.1,182.8},{83.05,
                  182.8},{165.8,182.8}}, color={0,0,255}));
          connect(signalBus, HPHs.signalBus) annotation (Line(
              points={{32,-220},{-119.222,-220},{-119.222,-121.6}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus, LPHs.signalBus) annotation (Line(
              points={{32,-220},{32,-220},{32,-120},{190,-120},{190,-38}},
              color={255,204,51},
              thickness=0.5));
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in)
            annotation (Line(points={{-140.2,160},{-90.1,160}}, color={0,0,0}));
          connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
            annotation (Line(points={{0.1,160},{165.8,160}}, color={0,0,0}));
          connect(constantSpeed1.flange, HPTurb.flange_HP_in)
            annotation (Line(points={{-260,160},{-223.8,160}}, color={0,0,0}));
          connect(LOAD11.y,sep_sourceH. u[1]) annotation (Line(points={{-299,40},{-290,40},
                  {-282,40}},                  color={0,0,127}));
          connect(LOAD12.y,sep_sourceW. u[1]) annotation (Line(points={{-299,10},{-282,10}},
                                        color={0,0,127}));
          connect(sep_sourceW.y[1],sourceMassFlow. in_w0) annotation (Line(
                points={{-259,10},{-254,10},{-254,-14}},color={0,0,127}));
          connect(sep_sourceH.y[1],sourceMassFlow. in_h) annotation (Line(
                points={{-259,40},{-246,40},{-246,-14}},  color={0,0,127}));
          connect(sourceMassFlow.flange, HPHs.SEP_in) annotation (Line(points={{-240,
                  -20},{-208.667,-20},{-208.667,-36}},
                                                  color={0,0,255}));
          connect(LPTurb_sinkP.u[1], LOAD4.y)
            annotation (Line(points={{362,220},{379,220}}, color={0,0,127}));
          connect(cond_sinkP.u[1], LOAD5.y)
            annotation (Line(points={{362,70},{379,70}}, color={0,0,127}));
          connect(FW_sourceH.u[1], LOAD6.y)
            annotation (Line(points={{362,-70},{379,-70},{379,-70}}, color={0,0,127}));
          connect(HPTurb_sourceH.y[1], sourcePressure_HPTurb.in_h) annotation (Line(
                points={{-299,280},{-299,278},{-266,278},{-266,229}}, color={0,0,127}));
          connect(LOAD7.y, HPTurb_sourceH.u[1]) annotation (Line(points={{-339,280},{-330,
                  280},{-322,280}}, color={0,0,127}));
          connect(LOAD8.y, HPTurb_sourceP.u[1]) annotation (Line(points={{-339,250},{-330,
                  250},{-322,250}}, color={0,0,127}));
          connect(HPTurb_sourceP.y[1], sourcePressure_HPTurb.in_p0) annotation (Line(
                points={{-299,250},{-299,250},{-274,250},{-274,229.2}}, color={0,0,127}));
          connect(IPH_sourceH.y[1], sourcePressure_IPTurb.in_h) annotation (Line(points=
                 {{-139,280},{-139,280},{-106,280},{-106,229}}, color={0,0,127}));
          connect(LOAD9.y, IPH_sourceH.u[1]) annotation (Line(points={{-179,280},{-170,280},
                  {-162,280}}, color={0,0,127}));
          connect(LOAD10.y, IPH_sourceP.u[1]) annotation (Line(points={{-179,250},{-170,
                  250},{-162,250}}, color={0,0,127}));
          connect(IPH_sourceP.y[1], sourcePressure_IPTurb.in_p0) annotation (Line(
                points={{-139,250},{-139,250},{-114,250},{-114,229.2}}, color={0,0,127}));
          connect(sourcePressure_HPTurb.flange, HPTurb.vap_in) annotation (Line(points={
                  {-260,220},{-244,220},{-223.8,220},{-223.8,182.8}}, color={0,0,255}));
          connect(sourcePressure_IPTurb.flange, IPTurb.vap_in) annotation (Line(points={
                  {-100,220},{-94,220},{-90.1,220},{-90.1,182.8}}, color={0,0,255}));
          connect(LOAD13.y, HPTurb_sinkP.u[1]) annotation (Line(points={{-319,110},{-310,
                  110},{-302,110}}, color={0,0,127}));
          connect(HPTurb_sinkP.y[1], sinkPressure_IPTurb.in_p0) annotation (Line(points=
                 {{-279,110},{-272,110},{-266,110},{-266,88.8}}, color={0,0,127}));
          connect(sinkPressure_IPTurb.flange, HPTurb.vap_out) annotation (Line(points={{
                  -260,80},{-223.8,80},{-223.8,129.6}}, color={0,0,255}));
          connect(preheaters_dea_controller_lin.signalBus, signalBus) annotation (Line(
              points={{78,-220},{56,-220},{32,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(preheaters_dea_controller_lin.du_w_COND, du_w_COND) annotation (Line(
                points={{162,-220},{172,-220},{200,-220}}, color={0,0,127}));
          connect(du_theta_HPH2, HPHs.dtheta2) annotation (Line(points={{-280,
                  -110},{-252,-110},{-252,-96},{-235.889,-96}},
                                                    color={0,0,127}));
          connect(du_theta_HPH1, HPHs.dtheta1) annotation (Line(points={{-280,
                  -140},{-246,-140},{-246,-112},{-235.889,-112}},
                                                      color={0,0,127}));
          connect(du_theta_LPH3, LPHs.dtheta3) annotation (Line(points={{56,-14},{75,-14},
                  {75,-13.4},{96.25,-13.4}}, color={0,0,127}));
          connect(du_theta_LPH2, LPHs.dtheta2) annotation (Line(points={{56,-46},{80,-46},
                  {80,-25.7},{96.25,-25.7}}, color={0,0,127}));
          connect(du_theta_LPH1, LPHs.dtheta1) annotation (Line(points={{60,-100},{88,-100},
                  {88,-38},{96.25,-38}}, color={0,0,127}));
          connect(signalBus.valveBP_PV, sensT.T) annotation (Line(
              points={{32,-220},{-120,-220},{-120,-260},{-400,-260},{-400,-60},{-286,-60},
                  {-286,-70},{-280,-70}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpCOND_PV, deaerator.level) annotation (Line(
              points={{32,-220},{32,-220},{32,-78},{32,-72},{60,-72},{60,
                  -60.4286},{52.0714,-60.4286}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-480,
                    -320},{480,320}})),
            Icon(coordinateSystem(extent={{-480,-320},{480,320}})),
            experiment(StopTime=100000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput(equidistant=false));
        end Feedwater_train_IO_100;
      end Linearization;

      package Test "Package containing control tests"
        model test_dryWetTransition
          "Test model to check the control switch between dry and wet mode of the separator"

          HeatExchangers.Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                  1.66591e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                623.137}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={199579,192529,183185,168175,136603},
              noInitialPressure=true),
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=5,
            nominalColdPressure=11500000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72) annotation (Placement(
                transformation(extent={{-134,-180},{-166,-148}})));

          HeatExchangers.Components.HE_2ph EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                  1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,
                  2.02847e+006,2.29575e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                629.917,629.888,630.182,630.842,632.016,634.097}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                  199646,197679},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                gamma_nom_2ph=10000,
                alpha=1.6),
            Shot=2251.9,
            Scold=1765.5,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalColdPressure=11400000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15)
                                       annotation (Placement(transformation(
                  extent={{-166,-100},{-134,-68}})));

          HeatExchangers.Components.HE_2ph EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                  2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                  2.69972e+006,2.74645e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                656.757,670.379,679.959,684.074,688.573,693.427}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                  295435,288187},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Shot=429.2,
            Scold=338,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalColdPressure=11300000,
            nominalHotPressure=730800,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95)
                                       annotation (Placement(transformation(
                  extent={{-134,-20},{-166,12}})));

          HeatExchangers.Components.nonEquilibriumVessel     separator(
            D=0.56,
            noInitialPressure=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            gamma=0,
            zl_start=0.25,
            hv_start=2.7e6,
            hl_start=1.2e6,
            w_small=1e4,
            noInitialLevel=false,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            H=8,
            p_start=17710000)
            annotation (Placement(transformation(extent={{-8,118},{48,174}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={20,76})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-44})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            rhonom=582.8,
            dpnom=(0.52492/2)*10^5,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-124})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-120,138})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{-80,-216},{-100,-236}})));
          ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                transformation(extent={{-180,-158},{-200,-178}})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-198})));
          ThermoPower.Water.SourceMassFlow sourceMS5(
            allowFlowReversal=false,
            G=0,
            w0=610.6,
            h=355877,
            p0=730800,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-90,-14},{-110,6}})));
          ThermoPower.Water.SinkPressure sinkSteam5(
            allowFlowReversal=false,
            use_in_p0=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=9700000)
            annotation (Placement(transformation(extent={{26,180},{46,200}})));
          ThermoPower.Water.SinkPressure sinkMS2(
            allowFlowReversal=false,
            p0=404671,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-210,-174},{-230,-154}})));
          ThermoPower.Water.SourceMassFlow sourceSteam2(
            allowFlowReversal=false,
            h=1231860,
            w0=88.59,
            p0=17910000,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{86,-232},{66,-212}})));
          Modelica.Blocks.Tables.CombiTable1D P_sink_separator(
            tableOnFile=false,
            table=[20,100.1e5; 30,100.3e5; 40,100.6e5; 50,101e5; 60,112.7e5; 70,129.3e5;
                80,145.7e5; 90,162e5; 100,177.1e5],
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={10,230})));
          Modelica.Blocks.Tables.CombiTable1D H_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,356.5e3; 30,351.2e3; 40,347.3e3; 50,344.1e3; 60,357.8e3; 70,373.4e3;
                80,374.4e3; 90,382.9e3; 100,356.849e3]) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,70})));
          Modelica.Blocks.Tables.CombiTable1D W_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,122.1; 30,183.2; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,488.4;
                90,549.4; 100,610.6]) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,30})));
          Modelica.Blocks.Tables.CombiTable1D H_source_FW(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,840.6e3; 30,933.8e3; 40,1004.5e3; 50,1062.5e3; 60,1111.4e3; 70,1126.7e3;
                80,1133.9e3; 90,1182.5e3; 100,1231.9e3]) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={50,-182})));
          Modelica.Blocks.Sources.Trapezoid LOAD(
            amplitude=-20,
            rising=100,
            falling=100,
            period=5000,
            nperiod=1,
            startTime=0,
            offset=60,
            width=2000)
            annotation (Placement(transformation(extent={{-76,-56},{-44,-24}})));
          Schemes.SingleControllers.control_wSEP control_w_SEP(
            Td_pumpSEP=0,
            Nd_pumpSEP=20,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            TS_pumpSEP=0,
            load_switch=55,
            T_FW_sp=558.15,
            Kp_pumpSEP=0.0152,
            Ti_pumpSEP=2.267,
            CSmin_pumpSEP=-0.5,
            CSmax_pumpSEP=0.5)
            annotation (Placement(transformation(extent={{120,-20},{180,40}})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{-260,240},{-240,260}})));
          Modelica.Blocks.Sources.BooleanConstant TS_sep(k=false)
            annotation (Placement(transformation(extent={{100,50},{120,70}})));
          Modelica.Blocks.Sources.BooleanConstant TS_l_sep(k=false) annotation (
             Placement(transformation(extent={{100,-58},{120,-38}})));
          Schemes.SingleControllers.control_wFW_low control_wFW_low(
            load_switch=55,
            l_sp=4,
            Kp_pumpFW_low=17.6,
            Ti_pumpFW_low=50,
            Td_pumpFW_low=0,
            Nd_pumpFW_low=20,
            CSmin_pumpFW_low=5,
            CSmax_pumpFW_low=100,
            CSstart_pumpFW_low=50,
            TS_pumpFW_low=0) annotation (Placement(transformation(extent={{120,
                    -160},{180,-100}})));
          Modelica.Blocks.Sources.Constant const(k=24) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Icons.SignalBus signalBus
            annotation (Placement(transformation(extent={{210,-10},{250,30}})));
          Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={90,-190})));
          ThermoPower.Water.ValveLiq valveLiq(
            Av=3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=4.45,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{90,100},{110,120}})));
          ThermoPower.Water.SinkPressure sinkPressure(
                            p0=101325, redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{132,100},{152,120}})));
          Modelica.Blocks.Sources.Step step(
            height=1,
            offset=0,
            startTime=2000) annotation (Placement(transformation(extent={{160,
                    160},{140,180}})));
        equation
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-150,-148},{-150,-134}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{20,128},{20,86}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-110,138},{10,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-150,-34},{-150,-20}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-150,-68},{-150,-54}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-150,12},{-150,138},{-130,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-166,-4},{-190,-4},{-190,-84},{-166,-84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-134,-84},{-110,-84},{-110,-164},{-134,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-150,-100},{-150,-114}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-150,-180},{-150,-188}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{-96,-222},{-96,-222},{-150,-222},{-150,-208}},
              color={0,0,255},
              thickness=0.5));
          connect(sinkSteam5.flange, separator.steam_out) annotation (Line(
              points={{26,190},{20,190},{20,170}},
              color={0,0,255},
              thickness=0.5));
          connect(H_source_EVA2.y[1], sourceMS5.in_h) annotation (Line(points={{-81,70},
                  {-81,70},{-104,70},{-104,2}}, color={0,0,127}));
          connect(W_source_EVA2.y[1], sourceMS5.in_w0)
            annotation (Line(points={{-81,30},{-96,30},{-96,2}}, color={0,0,127}));
          connect(sinkMS2.flange, sensT_MS.outlet) annotation (Line(
              points={{-210,-164},{-204,-164},{-196,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.inlet, ECO.outletHot) annotation (Line(
              points={{-184,-164},{-184,-164},{-166,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(H_source_FW.y[1], sourceSteam2.in_h)
            annotation (Line(points={{61,-182},{72,-182},{72,-216}}, color={0,0,127}));
          connect(sensT_FW.inlet, sourceSteam2.flange) annotation (Line(
              points={{-84,-222},{-84,-222},{66,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA2.inletHot, sourceMS5.flange) annotation (Line(
              points={{-134,-4},{-110,-4}},
              color={255,0,0},
              thickness=0.5));
          connect(LOAD.y, H_source_FW.u[1]) annotation (Line(points={{-42.4,-40},{-30,-40},
                  {-30,-182},{38,-182}}, color={0,0,127}));
          connect(LOAD.y, P_sink_separator.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,230},{-2,230}}, color={0,0,127}));
          connect(LOAD.y, W_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-42.4,
                  -39},{-30,-39},{-30,30},{-58,30}}, color={0,0,127}));
          connect(LOAD.y, H_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,70},{-58,70}}, color={0,0,127}));
          connect(sensT_FW.inlet, waterPump.outlet) annotation (Line(
              points={{-84,-222},{20,-222},{20,66}},
              color={0,0,255},
              thickness=0.5));
          connect(LOAD.y, control_w_SEP.load) annotation (Line(points={{-42.4,
                  -40},{-42.4,-40},{-30,-40},{-30,10},{117,10}}, color={0,0,127}));

          connect(TS_sep.y, control_w_SEP.TS_pumpSEP_bool) annotation (Line(
                points={{121,60},{150,60},{150,43}}, color={255,0,255}));
          connect(P_sink_separator.y[1], sinkSteam5.in_p0)
            annotation (Line(points={{21,230},{32,230},{32,198.8}}, color={0,0,127}));
          connect(LOAD.y, control_wFW_low.load) annotation (Line(points={{-42.4,
                  -40},{-30,-40},{-30,-112},{117,-112}}, color={0,0,127}));
          connect(TS_l_sep.y, control_wFW_low.TS_pumpFWlow_bool) annotation (
              Line(points={{121,-48},{135,-48},{135,-97}}, color={255,0,255}));
          connect(separator.level, control_wFW_low.PV) annotation (Line(points=
                  {{30,132},{40,132},{60,132},{60,-130},{117,-130}}, color={0,0,
                  127}));
          connect(const.y, control_wFW_low.TS) annotation (Line(points={{179,
                  -80},{165,-80},{165,-97}}, color={0,0,127}));
          connect(control_w_SEP.signalBus, signalBus) annotation (Line(
              points={{181.5,10},{200,10},{230,10}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{230,10},{230,10},{230,76},{230,80},{26,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{230,10},{230,10},{230,-202},{230,-240},{-118,-240},{-118,
                  -232},{-98,-232}},
              color={255,204,51},
              thickness=0.5));
          connect(add.y, sourceSteam2.in_w0) annotation (Line(points={{90,-201},
                  {90,-208},{80,-208},{80,-216}}, color={0,0,127}));
          connect(control_wFW_low.CS, add.u1) annotation (Line(points={{181.5,
                  -130},{200,-130},{200,-168},{96,-168},{96,-178}}, color={0,0,
                  127}));
          connect(const.y, add.u2) annotation (Line(points={{179,-80},{148,-80},
                  {84,-80},{84,-178}}, color={0,0,127}));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{230,10},{230,10},{230,108},{230,132},{30,132}},
              color={255,204,51},
              thickness=0.5));
          connect(valveLiq.outlet,sinkPressure. flange) annotation (Line(
              points={{110,110},{110,110},{132,110}},
              color={0,0,255},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet) annotation (Line(
              points={{20,128},{20,128},{20,110},{90,110}},
              color={0,0,255},
              thickness=0.5));
          connect(step.y, valveLiq.theta) annotation (Line(points={{139,170},{
                  139,170},{100,170},{100,118}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-260,-260},{260,260}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-260,-260},{260,260}}, preserveAspectRatio=false)),
            experiment(
              StartTime=-5000,
              StopTime=5000,
              __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>Test model to check the procedure of the filling and draining of the separator, as function of the plant load. The system is initialized at 70&percnt; load, at 0 s a negative ramp begins in order to reach the 50&percnt; load. At 55&percnt; the separator filling procedure starts, and the FW pump control is switched from degree of superheating to level control. </p>
<p>After 10 min a positive load ramp starts, and the separator is drained in order to get the 70&percnt; load.</p>
<p>OPEN POINTS:</p>
<p>- separator control optimization;</p>
<p>- pump ramp limits (from 0 a 100&percnt; mass flow in ~10-15s).</p>
</html>"));
        end test_dryWetTransition;

      end Test;

      package Old "Package containing old control schemes and FF tables"

        model control_wMS "Model of the mechanical power controller"

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={120,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_high,
            CSmax=CSmax_pumpMS_high,
            CS_start=CSstart_pumpMS_high,
            Kp=Kp_pumpMS_high,
            Ti=Ti_pumpMS_high,
            Td=Td_pumpMS_high,
            N=Nd_pumpMS_high) annotation (Placement(transformation(extent={{-80,
                    80},{-40,120}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
            annotation (Placement(transformation(extent={{-100,130},{-80,150}})));
          Modelica.Blocks.Math.Add add_high
            annotation (Placement(transformation(extent={{-20,84},{0,104}})));
          Modelica.Blocks.Interfaces.RealInput load
            annotation (Placement(transformation(extent={{-210,-20},{-170,20}}),
                iconTransformation(extent={{-240,-20},{-200,20}})));
          Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                transformation(extent={{100,120},{60,160}}),iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,220})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={180,-60}),iconTransformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={210,0})));
          Graphics.Label_input pumpMS_PV_high annotation (Placement(
                transformation(extent={{-148,104},{-100,92}})));
          Graphics.Label_output pumpMS_CS
            annotation (Placement(transformation(extent={{158,-6},{192,6}})));
          Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
            annotation (Placement(transformation(extent={{60,-10},{80,10}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_high(smoothness=
                Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                82.3774e6]) annotation (Placement(transformation(extent={{
                    -150,110},{-130,130}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=
                Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                [20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                495.8; 90,557.8; 100,619.8]) annotation (Placement(
                transformation(extent={{-60,40},{-40,60}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
          Modelica.Blocks.Logical.Switch switch_MS
            annotation (Placement(transformation(extent={{20,-10},{40,10}})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_low,
            CSmax=CSmax_pumpMS_low,
            CS_start=CSstart_pumpMS_low,
            Kp=Kp_pumpMS_low,
            Ti=Ti_pumpMS_low,
            Td=Td_pumpMS_low,
            N=Nd_pumpMS_low) annotation (Placement(transformation(extent={{-80,
                    -120},{-40,-80}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
            annotation (Placement(transformation(extent={{-100,-70},{-80,-50}})));
          Modelica.Blocks.Math.Add add_low annotation (Placement(
                transformation(extent={{-20,-116},{0,-96}})));
          Graphics.Label_input pumpMS_PV_low annotation (Placement(
                transformation(extent={{-148,-96},{-100,-108}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=
                Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                82.3774e6]) annotation (Placement(transformation(extent={{
                    -150,-90},{-130,-70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=
                Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                [20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                495.8; 90,557.8; 100,619.8]) annotation (Placement(
                transformation(extent={{-60,-160},{-40,-140}})));
        equation
          connect(pumpMS_TS_high.y, PID_pumpMS_high.TR) annotation (Line(
                points={{-79,140},{-60,140},{-60,116}}, color={0,0,127}));
          connect(add_high.u1, PID_pumpMS_high.CS) annotation (Line(points={{
                  -22,100},{-30,100},{-42,100}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{180,-60},{148,-60},{148,-12},{146,-12},{144,-12},{144,0},{142,0}},
              color={256,256,256},
              thickness=0.5));

          connect(signalBus.pumpMS_PV, PID_pumpMS_high.PV) annotation (Line(
              points={{180,-60},{90,-60},{90,-58},{0,-58},{0,20},{-82,20},{-82,
                  94},{-76,94},{-76,98}},
              color={256,256,256},
              thickness=0.5));
          connect(TS_pumpMS_bool, PID_pumpMS_high.TS) annotation (Line(points=
                 {{80,140},{-52,140},{-52,116}}, color={255,0,255}));
          connect(pumpMS_lim.y, pumpMS_dynamic.u) annotation (Line(points={{81,0},{81,0},
                  {96,0}},                   color={0,0,127}));
          connect(table_P_MEC_high.y[1], PID_pumpMS_high.SP) annotation (Line(
                points={{-129,120},{-110,120},{-110,112},{-76,112}}, color={0,
                  0,127}));
          connect(load, table_P_MEC_high.u[1]) annotation (Line(points={{-190,
                  0},{-170,0},{-170,120},{-152,120}}, color={0,0,127}));
          connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-190,
                  0},{-190,0},{-110,0},{-110,50},{-62,50}}, color={0,0,127}));
          connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points=
                  {{-39,50},{-30,50},{-30,88},{-22,88}}, color={0,0,127}));
          connect(load, greaterEqualThreshold.u)
            annotation (Line(points={{-190,0},{-190,0},{-62,0}}, color={0,0,127}));
          connect(pumpMS_lim.u, switch_MS.y)
            annotation (Line(points={{58,0},{41,0}}, color={0,0,127}));
          connect(greaterEqualThreshold.y, switch_MS.u2)
            annotation (Line(points={{-39,0},{-10.5,0},{18,0}}, color={255,0,255}));
          connect(add_high.y, switch_MS.u1) annotation (Line(points={{1,94},{
                  10,94},{10,8},{18,8}}, color={0,0,127}));
          connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points=
                 {{-79,-60},{-60,-60},{-60,-84}}, color={0,0,127}));
          connect(add_low.u1, PID_pumpMS_low.CS) annotation (Line(points={{-22,
                  -100},{-30,-100},{-42,-100}}, color={0,0,127}));
          connect(signalBus.pumpMS_PV, PID_pumpMS_low.PV) annotation (Line(
              points={{180,-60},{90,-60},{90,-258},{0,-258},{0,-180},{-82,-180},
                  {-82,-106},{-76,-106},{-76,-102}},
              color={256,256,256},
              thickness=0.5));
          connect(table_P_MEC_low.y[1], PID_pumpMS_low.SP) annotation (Line(
                points={{-129,-80},{-108,-80},{-108,-88},{-76,-88}}, color={0,
                  0,127}));
          connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{
                  -39,-150},{-30,-150},{-30,-112},{-22,-112}}, color={0,0,127}));
          connect(load, table_P_MEC_low.u[1]) annotation (Line(points={{-190,
                  0},{-170,0},{-170,-80},{-152,-80}}, color={0,0,127}));
          connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-190,0},
                  {-170,0},{-170,-150},{-62,-150}}, color={0,0,127}));
          connect(add_low.y, switch_MS.u3) annotation (Line(points={{1,-106},
                  {10,-106},{10,-8},{18,-8}}, color={0,0,127}));
          connect(TS_pumpMS_bool, PID_pumpMS_low.TS) annotation (Line(points=
                  {{80,140},{50,140},{50,-60},{-52,-60},{-52,-84}}, color={
                  255,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                  preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                    -200},{200,200}},
                                preserveAspectRatio=false), graphics={Rectangle(
                  extent={{-200,200},{200,-200}},
                  lineColor={0,0,0},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  lineThickness=0.5), Text(
                  extent={{-180,180},{180,-180}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  fontSize=14,
                  textString="w_MS

controller")}));
        end control_wMS;

        model control_wFW "Model of the w_FW"

          //-- General settings --
          parameter Real load_switch_FW
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpFW --
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Td_pumpFW_high
            "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Nd_pumpFW_high
            "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          Modelica.Blocks.Interfaces.RealInput load
            annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                iconTransformation(extent={{-240,-20},{-200,20}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={160,-60}),iconTransformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={210,0})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-180,-118},{-160,-98}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_high,
            CSmax=CSmax_pumpFW_high,
            CS_start=CSstart_pumpFW_high,
            Kp=Kp_pumpFW_high,
            Ti=Ti_pumpFW_high)
            annotation (Placement(transformation(extent={{-80,80},{-40,120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={140,0})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
            annotation (Placement(transformation(extent={{-100,130},{-80,150}})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{-20,84},{0,104}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{20,46},{40,66}})));
          Modelica.Blocks.Logical.Switch switch_FW
            annotation (Placement(transformation(extent={{56,-10},{76,10}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_low,
            CSmax=CSmax_pumpFW_low,
            CS_start=CSstart_pumpFW_low,
            Kp=Kp_pumpFW_low,
            Ti=Ti_pumpFW_low)
            annotation (Placement(transformation(extent={{-80,-140},{-40,-100}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                     k=TS_pumpFW_low)
            annotation (Placement(transformation(extent={{-100,-90},{-80,-70}})));
          Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
              Placement(transformation(extent={{0,120},{-40,160}}),
                                                                  iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={100,220})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch_FW)
            annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
          Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
            annotation (Placement(transformation(extent={{-180,102},{-160,122}})));
          Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWlow_bool annotation (
              Placement(transformation(extent={{0,-100},{-40,-60}}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={-98,220})));
          Graphics.Label_input pumpFW_PV_high
            annotation (Placement(transformation(extent={{-144,104},{-98,92}})));
          Graphics.Label_output pumpFW_CS
            annotation (Placement(transformation(extent={{180,-6},{212,6}})));
          Graphics.Label_input pumpFW_PV_low
            annotation (Placement(transformation(extent={{-146,-116},{-100,-128}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
              Placement(transformation(extent={{-60,40},{-40,60}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{86,-10},{106,10}})));
        equation
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{160,-60},{180,-60},{180,-8},{162,-8},{162,-2.66454e-015},{164,-2.66454e-015},
                  {164,0},{164,-2.66454e-015},{162,-2.66454e-015}},
              color={256,256,256},
              thickness=0.5));
          connect(product.y, add.u1) annotation (Line(points={{1,94},{1,94},{
                  0,94},{10,94},{10,62},{18,62}},
                                        color={0,0,127}));
          connect(add.y, switch_FW.u1)
            annotation (Line(points={{41,56},{49,56},{49,8},{54,8}}, color={0,0,127}));
          connect(product.u1, PID_pumpFW_high.CS)
            annotation (Line(points={{-22,100},{-22,100},{-42,100}},
                                                                   color={0,0,127}));
          connect(switch_FW.u3, PID_pumpFW_low.CS) annotation (Line(points={{54,-8},
                  {50,-8},{50,-120},{-42,-120}},
                                              color={0,0,127}));
          connect(pumpFW_TS_low.y, PID_pumpFW_low.TR)
            annotation (Line(points={{-79,-80},{-60,-80},{-60,-104}},color={0,0,127}));
          connect(l_SP.y, PID_pumpFW_low.SP) annotation (Line(points={{-159,-108},{-76,-108}},
                              color={0,0,127}));
          connect(pumpFW_TS_high.y, PID_pumpFW_high.TR) annotation (Line(points={{-79,140},
                  {-60,140},{-60,116}},    color={0,0,127}));
          connect(TS_pumpFWhigh_bool, PID_pumpFW_high.TS)
            annotation (Line(points={{-20,140},{-20,140},{-50,140},{-52,140},{
                  -52,116}},                                  color={255,0,255}));
          connect(switch_FW.u2, greaterEqualThreshold.y)
            annotation (Line(points={{54,0},{54,0},{-39,0}},
                                                           color={255,0,255}));
          connect(DT_sh_SP.y, PID_pumpFW_high.SP)
            annotation (Line(points={{-159,112},{-76,112}},  color={0,0,127}));

          connect(load, greaterEqualThreshold.u) annotation (Line(points={{-180,0},{-160,
                  0},{-160,4},{-160,0},{-62,0}},           color={0,0,127}));

          connect(TS_pumpFWlow_bool, PID_pumpFW_low.TS) annotation (Line(points={{-20,-80},
                  {-52,-80},{-52,-104}}, color={255,0,255}));
          connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
              points={{160,-60},{160,-60},{160,-160},{160,-180},{-100,-180},{-100,-134},
                  {-82,-134},{-82,-128},{-80,-128},{-80,-122},{-76,-122}},
              color={256,256,256},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW_high.PV) annotation (Line(
              points={{160,-60},{160,-58},{240,-58},{240,180},{-194,180},{-194,80},{-82,
                  80},{-82,94},{-80,94},{-80,98},{-76,98}},
              color={256,256,256},
              thickness=0.5));
          connect(table_w_FW.y[1], add.u2)
            annotation (Line(points={{-39,50},{18,50}}, color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-39,
                  50},{-30,50},{-30,88},{-22,88}}, color={0,0,127}));
          connect(load, table_w_FW.u[1]) annotation (Line(points={{-180,0},{
                  -100,0},{-100,50},{-62,50}}, color={0,0,127}));
          connect(switch_FW.y, pumpFW_lim.u)
            annotation (Line(points={{77,0},{84,0}}, color={0,0,127}));
          connect(pumpFW_lim.y, pumpFW_dynamic.u)
            annotation (Line(points={{107,0},{116,0}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                  preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                    {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                  extent={{-200,200},{200,-200}},
                  lineColor={0,0,0},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  lineThickness=0.5), Text(
                  extent={{-180,180},{180,-180}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  fontSize=14,
                  textString="w_FW

control")}));
        end control_wFW;

        model control_Yt "Model of the power-pressure section controller"

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{100,-20},{140,20}})));
          IndustrialControlSystems.Controllers.PI PID_valveTURB_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_valveTURB_high,
            CSmax=CSmax_valveTURB_high,
            CS_start=CSstart_valveTURB_high,
            Kp=Kp_valveTURB_high,
            Ti=Ti_valveTURB_high)
            annotation (Placement(transformation(extent={{-90,80},{-50,120}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS_high(k=TS_valveTURB_high)
            annotation (Placement(transformation(extent={{-110,130},{-90,150}})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{36,-10},{56,10}})));
          Modelica.Blocks.Math.Add add_high
            annotation (Placement(transformation(extent={{-30,84},{-10,104}})));
          Modelica.Blocks.Interfaces.RealInput load
            annotation (Placement(transformation(extent={{-210,-20},{-170,20}}),
                iconTransformation(extent={{-240,-20},{-200,20}})));
          Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBhigh_bool
            annotation (Placement(transformation(extent={{0,120},{-40,160}}),
                iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={100,220})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={180,-60}),iconTransformation(
                extent={{-20,20},{20,-20}},
                rotation=90,
                origin={210,0})));
          Graphics.Label_input valveTURB_PV_high
            annotation (Placement(transformation(extent={{-162,104},{-110,92}})));
          Graphics.Label_output valveTURB_CS
            annotation (Placement(transformation(extent={{160,-6},{200,6}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_high(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                80,139.7e5; 90,155.1e5; 100,171e5])
            annotation (Placement(transformation(extent={{-160,110},{-140,130}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt_high(
              table=[20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6; 60,5.01396e-6;
                70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,4.98849e-6],
              smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{-70,40},{-50,60}})));
          Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
            annotation (Placement(transformation(extent={{66,-10},{86,10}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
          Modelica.Blocks.Logical.Switch switch_Yt
            annotation (Placement(transformation(extent={{4,-10},{24,10}})));
          IndustrialControlSystems.Controllers.PI PID_valveTURB_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_valveTURB_low,
            CSmax=CSmax_valveTURB_low,
            CS_start=CSstart_valveTURB_low,
            Kp=Kp_valveTURB_low,
            Ti=Ti_valveTURB_low)
            annotation (Placement(transformation(extent={{-90,-120},{-50,-80}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS_low(k=TS_valveTURB_low)
            annotation (Placement(transformation(extent={{-110,-70},{-90,-50}})));
          Modelica.Blocks.Math.Add add_low
            annotation (Placement(transformation(extent={{-30,-116},{-10,-96}})));
          Graphics.Label_input valveTURB_PV_low
            annotation (Placement(transformation(extent={{-162,-96},{-110,-108}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_low(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                80,139.7e5; 90,155.1e5; 100,171e5])
            annotation (Placement(transformation(extent={{-160,-90},{-140,-70}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt_low(
              table=[20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6; 60,5.01396e-6;
                70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,4.98849e-6],
              smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
            annotation (Placement(transformation(extent={{-70,-160},{-50,-140}})));
          Modelica.Blocks.Interfaces.BooleanInput TS_valveTURBlow_bool
            annotation (Placement(transformation(extent={{0,-80},{-40,-40}}),
                iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={-100,220})));
        equation
          connect(valveTURB_TS_high.y, PID_valveTURB_high.TR)
            annotation (Line(points={{-89,140},{-70,140},{-70,116}}, color={0,0,127}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{180,-60},{164,-60},{164,-8},{142,-8},{142,0}},
              color={256,256,256},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB_high.PV) annotation (Line(
              points={{180,-60},{-14,-60},{-14,20},{-92,20},{-92,94},{-90,94},{-90,98},{
                  -86,98}},
              color={256,256,256},
              thickness=0.5));
          connect(PID_valveTURB_high.CS, add_high.u1) annotation (Line(points={{-52,100},
                  {-42,100},{-32,100}},           color={0,0,127}));
          connect(table_P_high.y[1], PID_valveTURB_high.SP) annotation (Line(points={{-139,
                  120},{-120,120},{-120,112},{-86,112}}, color={0,0,127}));
          connect(load, table_P_high.u[1]) annotation (Line(points={{-190,0},{-190,0},{-170,
                  0},{-170,120},{-162,120}}, color={0,0,127}));
          connect(load, table_Yt_high.u[1]) annotation (Line(points={{-190,0},{-190,0},{
                  -110,0},{-110,50},{-72,50}}, color={0,0,127}));
          connect(table_Yt_high.y[1], add_high.u2) annotation (Line(points={{-49,50},
                  {-40,50},{-40,88},{-32,88}},
                                          color={0,0,127}));
          connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(
                points={{57,0},{56,0},{64,0}},    color={0,0,127}));
          connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(
                points={{87,0},{87,0},{96,0}},      color={0,0,127}));
          connect(load, greaterEqualThreshold.u)
            annotation (Line(points={{-190,0},{-190,0},{-62,0}}, color={0,0,127}));
          connect(greaterEqualThreshold.y, switch_Yt.u2)
            annotation (Line(points={{-39,0},{-18.5,0},{2,0}}, color={255,0,255}));
          connect(switch_Yt.y, table_Y_tTOtheta.u[1])
            annotation (Line(points={{25,0},{29.5,0},{34,0}}, color={0,0,127}));
          connect(add_high.y, switch_Yt.u1) annotation (Line(points={{-9,94},
                  {-4,94},{-4,8},{2,8}},
                                color={0,0,127}));
          connect(valveTURB_TS_low.y, PID_valveTURB_low.TR)
            annotation (Line(points={{-89,-60},{-70,-60},{-70,-84}}, color={0,0,127}));
          connect(signalBus.valveTURB_PV, PID_valveTURB_low.PV) annotation (Line(
              points={{180,-60},{-36,-60},{-36,-178},{-94,-178},{-94,-104},{-90,-104},{-90,
                  -102},{-86,-102}},
              color={256,256,256},
              thickness=0.5));
          connect(PID_valveTURB_low.CS, add_low.u1) annotation (Line(points={{-52,
                  -100},{-42,-100},{-32,-100}},    color={0,0,127}));
          connect(table_P_low.y[1], PID_valveTURB_low.SP) annotation (Line(points={{-139,
                  -80},{-120,-80},{-120,-88},{-86,-88}}, color={0,0,127}));
          connect(table_Yt_low.y[1], add_low.u2) annotation (Line(points={{-49,
                  -150},{-40,-150},{-40,-112},{-32,-112}},
                                                color={0,0,127}));
          connect(add_low.y, switch_Yt.u3) annotation (Line(points={{-9,-106},
                  {-4,-106},{-4,-8},{2,-8}},
                                   color={0,0,127}));
          connect(load, table_P_low.u[1]) annotation (Line(points={{-190,0},{-170,0},{-170,
                  -80},{-162,-80}}, color={0,0,127}));
          connect(load, table_Yt_low.u[1]) annotation (Line(points={{-190,0},{-170,0},{-170,
                  -2},{-170,-150},{-72,-150}}, color={0,0,127}));
          connect(TS_valveTURBlow_bool, PID_valveTURB_low.TS) annotation (
              Line(points={{-20,-60},{-40,-60},{-62,-60},{-62,-84}}, color={
                  255,0,255}));
          connect(TS_valveTURBhigh_bool, PID_valveTURB_high.TS) annotation (
              Line(points={{-20,140},{-62,140},{-62,116}}, color={255,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                  preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                    -200},{200,200}},
                                preserveAspectRatio=false), graphics={Rectangle(
                  extent={{-200,200},{200,-200}},
                  lineColor={0,0,0},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  lineThickness=0.5), Text(
                  extent={{-180,180},{180,-180}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  fontSize=14,
                  textString="p_eva

controller")}));
        end control_Yt;

        model fullyDecentralized_old
          "Control schemes with fully decentralized control logic"
          extends Schemes.BaseClasses.BasePowerPressureController;

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Kp_pumpFW_high "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_high
            "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Td_pumpFW_high
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Nd_pumpFW_high
            "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSstart_pumpFW_high "Start value of CS"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real TS_pumpFW_high "Tracking signal"
                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                    annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS"
                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

          Old.control_wMS control_wMS(
            actuatorGain_pumpMS=actuatorGain_pumpMS,
            Ta_pumpMS=Ta_pumpMS,
            load_switch=load_switch,
            Kp_pumpMS_high=Kp_pumpMS_high,
            Ti_pumpMS_high=Ti_pumpMS_high,
            Td_pumpMS_high=Td_pumpMS_high,
            Nd_pumpMS_high=Nd_pumpMS_high,
            CSmin_pumpMS_high=CSmin_pumpMS_high,
            CSmax_pumpMS_high=CSmax_pumpMS_high,
            CSstart_pumpMS_high=CSstart_pumpMS_high,
            TS_pumpMS_high=TS_pumpMS_high,
            Kp_pumpMS_low=Kp_pumpMS_low,
            Ti_pumpMS_low=Ti_pumpMS_low,
            Td_pumpMS_low=Td_pumpMS_low,
            Nd_pumpMS_low=Nd_pumpMS_low,
            CSmin_pumpMS_low=CSmin_pumpMS_low,
            CSmax_pumpMS_low=CSmax_pumpMS_low,
            CSstart_pumpMS_low=CSstart_pumpMS_low,
            TS_pumpMS_low=TS_pumpMS_low) annotation (Placement(transformation(
                  extent={{-260,60},{-180,140}})));
          Old.control_Yt control_Yt(
            actuatorGain_valveTURB=actuatorGain_valveTURB,
            Ta_valveTURB=Ta_valveTURB,
            load_switch=load_switch,
            Kp_valveTURB_high=Kp_valveTURB_high,
            Ti_valveTURB_high=Ti_valveTURB_high,
            Td_valveTURB_high=Td_valveTURB_high,
            Nd_valveTURB_high=Nd_valveTURB_high,
            CSmin_valveTURB_high=CSmin_valveTURB_high,
            CSmax_valveTURB_high=CSmax_valveTURB_high,
            CSstart_valveTURB_high=CSstart_valveTURB_high,
            TS_valveTURB_high=TS_valveTURB_high,
            Kp_valveTURB_low=Kp_valveTURB_low,
            Ti_valveTURB_low=Ti_valveTURB_low,
            Td_valveTURB_low=Td_valveTURB_low,
            Nd_valveTURB_low=Nd_valveTURB_low,
            CSmin_valveTURB_low=CSmin_valveTURB_low,
            CSmax_valveTURB_low=CSmax_valveTURB_low,
            CSstart_valveTURB_low=CSstart_valveTURB_low,
            TS_valveTURB_low=TS_valveTURB_low) annotation (Placement(
                transformation(extent={{-260,200},{-180,280}})));
          Old.control_wFW control_wFW(
            actuatorGain_pumpFW=actuatorGain_pumpFW,
            Ta_pumpFW=Ta_pumpFW,
            DT_sh_sp=DT_sh_sp,
            Kp_pumpFW_high=Kp_pumpFW_high,
            Ti_pumpFW_high=Ti_pumpFW_high,
            Td_pumpFW_high=Td_pumpFW_high,
            Nd_pumpFW_high=Nd_pumpFW_high,
            CSmin_pumpFW_high=CSmin_pumpFW_high,
            CSmax_pumpFW_high=CSmax_pumpFW_high,
            CSstart_pumpFW_high=CSstart_pumpFW_high,
            TS_pumpFW_high=TS_pumpFW_high,
            l_sp=l_sp,
            Kp_pumpFW_low=Kp_pumpFW_low,
            Ti_pumpFW_low=Ti_pumpFW_low,
            Td_pumpFW_low=Td_pumpFW_low,
            Nd_pumpFW_low=Nd_pumpFW_low,
            CSmin_pumpFW_low=CSmin_pumpFW_low,
            CSmax_pumpFW_low=CSmax_pumpFW_low,
            CSstart_pumpFW_low=CSstart_pumpFW_low,
            TS_pumpFW_low=TS_pumpFW_low,
            load_switch_FW=load_switch) annotation (Placement(transformation(
                  extent={{-260,-240},{-180,-160}})));
        equation
          connect(TS_pumpMS_bool, control_wMS.TS_pumpMS_bool) annotation (Line(points={{-200,
                  390},{-220,390},{-220,144}},                 color={255,0,255}));
          connect(load, control_wMS.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,100},{-264,100}},
                                             color={0,0,127}));
          connect(load, control_Yt.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,240},{-264,240}},
                                           color={0,0,127}));
          connect(TS_pumpFWlow_bool, control_wFW.TS_pumpFWlow_bool) annotation (Line(
                points={{-200,-30},{-239.6,-30},{-239.6,-120},{-239.6,-156}},
                                                                           color={255,0,
                  255}));
          connect(TS_pumpFWhigh_bool, control_wFW.TS_pumpFWhigh_bool) annotation (Line(
                points={{-200,30},{-200,30},{-200,-156}},   color={255,0,255}));
          connect(load, control_wFW.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,-200},{-264,-200}},
                                               color={0,0,127}));
          connect(control_wMS.signalBus, signalBus) annotation (Line(
              points={{-178,100},{-178,100},{320,100},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(control_Yt.signalBus, signalBus) annotation (Line(
              points={{-178,240},{-178,240},{320,240},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(control_wFW.signalBus, signalBus) annotation (Line(
              points={{-178,-200},{-178,-200},{320,-200},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_valveTURBlow_bool, control_Yt.TS_valveTURBlow_bool)
            annotation (Line(points={{-200,-290},{-240,-290},{-240,284}},
                                                                        color=
                 {255,0,255}));
          connect(TS_valveTURBhigh_bool, control_Yt.TS_valveTURBhigh_bool)
            annotation (Line(points={{-200,-170},{-262,-170},{-262,284},{-200,
                  284}}, color={255,0,255}));
        end fullyDecentralized_old;

        model wMS_wFW_staticDecoupler_old
          "Control schemes with a static decoupler between molten salt and water mass flow rate"
          extends Schemes.BaseClasses.BasePowerPressureController;

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          //-- pumpFW --
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Kp_pumpFW_high "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_high
            "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Modelica.SIunits.Time Td_pumpFW_high
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real Nd_pumpFW_high
            "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSstart_pumpFW_high "Start value of CS"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real TS_pumpFW_high "Tracking signal"
                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                    annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS"
                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

          Old.control_Yt control_Yt(
            actuatorGain_valveTURB=actuatorGain_valveTURB,
            Ta_valveTURB=Ta_valveTURB,
            load_switch=load_switch,
            Kp_valveTURB_high=Kp_valveTURB_high,
            Ti_valveTURB_high=Ti_valveTURB_high,
            Td_valveTURB_high=Td_valveTURB_high,
            Nd_valveTURB_high=Nd_valveTURB_high,
            CSmin_valveTURB_high=CSmin_valveTURB_high,
            CSmax_valveTURB_high=CSmax_valveTURB_high,
            CSstart_valveTURB_high=CSstart_valveTURB_high,
            TS_valveTURB_high=TS_valveTURB_high,
            Kp_valveTURB_low=Kp_valveTURB_low,
            Ti_valveTURB_low=Ti_valveTURB_low,
            Td_valveTURB_low=Td_valveTURB_low,
            Nd_valveTURB_low=Nd_valveTURB_low,
            CSmin_valveTURB_low=CSmin_valveTURB_low,
            CSmax_valveTURB_low=CSmax_valveTURB_low,
            CSstart_valveTURB_low=CSstart_valveTURB_low,
            TS_valveTURB_low=TS_valveTURB_low)
            annotation (Placement(transformation(extent={{0,220},{80,300}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,80})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_high,
            CSmax=CSmax_pumpMS_high,
            CS_start=CSstart_pumpMS_high,
            Kp=Kp_pumpMS_high,
            Ti=Ti_pumpMS_high,
            Td=Td_pumpMS_high,
            N=Nd_pumpMS_high)
            annotation (Placement(transformation(extent={{-160,-10},{-120,30}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
            annotation (Placement(transformation(extent={{-180,40},{-160,60}})));
          Modelica.Blocks.Math.Add add_high
            annotation (Placement(transformation(extent={{40,-12},{60,8}})));
          Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
            annotation (Placement(transformation(extent={{140,70},{160,90}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_high(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,12},{-210,32}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,-50},{-120,-30}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
          Modelica.Blocks.Logical.Switch switch_MS
            annotation (Placement(transformation(extent={{100,90},{120,70}})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_low,
            CSmax=CSmax_pumpMS_low,
            CS_start=CSstart_pumpMS_low,
            Kp=Kp_pumpMS_low,
            Ti=Ti_pumpMS_low,
            Td=Td_pumpMS_low,
            N=Nd_pumpMS_low)
            annotation (Placement(transformation(extent={{-160,150},{-120,190}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
            annotation (Placement(transformation(extent={{-180,200},{-160,220}})));
          Modelica.Blocks.Math.Add add_low
            annotation (Placement(transformation(extent={{-80,154},{-60,174}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,172},{-210,192}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,110},{-120,130}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-232,-318},{-212,-298}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_high,
            CSmax=CSmax_pumpFW_high,
            CS_start=CSstart_pumpFW_high,
            Kp=Kp_pumpFW_high,
            Ti=Ti_pumpFW_high)
            annotation (Placement(transformation(extent={{-160,-160},{-120,-120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,-230})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
            annotation (Placement(transformation(extent={{-180,-110},{-160,-90}})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{-20,-150},{0,-130}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{20,-194},{40,-174}})));
          Modelica.Blocks.Logical.Switch switch_FW
            annotation (Placement(transformation(extent={{100,-240},{120,-220}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_low,
            CSmax=CSmax_pumpFW_low,
            CS_start=CSstart_pumpFW_low,
            Kp=Kp_pumpFW_low,
            Ti=Ti_pumpFW_low)
            annotation (Placement(transformation(extent={{-160,-340},{-120,-300}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                     k=TS_pumpFW_low)
            annotation (Placement(transformation(extent={{-180,-290},{-160,-270}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold1(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,-240},{-80,-220}})));
          Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
            annotation (Placement(transformation(extent={{-230,-138},{-210,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
              Placement(transformation(extent={{-140,-200},{-120,-180}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{140,-240},{160,-220}})));
          Modelica.Blocks.Math.Gain gamma_FW_MS(k=8.86459201881573*10)
            annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
          Modelica.Blocks.Math.Add add_dec_MS
            annotation (Placement(transformation(extent={{-20,-6},{0,14}})));
          Modelica.Blocks.Math.Add add_dec_FW
            annotation (Placement(transformation(extent={{-60,-144},{-40,-124}})));
          Modelica.Blocks.Math.Gain gamma_MS_FW(k=1e-3)
            annotation (Placement(transformation(extent={{-40,-100},{-60,-80}})));
        equation
          connect(load, control_Yt.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,260},{-4,260}},
                                           color={0,0,127}));
          connect(control_Yt.signalBus, signalBus) annotation (Line(
              points={{82,260},{82,258},{320,258},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS_high.y, PID_pumpMS_high.TR)
            annotation (Line(points={{-159,50},{-140,50},{-140,26}}, color={0,0,127}));
          connect(pumpMS_lim.y,pumpMS_dynamic. u) annotation (Line(points={{161,80},{161,
                  80},{176,80}},             color={0,0,127}));
          connect(table_P_MEC_high.y[1], PID_pumpMS_high.SP)
            annotation (Line(points={{-209,22},{-190,22},{-156,22}}, color={0,0,127}));
          connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points={{-119,-40},
                  {30,-40},{30,-8},{38,-8}}, color={0,0,127}));
          connect(pumpMS_lim.u,switch_MS. y)
            annotation (Line(points={{138,80},{121,80}},
                                                     color={0,0,127}));
          connect(greaterEqualThreshold.y,switch_MS. u2)
            annotation (Line(points={{-79,80},{98,80}},         color={255,0,255}));
          connect(add_high.y, switch_MS.u1) annotation (Line(points={{61,-2},{80,-2},{80,
                  72},{98,72}}, color={0,0,127}));
          connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points={{-159,210},
                  {-140,210},{-140,186}}, color={0,0,127}));
          connect(add_low.u1, PID_pumpMS_low.CS) annotation (Line(points={{-82,170},{-82,
                  170},{-122,170}}, color={0,0,127}));
          connect(table_P_MEC_low.y[1], PID_pumpMS_low.SP) annotation (Line(points={{-209,
                  182},{-188,182},{-156,182}}, color={0,0,127}));
          connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{-119,120},{
                  -110,120},{-110,158},{-82,158}}, color={0,0,127}));
          connect(add_low.y, switch_MS.u3) annotation (Line(points={{-59,164},{-40,164},
                  {-40,88},{98,88}}, color={0,0,127}));
          connect(product.y,add. u1) annotation (Line(points={{1,-140},{1,-140},{0,-140},
                  {10,-140},{10,-178},{18,-178}},
                                        color={0,0,127}));
          connect(add.y,switch_FW. u1)
            annotation (Line(points={{41,-184},{61,-184},{61,-222},{98,-222}},
                                                                     color={0,0,127}));
          connect(switch_FW.u3,PID_pumpFW_low. CS) annotation (Line(points={{98,-238},{60,
                  -238},{60,-320},{-122,-320}},
                                              color={0,0,127}));
          connect(pumpFW_TS_low.y,PID_pumpFW_low. TR)
            annotation (Line(points={{-159,-280},{-140,-280},{-140,-304}},
                                                                     color={0,0,127}));
          connect(l_SP.y,PID_pumpFW_low. SP) annotation (Line(points={{-211,-308},{-156,
                  -308}},     color={0,0,127}));
          connect(pumpFW_TS_high.y,PID_pumpFW_high. TR) annotation (Line(points={{-159,-100},
                  {-140,-100},{-140,-124}},color={0,0,127}));
          connect(switch_FW.u2, greaterEqualThreshold1.y) annotation (Line(points={{98,-230},
                  {98,-230},{-79,-230}}, color={255,0,255}));
          connect(DT_sh_SP.y,PID_pumpFW_high. SP)
            annotation (Line(points={{-209,-128},{-186,-128},{-156,-128}},
                                                             color={0,0,127}));
          connect(table_w_FW.y[1],add. u2)
            annotation (Line(points={{-119,-190},{-44,-190},{18,-190}},
                                                        color={0,0,127}));
          connect(table_w_FW.y[1],product. u2) annotation (Line(points={{-119,-190},{-30,
                  -190},{-30,-146},{-22,-146}},    color={0,0,127}));
          connect(switch_FW.y,pumpFW_lim. u)
            annotation (Line(points={{121,-230},{138,-230}},
                                                     color={0,0,127}));
          connect(pumpFW_lim.y,pumpFW_dynamic. u)
            annotation (Line(points={{161,-230},{176,-230}},
                                                       color={0,0,127}));
          connect(load, table_P_MEC_low.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,182},{-232,182}},
                                                   color={0,0,127}));
          connect(load, greaterEqualThreshold.u) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,80},{-102,80}},
                                                    color={0,0,127}));
          connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,120},{-142,120}},
                                                   color={0,0,127}));
          connect(load, table_P_MEC_high.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,22},{-232,22}},
                                                 color={0,0,127}));
          connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,-40},{-142,-40}},
                                                   color={0,0,127}));
          connect(load, greaterEqualThreshold1.u) annotation (Line(points={{-330,0},
                  {-330,0},{-360,0},{-360,-230},{-102,-230}},
                                                        color={0,0,127}));
          connect(load, table_w_FW.u[1]) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,-230},{-160,-230},{-160,-190},{-142,
                  -190}},                                              color={0,0,127}));
          connect(PID_pumpMS_high.CS, add_dec_MS.u1)
            annotation (Line(points={{-122,10},{-22,10}}, color={0,0,127}));
          connect(add_dec_MS.y, add_high.u1)
            annotation (Line(points={{1,4},{38,4}}, color={0,0,127}));
          connect(gamma_FW_MS.y, add_dec_MS.u2) annotation (Line(points={{-39,-10},
                  {-30,-10},{-30,-2},{-22,-2}},
                                           color={0,0,127}));
          connect(TS_pumpMS_bool, PID_pumpMS_low.TS) annotation (Line(points={{-200,
                  390},{-280,390},{-280,240},{-132,240},{-132,186}},
                                                                color={255,0,255}));
          connect(TS_pumpMS_bool, PID_pumpMS_high.TS) annotation (Line(points={{-200,
                  390},{-300,390},{-300,200},{-300,90},{-132,90},{-132,26}},
                                                                        color={255,0,255}));
          connect(add_dec_FW.y, product.u1) annotation (Line(points={{-39,-134},{-30.5,-134},
                  {-22,-134}}, color={0,0,127}));
          connect(add_dec_FW.y, gamma_FW_MS.u) annotation (Line(points={{-39,
                  -134},{-36,-134},{-32,-134},{-32,-56},{-88,-56},{-88,-10},{
                  -62,-10}},                                                 color={0,0,
                  127}));
          connect(add_dec_MS.y, gamma_MS_FW.u) annotation (Line(points={{1,4},{10,4},{10,
                  -90},{-38,-90}}, color={0,0,127}));
          connect(gamma_MS_FW.y, add_dec_FW.u1) annotation (Line(points={{-61,-90},{-74,
                  -90},{-88,-90},{-88,-128},{-62,-128}}, color={0,0,127}));
          connect(PID_pumpFW_high.CS, add_dec_FW.u2) annotation (Line(points={{-122,-140},
                  {-62,-140},{-62,-140}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,78},{360,80},{222,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,-234},{360,-230},{222,-230}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_pumpFWlow_bool, PID_pumpFW_low.TS) annotation (Line(points={{-200,
                  -30},{-300,-30},{-300,-120},{-300,-260},{-132,-260},{-132,
                  -304}},                                                       color={255,
                  0,255}));
          connect(TS_pumpFWhigh_bool, PID_pumpFW_high.TS) annotation (Line(points={{-200,30},
                  {-280,30},{-280,-72},{-132,-72},{-132,-124}},       color={255,0,255}));
          connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-362},{360,-360},{-188,-360},{-188,
                  -322},{-156,-322}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW_high.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-188,-360},{-188,-144},{-188,
                  -142},{-156,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_high.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-188,-360},{-188,8},{-156,8}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-188,-360},{-188,8},{-188,166},
                  {-156,166},{-156,168}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_valveTURBlow_bool, control_Yt.TS_valveTURBlow_bool)
            annotation (Line(points={{-200,-290},{-150,-290},{-150,304},{20,304}},
                color={255,0,255}));
          connect(TS_valveTURBhigh_bool, control_Yt.TS_valveTURBhigh_bool)
            annotation (Line(points={{-200,-170},{60,-170},{60,304}},
                                                                    color={
                  255,0,255}));
        end wMS_wFW_staticDecoupler_old;

        model wMS_wFW_staticDecoupler_4th_controller_old
          "Control schemes with a static decoupler between molten salt and water mass flow rate and a 4th order controller on wFW"
          extends Schemes.BaseClasses.BasePowerPressureController;

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          //-- pumpFW --
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                    annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS"
                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

          Old.control_Yt control_Yt(
            actuatorGain_valveTURB=actuatorGain_valveTURB,
            Ta_valveTURB=Ta_valveTURB,
            load_switch=load_switch,
            Kp_valveTURB_high=Kp_valveTURB_high,
            Ti_valveTURB_high=Ti_valveTURB_high,
            Td_valveTURB_high=Td_valveTURB_high,
            Nd_valveTURB_high=Nd_valveTURB_high,
            CSmin_valveTURB_high=CSmin_valveTURB_high,
            CSmax_valveTURB_high=CSmax_valveTURB_high,
            CSstart_valveTURB_high=CSstart_valveTURB_high,
            TS_valveTURB_high=TS_valveTURB_high,
            Kp_valveTURB_low=Kp_valveTURB_low,
            Ti_valveTURB_low=Ti_valveTURB_low,
            Td_valveTURB_low=Td_valveTURB_low,
            Nd_valveTURB_low=Nd_valveTURB_low,
            CSmin_valveTURB_low=CSmin_valveTURB_low,
            CSmax_valveTURB_low=CSmax_valveTURB_low,
            CSstart_valveTURB_low=CSstart_valveTURB_low,
            TS_valveTURB_low=TS_valveTURB_low)
            annotation (Placement(transformation(extent={{0,220},{80,300}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,80})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_high,
            CSmax=CSmax_pumpMS_high,
            CS_start=CSstart_pumpMS_high,
            Kp=Kp_pumpMS_high,
            Ti=Ti_pumpMS_high,
            Td=Td_pumpMS_high,
            N=Nd_pumpMS_high)
            annotation (Placement(transformation(extent={{-160,-10},{-120,30}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
            annotation (Placement(transformation(extent={{-180,40},{-160,60}})));
          Modelica.Blocks.Math.Add add_high
            annotation (Placement(transformation(extent={{40,-12},{60,8}})));
          Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
            annotation (Placement(transformation(extent={{140,70},{160,90}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_high(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,12},{-210,32}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,-50},{-120,-30}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
          Modelica.Blocks.Logical.Switch switch_MS
            annotation (Placement(transformation(extent={{100,90},{120,70}})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_low,
            CSmax=CSmax_pumpMS_low,
            CS_start=CSstart_pumpMS_low,
            Kp=Kp_pumpMS_low,
            Ti=Ti_pumpMS_low,
            Td=Td_pumpMS_low,
            N=Nd_pumpMS_low)
            annotation (Placement(transformation(extent={{-160,150},{-120,190}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
            annotation (Placement(transformation(extent={{-180,200},{-160,220}})));
          Modelica.Blocks.Math.Add add_low
            annotation (Placement(transformation(extent={{-80,154},{-60,174}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,172},{-210,192}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,110},{-120,130}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-232,-318},{-212,-298}})));
          Modelica.Blocks.Continuous.StateSpace controller4th_pumpFW_high(
            A=A,
            B=B,
            C=C,
            D=D)
            annotation (Placement(transformation(extent={{-174,-160},{-134,
                    -120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,-230})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{-20,-150},{0,-130}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{20,-194},{40,-174}})));
          Modelica.Blocks.Logical.Switch switch_FW
            annotation (Placement(transformation(extent={{100,-240},{120,-220}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_low,
            CSmax=CSmax_pumpFW_low,
            CS_start=CSstart_pumpFW_low,
            Kp=Kp_pumpFW_low,
            Ti=Ti_pumpFW_low)
            annotation (Placement(transformation(extent={{-160,-340},{-120,-300}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                     k=TS_pumpFW_low)
            annotation (Placement(transformation(extent={{-180,-290},{-160,-270}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold1(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,-240},{-80,-220}})));
          Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
            annotation (Placement(transformation(extent={{-260,-120},{-240,-100}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
              Placement(transformation(extent={{-140,-200},{-120,-180}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{140,-240},{160,-220}})));
          Modelica.Blocks.Math.Gain gamma_FW_MS(k=8.86459201881573*10)
            annotation (Placement(transformation(extent={{-60,-22},{-40,-2}})));
          Modelica.Blocks.Math.Add add_dec_MS
            annotation (Placement(transformation(extent={{-20,-6},{0,14}})));
          Modelica.Blocks.Math.Add add_dec_FW
            annotation (Placement(transformation(extent={{-60,-144},{-40,-124}})));
          Modelica.Blocks.Math.Gain gamma_MS_FW(k=1e-3)
            annotation (Placement(transformation(extent={{-40,-100},{-60,-80}})));
          Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
            annotation (Placement(transformation(extent={{-220,-150},{-200,-130}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
              uMin=CSmin_pumpFW_high)
            annotation (Placement(transformation(extent={{-124,-150},{-104,
                    -130}})));
          Modelica.Blocks.Logical.Switch switch_FW1
            annotation (Placement(transformation(extent={{-92,-120},{-82,-110}})));
          Modelica.Blocks.Sources.Constant const(k=0) annotation (Placement(
                transformation(extent={{-130,-102},{-120,-92}})));
        equation
          connect(load, control_Yt.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,260},{-4,260}},
                                           color={0,0,127}));
          connect(control_Yt.signalBus, signalBus) annotation (Line(
              points={{82,260},{82,260},{320,260},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS_high.y, PID_pumpMS_high.TR)
            annotation (Line(points={{-159,50},{-140,50},{-140,26}}, color={0,0,127}));
          connect(pumpMS_lim.y,pumpMS_dynamic. u) annotation (Line(points={{161,80},{161,
                  80},{176,80}},             color={0,0,127}));
          connect(table_P_MEC_high.y[1], PID_pumpMS_high.SP)
            annotation (Line(points={{-209,22},{-156,22}},           color={0,0,127}));
          connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points={{-119,-40},
                  {30,-40},{30,-8},{38,-8}}, color={0,0,127}));
          connect(pumpMS_lim.u,switch_MS. y)
            annotation (Line(points={{138,80},{121,80}},
                                                     color={0,0,127}));
          connect(greaterEqualThreshold.y,switch_MS. u2)
            annotation (Line(points={{-79,80},{98,80}},         color={255,0,255}));
          connect(add_high.y, switch_MS.u1) annotation (Line(points={{61,-2},{80,-2},{80,
                  72},{98,72}}, color={0,0,127}));
          connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points={{-159,210},
                  {-140,210},{-140,186}}, color={0,0,127}));
          connect(add_low.u1, PID_pumpMS_low.CS) annotation (Line(points={{-82,170},{-82,
                  170},{-122,170}}, color={0,0,127}));
          connect(table_P_MEC_low.y[1], PID_pumpMS_low.SP) annotation (Line(points={{-209,
                  182},{-188,182},{-156,182}}, color={0,0,127}));
          connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{-119,120},{
                  -110,120},{-110,158},{-82,158}}, color={0,0,127}));
          connect(add_low.y, switch_MS.u3) annotation (Line(points={{-59,164},{-40,164},
                  {-40,88},{98,88}}, color={0,0,127}));
          connect(product.y,add. u1) annotation (Line(points={{1,-140},{1,-140},{0,-140},
                  {10,-140},{10,-178},{18,-178}},
                                        color={0,0,127}));
          connect(add.y,switch_FW. u1)
            annotation (Line(points={{41,-184},{61,-184},{61,-222},{98,-222}},
                                                                     color={0,0,127}));
          connect(switch_FW.u3,PID_pumpFW_low. CS) annotation (Line(points={{98,-238},{60,
                  -238},{60,-320},{-122,-320}},
                                              color={0,0,127}));
          connect(pumpFW_TS_low.y,PID_pumpFW_low. TR)
            annotation (Line(points={{-159,-280},{-140,-280},{-140,-304}},
                                                                     color={0,0,127}));
          connect(l_SP.y,PID_pumpFW_low. SP) annotation (Line(points={{-211,-308},{-156,
                  -308}},     color={0,0,127}));
          connect(switch_FW.u2, greaterEqualThreshold1.y) annotation (Line(points={{98,-230},
                  {98,-230},{-79,-230}}, color={255,0,255}));
          connect(table_w_FW.y[1],add. u2)
            annotation (Line(points={{-119,-190},{-44,-190},{18,-190}},
                                                        color={0,0,127}));
          connect(table_w_FW.y[1],product. u2) annotation (Line(points={{-119,-190},{-30,
                  -190},{-30,-146},{-22,-146}},    color={0,0,127}));
          connect(switch_FW.y,pumpFW_lim. u)
            annotation (Line(points={{121,-230},{138,-230}},
                                                     color={0,0,127}));
          connect(pumpFW_lim.y,pumpFW_dynamic. u)
            annotation (Line(points={{161,-230},{176,-230}},
                                                       color={0,0,127}));
          connect(load, table_P_MEC_low.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,182},{-232,182}},
                                                   color={0,0,127}));
          connect(load, greaterEqualThreshold.u) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,80},{-102,80}},
                                                    color={0,0,127}));
          connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,120},{-142,120}},
                                                   color={0,0,127}));
          connect(load, table_P_MEC_high.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,22},{-232,22}},
                                                 color={0,0,127}));
          connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-330,0},
                  {-330,0},{-260,0},{-260,-40},{-142,-40}},
                                                   color={0,0,127}));
          connect(load, greaterEqualThreshold1.u) annotation (Line(points={{-330,0},
                  {-330,0},{-360,0},{-360,-230},{-102,-230}},
                                                        color={0,0,127}));
          connect(load, table_w_FW.u[1]) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,-230},{-160,-230},{-160,-190},{-142,
                  -190}},                                              color={0,0,127}));
          connect(PID_pumpMS_high.CS, add_dec_MS.u1)
            annotation (Line(points={{-122,10},{-22,10}}, color={0,0,127}));
          connect(add_dec_MS.y, add_high.u1)
            annotation (Line(points={{1,4},{38,4}}, color={0,0,127}));
          connect(gamma_FW_MS.y, add_dec_MS.u2) annotation (Line(points={{-39,-12},{-30,
                  -12},{-30,-2},{-22,-2}}, color={0,0,127}));
          connect(TS_pumpMS_bool, PID_pumpMS_low.TS) annotation (Line(points={{-200,
                  390},{-280,390},{-280,240},{-132,240},{-132,186}},
                                                                color={255,0,255}));
          connect(TS_pumpMS_bool, PID_pumpMS_high.TS) annotation (Line(points={{-200,
                  390},{-300,390},{-300,200},{-300,90},{-132,90},{-132,26}},
                                                                        color={255,0,255}));
          connect(add_dec_FW.y, product.u1) annotation (Line(points={{-39,-134},{-30.5,-134},
                  {-22,-134}}, color={0,0,127}));
          connect(add_dec_FW.y, gamma_FW_MS.u) annotation (Line(points={{-39,-134},{-36,
                  -134},{-32,-134},{-32,-56},{-88,-56},{-88,-12},{-62,-12}}, color={0,0,
                  127}));
          connect(add_dec_MS.y, gamma_MS_FW.u) annotation (Line(points={{1,4},{10,4},{10,
                  -90},{-38,-90}}, color={0,0,127}));
          connect(gamma_MS_FW.y, add_dec_FW.u1) annotation (Line(points={{-61,-90},{-61,
                  -90},{-70,-90},{-70,-128},{-62,-128}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,78},{360,80},{222,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,-234},{360,-230},{222,-230}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_pumpFWlow_bool, PID_pumpFW_low.TS) annotation (Line(points={{-200,
                  -30},{-300,-30},{-300,-120},{-300,-260},{-132,-260},{-132,
                  -304}},                                                       color={255,
                  0,255}));
          connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-362},{360,-360},{-188,-360},{-188,
                  -322},{-156,-322}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_high.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-188,-360},{-188,8},{-156,8}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-188,-360},{-188,8},{-188,166},
                  {-156,166},{-156,168}},
              color={255,204,51},
              thickness=0.5));
          connect(DT_sh_SP.y, DT_sh_error.u1) annotation (Line(points={{-239,-110},{-234,
                  -110},{-230,-110},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(DT_sh_error.y, controller4th_pumpFW_high.u[1])
            annotation (Line(points={{-199,-140},{-178,-140}}, color={0,0,127}));
          connect(signalBus.pumpFW_PV_high, DT_sh_error.u2) annotation (Line(
              points={{320,0},{360,0},{360,-362},{-188,-362},{-188,-180},{-230,
                  -180},{-230,-146},{-222,-146}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_valveTURBhigh_bool, control_Yt.TS_valveTURBhigh_bool)
            annotation (Line(points={{-200,-170},{-132,-170},{-132,304},{60,304}},
                color={255,0,255}));
          connect(TS_valveTURBlow_bool, control_Yt.TS_valveTURBlow_bool)
            annotation (Line(points={{-200,-290},{20,-290},{20,304}},
                                                                    color={
                  255,0,255}));
          connect(controller4th_pumpFW_high.y[1], pumpFW_lim_adim.u) annotation (Line(
                points={{-132,-140},{-132,-140},{-126,-140}}, color={0,0,127}));
          connect(add_dec_FW.u2, switch_FW1.y) annotation (Line(points={{-62,
                  -140},{-80,-140},{-80,-138},{-80,-115},{-81.5,-115}}, color=
                 {0,0,127}));
          connect(pumpFW_lim_adim.y, switch_FW1.u3) annotation (Line(points={
                  {-103,-140},{-100,-140},{-100,-119},{-93,-119}}, color={0,0,
                  127}));
          connect(TS_pumpFWhigh_bool, switch_FW1.u2) annotation (Line(points={{-200,30},
                  {-218,30},{-218,-80},{-93,-80},{-93,-115}},
                color={255,0,255}));
          connect(const.y, switch_FW1.u1) annotation (Line(points={{-119.5,
                  -97},{-100,-97},{-100,-111},{-93,-111}}, color={0,0,127}));
        end wMS_wFW_staticDecoupler_4th_controller_old;

        model wMS_wFW_staticDecoupler_10th_controller_old
          "Control schemes with a static decoupler between molten salt and water mass flow rate and a 10th order controller on wFW"
          extends Schemes.BaseClasses.BasePowerPressureController;

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          //-- pumpFW --
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                    annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS"
                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

          Old.control_Yt control_Yt(
            actuatorGain_valveTURB=actuatorGain_valveTURB,
            Ta_valveTURB=Ta_valveTURB,
            load_switch=load_switch,
            Kp_valveTURB_high=Kp_valveTURB_high,
            Ti_valveTURB_high=Ti_valveTURB_high,
            Td_valveTURB_high=Td_valveTURB_high,
            Nd_valveTURB_high=Nd_valveTURB_high,
            CSmin_valveTURB_high=CSmin_valveTURB_high,
            CSmax_valveTURB_high=CSmax_valveTURB_high,
            CSstart_valveTURB_high=CSstart_valveTURB_high,
            TS_valveTURB_high=TS_valveTURB_high,
            Kp_valveTURB_low=Kp_valveTURB_low,
            Ti_valveTURB_low=Ti_valveTURB_low,
            Td_valveTURB_low=Td_valveTURB_low,
            Nd_valveTURB_low=Nd_valveTURB_low,
            CSmin_valveTURB_low=CSmin_valveTURB_low,
            CSmax_valveTURB_low=CSmax_valveTURB_low,
            CSstart_valveTURB_low=CSstart_valveTURB_low,
            TS_valveTURB_low=TS_valveTURB_low)
            annotation (Placement(transformation(extent={{0,220},{80,300}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,80})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_high,
            CSmax=CSmax_pumpMS_high,
            CS_start=CSstart_pumpMS_high,
            Kp=Kp_pumpMS_high,
            Ti=Ti_pumpMS_high,
            Td=Td_pumpMS_high,
            N=Nd_pumpMS_high)
            annotation (Placement(transformation(extent={{-160,-10},{-120,30}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
            annotation (Placement(transformation(extent={{-180,40},{-160,60}})));
          Modelica.Blocks.Math.Add add_high
            annotation (Placement(transformation(extent={{40,-12},{60,8}})));
          Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
            annotation (Placement(transformation(extent={{140,70},{160,90}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_high(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,12},{-210,32}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,-50},{-120,-30}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
          Modelica.Blocks.Logical.Switch switch_MS
            annotation (Placement(transformation(extent={{100,90},{120,70}})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpMS_low,
            CSmax=CSmax_pumpMS_low,
            CS_start=CSstart_pumpMS_low,
            Kp=Kp_pumpMS_low,
            Ti=Ti_pumpMS_low,
            Td=Td_pumpMS_low,
            N=Nd_pumpMS_low)
            annotation (Placement(transformation(extent={{-160,150},{-120,190}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
            annotation (Placement(transformation(extent={{-180,200},{-160,220}})));
          Modelica.Blocks.Math.Add add_low
            annotation (Placement(transformation(extent={{-80,154},{-60,174}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,51.134e6;
                70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
            annotation (Placement(transformation(extent={{-230,172},{-210,192}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,495.8;
                90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{-140,110},{-120,130}})));
          Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
            annotation (Placement(transformation(extent={{-232,-318},{-212,-298}})));
          Modelica.Blocks.Continuous.StateSpace controller10th_pumpFW_high(
            A=A,
            B=B,
            C=C,
            D=D)
            annotation (Placement(transformation(extent={{-160,-160},{-120,-120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={200,-230})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{-20,-150},{0,-130}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{20,-194},{40,-174}})));
          Modelica.Blocks.Logical.Switch switch_FW
            annotation (Placement(transformation(extent={{100,-240},{120,-220}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
            AntiWindup=true,
            useTS=true,
            CSmin=CSmin_pumpFW_low,
            CSmax=CSmax_pumpFW_low,
            CS_start=CSstart_pumpFW_low,
            Kp=Kp_pumpFW_low,
            Ti=Ti_pumpFW_low)
            annotation (Placement(transformation(extent={{-160,-340},{-120,-300}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                     k=TS_pumpFW_low)
            annotation (Placement(transformation(extent={{-180,-290},{-160,-270}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold1(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-100,-240},{-80,-220}})));
          Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
            annotation (Placement(transformation(extent={{-260,-120},{-240,-100}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
                70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
              Placement(transformation(extent={{-140,-200},{-120,-180}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{140,-240},{160,-220}})));
          Modelica.Blocks.Math.Gain gamma_FW_MS(k=8.86459201881573*10)
            annotation (Placement(transformation(extent={{-60,-22},{-40,-2}})));
          Modelica.Blocks.Math.Add add_dec_MS
            annotation (Placement(transformation(extent={{-20,-6},{0,14}})));
          Modelica.Blocks.Math.Add add_dec_FW
            annotation (Placement(transformation(extent={{-60,-144},{-40,-124}})));
          Modelica.Blocks.Math.Gain gamma_MS_FW(k=1e-3)
            annotation (Placement(transformation(extent={{-40,-100},{-60,-80}})));
          Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
            annotation (Placement(transformation(extent={{-220,-150},{-200,-130}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
              uMin=CSmin_pumpFW_high)
            annotation (Placement(transformation(extent={{-100,-150},{-80,-130}})));
        equation
          connect(load, control_Yt.load) annotation (Line(points={{-420,0},{
                  -390,0},{-360,0},{-360,260},{-4,260}},
                                           color={0,0,127}));
          connect(control_Yt.signalBus, signalBus) annotation (Line(
              points={{82,260},{82,260},{360,260},{360,0}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS_high.y, PID_pumpMS_high.TR)
            annotation (Line(points={{-159,50},{-140,50},{-140,26}}, color={0,0,127}));
          connect(pumpMS_lim.y,pumpMS_dynamic. u) annotation (Line(points={{161,80},{161,
                  80},{176,80}},             color={0,0,127}));
          connect(table_P_MEC_high.y[1], PID_pumpMS_high.SP)
            annotation (Line(points={{-209,22},{-190,22},{-156,22}}, color={0,0,127}));
          connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points={{-119,-40},
                  {30,-40},{30,-8},{38,-8}}, color={0,0,127}));
          connect(pumpMS_lim.u,switch_MS. y)
            annotation (Line(points={{138,80},{121,80}},
                                                     color={0,0,127}));
          connect(greaterEqualThreshold.y,switch_MS. u2)
            annotation (Line(points={{-79,80},{98,80}},         color={255,0,255}));
          connect(add_high.y, switch_MS.u1) annotation (Line(points={{61,-2},{80,-2},{80,
                  72},{98,72}}, color={0,0,127}));
          connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points={{-159,210},
                  {-140,210},{-140,186}}, color={0,0,127}));
          connect(add_low.u1, PID_pumpMS_low.CS) annotation (Line(points={{-82,170},{-82,
                  170},{-122,170}}, color={0,0,127}));
          connect(table_P_MEC_low.y[1], PID_pumpMS_low.SP) annotation (Line(points={{-209,
                  182},{-188,182},{-156,182}}, color={0,0,127}));
          connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{-119,120},{
                  -110,120},{-110,158},{-82,158}}, color={0,0,127}));
          connect(add_low.y, switch_MS.u3) annotation (Line(points={{-59,164},{-40,164},
                  {-40,88},{98,88}}, color={0,0,127}));
          connect(product.y,add. u1) annotation (Line(points={{1,-140},{1,-140},{0,-140},
                  {10,-140},{10,-178},{18,-178}},
                                        color={0,0,127}));
          connect(add.y,switch_FW. u1)
            annotation (Line(points={{41,-184},{61,-184},{61,-222},{98,-222}},
                                                                     color={0,0,127}));
          connect(switch_FW.u3,PID_pumpFW_low. CS) annotation (Line(points={{98,-238},{60,
                  -238},{60,-320},{-122,-320}},
                                              color={0,0,127}));
          connect(pumpFW_TS_low.y,PID_pumpFW_low. TR)
            annotation (Line(points={{-159,-280},{-140,-280},{-140,-304}},
                                                                     color={0,0,127}));
          connect(l_SP.y,PID_pumpFW_low. SP) annotation (Line(points={{-211,-308},{-156,
                  -308}},     color={0,0,127}));
          connect(switch_FW.u2, greaterEqualThreshold1.y) annotation (Line(points={{98,-230},
                  {98,-230},{-79,-230}}, color={255,0,255}));
          connect(table_w_FW.y[1],add. u2)
            annotation (Line(points={{-119,-190},{-44,-190},{18,-190}},
                                                        color={0,0,127}));
          connect(table_w_FW.y[1],product. u2) annotation (Line(points={{-119,-190},{-30,
                  -190},{-30,-146},{-22,-146}},    color={0,0,127}));
          connect(switch_FW.y,pumpFW_lim. u)
            annotation (Line(points={{121,-230},{138,-230}},
                                                     color={0,0,127}));
          connect(pumpFW_lim.y,pumpFW_dynamic. u)
            annotation (Line(points={{161,-230},{176,-230}},
                                                       color={0,0,127}));
          connect(load, table_P_MEC_low.u[1]) annotation (Line(points={{-420,0},{-342,0},
                  {-260,0},{-260,182},{-232,182}}, color={0,0,127}));
          connect(load, greaterEqualThreshold.u) annotation (Line(points={{-420,0},{-420,
                  0},{-260,0},{-260,80},{-102,80}}, color={0,0,127}));
          connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-420,0},{-420,0},
                  {-260,0},{-260,120},{-142,120}}, color={0,0,127}));
          connect(load, table_P_MEC_high.u[1]) annotation (Line(points={{-420,0},{-420,0},
                  {-260,0},{-260,22},{-232,22}}, color={0,0,127}));
          connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-420,0},{-420,0},
                  {-260,0},{-260,-40},{-142,-40}}, color={0,0,127}));
          connect(load, greaterEqualThreshold1.u) annotation (Line(points={{-420,0},{-392,
                  0},{-360,0},{-360,-230},{-102,-230}}, color={0,0,127}));
          connect(load, table_w_FW.u[1]) annotation (Line(points={{-420,0},{-420,0},{-360,
                  0},{-360,-230},{-160,-230},{-160,-190},{-142,-190}}, color={0,0,127}));
          connect(PID_pumpMS_high.CS, add_dec_MS.u1)
            annotation (Line(points={{-122,10},{-22,10}}, color={0,0,127}));
          connect(add_dec_MS.y, add_high.u1)
            annotation (Line(points={{1,4},{38,4}}, color={0,0,127}));
          connect(gamma_FW_MS.y, add_dec_MS.u2) annotation (Line(points={{-39,-12},{-30,
                  -12},{-30,-2},{-22,-2}}, color={0,0,127}));
          connect(TS_pumpMS_bool, PID_pumpMS_low.TS) annotation (Line(points={{-320,
                  160},{-280,160},{-280,240},{-132,240},{-132,186}},
                                                                color={255,0,255}));
          connect(TS_pumpMS_bool, PID_pumpMS_high.TS) annotation (Line(points={{-320,
                  160},{-300,160},{-300,200},{-300,90},{-132,90},{-132,26}},
                                                                        color={255,0,255}));
          connect(add_dec_FW.y, product.u1) annotation (Line(points={{-39,-134},{-30.5,-134},
                  {-22,-134}}, color={0,0,127}));
          connect(add_dec_FW.y, gamma_FW_MS.u) annotation (Line(points={{-39,-134},{-36,
                  -134},{-32,-134},{-32,-56},{-88,-56},{-88,-12},{-62,-12}}, color={0,0,
                  127}));
          connect(add_dec_MS.y, gamma_MS_FW.u) annotation (Line(points={{1,4},{10,4},{10,
                  -90},{-38,-90}}, color={0,0,127}));
          connect(gamma_MS_FW.y, add_dec_FW.u1) annotation (Line(points={{-61,-90},{-61,
                  -90},{-70,-90},{-70,-128},{-62,-128}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{360,0},{360,0},{360,78},{360,80},{222,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{360,0},{360,0},{360,-234},{360,-230},{222,-230}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_pumpFWlow_bool, PID_pumpFW_low.TS) annotation (Line(points={{-320,-120},
                  {-300,-120},{-280,-120},{-280,-260},{-132,-260},{-132,-304}}, color={255,
                  0,255}));
          connect(signalBus.pumpFW_PV_low, PID_pumpFW_low.PV) annotation (Line(
              points={{360,0},{360,0},{360,-362},{360,-360},{-188,-360},{-188,-322},{-156,
                  -322}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_high.PV) annotation (Line(
              points={{360,0},{360,0},{360,-360},{-188,-360},{-188,8},{-156,8}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, PID_pumpMS_low.PV) annotation (Line(
              points={{360,0},{360,0},{360,-360},{-188,-360},{-188,8},{-188,166},{-156,166},
                  {-156,168}},
              color={255,204,51},
              thickness=0.5));
          connect(DT_sh_SP.y, DT_sh_error.u1) annotation (Line(points={{-239,-110},{-234,
                  -110},{-230,-110},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(signalBus.pumpFW_PV_high, DT_sh_error.u2) annotation (Line(
              points={{360,0},{360,0},{360,-362},{-188,-362},{-188,-180},{-230,-180},{-230,
                  -146},{-222,-146}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_valveTURBhigh_bool, control_Yt.TS_valveTURBhigh_bool)
            annotation (Line(points={{-320,340},{-130,340},{60,340},{60,304}},
                color={255,0,255}));
          connect(TS_valveTURBlow_bool, control_Yt.TS_valveTURBlow_bool)
            annotation (Line(points={{-320,310},{20,310},{20,304}}, color={
                  255,0,255}));
          connect(DT_sh_error.y, controller10th_pumpFW_high.u[1]) annotation (
             Line(points={{-199,-140},{-164,-140}},             color={0,0,
                  127}));
          connect(pumpFW_lim_adim.y, add_dec_FW.u2) annotation (Line(points={{-79,-140},
                  {-70.5,-140},{-62,-140}}, color={0,0,127}));
          connect(controller10th_pumpFW_high.y[1], pumpFW_lim_adim.u)
            annotation (Line(points={{-118,-140},{-102,-140}}, color={0,0,127}));
        end wMS_wFW_staticDecoupler_10th_controller_old;

        model wMS_wFW_staticDecoupler_4th_controller
          "Control schemes with a static decoupler between molten salt and water mass flow rate and a 4th order controller on wFW"
          extends Schemes.BaseClasses.BasePowerPressureController;

          //-- General settings --
          parameter Real load_switch
            "Plant load limit for switching from dry to wet separator configuration"
                                                                                     annotation (Dialog(tab="General"));

          //-- pumpMS --
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

          //-- pumpMS_high --
          parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_high
            "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_high
            "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real Nd_pumpMS_high
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmin_pumpMS_high
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSmax_pumpMS_high
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
          parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

          //-- pumpMS_low --
          parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_pumpMS_low
            "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_pumpMS_low
            "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real Nd_pumpMS_low
            "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmin_pumpMS_low
            "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSmax_pumpMS_low
            "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
          parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

          //-- valveTURB --
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));

          //-- valveTURB_high
          parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_high
            "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_high
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real Nd_valveTURB_high
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmin_valveTURB_high
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSmax_valveTURB_high
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
          parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

          //-- valveTURB_low
          parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Ti_valveTURB_low
            "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Modelica.SIunits.Time Td_valveTURB_low
            "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real Nd_valveTURB_low
            "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmin_valveTURB_low
            "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSmax_valveTURB_low
            "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
          parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

          //-- pumpFW --
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

          //-- pumpFW_high --
          parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
            "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
          parameter Real TS_pumpFW_high "Tracking signal"
                                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

          //-- pumpFW_low --
          parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                    annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Kp_pumpFW_low "Controller proportional gain"
                                           annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Ti_pumpFW_low
            "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Modelica.SIunits.Time Td_pumpFW_low
            "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real Nd_pumpFW_low
            "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real CSstart_pumpFW_low "Start value of CS"
                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
          parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

          Old.control_Yt control_Yt(
            actuatorGain_valveTURB=actuatorGain_valveTURB,
            Ta_valveTURB=Ta_valveTURB,
            load_switch=load_switch,
            Kp_valveTURB_high=Kp_valveTURB_high,
            Ti_valveTURB_high=Ti_valveTURB_high,
            Td_valveTURB_high=Td_valveTURB_high,
            Nd_valveTURB_high=Nd_valveTURB_high,
            CSmin_valveTURB_high=CSmin_valveTURB_high,
            CSmax_valveTURB_high=CSmax_valveTURB_high,
            CSstart_valveTURB_high=CSstart_valveTURB_high,
            TS_valveTURB_high=TS_valveTURB_high,
            Kp_valveTURB_low=Kp_valveTURB_low,
            Ti_valveTURB_low=Ti_valveTURB_low,
            Td_valveTURB_low=Td_valveTURB_low,
            Nd_valveTURB_low=Nd_valveTURB_low,
            CSmin_valveTURB_low=CSmin_valveTURB_low,
            CSmax_valveTURB_low=CSmax_valveTURB_low,
            CSstart_valveTURB_low=CSstart_valveTURB_low,
            TS_valveTURB_low=TS_valveTURB_low)
            annotation (Placement(transformation(extent={{0,220},{80,300}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={120,120})));
          Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
            annotation (Placement(transformation(extent={{40,110},{60,130}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-80,110},{-60,130}})));
          Modelica.Blocks.Logical.Switch switch_MS
            annotation (Placement(transformation(extent={{-20,130},{0,110}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={120,-220})));
          Modelica.Blocks.Logical.Switch switch_FW
            annotation (Placement(transformation(extent={{-18,-230},{2,-210}})));
          Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold1(threshold=
               load_switch)
            annotation (Placement(transformation(extent={{-80,-230},{-60,-210}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{40,-230},{60,-210}})));
          Modelica.Blocks.Math.Gain gamma_FW_MS(k=8.86459201881573*10)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-162,-30})));
          Modelica.Blocks.Math.Gain gamma_MS_FW(k=1e-3)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-100,-30})));
          Schemes.SingleControllers.control_wMS_high control_wMS_high(
            load_switch=load_switch,
            Kp_pumpMS_high=Kp_pumpMS_high,
            Ti_pumpMS_high=Ti_pumpMS_high,
            Td_pumpMS_high=Td_pumpMS_high,
            Nd_pumpMS_high=Nd_pumpMS_high,
            CSmin_pumpMS_high=CSmin_pumpMS_high,
            CSmax_pumpMS_high=CSmax_pumpMS_high,
            CSstart_pumpMS_high=CSstart_pumpMS_high,
            TS_pumpMS_high=TS_pumpMS_high)
            annotation (Placement(transformation(extent={{-180,0},{-120,60}})));
          Schemes.SingleControllers.control_wMS_low control_wMS_low(
            load_switch=load_switch,
            Kp_pumpMS_low=Kp_pumpMS_low,
            Ti_pumpMS_low=Ti_pumpMS_low,
            Td_pumpMS_low=Td_pumpMS_low,
            Nd_pumpMS_low=Nd_pumpMS_low,
            CSmin_pumpMS_low=CSmin_pumpMS_low,
            CSmax_pumpMS_low=CSmax_pumpMS_low,
            CSstart_pumpMS_low=CSstart_pumpMS_low,
            TS_pumpMS_low=TS_pumpMS_low) annotation (Placement(transformation(
                  extent={{-180,140},{-120,200}})));
          Schemes.SingleControllers.control_wFW_low control_wFW_low(
            load_switch=load_switch,
            l_sp=l_sp,
            Kp_pumpFW_low=Kp_pumpFW_low,
            Ti_pumpFW_low=Ti_pumpFW_low,
            Td_pumpFW_low=Td_pumpFW_low,
            Nd_pumpFW_low=Nd_pumpFW_low,
            CSmin_pumpFW_low=CSmin_pumpFW_low,
            CSmax_pumpFW_low=CSmax_pumpFW_low,
            CSstart_pumpFW_low=CSstart_pumpFW_low,
            TS_pumpFW_low=TS_pumpFW_low) annotation (Placement(transformation(
                  extent={{-180,-320},{-120,-260}})));
          Schemes.SingleControllers.control_wFW_high_4th control_wFW_high_4th(
            load_switch=load_switch,
            DT_sh_sp=DT_sh_sp,
            A=A,
            B=B,
            C=C,
            D=D,
            CSmin_pumpFW_high=CSmin_pumpFW_high,
            CSmax_pumpFW_high=CSmax_pumpFW_high,
            TS_pumpFW_high=0) annotation (Placement(transformation(extent={{-180,
                    -180},{-120,-120}})));
        equation
          connect(load, control_Yt.load) annotation (Line(points={{-330,0},{
                  -330,0},{-360,0},{-360,260},{-4,260}},
                                           color={0,0,127}));
          connect(control_Yt.signalBus, signalBus) annotation (Line(
              points={{82,260},{82,260},{320,260},{320,0}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_lim.y,pumpMS_dynamic. u) annotation (Line(points={{61,120},
                  {61,120},{96,120}},        color={0,0,127}));
          connect(pumpMS_lim.u,switch_MS. y)
            annotation (Line(points={{38,120},{1,120}},
                                                     color={0,0,127}));
          connect(greaterEqualThreshold.y,switch_MS. u2)
            annotation (Line(points={{-59,120},{-59,120},{-22,120}},
                                                                color={255,0,255}));
          connect(switch_FW.u2, greaterEqualThreshold1.y) annotation (Line(points={{-20,
                  -220},{-20,-220},{-59,-220}},
                                         color={255,0,255}));
          connect(switch_FW.y,pumpFW_lim. u)
            annotation (Line(points={{3,-220},{38,-220}},
                                                     color={0,0,127}));
          connect(pumpFW_lim.y,pumpFW_dynamic. u)
            annotation (Line(points={{61,-220},{61,-220},{96,-220}},
                                                       color={0,0,127}));
          connect(load, greaterEqualThreshold1.u) annotation (Line(points={{-330,0},
                  {-330,0},{-360,0},{-360,-220},{-82,-220}},
                                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,78},{360,120},{142,120}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{320,0},{360,0},{360,-204},{360,-220},{142,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(TS_valveTURBhigh_bool, control_Yt.TS_valveTURBhigh_bool)
            annotation (Line(points={{-200,-170},{-132,-170},{-132,304},{60,304}},
                color={255,0,255}));
          connect(TS_valveTURBlow_bool, control_Yt.TS_valveTURBlow_bool)
            annotation (Line(points={{-200,-290},{20,-290},{20,304}},
                                                                    color={
                  255,0,255}));
          connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool)
            annotation (Line(points={{-200,390},{-290,390},{-290,160},{-290,100},
                  {-165,100},{-165,63}},          color={255,0,255}));
          connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (
             Line(points={{-200,390},{-260,390},{-260,240},{-165,240},{-165,203}},
                         color={255,0,255}));
          connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points=
                  {{-118.5,30},{-40,30},{-40,112},{-22,112}}, color={0,0,127}));
          connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={
                  {-118.5,170},{-40,170},{-40,128},{-22,128}}, color={0,0,127}));
          connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},
                  {-330,0},{-230,0},{-230,51},{-183,51}},    color={0,0,127}));
          connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},
                  {-330,0},{-230,0},{-230,52},{-230,191},{-183,191}},
                color={0,0,127}));
          connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-192,-360},{-192,-160},{-192,
                  32},{-192,30},{-183,30}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-192,-360},{-192,170},{-183,
                  170}},
              color={255,204,51},
              thickness=0.5));
          connect(control_wMS_high.dec_in, gamma_FW_MS.y) annotation (Line(
                points={{-132,-3},{-132,-12},{-162,-12},{-162,-19}},
                                               color={0,0,127}));
          connect(pumpMS_dynamic.y, control_wMS_high.TS) annotation (Line(
                points={{142,120},{152,120},{160,120},{160,80},{-135,80},{-135,
                  63}},      color={0,0,127}));
          connect(pumpMS_dynamic.y, control_wMS_low.TS) annotation (Line(
                points={{142,120},{152,120},{160,120},{160,212},{-135,212},{
                  -135,203}}, color={0,0,127}));
          connect(load, greaterEqualThreshold.u) annotation (Line(points={{-330,0},
                  {-360,0},{-360,120},{-82,120}},         color={0,0,127}));
          connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-168,
                  -1.5},{-168,-8.75},{-100,-8.75},{-100,-18}}, color={0,0,127}));
          connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-118.5,-290},
                  {-80,-290},{-40,-290},{-40,-228},{-20,-228}}, color={0,0,127}));
          connect(TS_pumpFWhigh_bool, control_wFW_high_4th.TS_pumpFWhigh_bool)
            annotation (Line(points={{-200,30},{-165,30},{-165,-117}},   color={255,0,255}));
          connect(pumpFW_dynamic.y, control_wFW_high_4th.TS) annotation (Line(points={{142,
                  -220},{160,-220},{160,-110},{-135,-110},{-135,-117}}, color={0,0,127}));
          connect(pumpFW_dynamic.y, control_wFW_low.TS) annotation (Line(points={{142,
                  -220},{154,-220},{160,-220},{160,-248},{-135,-248},{-135,-257}},
                                                                             color={0,0,
                  127}));
          connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
              Line(points={{-200,-30},{-260,-30},{-260,-240},{-165,-240},{-165,
                  -257}},
                color={255,0,255}));
          connect(control_wFW_high_4th.CS, switch_FW.u1) annotation (Line(points={{-118.5,
                  -150},{-78,-150},{-40,-150},{-40,-212},{-20,-212}}, color={0,0,127}));
          connect(control_wFW_high_4th.dec_out, gamma_FW_MS.u) annotation (Line(points={{-132,
                  -181.5},{-132,-192},{-210,-192},{-210,-60},{-162,-60},{-162,
                  -42}},
                color={0,0,127}));
          connect(gamma_MS_FW.y, control_wFW_high_4th.dec_in) annotation (Line(points={{-100,
                  -41},{-100,-41},{-100,-200},{-168,-200},{-168,-183}},      color={0,0,
                  127}));
          connect(signalBus.pumpFW_PV_high, control_wFW_high_4th.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-192,-360},{-192,-150},{-183,
                  -150}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
              points={{320,0},{360,0},{360,-360},{-192,-360},{-192,-290},{-183,
                  -290}},
              color={255,204,51},
              thickness=0.5));
          connect(load, control_wFW_high_4th.load) annotation (Line(points={{-330,0},
                  {-230,0},{-230,-129},{-183,-129}},         color={0,0,127}));
          connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},
                  {-330,0},{-360,0},{-360,-220},{-230,-220},{-230,-272},{-183,
                  -272}},      color={0,0,127}));
        end wMS_wFW_staticDecoupler_4th_controller;

        model plant_controller_HPpart_lin_highLoad_wHPHsens
          "Model of the HP plant control system"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp_TS
            "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
          parameter Boolean TS_start = true
            "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

          //-- pumpMS --
          parameter Modelica.SIunits.Power P_mec_sp "Plant power set point" annotation (Dialog(tab="pumpMS"));
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Modelica.SIunits.AbsolutePressure p_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="valveTURB"));
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
          Modelica.Blocks.Sources.Constant P_MEC_SP(k=P_mec_sp) annotation (
              Placement(transformation(extent={{400,200},{380,220}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanStep booleanStep2(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          Modelica.Blocks.Sources.Constant T_FW_SP(k=T_FW_sp)
            annotation (Placement(transformation(extent={{-400,14},{-380,34}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.Constant p_SP(k=p_sp)
            annotation (Placement(transformation(extent={{400,20},{380,40}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep6(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                     smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                518.15; 80,518.15; 90,518.15; 100,518.15])
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-190})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,-100},{-400,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,220},{-400,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,60},{-400,100}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{210,56},{190,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{-220,56},{-200,76}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-260},{-400,-220}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                495.8; 90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                6.743; 100,24.51])
            annotation (Placement(transformation(extent={{200,-200},{180,-180}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep1(
              startTime=t_start_ramp_TS, startValue=TS_start)
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-400,62},{-380,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                0; 20,0; 30,0; 40,0; 50,0; 60,0.01; 70,0.145652; 80,0.208685;
                90,0.349201; 100,0.866205])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897; 70,
                65.503; 80,74.0789; 90,82.5593; 100,90.8672])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                4.98849e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                82.3774e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Sources.Ramp rampPos(
            offset=0,
            startTime=20000,
            duration=5000,
            height=0.15) annotation (Placement(transformation(extent={{240,-124},
                    {220,-104}})));
          Modelica.Blocks.Sources.Ramp rampNeg(
            duration=10000,
            offset=0,
            startTime=25000,
            height=-1.1) annotation (Placement(transformation(extent={{240,-164},
                    {220,-144}})));
          Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                  extent={{200,-144},{180,-124}})));
          Modelica.Blocks.Math.Product product1 annotation (Placement(
                transformation(extent={{150,-144},{130,-124}})));
          Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                  extent={{116,-150},{96,-130}})));
        equation
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{296,72},{339,72}},
                                                         color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,-100},{-230,
                  -100},{-230,-122},{-222,-122}},      color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{212,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{242,
                  60},{212,60}},                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{172,66},{182,66},{182,
                  66},{189,66}}, color={0,0,127}));
          connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-262,-140},{-254,
                  -140},{-254,-116},{-280,-116},{-280,-124}},             color={
                  0,0,127}));
          connect(PID_valveTURB.CS, PID_valveTURB.TR) annotation (Line(points={{
                  262,60},{252,60},{252,84},{280,84},{280,76}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},{-84,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{-230,100},{
                  -230,72},{-222,72}}, color={0,0,127}));
          connect(add11.y, add8.u1) annotation (Line(points={{-199,66},{-170.5,66},{-142,
                  66}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_valveBP.CS, add11.u2)
            annotation (Line(points={{-262,60},{-242,60},{-222,60}}, color={0,0,127}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(table_w_HPH.u[1], LOAD5.y)
            annotation (Line(points={{202,-190},{219,-190}}, color={0,0,127}));
          connect(table_w_MS.u[1], LOAD7.y) annotation (Line(points={{242,190},
                  {242,190},{259,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},
                  {140,190},{140,234},{122,234}}, color={0,0,127}));
          connect(booleanStep1.y, PID_valveBP.TS) annotation (Line(points={{
                  -261,100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(PID_valveBP.CS, PID_valveBP.TR) annotation (Line(points={{
                  -262,60},{-254,60},{-254,82},{-280,82},{-280,76}}, color={0,0,
                  127}));
          connect(LOAD1.y, table_T_FW.u[1])
            annotation (Line(points={{-379,72},{-362,72}}, color={0,0,127}));
          connect(table_T_FW.y[1], PID_valveBP.SP)
            annotation (Line(points={{-339,72},{-296,72}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,
                  10},{-270.5,10},{-262,10}}, color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-279,-190},
                  {-270,-190},{-262,-190}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,
                  10},{-200,10},{-160,10},{-160,54},{-142,54}}, color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                  {-196,-190},{-150,-190},{-150,-146},{-142,-146}}, color={0,0,
                  127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,
                  -190},{-216,-190},{-190,-190},{-190,-140},{-182,-140}}, color=
                 {0,0,127}));
          connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{242,10},{
                  259,10},{259,10}}, color={0,0,127}));
          connect(table_Yt.y[1], add5.u2) annotation (Line(points={{219,10},{
                  219,10},{180,10},{180,54},{172,54}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,252},
                  {379,252},{379,252}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{
                  296,252},{339,252},{339,252}}, color={0,0,127}));
          connect(rampPos.y,add. u1) annotation (Line(points={{219,-114},{209,
                  -114},{209,-128},{202,-128}},color={0,0,127}));
          connect(rampNeg.y,add. u2) annotation (Line(points={{219,-154},{209,
                  -154},{209,-140},{202,-140}},               color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{179,
                  -190},{160,-190},{160,-140},{152,-140}}, color={0,0,127}));
          connect(product1.u1, add.y) annotation (Line(points={{152,-128},{168,
                  -128},{168,-134},{179,-134}}, color={0,0,127}));
          connect(add2.u1, product1.y) annotation (Line(points={{118,-134},{126,
                  -134},{126,-134},{129,-134}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},
                  {95,-140},{95,-140}}, color={0,0,127}));
          connect(add2.u2, table_w_HPH.y[1]) annotation (Line(points={{118,-146},
                  {132,-146},{132,-150},{140,-150},{140,-190},{179,-190}},
                color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad_wHPHsens;

        model plant_controller_HPpart_lin_highLoad_FF
          "Model of the HP plant control system for linearization purpose, only feedforward"

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

          //-- pumpMS --
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- pumpHPH --
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));

          //-- valveBP --
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-146,
                    -150},{-126,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-140})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-120,-120},{-160,-80}}),
                iconTransformation(extent={{-440,-100},{-400,-60}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{100,260},{140,300}}),iconTransformation(
                  extent={{-440,220},{-400,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{100,80},{140,120}}),  iconTransformation(
                  extent={{-440,60},{-400,100}})));
          Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent=
                   {{-220,-138},{-200,-118}})));
          Modelica.Blocks.Math.Add add10
            annotation (Placement(transformation(extent={{180,236},{160,256}})));
          Modelica.Blocks.Math.Add add3
            annotation (Placement(transformation(extent={{214,56},{194,76}})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{184,50},{164,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-160,50},
                    {-140,70}})));
          Modelica.Blocks.Math.Add add11
            annotation (Placement(transformation(extent={{-220,56},{-200,76}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaBP annotation (Placement(
                transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                  extent={{-440,-260},{-400,-220}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={380,150}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,0.1; 70,0.1; 80,0.1; 90,
                6.743; 100,24.51])
            annotation (Placement(transformation(extent={{240,-150},{220,-130}})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
              table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                0.952380955219269; 5.05130128658493e-06,1])
            annotation (Placement(transformation(extent={{144,50},{124,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
                495.8; 90,557.8; 100,619.8])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Tables.CombiTable1D table_P(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                     smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                518.15; 80,518.15; 90,518.15; 100,518.15])
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-390,72})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                60,0; 60.06,0; 60.12,0; 60.18,0; 60.24,0; 60.3,0; 60.36,0; 60.42,0; 60.48,
                0; 60.54,0; 60.6,0; 60.66,0; 60.72,0; 60.78,0; 60.84,0; 60.9,0; 60.96,0;
                61.02,0; 61.08,0; 61.12,0; 61.18,0.001; 61.24,0.002; 61.3,0.002; 61.36,0.003;
                61.42,0.004; 61.48,0.005; 61.54,0.006; 61.6,0.007; 61.66,0.007; 61.72,0.008;
                61.78,0.009; 61.84,0.01; 61.9,0.011; 61.96,0.012; 62.02,0.013; 62.08,0.014;
                62.14,0.014; 62.2,0.015; 62.26,0.016; 62.32,0.017; 62.38,0.018; 62.44,0.019;
                62.5,0.02; 62.56,0.021; 62.62,0.021; 62.68,0.022; 62.74,0.023; 62.8,0.024;
                62.86,0.025; 62.92,0.026; 62.98,0.027; 63.04,0.028; 63.1,0.029; 63.16,0.029;
                63.22,0.03; 63.28,0.031; 63.34,0.032; 63.4,0.033; 63.46,0.034; 63.52,0.035;
                63.58,0.036; 63.64,0.037; 63.7,0.038; 63.76,0.039; 63.82,0.039; 63.88,0.04;
                63.94,0.041; 64,0.042; 64.06,0.043; 64.12,0.044; 64.18,0.045; 64.24,0.046;
                64.3,0.047; 64.36,0.048; 64.42,0.049; 64.48,0.05; 64.54,0.051; 64.6,0.052;
                64.66,0.053; 64.72,0.054; 64.78,0.055; 64.84,0.056; 64.9,0.057; 64.96,0.058;
                65.02,0.058; 65.08,0.059; 65.14,0.06; 65.2,0.061; 65.26,0.062; 65.32,0.063;
                65.38,0.064; 65.44,0.065; 65.5,0.066; 65.56,0.067; 65.62,0.068; 65.68,0.069;
                65.74,0.07; 65.8,0.071; 65.86,0.072; 65.92,0.073; 65.98,0.074; 66.04,0.075;
                66.1,0.076; 66.16,0.076; 66.22,0.077; 66.28,0.078; 66.34,0.079; 66.4,0.08;
                66.46,0.081; 66.52,0.082; 66.58,0.083; 66.64,0.084; 66.7,0.085; 66.76,0.085;
                66.82,0.086; 66.88,0.087; 66.94,0.088; 67,0.089; 67.06,0.09; 67.12,0.091;
                67.18,0.091; 67.24,0.092; 67.3,0.093; 67.36,0.094; 67.42,0.095; 67.48,0.096;
                67.54,0.096; 67.6,0.097; 67.66,0.098; 67.72,0.099; 67.78,0.099; 67.84,0.1;
                67.9,0.101; 67.96,0.102; 68.02,0.102; 68.08,0.103; 68.14,0.104; 68.2,0.105;
                68.26,0.105; 68.32,0.106; 68.38,0.107; 68.44,0.107; 68.5,0.108; 68.56,0.109;
                68.62,0.109; 68.68,0.11; 68.74,0.11; 68.8,0.111; 68.86,0.112; 68.92,0.112;
                68.98,0.113; 69.04,0.113; 69.1,0.114; 69.16,0.115; 69.22,0.115; 69.28,0.116;
                69.34,0.116; 69.4,0.117; 69.46,0.117; 69.52,0.118; 69.58,0.118; 69.64,0.118;
                69.7,0.119; 69.76,0.119; 69.82,0.12; 69.88,0.12; 69.94,0.12; 70,0.121; 70.06,
                0.121; 70.12,0.121; 70.18,0.122; 70.24,0.122; 70.3,0.122; 70.36,0.123; 70.42,
                0.123; 70.48,0.123; 70.54,0.124; 70.6,0.124; 70.66,0.124; 70.72,0.125; 70.78,
                0.125; 70.84,0.125; 70.9,0.126; 70.96,0.126; 71.02,0.126; 71.08,0.127; 71.14,
                0.127; 71.2,0.127; 71.26,0.128; 71.32,0.128; 71.38,0.129; 71.44,0.129; 71.5,
                0.129; 71.56,0.13; 71.62,0.13; 71.68,0.13; 71.74,0.131; 71.8,0.131; 71.86,
                0.131; 71.92,0.132; 71.98,0.132; 72.04,0.132; 72.1,0.133; 72.16,0.133; 72.22,
                0.133; 72.28,0.134; 72.34,0.134; 72.4,0.134; 72.46,0.135; 72.52,0.135; 72.58,
                0.135; 72.64,0.136; 72.7,0.136; 72.76,0.136; 72.82,0.137; 72.88,0.137; 72.94,
                0.137; 73,0.138; 73.06,0.138; 73.12,0.138; 73.18,0.139; 73.24,0.139; 73.3,
                0.139; 73.36,0.14; 73.42,0.14; 73.48,0.141; 73.53,0.141; 73.59,0.141; 73.65,
                0.142; 73.71,0.142; 73.77,0.142; 73.83,0.143; 73.89,0.143; 73.95,0.143;
                74.01,0.144; 74.07,0.144; 74.13,0.144; 74.19,0.145; 74.25,0.145; 74.31,0.145;
                74.37,0.146; 74.43,0.146; 74.49,0.146; 74.55,0.147; 74.61,0.147; 74.67,0.147;
                74.73,0.148; 74.79,0.148; 74.85,0.149; 74.91,0.149; 74.97,0.149; 75.03,0.15;
                75.09,0.15; 75.15,0.15; 75.21,0.151; 75.27,0.151; 75.33,0.151; 75.39,0.152;
                75.45,0.152; 75.51,0.152; 75.57,0.153; 75.63,0.153; 75.69,0.153; 75.75,0.154;
                75.81,0.154; 75.87,0.154; 75.93,0.155; 75.99,0.155; 76.05,0.156; 76.11,0.156;
                76.17,0.156; 76.23,0.157; 76.29,0.157; 76.35,0.157; 76.41,0.158; 76.47,0.158;
                76.53,0.158; 76.59,0.159; 76.65,0.159; 76.71,0.159; 76.77,0.16; 76.83,0.16;
                76.89,0.161; 76.95,0.161; 77.01,0.161; 77.07,0.162; 77.13,0.162; 77.19,0.162;
                77.25,0.163; 77.31,0.163; 77.37,0.163; 77.43,0.164; 77.49,0.164; 77.55,0.165;
                77.61,0.165; 77.67,0.165; 77.73,0.166; 77.79,0.166; 77.85,0.166; 77.91,0.167;
                77.97,0.167; 78.03,0.167; 78.09,0.168; 78.15,0.168; 78.21,0.168; 78.27,0.169;
                78.33,0.169; 78.39,0.17; 78.45,0.17; 78.51,0.17; 78.57,0.171; 78.63,0.171;
                78.69,0.171; 78.75,0.172; 78.81,0.172; 78.87,0.173; 78.93,0.173; 78.99,0.173;
                79.05,0.174; 79.11,0.174; 79.17,0.174; 79.23,0.175; 79.29,0.175; 79.35,0.175;
                79.41,0.176; 79.47,0.176; 79.53,0.177; 79.59,0.177; 79.65,0.177; 79.71,0.178;
                79.77,0.178; 79.83,0.178; 79.89,0.179; 79.95,0.179; 80.01,0.18; 80.07,0.18;
                80.13,0.18; 80.19,0.181; 80.25,0.181; 80.31,0.181; 80.37,0.182; 80.43,0.182;
                80.49,0.183; 80.55,0.183; 80.61,0.183; 80.67,0.184; 80.73,0.184; 80.79,0.184;
                80.85,0.185; 80.91,0.185; 80.97,0.186; 81.03,0.186; 81.09,0.186; 81.15,0.187;
                81.21,0.187; 81.27,0.187; 81.33,0.188; 81.36,0.188; 81.42,0.189; 81.48,0.189;
                81.54,0.19; 81.6,0.191; 81.66,0.191; 81.72,0.192; 81.78,0.193; 81.84,0.193;
                81.9,0.194; 81.96,0.194; 82.02,0.195; 82.08,0.196; 82.14,0.196; 82.2,0.197;
                82.26,0.198; 82.32,0.198; 82.38,0.199; 82.44,0.2; 82.5,0.2; 82.56,0.201;
                82.62,0.202; 82.68,0.202; 82.74,0.203; 82.8,0.204; 82.86,0.204; 82.92,0.205;
                82.98,0.206; 83.04,0.206; 83.1,0.207; 83.16,0.208; 83.22,0.208; 83.28,0.209;
                83.34,0.21; 83.4,0.21; 83.46,0.211; 83.52,0.212; 83.58,0.212; 83.64,0.213;
                83.7,0.214; 83.76,0.214; 83.82,0.215; 83.88,0.216; 83.94,0.217; 84,0.217;
                84.06,0.218; 84.12,0.219; 84.18,0.219; 84.24,0.22; 84.3,0.221; 84.36,0.222;
                84.42,0.222; 84.48,0.223; 84.54,0.224; 84.6,0.224; 84.66,0.225; 84.72,0.226;
                84.78,0.227; 84.84,0.227; 84.9,0.228; 84.96,0.229; 85.02,0.23; 85.08,0.23;
                85.14,0.231; 85.2,0.232; 85.26,0.232; 85.32,0.233; 85.38,0.234; 85.44,0.235;
                85.5,0.235; 85.56,0.236; 85.62,0.237; 85.68,0.238; 85.74,0.238; 85.8,0.239;
                85.86,0.24; 85.92,0.241; 85.98,0.242; 86.04,0.242; 86.1,0.243; 86.16,0.244;
                86.22,0.245; 86.28,0.245; 86.34,0.246; 86.4,0.247; 86.46,0.248; 86.52,0.249;
                86.58,0.249; 86.64,0.25; 86.7,0.251; 86.76,0.252; 86.82,0.252; 86.88,0.253;
                86.94,0.254; 87,0.255; 87.06,0.256; 87.12,0.257; 87.18,0.257; 87.24,0.258;
                87.3,0.259; 87.36,0.26; 87.42,0.261; 87.48,0.261; 87.54,0.262; 87.6,0.263;
                87.66,0.264; 87.72,0.265; 87.78,0.266; 87.84,0.266; 87.9,0.267; 87.96,0.268;
                88.02,0.269; 88.08,0.27; 88.14,0.271; 88.2,0.271; 88.26,0.272; 88.32,0.273;
                88.38,0.274; 88.44,0.275; 88.5,0.276; 88.56,0.277; 88.62,0.277; 88.68,0.278;
                88.74,0.279; 88.8,0.28; 88.86,0.281; 88.92,0.282; 88.98,0.283; 89.04,0.284;
                89.1,0.284; 89.16,0.285; 89.22,0.286; 89.28,0.287; 89.34,0.288; 89.4,0.289;
                89.46,0.29; 89.52,0.291; 89.58,0.292; 89.64,0.292; 89.7,0.293; 89.76,0.294;
                89.82,0.295; 89.88,0.296; 89.94,0.297; 90,0.298; 90.06,0.3; 90.12,0.301;
                90.18,0.303; 90.24,0.304; 90.3,0.306; 90.36,0.308; 90.42,0.309; 90.48,0.311;
                90.54,0.313; 90.6,0.314; 90.66,0.316; 90.73,0.318; 90.79,0.32; 90.85,0.321;
                90.91,0.323; 90.97,0.325; 91.03,0.327; 91.09,0.328; 91.15,0.33; 91.21,0.332;
                91.27,0.334; 91.33,0.335; 91.39,0.337; 91.45,0.339; 91.51,0.341; 91.57,0.343;
                91.63,0.345; 91.69,0.346; 91.75,0.348; 91.81,0.35; 91.87,0.352; 91.93,0.354;
                91.99,0.356; 92.05,0.358; 92.11,0.36; 92.17,0.362; 92.23,0.364; 92.29,0.366;
                92.35,0.368; 92.41,0.37; 92.47,0.372; 92.53,0.374; 92.59,0.376; 92.65,0.378;
                92.71,0.38; 92.77,0.382; 92.83,0.384; 92.89,0.386; 92.95,0.388; 93.01,0.39;
                93.07,0.392; 93.13,0.394; 93.19,0.396; 93.25,0.399; 93.31,0.401; 93.37,0.403;
                93.43,0.405; 93.49,0.407; 93.55,0.41; 93.61,0.412; 93.67,0.414; 93.73,0.416;
                93.79,0.418; 93.85,0.421; 93.91,0.423; 93.97,0.425; 94.03,0.428; 94.09,0.43;
                94.15,0.432; 94.21,0.435; 94.27,0.437; 94.33,0.439; 94.39,0.442; 94.45,0.444;
                94.51,0.446; 94.57,0.449; 94.63,0.451; 94.69,0.454; 94.75,0.456; 94.81,0.459;
                94.87,0.461; 94.93,0.464; 94.99,0.466; 95.05,0.469; 95.11,0.471; 95.17,0.474;
                95.23,0.476; 95.29,0.479; 95.35,0.481; 95.41,0.484; 95.47,0.486; 95.53,0.489;
                95.59,0.492; 95.65,0.494; 95.71,0.497; 95.77,0.5; 95.83,0.502; 95.89,0.505;
                95.95,0.508; 96.01,0.511; 96.07,0.513; 96.13,0.516; 96.19,0.519; 96.25,0.522;
                96.31,0.524; 96.37,0.527; 96.43,0.53; 96.49,0.533; 96.55,0.536; 96.61,0.539;
                96.67,0.542; 96.73,0.545; 96.79,0.548; 96.85,0.55; 96.91,0.553; 96.97,0.556;
                97.03,0.559; 97.09,0.562; 97.15,0.565; 97.21,0.568; 97.27,0.572; 97.33,0.575;
                97.39,0.578; 97.45,0.581; 97.51,0.584; 97.57,0.587; 97.63,0.59; 97.69,0.593;
                97.75,0.597; 97.81,0.6; 97.87,0.603; 97.93,0.606; 97.99,0.61; 98.05,0.613;
                98.11,0.616; 98.17,0.619; 98.23,0.623; 98.29,0.626; 98.35,0.63; 98.41,0.633;
                98.47,0.636; 98.53,0.64; 98.59,0.643; 98.65,0.647; 98.71,0.65; 98.77,0.654;
                98.83,0.657; 98.89,0.661; 98.95,0.664; 99.01,0.668; 99.07,0.671; 99.13,0.675;
                99.19,0.679; 99.25,0.682; 99.31,0.686; 99.37,0.69; 99.43,0.693; 99.49,0.697;
                99.55,0.701; 99.6,0.704; 99.66,0.708; 99.72,0.712; 99.78,0.715; 99.84,0.719;
                99.9,0.723; 99.96,0.727; 100,0.73])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                60,56.975; 60.06,57.024; 60.12,57.076; 60.18,57.129; 60.24,57.181; 60.3,
                57.234; 60.36,57.287; 60.42,57.339; 60.48,57.392; 60.54,57.444; 60.6,57.497;
                60.66,57.549; 60.72,57.602; 60.78,57.655; 60.84,57.707; 60.9,57.76; 60.96,
                57.812; 61.02,57.865; 61.08,57.918; 61.12,57.95; 61.18,58; 61.24,58.051;
                61.3,58.102; 61.36,58.15; 61.42,58.2; 61.48,58.26; 61.54,58.31; 61.6,58.36;
                61.66,58.41; 61.72,58.46; 61.78,58.51; 61.84,58.56; 61.9,58.61; 61.96,58.66;
                62.02,58.71; 62.08,58.77; 62.14,58.82; 62.2,58.87; 62.26,58.92; 62.32,58.97;
                62.38,59.02; 62.44,59.07; 62.5,59.12; 62.56,59.17; 62.62,59.22; 62.68,59.28;
                62.74,59.33; 62.8,59.38; 62.86,59.43; 62.92,59.48; 62.98,59.53; 63.04,59.58;
                63.1,59.63; 63.16,59.68; 63.22,59.73; 63.28,59.78; 63.34,59.84; 63.4,59.89;
                63.46,59.94; 63.52,59.99; 63.58,60.04; 63.64,60.09; 63.7,60.14; 63.76,60.19;
                63.82,60.24; 63.88,60.29; 63.94,60.34; 64,60.4; 64.06,60.45; 64.12,60.5;
                64.18,60.55; 64.24,60.6; 64.3,60.65; 64.36,60.7; 64.42,60.75; 64.48,60.8;
                64.54,60.85; 64.6,60.9; 64.66,60.96; 64.72,61.01; 64.78,61.06; 64.84,61.11;
                64.9,61.16; 64.96,61.21; 65.02,61.26; 65.08,61.31; 65.14,61.36; 65.2,61.41;
                65.26,61.46; 65.32,61.52; 65.38,61.57; 65.44,61.62; 65.5,61.67; 65.56,61.72;
                65.62,61.77; 65.68,61.82; 65.74,61.87; 65.8,61.92; 65.86,61.97; 65.92,62.03;
                65.98,62.08; 66.04,62.13; 66.1,62.18; 66.16,62.23; 66.22,62.28; 66.28,62.33;
                66.34,62.38; 66.4,62.43; 66.46,62.48; 66.52,62.54; 66.58,62.59; 66.64,62.64;
                66.7,62.69; 66.76,62.74; 66.82,62.79; 66.88,62.84; 66.94,62.89; 67,62.94;
                67.06,62.99; 67.12,63.05; 67.18,63.1; 67.24,63.15; 67.3,63.2; 67.36,63.25;
                67.42,63.3; 67.48,63.35; 67.54,63.4; 67.6,63.46; 67.66,63.51; 67.72,63.56;
                67.78,63.61; 67.84,63.66; 67.9,63.71; 67.96,63.76; 68.02,63.81; 68.08,63.86;
                68.14,63.92; 68.2,63.97; 68.26,64.02; 68.32,64.07; 68.38,64.12; 68.44,64.17;
                68.5,64.22; 68.56,64.27; 68.62,64.33; 68.68,64.38; 68.74,64.43; 68.8,64.48;
                68.86,64.53; 68.92,64.58; 68.98,64.63; 69.04,64.69; 69.1,64.74; 69.16,64.79;
                69.22,64.84; 69.28,64.89; 69.34,64.94; 69.4,64.99; 69.46,65.05; 69.52,65.1;
                69.58,65.15; 69.64,65.2; 69.7,65.25; 69.76,65.3; 69.82,65.36; 69.88,65.41;
                69.94,65.46; 70,65.51; 70.06,65.56; 70.12,65.61; 70.18,65.67; 70.24,65.72;
                70.3,65.77; 70.36,65.82; 70.42,65.87; 70.48,65.92; 70.54,65.98; 70.6,66.03;
                70.66,66.08; 70.72,66.13; 70.78,66.18; 70.84,66.23; 70.9,66.29; 70.96,66.34;
                71.02,66.39; 71.08,66.44; 71.14,66.49; 71.2,66.54; 71.26,66.6; 71.32,66.65;
                71.38,66.7; 71.44,66.75; 71.5,66.8; 71.56,66.85; 71.62,66.9; 71.68,66.96;
                71.74,67.01; 71.8,67.06; 71.86,67.11; 71.92,67.16; 71.98,67.21; 72.04,67.27;
                72.1,67.32; 72.16,67.37; 72.22,67.42; 72.28,67.47; 72.34,67.52; 72.4,67.57;
                72.46,67.63; 72.52,67.68; 72.58,67.73; 72.64,67.78; 72.7,67.83; 72.76,67.88;
                72.82,67.93; 72.88,67.99; 72.94,68.04; 73,68.09; 73.06,68.14; 73.12,68.19;
                73.18,68.24; 73.24,68.29; 73.3,68.35; 73.36,68.4; 73.42,68.45; 73.48,68.5;
                73.53,68.55; 73.59,68.6; 73.65,68.65; 73.71,68.71; 73.77,68.76; 73.83,68.81;
                73.89,68.86; 73.95,68.91; 74.01,68.96; 74.07,69.01; 74.13,69.07; 74.19,69.12;
                74.25,69.17; 74.31,69.22; 74.37,69.27; 74.43,69.32; 74.49,69.37; 74.55,69.43;
                74.61,69.48; 74.67,69.53; 74.73,69.58; 74.79,69.63; 74.85,69.68; 74.91,69.73;
                74.97,69.78; 75.03,69.84; 75.09,69.89; 75.15,69.94; 75.21,69.99; 75.27,70.04;
                75.33,70.09; 75.39,70.14; 75.45,70.2; 75.51,70.25; 75.57,70.3; 75.63,70.35;
                75.69,70.4; 75.75,70.45; 75.81,70.5; 75.87,70.55; 75.93,70.61; 75.99,70.66;
                76.05,70.71; 76.11,70.76; 76.17,70.81; 76.23,70.86; 76.29,70.91; 76.35,70.97;
                76.41,71.02; 76.47,71.07; 76.53,71.12; 76.59,71.17; 76.65,71.22; 76.71,71.27;
                76.77,71.33; 76.83,71.38; 76.89,71.43; 76.95,71.48; 77.01,71.53; 77.07,71.58;
                77.13,71.63; 77.19,71.69; 77.25,71.74; 77.31,71.79; 77.37,71.84; 77.43,71.89;
                77.49,71.94; 77.55,71.99; 77.61,72.05; 77.67,72.1; 77.73,72.15; 77.79,72.2;
                77.85,72.25; 77.91,72.3; 77.97,72.35; 78.03,72.41; 78.09,72.46; 78.15,72.51;
                78.21,72.56; 78.27,72.61; 78.33,72.66; 78.39,72.71; 78.45,72.76; 78.51,72.82;
                78.57,72.87; 78.63,72.92; 78.69,72.97; 78.75,73.02; 78.81,73.07; 78.87,73.12;
                78.93,73.18; 78.99,73.23; 79.05,73.28; 79.11,73.33; 79.17,73.38; 79.23,73.43;
                79.29,73.48; 79.35,73.54; 79.41,73.59; 79.47,73.64; 79.53,73.69; 79.59,73.74;
                79.65,73.79; 79.71,73.84; 79.77,73.9; 79.83,73.95; 79.89,74; 79.95,74.05;
                80.01,74.1; 80.07,74.15; 80.13,74.2; 80.19,74.26; 80.25,74.31; 80.31,74.36;
                80.37,74.41; 80.43,74.46; 80.49,74.51; 80.55,74.56; 80.61,74.62; 80.67,74.67;
                80.73,74.72; 80.79,74.77; 80.85,74.82; 80.91,74.87; 80.97,74.92; 81.03,74.98;
                81.09,75.03; 81.15,75.08; 81.21,75.13; 81.27,75.18; 81.33,75.23; 81.36,75.26;
                81.42,75.32; 81.48,75.37; 81.54,75.42; 81.6,75.47; 81.66,75.52; 81.72,75.57;
                81.78,75.62; 81.84,75.67; 81.9,75.72; 81.96,75.78; 82.02,75.83; 82.08,75.88;
                82.14,75.93; 82.2,75.98; 82.26,76.03; 82.32,76.08; 82.38,76.13; 82.44,76.18;
                82.5,76.24; 82.56,76.29; 82.62,76.34; 82.68,76.39; 82.74,76.44; 82.8,76.49;
                82.86,76.54; 82.92,76.59; 82.98,76.64; 83.04,76.69; 83.1,76.75; 83.16,76.8;
                83.22,76.85; 83.28,76.9; 83.34,76.95; 83.4,77; 83.46,77.05; 83.52,77.1;
                83.58,77.15; 83.64,77.21; 83.7,77.26; 83.76,77.31; 83.82,77.36; 83.88,77.41;
                83.94,77.46; 84,77.51; 84.06,77.56; 84.12,77.61; 84.18,77.66; 84.24,77.72;
                84.3,77.77; 84.36,77.82; 84.42,77.87; 84.48,77.92; 84.54,77.97; 84.6,78.02;
                84.66,78.07; 84.72,78.12; 84.78,78.17; 84.84,78.23; 84.9,78.28; 84.96,78.33;
                85.02,78.38; 85.08,78.43; 85.14,78.48; 85.2,78.53; 85.26,78.58; 85.32,78.63;
                85.38,78.68; 85.44,78.73; 85.5,78.79; 85.56,78.84; 85.62,78.89; 85.68,78.94;
                85.74,78.99; 85.8,79.04; 85.86,79.09; 85.92,79.14; 85.98,79.19; 86.04,79.24;
                86.1,79.29; 86.16,79.34; 86.22,79.39; 86.28,79.45; 86.34,79.5; 86.4,79.55;
                86.46,79.6; 86.52,79.65; 86.58,79.7; 86.64,79.75; 86.7,79.8; 86.76,79.85;
                86.82,79.9; 86.88,79.95; 86.94,80.01; 87,80.06; 87.06,80.11; 87.12,80.16;
                87.18,80.21; 87.24,80.26; 87.3,80.31; 87.36,80.36; 87.42,80.41; 87.48,80.46;
                87.54,80.51; 87.6,80.57; 87.66,80.62; 87.72,80.67; 87.78,80.72; 87.84,80.77;
                87.9,80.82; 87.96,80.87; 88.02,80.92; 88.08,80.97; 88.14,81.02; 88.2,81.07;
                88.26,81.12; 88.32,81.18; 88.38,81.23; 88.44,81.28; 88.5,81.33; 88.56,81.38;
                88.62,81.43; 88.68,81.48; 88.74,81.53; 88.8,81.58; 88.86,81.63; 88.92,81.68;
                88.98,81.73; 89.04,81.79; 89.1,81.84; 89.16,81.89; 89.22,81.94; 89.28,81.99;
                89.34,82.04; 89.4,82.09; 89.46,82.14; 89.52,82.19; 89.58,82.24; 89.64,82.29;
                89.7,82.34; 89.76,82.39; 89.82,82.44; 89.88,82.5; 89.94,82.55; 90,82.6;
                90.06,82.65; 90.12,82.7; 90.18,82.75; 90.24,82.8; 90.3,82.85; 90.36,82.9;
                90.42,82.95; 90.48,83; 90.54,83.05; 90.6,83.1; 90.66,83.15; 90.73,83.2;
                90.79,83.25; 90.85,83.3; 90.91,83.35; 90.97,83.4; 91.03,83.45; 91.09,83.5;
                91.15,83.55; 91.21,83.6; 91.27,83.65; 91.33,83.7; 91.39,83.75; 91.45,83.8;
                91.51,83.85; 91.57,83.9; 91.63,83.95; 91.69,84; 91.75,84.05; 91.81,84.1;
                91.87,84.15; 91.93,84.2; 91.99,84.25; 92.05,84.3; 92.11,84.35; 92.17,84.4;
                92.23,84.45; 92.29,84.5; 92.35,84.55; 92.41,84.6; 92.47,84.65; 92.53,84.7;
                92.59,84.75; 92.65,84.8; 92.71,84.85; 92.77,84.9; 92.83,84.95; 92.89,85;
                92.95,85.05; 93.01,85.1; 93.07,85.15; 93.13,85.2; 93.19,85.25; 93.25,85.3;
                93.31,85.35; 93.37,85.4; 93.43,85.45; 93.49,85.5; 93.55,85.55; 93.61,85.6;
                93.67,85.65; 93.73,85.7; 93.79,85.75; 93.85,85.8; 93.91,85.85; 93.97,85.9;
                94.03,85.95; 94.09,86; 94.15,86.05; 94.21,86.1; 94.27,86.15; 94.33,86.2;
                94.39,86.25; 94.45,86.3; 94.51,86.35; 94.57,86.4; 94.63,86.45; 94.69,86.5;
                94.75,86.55; 94.81,86.6; 94.87,86.65; 94.93,86.7; 94.99,86.75; 95.05,86.8;
                95.11,86.85; 95.17,86.9; 95.23,86.95; 95.29,87; 95.35,87.05; 95.41,87.1;
                95.47,87.15; 95.53,87.2; 95.59,87.25; 95.65,87.3; 95.71,87.35; 95.77,87.4;
                95.83,87.45; 95.89,87.5; 95.95,87.55; 96.01,87.6; 96.07,87.65; 96.13,87.7;
                96.19,87.75; 96.25,87.8; 96.31,87.85; 96.37,87.9; 96.43,87.95; 96.49,88;
                96.55,88.05; 96.61,88.1; 96.67,88.15; 96.73,88.2; 96.79,88.24; 96.85,88.29;
                96.91,88.34; 96.97,88.39; 97.03,88.44; 97.09,88.49; 97.15,88.54; 97.21,88.59;
                97.27,88.64; 97.33,88.69; 97.39,88.74; 97.45,88.79; 97.51,88.84; 97.57,88.89;
                97.63,88.94; 97.69,88.99; 97.75,89.04; 97.81,89.09; 97.87,89.14; 97.93,89.19;
                97.99,89.24; 98.05,89.29; 98.11,89.34; 98.17,89.39; 98.23,89.44; 98.29,89.49;
                98.35,89.54; 98.41,89.59; 98.47,89.64; 98.53,89.69; 98.59,89.74; 98.65,89.79;
                98.71,89.84; 98.77,89.89; 98.83,89.94; 98.89,89.99; 98.95,90.04; 99.01,90.09;
                99.07,90.14; 99.13,90.19; 99.19,90.24; 99.25,90.29; 99.31,90.34; 99.37,90.39;
                99.43,90.44; 99.49,90.49; 99.55,90.54; 99.6,90.58; 99.66,90.63; 99.72,90.68;
                99.78,90.73; 99.84,90.78; 99.9,90.83; 99.96,90.88; 100,90.92])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[60,
                4.9831e-06; 60.06,4.9833e-06; 60.12,4.9836e-06; 60.18,4.9838e-06; 60.24,
                4.9841e-06; 60.3,4.9843e-06; 60.36,4.9846e-06; 60.42,4.9848e-06; 60.48,4.985e-06;
                60.54,4.9853e-06; 60.6,4.9855e-06; 60.66,4.9857e-06; 60.72,4.986e-06; 60.78,
                4.9863e-06; 60.84,4.9865e-06; 60.9,4.9867e-06; 60.96,4.987e-06; 61.02,4.9872e-06;
                61.08,4.9874e-06; 61.12,4.9877e-06; 61.18,4.9879e-06; 61.24,4.9881e-06;
                61.3,4.9883e-06; 61.36,4.9885e-06; 61.42,4.9888e-06; 61.48,4.989e-06; 61.54,
                4.9892e-06; 61.6,4.9894e-06; 61.66,4.9896e-06; 61.72,4.9899e-06; 61.78,4.9901e-06;
                61.84,4.9903e-06; 61.9,4.9905e-06; 61.96,4.9907e-06; 62.02,4.991e-06; 62.08,
                4.9912e-06; 62.14,4.9914e-06; 62.2,4.9916e-06; 62.26,4.9918e-06; 62.32,4.992e-06;
                62.38,4.9922e-06; 62.44,4.9924e-06; 62.5,4.9926e-06; 62.56,4.9928e-06; 62.62,
                4.993e-06; 62.68,4.9933e-06; 62.74,4.9935e-06; 62.8,4.9937e-06; 62.86,4.994e-06;
                62.92,4.9942e-06; 62.98,4.9944e-06; 63.04,4.9946e-06; 63.1,4.9948e-06; 63.16,
                4.995e-06; 63.22,4.9952e-06; 63.28,4.9954e-06; 63.34,4.9956e-06; 63.4,4.9958e-06;
                63.46,4.996e-06; 63.52,4.9962e-06; 63.58,4.9964e-06; 63.64,4.9966e-06; 63.7,
                4.9967e-06; 63.76,4.9969e-06; 63.82,4.9971e-06; 63.88,4.9973e-06; 63.94,
                4.9975e-06; 64,4.9976e-06; 64.06,4.9978e-06; 64.12,4.998e-06; 64.18,4.9982e-06;
                64.24,4.9983e-06; 64.3,4.9985e-06; 64.36,4.9987e-06; 64.42,4.9988e-06; 64.48,
                4.999e-06; 64.54,4.9992e-06; 64.6,4.9993e-06; 64.66,4.9995e-06; 64.72,4.9996e-06;
                64.78,4.9998e-06; 64.84,4.9999e-06; 64.9,5.0001e-06; 64.96,5.0002e-06; 65.02,
                5.0004e-06; 65.08,5.0005e-06; 65.14,5.0007e-06; 65.2,5.0008e-06; 65.26,5.0009e-06;
                65.32,5.0011e-06; 65.38,5.0012e-06; 65.44,5.0014e-06; 65.5,5.0015e-06; 65.56,
                5.0016e-06; 65.62,5.0018e-06; 65.68,5.0019e-06; 65.74,5.0021e-06; 65.8,5.0022e-06;
                65.86,5.0024e-06; 65.92,5.0025e-06; 65.98,5.0027e-06; 66.04,5.0028e-06;
                66.1,5.0029e-06; 66.16,5.0031e-06; 66.22,5.0032e-06; 66.28,5.0033e-06; 66.34,
                5.0035e-06; 66.4,5.0036e-06; 66.46,5.0037e-06; 66.52,5.0038e-06; 66.58,5.0039e-06;
                66.64,5.0041e-06; 66.7,5.0042e-06; 66.76,5.0043e-06; 66.82,5.0044e-06; 66.88,
                5.0045e-06; 66.94,5.0046e-06; 67,5.0047e-06; 67.06,5.0048e-06; 67.12,5.0049e-06;
                67.18,5.005e-06; 67.24,5.0052e-06; 67.3,5.0053e-06; 67.36,5.0053e-06; 67.42,
                5.0054e-06; 67.48,5.0055e-06; 67.54,5.0056e-06; 67.6,5.0057e-06; 67.66,5.0058e-06;
                67.72,5.0059e-06; 67.78,5.006e-06; 67.84,5.0061e-06; 67.9,5.0061e-06; 67.96,
                5.0062e-06; 68.02,5.0063e-06; 68.08,5.0064e-06; 68.14,5.0064e-06; 68.2,5.0065e-06;
                68.26,5.0066e-06; 68.32,5.0066e-06; 68.38,5.0067e-06; 68.44,5.0068e-06;
                68.5,5.0068e-06; 68.56,5.0069e-06; 68.62,5.0069e-06; 68.68,5.007e-06; 68.74,
                5.007e-06; 68.8,5.0071e-06; 68.86,5.0071e-06; 68.92,5.0072e-06; 68.98,5.0072e-06;
                69.04,5.0072e-06; 69.1,5.0073e-06; 69.16,5.0073e-06; 69.22,5.0073e-06; 69.28,
                5.0074e-06; 69.34,5.0074e-06; 69.4,5.0074e-06; 69.46,5.0074e-06; 69.52,5.0075e-06;
                69.58,5.0075e-06; 69.64,5.0075e-06; 69.7,5.0075e-06; 69.76,5.0075e-06; 69.82,
                5.0075e-06; 69.88,5.0075e-06; 69.94,5.0075e-06; 70,5.0076e-06; 70.06,5.0076e-06;
                70.12,5.0077e-06; 70.18,5.0078e-06; 70.24,5.0079e-06; 70.3,5.0081e-06; 70.36,
                5.0081e-06; 70.42,5.0082e-06; 70.48,5.0083e-06; 70.54,5.0084e-06; 70.6,5.0084e-06;
                70.66,5.0084e-06; 70.72,5.0084e-06; 70.78,5.0084e-06; 70.84,5.0084e-06;
                70.9,5.0084e-06; 70.96,5.0084e-06; 71.02,5.0084e-06; 71.08,5.0084e-06; 71.14,
                5.0085e-06; 71.2,5.0085e-06; 71.26,5.0085e-06; 71.32,5.0085e-06; 71.38,5.0085e-06;
                71.44,5.0085e-06; 71.5,5.0085e-06; 71.56,5.0085e-06; 71.62,5.0085e-06; 71.68,
                5.0086e-06; 71.74,5.0086e-06; 71.8,5.0086e-06; 71.86,5.0086e-06; 71.92,5.0086e-06;
                71.98,5.0086e-06; 72.04,5.0086e-06; 72.1,5.0086e-06; 72.16,5.0087e-06; 72.22,
                5.0087e-06; 72.28,5.0087e-06; 72.34,5.0087e-06; 72.4,5.0087e-06; 72.46,5.0087e-06;
                72.52,5.0087e-06; 72.58,5.0088e-06; 72.64,5.0088e-06; 72.7,5.0088e-06; 72.76,
                5.0088e-06; 72.82,5.0088e-06; 72.88,5.0088e-06; 72.94,5.0088e-06; 73,5.0088e-06;
                73.06,5.0088e-06; 73.12,5.0089e-06; 73.18,5.0089e-06; 73.24,5.0089e-06;
                73.3,5.0089e-06; 73.36,5.0089e-06; 73.42,5.0089e-06; 73.48,5.009e-06; 73.53,
                5.009e-06; 73.59,5.009e-06; 73.65,5.009e-06; 73.71,5.009e-06; 73.77,5.009e-06;
                73.83,5.009e-06; 73.89,5.009e-06; 73.95,5.0091e-06; 74.01,5.0091e-06; 74.07,
                5.0091e-06; 74.13,5.0091e-06; 74.19,5.0091e-06; 74.25,5.0091e-06; 74.31,
                5.0091e-06; 74.37,5.0091e-06; 74.43,5.0092e-06; 74.49,5.0092e-06; 74.55,
                5.0092e-06; 74.61,5.0092e-06; 74.67,5.0092e-06; 74.73,5.0093e-06; 74.79,
                5.0093e-06; 74.85,5.0093e-06; 74.91,5.0093e-06; 74.97,5.0093e-06; 75.03,
                5.0093e-06; 75.09,5.0093e-06; 75.15,5.0094e-06; 75.21,5.0094e-06; 75.27,
                5.0094e-06; 75.33,5.0094e-06; 75.39,5.0094e-06; 75.45,5.0095e-06; 75.51,
                5.0095e-06; 75.57,5.0095e-06; 75.63,5.0095e-06; 75.69,5.0095e-06; 75.75,
                5.0095e-06; 75.81,5.0095e-06; 75.87,5.0095e-06; 75.93,5.0095e-06; 75.99,
                5.0096e-06; 76.05,5.0096e-06; 76.11,5.0096e-06; 76.17,5.0096e-06; 76.23,
                5.0096e-06; 76.29,5.0096e-06; 76.35,5.0096e-06; 76.41,5.0096e-06; 76.47,
                5.0097e-06; 76.53,5.0097e-06; 76.59,5.0097e-06; 76.65,5.0097e-06; 76.71,
                5.0097e-06; 76.77,5.0097e-06; 76.83,5.0097e-06; 76.89,5.0097e-06; 76.95,
                5.0097e-06; 77.01,5.0097e-06; 77.07,5.0097e-06; 77.13,5.0097e-06; 77.19,
                5.0098e-06; 77.25,5.0098e-06; 77.31,5.0098e-06; 77.37,5.0098e-06; 77.43,
                5.0098e-06; 77.49,5.0098e-06; 77.55,5.0098e-06; 77.61,5.0098e-06; 77.67,
                5.0099e-06; 77.73,5.0099e-06; 77.79,5.0099e-06; 77.85,5.0099e-06; 77.91,
                5.0099e-06; 77.97,5.0099e-06; 78.03,5.0099e-06; 78.09,5.0099e-06; 78.15,
                5.0099e-06; 78.21,5.0099e-06; 78.27,5.0099e-06; 78.33,5.01e-06; 78.39,5.01e-06;
                78.45,5.01e-06; 78.51,5.01e-06; 78.57,5.01e-06; 78.63,5.01e-06; 78.69,5.01e-06;
                78.75,5.01e-06; 78.81,5.01e-06; 78.87,5.01e-06; 78.93,5.0101e-06; 78.99,
                5.0101e-06; 79.05,5.0101e-06; 79.11,5.0101e-06; 79.17,5.0101e-06; 79.23,
                5.0101e-06; 79.29,5.0101e-06; 79.35,5.0101e-06; 79.41,5.0101e-06; 79.47,
                5.0101e-06; 79.53,5.0101e-06; 79.59,5.0101e-06; 79.65,5.0101e-06; 79.71,
                5.0101e-06; 79.77,5.0102e-06; 79.83,5.0102e-06; 79.89,5.0102e-06; 79.95,
                5.0102e-06; 80.01,5.0102e-06; 80.07,5.0102e-06; 80.13,5.0102e-06; 80.19,
                5.0102e-06; 80.25,5.0102e-06; 80.31,5.0102e-06; 80.37,5.0102e-06; 80.43,
                5.0102e-06; 80.49,5.0102e-06; 80.55,5.0102e-06; 80.61,5.0102e-06; 80.67,
                5.0102e-06; 80.73,5.0102e-06; 80.79,5.0102e-06; 80.85,5.0102e-06; 80.91,
                5.0102e-06; 80.97,5.0102e-06; 81.03,5.0103e-06; 81.09,5.0103e-06; 81.15,
                5.0103e-06; 81.21,5.0103e-06; 81.27,5.0103e-06; 81.33,5.0103e-06; 81.36,
                5.0103e-06; 81.42,5.0103e-06; 81.48,5.0103e-06; 81.54,5.0103e-06; 81.6,5.0103e-06;
                81.66,5.0103e-06; 81.72,5.0103e-06; 81.78,5.0103e-06; 81.84,5.0103e-06;
                81.9,5.0103e-06; 81.96,5.0103e-06; 82.02,5.0103e-06; 82.08,5.0103e-06; 82.14,
                5.0104e-06; 82.2,5.0104e-06; 82.26,5.0105e-06; 82.32,5.0105e-06; 82.38,5.0105e-06;
                82.44,5.0106e-06; 82.5,5.0106e-06; 82.56,5.0107e-06; 82.62,5.0107e-06; 82.68,
                5.0108e-06; 82.74,5.0108e-06; 82.8,5.0109e-06; 82.86,5.0109e-06; 82.92,5.0109e-06;
                82.98,5.011e-06; 83.04,5.011e-06; 83.1,5.0111e-06; 83.16,5.0111e-06; 83.22,
                5.0112e-06; 83.28,5.0112e-06; 83.34,5.0112e-06; 83.4,5.0113e-06; 83.46,5.0113e-06;
                83.52,5.0114e-06; 83.58,5.0114e-06; 83.64,5.0115e-06; 83.7,5.0115e-06; 83.76,
                5.0115e-06; 83.82,5.0116e-06; 83.88,5.0116e-06; 83.94,5.0117e-06; 84,5.0117e-06;
                84.06,5.0118e-06; 84.12,5.0118e-06; 84.18,5.0119e-06; 84.24,5.012e-06; 84.3,
                5.012e-06; 84.36,5.0121e-06; 84.42,5.0121e-06; 84.48,5.0122e-06; 84.54,5.0122e-06;
                84.6,5.0123e-06; 84.66,5.0123e-06; 84.72,5.0124e-06; 84.78,5.0124e-06; 84.84,
                5.0125e-06; 84.9,5.0125e-06; 84.96,5.0126e-06; 85.02,5.0126e-06; 85.08,5.0127e-06;
                85.14,5.0127e-06; 85.2,5.0127e-06; 85.26,5.0127e-06; 85.32,5.0128e-06; 85.38,
                5.0128e-06; 85.44,5.0128e-06; 85.5,5.0128e-06; 85.56,5.0128e-06; 85.62,5.0129e-06;
                85.68,5.0129e-06; 85.74,5.0129e-06; 85.8,5.0129e-06; 85.86,5.013e-06; 85.92,
                5.013e-06; 85.98,5.013e-06; 86.04,5.013e-06; 86.1,5.013e-06; 86.16,5.0131e-06;
                86.22,5.0131e-06; 86.28,5.0131e-06; 86.34,5.0131e-06; 86.4,5.0132e-06; 86.46,
                5.0132e-06; 86.52,5.0132e-06; 86.58,5.0132e-06; 86.64,5.0132e-06; 86.7,5.0132e-06;
                86.76,5.0133e-06; 86.82,5.0133e-06; 86.88,5.0133e-06; 86.94,5.0133e-06;
                87,5.0133e-06; 87.06,5.0134e-06; 87.12,5.0134e-06; 87.18,5.0134e-06; 87.24,
                5.0134e-06; 87.3,5.0135e-06; 87.36,5.0135e-06; 87.42,5.0135e-06; 87.48,5.0135e-06;
                87.54,5.0135e-06; 87.6,5.0135e-06; 87.66,5.0135e-06; 87.72,5.0135e-06; 87.78,
                5.0136e-06; 87.84,5.0136e-06; 87.9,5.0136e-06; 87.96,5.0136e-06; 88.02,5.0136e-06;
                88.08,5.0137e-06; 88.14,5.0137e-06; 88.2,5.0137e-06; 88.26,5.0137e-06; 88.32,
                5.0137e-06; 88.38,5.0137e-06; 88.44,5.0137e-06; 88.5,5.0137e-06; 88.56,5.0137e-06;
                88.62,5.0137e-06; 88.68,5.0137e-06; 88.74,5.0137e-06; 88.8,5.0137e-06; 88.86,
                5.0137e-06; 88.92,5.0137e-06; 88.98,5.0137e-06; 89.04,5.0137e-06; 89.1,5.0137e-06;
                89.16,5.0137e-06; 89.22,5.0137e-06; 89.28,5.0137e-06; 89.34,5.0137e-06;
                89.4,5.0137e-06; 89.46,5.0137e-06; 89.52,5.0137e-06; 89.58,5.0137e-06; 89.64,
                5.0138e-06; 89.7,5.0138e-06; 89.76,5.0138e-06; 89.82,5.0138e-06; 89.88,5.0138e-06;
                89.94,5.0138e-06; 90,5.0138e-06; 90.06,5.0138e-06; 90.12,5.0138e-06; 90.18,
                5.0138e-06; 90.24,5.0138e-06; 90.3,5.0138e-06; 90.36,5.0138e-06; 90.42,5.0138e-06;
                90.48,5.0138e-06; 90.54,5.0138e-06; 90.6,5.0138e-06; 90.66,5.0138e-06; 90.73,
                5.0138e-06; 90.79,5.0138e-06; 90.85,5.0138e-06; 90.91,5.0138e-06; 90.97,
                5.0138e-06; 91.03,5.0138e-06; 91.09,5.0138e-06; 91.15,5.0138e-06; 91.21,
                5.0138e-06; 91.27,5.0138e-06; 91.33,5.0138e-06; 91.39,5.0138e-06; 91.45,
                5.0138e-06; 91.51,5.0138e-06; 91.57,5.0138e-06; 91.63,5.0138e-06; 91.69,
                5.0138e-06; 91.75,5.0138e-06; 91.81,5.0138e-06; 91.87,5.0138e-06; 91.93,
                5.0138e-06; 91.99,5.0138e-06; 92.05,5.0138e-06; 92.11,5.0138e-06; 92.17,
                5.0138e-06; 92.23,5.0138e-06; 92.29,5.0138e-06; 92.35,5.0139e-06; 92.41,
                5.0139e-06; 92.47,5.0139e-06; 92.53,5.0139e-06; 92.59,5.0139e-06; 92.65,
                5.0139e-06; 92.71,5.0139e-06; 92.77,5.0139e-06; 92.83,5.0139e-06; 92.89,
                5.0139e-06; 92.95,5.0139e-06; 93.01,5.0139e-06; 93.07,5.0139e-06; 93.13,
                5.0139e-06; 93.19,5.0139e-06; 93.25,5.0139e-06; 93.31,5.0139e-06; 93.37,
                5.0139e-06; 93.43,5.0139e-06; 93.49,5.0139e-06; 93.55,5.0139e-06; 93.61,
                5.0139e-06; 93.67,5.0139e-06; 93.73,5.0139e-06; 93.79,5.0139e-06; 93.85,
                5.0139e-06; 93.91,5.0139e-06; 93.97,5.0139e-06; 94.03,5.0139e-06; 94.09,
                5.0139e-06; 94.15,5.0139e-06; 94.21,5.0139e-06; 94.27,5.0139e-06; 94.33,
                5.0139e-06; 94.39,5.0139e-06; 94.45,5.0139e-06; 94.51,5.0139e-06; 94.57,
                5.0139e-06; 94.63,5.0139e-06; 94.69,5.0139e-06; 94.75,5.0139e-06; 94.81,
                5.0139e-06; 94.87,5.0139e-06; 94.93,5.0139e-06; 94.99,5.014e-06; 95.05,5.014e-06;
                95.11,5.014e-06; 95.17,5.014e-06; 95.23,5.014e-06; 95.29,5.014e-06; 95.35,
                5.014e-06; 95.41,5.014e-06; 95.47,5.014e-06; 95.53,5.014e-06; 95.59,5.014e-06;
                95.65,5.014e-06; 95.71,5.014e-06; 95.77,5.014e-06; 95.83,5.014e-06; 95.89,
                5.0141e-06; 95.95,5.0141e-06; 96.01,5.0141e-06; 96.07,5.0141e-06; 96.13,
                5.0141e-06; 96.19,5.0141e-06; 96.25,5.0141e-06; 96.31,5.0141e-06; 96.37,
                5.0142e-06; 96.43,5.0142e-06; 96.49,5.0142e-06; 96.55,5.0142e-06; 96.61,
                5.0142e-06; 96.67,5.0142e-06; 96.73,5.0142e-06; 96.79,5.0142e-06; 96.85,
                5.0143e-06; 96.91,5.0143e-06; 96.97,5.0143e-06; 97.03,5.0143e-06; 97.09,
                5.0143e-06; 97.15,5.0143e-06; 97.21,5.0143e-06; 97.27,5.0143e-06; 97.33,
                5.0143e-06; 97.39,5.0144e-06; 97.45,5.0144e-06; 97.51,5.0144e-06; 97.57,
                5.0144e-06; 97.63,5.0144e-06; 97.69,5.0144e-06; 97.75,5.0144e-06; 97.81,
                5.0144e-06; 97.87,5.0144e-06; 97.93,5.0144e-06; 97.99,5.0144e-06; 98.05,
                5.0144e-06; 98.11,5.0145e-06; 98.17,5.0145e-06; 98.23,5.0145e-06; 98.29,
                5.0145e-06; 98.35,5.0145e-06; 98.41,5.0145e-06; 98.47,5.0145e-06; 98.53,
                5.0145e-06; 98.59,5.0145e-06; 98.65,5.0145e-06; 98.71,5.0145e-06; 98.77,
                5.0145e-06; 98.83,5.0145e-06; 98.89,5.0145e-06; 98.95,5.0145e-06; 99.01,
                5.0145e-06; 99.07,5.0145e-06; 99.13,5.0145e-06; 99.19,5.0145e-06; 99.25,
                5.0145e-06; 99.31,5.0145e-06; 99.37,5.0145e-06; 99.43,5.0145e-06; 99.49,
                5.0147e-06; 99.55,5.0149e-06; 99.6,5.0151e-06; 99.66,5.0154e-06; 99.72,5.0157e-06;
                99.78,5.0159e-06; 99.84,5.0161e-06; 99.9,5.0162e-06; 99.96,5.0163e-06; 100,
                5.0165e-06])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                82.3774e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
            annotation (Placement(transformation(extent={{-114,-150},{-94,-130}})));
          Modelica.Blocks.Nonlinear.Limiter valveBP_lim(uMax=1, uMin=0)
            annotation (Placement(transformation(extent={{-120,50},{-100,70}})));
          Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=30, uMin=1)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
            annotation (Placement(transformation(extent={{116,50},{96,70}})));
        equation
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-159,-134},{-148,-134}},
                                                               color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(add9.y, product.u1) annotation (Line(points={{-199,-128},{-190,
                  -128},{-182,-128}}, color={0,0,127}));
          connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-262,-140},{
                  -230,-140},{-230,-134},{-222,-134}}, color={0,0,127}));
          connect(du_w_FW, add9.u1) annotation (Line(points={{-140,-100},{-184,-100},{-230,
                  -100},{-230,-122},{-222,-122}},      color={0,0,127}));
          connect(du_w_MS, add10.u1) annotation (Line(points={{120,280},{200,280},{
                  200,252},{182,252}}, color={0,0,127}));
          connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,240},{212,
                  240},{182,240}},           color={0,0,127}));
          connect(du_Y_t, add3.u1) annotation (Line(points={{120,100},{120,100},{220,100},
                  {220,72},{216,72}},          color={0,0,127}));
          connect(PID_valveTURB.CS, add3.u2) annotation (Line(points={{262,60},{216,60}},
                                                   color={0,0,127}));
          connect(add4.u1, add10.y)
            annotation (Line(points={{122,246},{159,246}}, color={0,0,127}));
          connect(add5.u1, add3.y) annotation (Line(points={{186,66},{194,66},{193,66}},
                                 color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,
                  -128},{-296,-128}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaBP, add11.u1) annotation (Line(points={{-140,100},{-230,100},{
                  -230,72},{-222,72}}, color={0,0,127}));
          connect(add11.y, add8.u1) annotation (Line(points={{-199,66},{-199,66},{-162,66}},
                        color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_valveBP.CS, add11.u2)
            annotation (Line(points={{-262,60},{-242,60},{-222,60}}, color={0,0,127}));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,150},{320,150},{320,
                  238},{296,238}}, color={0,0,127}));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                  -100},{-280,-124}}, color={0,0,127}));
          connect(valveTURB_TS.y, PID_valveTURB.TR)
            annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y) annotation (Line(points={{146,60},{163,
                  60}},                   color={0,0,127}));
          connect(table_w_MS.u[1], LOAD7.y)
            annotation (Line(points={{242,190},{259,190}}, color={0,0,127}));
          connect(table_w_HPH.u[1], LOAD5.y)
            annotation (Line(points={{242,-140},{259,-140}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},
                  {180,190},{140,190},{140,234},{122,234}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1]) annotation (Line(points={{296,72},
                  {339,72}},              color={0,0,127}));
          connect(table_P.u[1], LOAD2.y) annotation (Line(points={{362,72},{379,
                  72}},          color={0,0,127}));
          connect(table_T_FW.y[1], PID_valveBP.SP) annotation (Line(points={{
                  -339,72},{-296,72},{-296,72}}, color={0,0,127}));
          connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},
                  {-362,72},{-362,72}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-269.5,
                  10},{-262,10}},                         color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-180,
                  10},{-180,54},{-162,54}},           color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-279,-190},
                  {-270,-190},{-262,-190}}, color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,
                  -190},{-214,-190},{-190,-190},{-190,-140},{-182,-140}}, color=
                 {0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},{-156,-190},
                  {-156,-146},{-148,-146}},             color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y) annotation (Line(points={{242,10},{259,10}},
                                     color={0,0,127}));
          connect(table_Yt.y[1], add5.u2) annotation (Line(points={{219,10},{219,10},{192,
                  10},{192,54},{186,54}},              color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,252},
                  {379,252},{379,252}}, color={0,0,127}));
          connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{
                  296,252},{339,252},{339,252}}, color={0,0,127}));
          connect(valveBP_lim.y, valveBP_dynamic.u)
            annotation (Line(points={{-99,60},{-84,60},{-84,60}}, color={0,0,127}));
          connect(add8.y, valveBP_lim.u) annotation (Line(points={{-139,60},{-130.5,60},
                  {-122,60}}, color={0,0,127}));
          connect(pumpFW_lim.y, pumpFW_dynamic.u) annotation (Line(points={{-93,-140},{-84,
                  -140},{-84,-140}}, color={0,0,127}));
          connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-125,-140},{-116,-140},
                  {-116,-140}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, pumpHPH_lim.y) annotation (Line(points={{84,-140},{
                  139,-140},{139,-140}}, color={0,0,127}));
          connect(pumpHPH_lim.u, table_w_HPH.y[1]) annotation (Line(points={{162,-140},{
                  219,-140},{219,-140}}, color={0,0,127}));
          connect(table_Y_tTOtheta.y[1], valveTURB_lim.u)
            annotation (Line(points={{123,60},{120.5,60},{118,60}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, valveTURB_lim.y) annotation (Line(points={{84,60},
                  {92,60},{92,60},{95,60}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_lin_highLoad_FF;

        model desuperheating_controller "Model of the OTSG control system"

          //Controllers parameter
          //--SH DESUPERHEATING CONTROL--
          parameter Modelica.SIunits.Temperature T_des_SH_sp
            "SH desuperheating temperature set point"                                                  annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real Kp_des_SH "Controller proportional gain" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Ti_des_SH "Controller integral time" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Td_des_SH
            "Controller derivative time"                                         annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real Nd_des_SH
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSmin_des_SH
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSmax_des_SH
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real CSstart_des_SH "Start value of CS" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Real actuatorGain_des_SH "Actuator gain" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Modelica.SIunits.Time Ta_des_SH "Actuator time constant" annotation (Dialog(tab="SH desuperheating controller"));
          parameter Boolean useTS_des_SH "Tracking reference mode" annotation (Dialog(tab="SH desuperheating controller"));

          //--RH DESUPERHEATING CONTROL--
          parameter Modelica.SIunits.Temperature T_des_RH_sp
            "RH desuperheating temperature set point"                                              annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real Kp_des_RH "Controller proportional gain" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Ti_des_RH "Controller integral time" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Td_des_RH
            "Controller derivative time"                                         annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real Nd_des_RH
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSmin_des_RH
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSmax_des_RH
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real CSstart_des_RH "Start value of CS" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Real actuatorGain_des_RH "Actuator gain" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Modelica.SIunits.Time Ta_des_RH "Actuator time constant" annotation (Dialog(tab="RH desuperheating controller"));
          parameter Boolean useTS_des_RH "Tracking reference mode" annotation (Dialog(tab="RH desuperheating controller"));

          //--SH LAMINATING CONTROL--
          parameter Modelica.SIunits.AbsolutePressure p_SH_sp
            "SH pressure set point"     annotation (Dialog(tab="SH pressure controller"));
          parameter Real Kp_p_SH "Controller proportional gain" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Ti_p_SH "Controller integral time" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Td_p_SH "Controller derivative time" annotation (Dialog(tab="SH pressure controller"));
          parameter Real Nd_p_SH
            "Controller derivative action up to Nd/Td rad/s"                      annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSmin_p_SH
            "Minimum value of control signal for scaling"                         annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSmax_p_SH
            "Maximum value of control signal for scaling"                         annotation (Dialog(tab="SH pressure controller"));
          parameter Real CSstart_p_SH "Start value of CS" annotation (Dialog(tab="SH pressure controller"));
          parameter Real actuatorGain_p_SH "Actuator gain" annotation (Dialog(tab="SH pressure controller"));
          parameter Modelica.SIunits.Time Ta_p_SH "Actuator time constant" annotation (Dialog(tab="SH pressure controller"));
          parameter Boolean useTS_p_SH "Tracking reference mode" annotation (Dialog(tab="SH pressure controller"));

          //--RH LAMINATING CONTROL--
          parameter Modelica.SIunits.AbsolutePressure p_RH_sp
            "RH pressure set point"     annotation (Dialog(tab="RH pressure controller"));
          parameter Real Kp_p_RH "Controller proportional gain" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Ti_p_RH "Controller integral time" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Td_p_RH "Controller derivative time" annotation (Dialog(tab="RH pressure controller"));
          parameter Real Nd_p_RH
            "Controller derivative action up to Nd/Td rad/s"                      annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSmin_p_RH
            "Minimum value of control signal for scaling"                         annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSmax_p_RH
            "Maximum value of control signal for scaling"                         annotation (Dialog(tab="RH pressure controller"));
          parameter Real CSstart_p_RH "Start value of CS" annotation (Dialog(tab="RH pressure controller"));
          parameter Real actuatorGain_p_RH "Actuator gain" annotation (Dialog(tab="RH pressure controller"));
          parameter Modelica.SIunits.Time Ta_p_RH "Actuator time constant" annotation (Dialog(tab="RH pressure controller"));
          parameter Boolean useTS_p_RH "Tracking reference mode" annotation (Dialog(tab="RH pressure controller"));

          Modelica.Blocks.Continuous.FirstOrder valveDynamic_desSH(
            k=actuatorGain_des_SH,
            T=Ta_des_SH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{40,40},{60,60}})));
          IndustrialControlSystems.Controllers.PI PID_desSH(
            Ti=Ti_des_SH,
            CSmin=CSmin_des_SH,
            CSmax=CSmax_des_SH,
            CS_start=CSstart_des_SH,
            Kp=Kp_des_SH,
            AntiWindup=true,
            useTS=useTS_des_SH)
            annotation (Placement(transformation(extent={{-10,40},{10,60}})));
          Modelica.Blocks.Sources.Constant T_desSH_SP(k=T_des_SH_sp)
            annotation (Placement(transformation(extent={{-90,46},{-70,66}})));
          Modelica.Blocks.Sources.Constant p_RH_SP(k=p_RH_sp)
            annotation (Placement(transformation(extent={{-88,-74},{-68,-54}})));
          IndustrialControlSystems.Controllers.PI PID_p_RH(
            Kp=Kp_p_RH,
            Ti=Ti_p_RH,
            CSmin=CSmin_p_RH,
            CSmax=CSmax_p_RH,
            CS_start=CSstart_p_RH,
            AntiWindup=true,
            useTS=useTS_p_RH) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={0,-70})));
         Modelica.Blocks.Continuous.FirstOrder valveDynamic_p_RH(
            k=actuatorGain_p_RH,
            T=Ta_p_RH,
            initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={50,-70})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={110,0})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep
            annotation (Placement(transformation(extent={{40,-40},{20,-20}})));
          IndustrialControlSystems.Controllers.PI PID_p_SH(
            CSmin=CSmin_p_SH,
            CSmax=CSmax_p_SH,
            CS_start=CSstart_p_SH,
            Kp=Kp_p_SH,
            Ti=Ti_p_SH,
            AntiWindup=true,
            useTS=useTS_p_SH)
            annotation (Placement(transformation(extent={{-10,-160},{10,-140}})));
          Modelica.Blocks.Sources.Constant p_SH_SP(k=p_SH_sp)
            annotation (Placement(transformation(extent={{-86,-154},{-66,-134}})));
         Modelica.Blocks.Continuous.FirstOrder valveDynamic_p_SH(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_p_SH,
            T=Ta_p_SH) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=180,
                origin={50,-150})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep1
            annotation (Placement(transformation(extent={{40,70},{20,90}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{40,-130},{20,-110}})));
          Modelica.Blocks.Continuous.FirstOrder valveDynamic_desRH(
            k=actuatorGain_des_RH,
            T=Ta_des_RH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{40,120},{60,140}})));
          IndustrialControlSystems.Controllers.PI
                                              PID_desRH(
            Ti=Ti_des_RH,
            CSmin=CSmin_des_RH,
            CSmax=CSmax_des_RH,
            CS_start=CSstart_des_RH,
            Kp=Kp_des_RH,
            AntiWindup=true,
            useTS=useTS_des_RH)
            annotation (Placement(transformation(extent={{-12,120},{8,140}})));
          Modelica.Blocks.Sources.Constant T_desRH_SP(k=T_des_RH_sp)
            annotation (Placement(transformation(extent={{-90,126},{-70,146}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{40,150},{20,170}})));
          Modelica.Blocks.Sources.Constant const(k=0.0522)
            annotation (Placement(transformation(extent={{-30,150},{-10,170}})));
          Modelica.Blocks.Sources.Constant const1(k=0.6341)
            annotation (Placement(transformation(extent={{-30,70},{-10,90}})));
          Modelica.Blocks.Sources.Constant const2(k=0.6)
            annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
          Modelica.Blocks.Sources.Constant const3(k=0.6)
            annotation (Placement(transformation(extent={{-30,-130},{-10,-110}})));
        equation
          connect(T_desSH_SP.y, PID_desSH.SP) annotation (Line(
              points={{-69,56},{-8,56}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_desSH.CS, valveDynamic_desSH.u) annotation (Line(
              points={{9,50},{38,50}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_p_RH.SP, p_RH_SP.y) annotation (Line(
              points={{-8,-64},{-67,-64}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep.y, PID_p_RH.TS) annotation (Line(points={{19,-30},{4,-30},
                  {4,-62}},                 color={255,0,255}));
          connect(PID_p_RH.CS, valveDynamic_p_RH.u)
            annotation (Line(points={{9,-70},{24,-70},{38,-70}},
                                                        color={0,0,127}));
          connect(booleanStep1.y, PID_desSH.TS)
            annotation (Line(points={{19,80},{4,80},{4,58}}, color={255,0,255}));
          connect(PID_p_SH.TS, booleanStep2.y) annotation (Line(points={{4,-142},{4,-142},
                  {4,-122},{4,-120},{19,-120}}, color={255,0,255}));
          connect(p_SH_SP.y, PID_p_SH.SP) annotation (Line(points={{-65,-144},{-60,-144},
                  {-8,-144}}, color={0,0,127}));
          connect(T_desRH_SP.y, PID_desRH.SP) annotation (Line(
              points={{-69,136},{-10,136}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_desRH.CS, valveDynamic_desRH.u) annotation (Line(
              points={{7,130},{38,130}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(booleanStep3.y, PID_desRH.TS)
            annotation (Line(points={{19,160},{2,160},{2,138}}, color={255,0,255}));
          connect(PID_p_SH.CS, valveDynamic_p_SH.u)
            annotation (Line(points={{9,-150},{24,-150},{38,-150}}, color={0,0,127}));
          connect(signalBus.sensT_des_RH, PID_desRH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,129},{-10,129}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensT_des_SH, PID_desSH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,49},{-8,49}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDes_RH_CS, valveDynamic_desRH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,130},{61,130}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDes_SH_CS, valveDynamic_desSH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,50},{61,50}},
              color={255,204,51},
              thickness=0.5));
          connect(const.y, PID_desRH.TR) annotation (Line(points={{-9,160},{-2,160},
                  {-2,138}}, color={0,0,127}));
          connect(const1.y, PID_desSH.TR)
            annotation (Line(points={{-9,80},{0,80},{0,58}}, color={0,0,127}));
          connect(const2.y, PID_p_RH.TR)
            annotation (Line(points={{-9,-30},{0,-30},{0,-62}}, color={0,0,127}));
          connect(const3.y, PID_p_SH.TR) annotation (Line(points={{-9,-120},{0,-120},
                  {0,-142}}, color={0,0,127}));
          connect(signalBus.valveLam_RH_CS, valveDynamic_p_RH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,-70},{61,-70}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveLam_SH_CS, valveDynamic_p_SH.y) annotation (Line(
              points={{0,0},{40,0},{80,0},{80,-150},{61,-150}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensP_RH, PID_p_RH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,-71},{-8,-71}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.sensP_SH, PID_p_SH.PV) annotation (Line(
              points={{0,0},{-20,0},{-40,0},{-40,-151},{-8,-151}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -180},{100,180}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-100,-180},{100,180}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-94,98},{94,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="Desuperheating/
laminating
station
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-100,180},{100,-180}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end desuperheating_controller;

        model Plant_HP_IO_50_stepTest
          "Model of the high pressure parto of the OTSG for linearization at 50% load"

          SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=88.3e5,
                  fixed=true)))
            annotation (Placement(transformation(extent={{18,102},{94,178}})));
          SteamTurbine.Corps.IPT IPTurb(pressDrop_IPT1_HPH1(pin(start=1100000,
                  fixed=true)), vap_in(p(start=2215000))) annotation (Placement(
                transformation(extent={{124,102},{206,178}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-158,150},{
                    -138,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                    {-160,-170}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{262,130},{242,150}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes OTSG(
            PDSteamEVA1(pin(start=9000000, fixed=true)),
            valveVap(inlet(p(start=8882000))),
            RH(coldFluid(noInitialPressure=true)),
            separator(zl_start=1),
            PDSteamECO2(pin(start=9074000, fixed=true)),
            PDSteamECO1(pin(start=9249000, fixed=true)),
            valveLiq(w(start=0))) annotation (Placement(transformation(extent={
                    {-160,-160},{-20,80}})));
          HeatExchangers.FeedwaterTrain.Old.HPH_train_controlledLevel_50 HPHs(
            SP1(p(start=3941000, fixed=true)),
            DPSteamHPH2(w(start=46, fixed=true)),
            DPSteamHPH1(w(start=46, fixed=true)),
            SP2(p(start=1000000)),
            HPH2(
              pressDropLin(R=0.5e5, inlet(m_flow(start=6.022))),
              NusseltCondenser(w_cond(fixed=true, start=6.022)),
              nominalColdPressure=9900000,
              nominalHotPressure=3900000),
            HPH1(
              pressDropLin(R=0.5e5),
              NusseltCondenser(
                w_cond(start=1),
                wd_out(start=7.013),
                ws_in(start=1, fixed=true),
                hv(start=2.8e6)),
              des_SP(w(start=1, fixed=true)),
              nominalColdPressure=9950000,
              nominalHotPressure=900000)) annotation (Placement(transformation(
                  extent={{20,-160},{120,-104}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lin_lowLoad
            controllers(
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            Td_valveTURB=0,
            Nd_valveTURB=1,
            actuatorGain_valveTURB=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            CSstart_valveTURB=0,
            TS_valveTURB=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            CSmin_valveTURB=-5.03e-6,
            Ti_valveTURB=5,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpMS=2,
            Ta_valveTURB=0.3,
            useTS_pumpFW=true,
            useTS_valveTURB=true,
            l_sp=4,
            Ti_pumpSEP=100,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSmin_pumpSEP=-0.9,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            CSmin_pumpFW=1,
            CSmax_pumpFW=100,
            CSstart_pumpFW=46.95,
            Kp_valveTURB=-0.005e-11,
            CSmax_valveTURB=+5.04e-6,
            CSmax_pumpSEP=1,
            load_end=50,
            t_ramp=0,
            t_start_ramp=0,
            CSstart_pumpSEP=0,
            TS_start=false,
            load_start=50,
            Kp_pumpSEP=0.05,
            t_start_TS=40000,
            P_mec_sp=79725800,
            p_sp=17611000,
            Kp_pumpFW=15,
            Ti_pumpFW=714,
            T_MS_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -60},{-200,-20}})));
          ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
              Medium =
                Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
          ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
              Medium = Modelica.Media.Water.WaterIF97_ph,
            h=768600,
            use_in_h=true,
            p0=18380000)
            annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=450000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{214,170},{234,190}})));

          ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=508800,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,30},{220,50}})));
          ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph, p0=900000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
          Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                IPTurb.Pm))
            annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,210})));
          Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                2.753e5; 90,3.09e5; 100,3.448e5])
            annotation (Placement(transformation(extent={{260,200},{240,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,60})));
          Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                2.633e5; 90,2.946e5; 100,3.276e5])
            annotation (Placement(transformation(extent={{260,50},{240,70}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={290,0})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-80})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=controllers.load_end - controllers.load_start,
            duration=controllers.t_ramp,
            offset=controllers.load_start,
            startTime=controllers.t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={230,-120})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                764100; 90,783800; 100,803100]) annotation (Placement(
                transformation(extent={{200,-130},{180,-110}})));
          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}), iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-20},{-320,20}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-180},{-320,-140}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = Power_sensor.y annotation (Placement(transformation(extent={{320,70},
                    {340,90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_l=OTSG.sep_lev annotation (Placement(
                transformation(extent={{320,-90},{340,-70}}), iconTransformation(extent=
                   {{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -170},{340,-150}})));

          Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{260,-10},{240,10}})));
          Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                        table=[20,2.234e5; 30,
                3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                transformation(extent={{200,-90},{180,-70}})));
          Modelica.Blocks.Sources.Step step(startTime=5000, height=5)
            annotation (Placement(transformation(extent={{-340,-90},{-320,-70}})));
        equation
          connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
              points={{97.8,140},{119.9,140}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-140,-180},{-128.889,-180},{-128.889,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-138,160},{-128.889,160},{-128.889,84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
              points={{-16.1111,48},{14.2,48},{14.2,109.6}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
              points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
              points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
              points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                  -101.2}},
              color={0,0,255},
              thickness=0.5));

          connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
              points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{81.1111,
                  -180},{81.1111,-162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
              points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},{
                  119.9,162.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                  140},{210.1,140},{242,140}},       color={0,0,0}));
          connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                  -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
              thickness=0.5));

          connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                  -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                          color={0,127,0},
              thickness=0.5));

          connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                  {210.1,180},{210.1,162.8}}, color={0,0,255}));
          connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                  {279,210},{262,210}},color={0,0,127}));
          connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                  {220,210},{220,188.8}},          color={0,0,127}));
          connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                  279,60},{262,60}},
                                 color={0,0,127}));
          connect(LOAD5.y, HPH1_P_source.u[1]) annotation (Line(points={{219,-120},
                  {219,-120},{202,-120}}, color={0,0,127}));
          connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                  {206,60},{206,48.8}},     color={0,0,127}));
          connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
          connect(du_w_MS, controllers.du_w_MS) annotation (Line(points={{-340,80},{-270,
                  80},{-270,-24},{-261.5,-24}},         color={0,0,127}));
          connect(du_Y_t, controllers.du_Y_t) annotation (Line(points={{-340,0},
                  {-280,0},{-280,-34.6667},{-261.5,-34.6667}},   color={0,0,127}));
          connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
              points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
              color={0,127,0},
              thickness=0.5));

          connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
              points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
              points={{189.6,98.2},{189.6,40},{200,40}},
              color={0,127,0},
              thickness=0.5));
          connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                  {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
          connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                  279,0},{262,0}}, color={0,0,127}));
          connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
              points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
              color={0,127,0},
              thickness=0.5));
          connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                  20},{-230,20},{-230,-18.6667}},
                                              color={0,0,127}));
          connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-165.444,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
              points={{-198.5,-40},{-190,-40},{-180,-40},{-180,-200},{100.556,
                  -200},{100.556,-161.12}},
              color={255,204,51},
              thickness=0.5));
          connect(du_w_SEP, controllers.du_w_SEP) annotation (Line(points={{
                  -340,-160},{-306,-160},{-270,-160},{-270,-56},{-261.5,-56}},
                color={0,0,127}));
          connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                  {219,-80}},           color={0,0,127}));
          connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                  127}));
          connect(step.y, controllers.du_w_FW) annotation (Line(points={{-319,
                  -80},{-280,-80},{-280,-45.3333},{-261.5,-45.3333}}, color={0,
                  0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=40000, __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Plant_HP_IO_50_stepTest;
      end Old;
    end Control;

    package Plants
      "Package containing partial/complete models of the power plant"

      model Plant_Full_100 "Model of the full steam cycle"

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{-56,102},{20,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{54,102},{136,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-240,90},{
                  -220,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                  -240,-170}})));
        HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                               annotation (Placement(transformation(extent={{-240,
                  -160},{-100,80}})));
        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
          HPHs
          annotation (Placement(transformation(extent={{-60,-160},{60,-100}})));

        Control.Schemes.PlantControlSchemes.plantController
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSmin_valveTURB_high=-0.1e-5,
          CSmax_valveTURB_high=0.1e-5,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_valveBP=false,
          useTS_pumpSEP=false,
          Td_pumpCOND=0,
          Nd_pumpCOND=20,
          CSmin_pumpCOND=0,
          CSmax_pumpCOND=100,
          CSstart_pumpCOND=77,
          actuatorGain_pumpCOND=1,
          Ta_pumpCOND=2,
          TS_pumpCOND=0,
          useTS_pumpCOND=false,
          staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6])), control_wMS_high(table_P_MEC_high(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6]))),
          useTS_pumpMS=false,
          dec_wMS_wFW=1e-3,
          dec_wFW_wMS=80,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          CSmin_pumpFW_high=-0.1,
          CSmax_pumpFW_high=0.1,
          CSmin_valveDEA=0,
          CSmax_valveDEA=1,
          CSstart_valveDEA=0.5,
          actuatorGain_valveDEA=1,
          Ta_valveDEA=0.3,
          Kp_valveDEA=0.0001,
          Ti_valveDEA=20,
          Td_valveDEA=0,
          Nd_valveDEA=20,
          useTS_valveDEA=true,
          TS_valveDEA=1,
          useTS_valveTURB_high=false,
          Kp_pumpCOND=1560,
          Ti_pumpCOND=128,
          DT_sh_sp=20,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.848,
          B=[0.015625; 0; 0; 0; 0],
          C=[-0.0064,-0.0026,-0.00025,-1.22E-5,-2.78e-8],
          Kp_pumpFW_low=17.6,
          Ti_pumpFW_low=571,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-330,
                  -60},{-282,-20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
        Auxiliaries.Components.powerSensor powerSensor
          annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-354,-46},{-342,-34}})));
        Modelica.Blocks.Sources.Constant
                                     LOAD(k=100)
                           annotation (Placement(transformation(extent={{-384,
                  -50},{-364,-30}})));
        HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
          LPHs
          annotation (Placement(transformation(extent={{170,-160},{328,-100}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{360,-100},{380,-80}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=742500,
          use_in_h=true,
          p0=900000)
          annotation (Placement(transformation(extent={{380,-120},{360,-140}})));
        Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
              30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
              211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
              transformation(extent={{400,-210},{380,-190}})));
        Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
              30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
              0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
           Placement(transformation(extent={{400,-70},{380,-50}})));
        SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{230,102},{314,178}})));
        ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                       redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=900000)
          annotation (Placement(transformation(extent={{360,154},{380,174}})));
        Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
              0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
              0.1028e5; 90,0.1137e5; 100,0.126e5])
          annotation (Placement(transformation(extent={{400,190},{380,210}})));
        HeatExchangers.Components.Deaerator_controlled
                                            deaerator(
          L=12,
          H=2.677,
          zl_start=2,
          h_start=1e6,
          w_small=100,
          p_start=1086000)
          annotation (Placement(transformation(extent={{86,-126},{146,-70}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{440,190},{420,210}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{440,-70},{420,-50}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{440,-210},{420,-190}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{23.8,140},{49.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-220,-180},{-208.889,-180},{-208.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-220,100},{-208.889,100},{-208.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},{
                49.9,162.8}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-106,140},{-99,140}},          color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{-77,140},{-59.8,140}},         color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-341.4,-40},
                {-332.182,-40}},      color={0,0,127}));
        connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
            points={{331.292,-130},{331.292,-130},{360,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
              points={{379,-200},{366,-200},{366,-139}},
                                                     color={0,0,127}));
        connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
              points={{379,-60},{366,-60},{366,-81.2}},
                                                     color={0,0,127}));
        connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
            points={{331.292,-112},{348,-112},{348,-90},{360,-90}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{140.1,162.8},{225.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
            points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
            points={{249.32,98.2},{249.32,27.1},{249,27.1},{249,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
            points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
              points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
        connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
            points={{318.2,162.8},{360,162.8},{360,164}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{63.3333,-112},{63.3333,-112},{88.1429,-112}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
            points={{99.92,98.2},{99.92,-94},{107.857,-94}},
            color={0,127,0},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{123.714,-82},{123.714,-82},{152,-82},{160,-82},{160,-130},
                {166.708,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
            points={{116,-120},{116,-130},{63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                419,200}},           color={0,0,127}));
        connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-60},{
                419,-60}},           color={0,0,127}));
        connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-200},{
                419,-200}},            color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-279.818,-40},{-279.818,-40},{-245.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-279.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},{
                -279.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
              points={{140.1,140},{140.1,140},{225.8,140}}, color={0,0,0}));
        connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
            points={{-279.818,-40},{-279.818,-40},{-270,-40},{-270,-220},{132,
                -220},{132,-120},{133.143,-120}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
            points={{-279.818,-40},{-279.818,-40},{-270,-40},{-270,-220},{136,
                -220},{250,-220},{250,-190},{249,-190},{249,-160}},
            color={255,204,51},
            thickness=0.5));
        connect(LOAD.y, gain.u)
          annotation (Line(points={{-363,-40},{-364,-40},{-355.2,-40}},
                                                             color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=5000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
      end Plant_Full_100;

      model Plant_Full_50 "Model of the full steam cycle"

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{-56,102},{20,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{54,102},{136,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-240,90},{
                  -220,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                  -240,-170}})));
        HeatExchangers.OTSG.OTSG_init50_5nodes OTSG      annotation (Placement(
              transformation(extent={{-240,-160},{-100,80}})));
        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
          HPHs
          annotation (Placement(transformation(extent={{-60,-160},{60,-100}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
        Auxiliaries.Components.powerSensor powerSensor
          annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-370,-46},{-358,-34}})));
        HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_50_dp
          LPHs
          annotation (Placement(transformation(extent={{170,-160},{328,-100}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{360,-90},{380,-70}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=742500,
          use_in_h=true,
          p0=900000)
          annotation (Placement(transformation(extent={{380,-120},{360,-140}})));
        Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
              30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
              211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
              transformation(extent={{400,-210},{380,-190}})));
        Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
              30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
              0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
           Placement(transformation(extent={{400,-60},{380,-40}})));
        SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{230,102},{314,178}})));
        ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                       redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=900000)
          annotation (Placement(transformation(extent={{360,154},{380,174}})));
        Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
              0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
              0.1028e5; 90,0.1137e5; 100,0.126e5])
          annotation (Placement(transformation(extent={{400,190},{380,210}})));
        HeatExchangers.Components.Deaerator_controlled
                                            deaerator(
          L=12,
          H=2.677,
          h_start=1.2e6,
          zl_start=2,
          w_small=1e4,
          p_start=550000)
          annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{440,190},{420,210}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{440,-60},{420,-40}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{440,-210},{420,-190}})));
        Modelica.Blocks.Sources.Constant load(k=50) annotation (Placement(
              transformation(extent={{-420,-50},{-400,-30}})));
        Control.Schemes.PlantControlSchemes.plantController
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSmin_valveTURB_high=-0.1e-5,
          CSmax_valveTURB_high=0.1e-5,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_valveBP=false,
          useTS_pumpSEP=false,
          Td_pumpCOND=0,
          Nd_pumpCOND=20,
          CSmin_pumpCOND=0,
          CSmax_pumpCOND=100,
          CSstart_pumpCOND=77,
          actuatorGain_pumpCOND=1,
          Ta_pumpCOND=2,
          TS_pumpCOND=0,
          useTS_pumpCOND=false,
          staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6])), control_wMS_high(table_P_MEC_high(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6]))),
          useTS_pumpMS=false,
          dec_wMS_wFW=1e-3,
          dec_wFW_wMS=80,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          CSmin_pumpFW_high=-0.1,
          CSmax_pumpFW_high=0.1,
          CSmin_valveDEA=0,
          CSmax_valveDEA=1,
          CSstart_valveDEA=0.5,
          actuatorGain_valveDEA=1,
          Ta_valveDEA=0.3,
          Kp_valveDEA=0.0001,
          Ti_valveDEA=20,
          Td_valveDEA=0,
          Nd_valveDEA=20,
          useTS_valveDEA=true,
          TS_valveDEA=1,
          useTS_valveTURB_high=false,
          Kp_pumpCOND=1560,
          Ti_pumpCOND=128,
          DT_sh_sp=20,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.848,
          B=[0.015625; 0; 0; 0; 0],
          C=[-0.0064,-0.0026,-0.00025,-1.22E-5,-2.78e-8],
          Kp_pumpFW_low=17.6,
          Ti_pumpFW_low=571,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-334,
                  -60},{-286,-20}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{23.8,140},{49.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-220,-180},{-208.889,-180},{-208.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-220,100},{-208.889,100},{-208.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},{
                49.9,162.8}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-106,140},{-99,140}},          color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{-77,140},{-70,140},{-59.8,140}},
                                                                   color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
            points={{331.292,-130},{331.292,-130},{360,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
              points={{379,-200},{366,-200},{366,-139}},
                                                     color={0,0,127}));
        connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
              points={{379,-50},{366,-50},{366,-71.2}},
                                                     color={0,0,127}));
        connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
            points={{331.292,-112},{348,-112},{348,-80},{360,-80}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{140.1,162.8},{140.1,162.8},{225.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
            points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
            points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
            points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
              points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
        connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
            points={{318.2,162.8},{360,162.8},{360,164}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
            points={{99.92,98.2},{99.92,-94},{111.857,-94}},
            color={0,127,0},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{127.714,-82},{127.714,-82},{140,-82},{154,-82},{154,-130},
                {166.708,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
            points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                419,200}},           color={0,0,127}));
        connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-50},{
                406,-50},{410,-50},{419,-50}},
                                     color={0,0,127}));
        connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-200},{
                419,-200}},            color={0,0,127}));

        connect(load.y, gain.u)
          annotation (Line(points={{-399,-40},{-382,-40},{-371.2,-40}},
                                                             color={0,0,127}));
        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
          annotation (Line(points={{140.1,140},{140.1,140},{225.8,140}},
                                                             color={0,0,0}));
        connect(gain.y, controllers.load) annotation (Line(points={{-357.4,-40},
                {-336.182,-40},{-336.182,-40}}, color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-283.818,-40},{-283.818,-40},{-245.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-283.818,-40},{-268,-40},{-268,120},{-88,120},{-88,130}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-283.818,-40},{-268,-40},{-268,-220},{36.6667,-220},{
                36.6667,-161.2}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
            points={{-283.818,-40},{-268,-40},{-268,-220},{137.143,-220},{
                137.143,-120}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
            points={{-283.818,-40},{-268,-40},{-268,-220},{249,-220},{249,-160}},
            color={255,204,51},
            thickness=0.5));

        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=10000, __Dymola_NumberOfIntervals=10000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_Full_50;

      model Plant_Full_20 "Model of the full steam cycle"

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{-56,102},{20,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{54,102},{136,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-240,90},{
                  -220,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                  -240,-170}})));
        HeatExchangers.OTSG.OTSG_init20_5nodes OTSG
                                 annotation (Placement(transformation(extent={{
                  -240,-160},{-100,80}})));
        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
          HPHs(HPH1(Ti=100))
          annotation (Placement(transformation(extent={{-60,-160},{60,-100}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
        Auxiliaries.Components.powerSensor powerSensor
          annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-364,-46},{-352,-34}})));
        HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_20_dp
          LPHs
          annotation (Placement(transformation(extent={{170,-160},{328,-100}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{360,-90},{380,-70}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=742500,
          use_in_h=true,
          p0=900000)
          annotation (Placement(transformation(extent={{380,-120},{360,-140}})));
        Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
              30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
              211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
              transformation(extent={{400,-210},{380,-190}})));
        Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
              30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
              0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
           Placement(transformation(extent={{400,-60},{380,-40}})));
        SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{230,102},{314,178}})));
        ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                       redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=900000)
          annotation (Placement(transformation(extent={{360,154},{380,174}})));
        Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
              0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
              0.1028e5; 90,0.1137e5; 100,0.126e5])
          annotation (Placement(transformation(extent={{400,190},{380,210}})));
        HeatExchangers.Components.Deaerator_controlled
                                            deaerator(
          L=12,
          H=2.677,
          initOpt=ThermoPower.Choices.Init.Options.fixedState,
          w_small=1e4,
          h_start=1e6,
          zl_start=2.05,
          p_start=223400)
          annotation (Placement(transformation(extent={{90,-124},{150,-68}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{440,190},{420,210}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{440,-60},{420,-40}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{440,-210},{420,-190}})));
        Modelica.Blocks.Sources.Ramp LOAD(
          startTime=1000,
          offset=40,
          duration=1000,
          height=20 - LOAD.offset) annotation (Placement(transformation(extent=
                  {{-420,-50},{-400,-30}})));
        Control.Schemes.PlantControlSchemes.plantController
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSmin_valveTURB_high=-0.1e-5,
          CSmax_valveTURB_high=0.1e-5,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_valveBP=false,
          useTS_pumpSEP=false,
          Td_pumpCOND=0,
          Nd_pumpCOND=20,
          CSmin_pumpCOND=0,
          CSmax_pumpCOND=100,
          CSstart_pumpCOND=77,
          actuatorGain_pumpCOND=1,
          Ta_pumpCOND=2,
          TS_pumpCOND=0,
          useTS_pumpCOND=false,
          staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6])), control_wMS_high(table_P_MEC_high(table=[20,
                    20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                    69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                    114.430e6]))),
          useTS_pumpMS=false,
          dec_wMS_wFW=1e-3,
          dec_wFW_wMS=80,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          CSmin_pumpFW_high=-0.1,
          CSmax_pumpFW_high=0.1,
          CSmin_valveDEA=0,
          CSmax_valveDEA=1,
          CSstart_valveDEA=0.5,
          actuatorGain_valveDEA=1,
          Ta_valveDEA=0.3,
          Kp_valveDEA=0.0001,
          Ti_valveDEA=20,
          Td_valveDEA=0,
          Nd_valveDEA=20,
          useTS_valveDEA=true,
          TS_valveDEA=1,
          useTS_valveTURB_high=false,
          Kp_pumpCOND=1560,
          Ti_pumpCOND=128,
          DT_sh_sp=20,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.848,
          B=[0.015625; 0; 0; 0; 0],
          C=[-0.0064,-0.0026,-0.00025,-1.22E-5,-2.78e-8],
          Kp_pumpFW_low=17.6,
          Ti_pumpFW_low=571,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-334,
                  -60},{-286,-20}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{23.8,140},{49.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-220,-180},{-208.889,-180},{-208.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-220,100},{-208.889,100},{-208.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},{
                49.9,162.8}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-106,140},{-99,140}},          color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{-77,140},{-70,140},{-59.8,140}},
                                                                   color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
            points={{331.292,-130},{331.292,-130},{360,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
              points={{379,-200},{366,-200},{366,-139}},
                                                     color={0,0,127}));
        connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
              points={{379,-50},{366,-50},{366,-71.2}},
                                                     color={0,0,127}));
        connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
            points={{331.292,-112},{348,-112},{348,-80},{360,-80}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{140.1,162.8},{182,162.8},{225.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
            points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
            points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
            points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
              points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
        connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
            points={{318.2,162.8},{360,162.8},{360,164}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{63.3333,-112},{63.3333,-110},{92.1429,-110}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
            points={{99.92,98.2},{99.92,-92},{111.857,-92}},
            color={0,127,0},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{127.714,-80},{127.714,-80},{144,-80},{156,-80},{156,-130},
                {166.708,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
            points={{120,-118},{120,-118},{120,-130},{63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                419,200}},           color={0,0,127}));
        connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-50},{
                406,-50},{410,-50},{419,-50}},
                                     color={0,0,127}));
        connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-200},{
                419,-200}},            color={0,0,127}));

        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
          annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                             color={0,0,0}));
        connect(LOAD.y, gain.u)
          annotation (Line(points={{-399,-40},{-365.2,-40}}, color={0,0,127}));
        connect(gain.y, controllers.load) annotation (Line(points={{-351.4,-40},
                {-336.182,-40}}, color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-283.818,-40},{-283.818,-40},{-245.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-283.818,-40},{-270,-40},{-270,-220},{36.6667,-220},{
                36.6667,-161.2}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
            points={{-283.818,-40},{-283.818,-40},{-270,-40},{-270,-220},{
                137.143,-220},{137.143,-118}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
            points={{-283.818,-40},{-283.818,-40},{-270,-40},{-270,-219},{138,
                -219},{249,-219},{249,-160}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-283.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
            color={255,204,51},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=10000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_Full_20;

      package Test
        "Package containing some test model on the HP part of the plant"

        package Sensitivity
          "Package containing models for sensitivity analysis "
          model test_valveBPeffectiveness
            "Model of the high pressure parto of the OTSG for to check the effectivenesss of the bypass valve"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-158,150},{
                      -138,170}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{262,130},{242,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes         OTSG
                                                     annotation (Placement(
                  transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            Control.Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
                                                                controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              load_start=100,
              Nd_pumpFW=30,
              Nd_pumpMS=20,
              useTS_pumpMS=true,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=1,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              useTS_valveBP=true,
              TS_valveBP=0,
              Td_pumpFW=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              useTS_pumpFW=true,
              load_end=100,
              t_ramp=0,
              t_start_ramp=0,
              useTS_valveTURB=true,
              Kp_pumpMS=4.57e-4,
              Ti_pumpMS=98.66,
              Td_pumpMS=1.128,
              CSmin_pumpMS=-0.5,
              CSmax_pumpMS=0.5,
              Kp_valveTURB=-1.077e-11,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1e-5,
              CSmax_valveTURB=1e-5,
              DT_SH_sp=20,
              Kp_pumpFW=-0.001,
              CSmax_pumpFW=0.3,
              Kp_valveBP=-7.93e-6,
              Ti_valveBP=0.001,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              TS_start=false,
              t_start_ramp_TS=5000,
              Ti_pumpFW=250,
              T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-200,-20}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                  IPTurb.Pm))
              annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,210})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,60})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,0})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-80})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-120})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Sources.Step dw_MS(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-340,70},{-320,90}})));
            Modelica.Blocks.Sources.Step dY_t(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-340,10},{-320,30}})));
            Modelica.Blocks.Sources.Step dw_FW(
              offset=0,
              height=0,
              startTime=5000)
                        annotation (Placement(transformation(extent={{-340,-70},{
                      -320,-50}})));
            Modelica.Blocks.Sources.Ramp rampNeg(
              offset=0,
              height=-0.75,
              duration=1000,
              startTime=5000)
                            annotation (Placement(transformation(extent={{-340,-170},
                      {-320,-150}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400; 30,
                  622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,764100; 90,
                  783800; 100,803100]) annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-138,160},{-128.889,160},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                    140},{210.1,140},{242,140}},       color={0,0,0}));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                    {279,210},{262,210}},color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                    279,60},{262,60}},
                                   color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-198.5,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                    279,0},{262,0}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                    20},{-230,20},{-230,-18.6667}},        color={0,0,127}));
            connect(dw_FW.y, controllers.du_w_FW) annotation (Line(points={{-319,
                    -60},{-300,-60},{-300,-45.3333},{-261.5,-45.3333}}, color={0,0,
                    127}));
            connect(dw_MS.y, controllers.du_w_MS) annotation (Line(points={{-319,80},
                    {-300,80},{-280,80},{-280,-24},{-261.5,-24}}, color={0,0,127}));
            connect(dY_t.y, controllers.du_Y_t) annotation (Line(points={{-319,20},
                    {-300,20},{-300,-34.6667},{-261.5,-34.6667}}, color={0,0,127}));
            connect(rampNeg.y, controllers.du_thetaBP) annotation (Line(points={{
                    -319,-160},{-280,-160},{-280,-56},{-261.5,-56}}, color={0,0,127}));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(points=
                   {{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},{
                    219,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120},{219,-120}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end test_valveBPeffectiveness;

          model test_wHPHeffectiveness
            "Model of the high pressure parto of the OTSG for to check the effectivenesss of the HPH FW flow"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-158,150},{
                      -138,170}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{262,130},{242,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes         OTSG
                                                     annotation (Placement(
                  transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad_wHPHsens
              controllers(
              Td_pumpHPH=0,
              Nd_pumpHPH=1,
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSmin_pumpHPH=-0.5,
              CSmax_pumpHPH=0.5,
              CSstart_pumpHPH=0,
              TS_pumpHPH=0,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              load_start=100,
              Nd_pumpFW=30,
              Kp_pumpHPH=0.6461,
              Ti_pumpHPH=19.05,
              Nd_pumpMS=20,
              useTS_pumpHPH=true,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=1,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Td_pumpFW=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              load_end=100,
              t_ramp=0,
              t_start_ramp=0,
              Kp_pumpMS=4.57e-4,
              Ti_pumpMS=98.66,
              Td_pumpMS=1.128,
              CSmin_pumpMS=-0.5,
              CSmax_pumpMS=0.5,
              useTS_pumpMS=false,
              Kp_valveTURB=-1.077e-11,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1e-5,
              CSmax_valveTURB=1e-5,
              useTS_valveTURB=false,
              DT_SH_sp=20,
              Kp_pumpFW=-0.0005,
              Ti_pumpFW=100,
              CSmax_pumpFW=0.3,
              useTS_pumpFW=false,
              T_FW_sp=518.15,
              Kp_valveBP=-7.93e-6,
              Ti_valveBP=0.001,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              useTS_valveBP=false,
              T_MS_sp=563.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-200,-20}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                  IPTurb.Pm))
              annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,210})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,60})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,0})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-80})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-120})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400; 30,
                  622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,764100; 90,
                  783800; 100,803100]) annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-138,160},{-128.889,160},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                    140},{210.1,140},{242,140}},       color={0,0,0}));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                    {279,210},{262,210}},color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                    279,60},{262,60}},
                                   color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-198.5,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                    279,0},{262,0}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                    20},{-230,20},{-230,-18.6667}},        color={0,0,127}));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(points=
                   {{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},{
                    219,-80},{219,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120},{219,-120}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end test_wHPHeffectiveness;

          model test_wFWsensitivity
            "Model of the high pressure parto of the OTSG for to check the sensitivity of the degree of superheating against the FW flow"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-158,150},{
                      -138,170}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{262,130},{242,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes         OTSG
                                                     annotation (Placement(
                  transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                  IPTurb.Pm))
              annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,210})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,60})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,0})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-80})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-120})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Sources.Step dw_MS(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-320,42},{-300,62}})));
            Modelica.Blocks.Sources.Step dY_t(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
            Modelica.Blocks.Sources.Step dtheta_BP(
              offset=0,
              height=0,
              startTime=5000)
                        annotation (Placement(transformation(extent={{-320,-140},
                      {-300,-120}})));
            Modelica.Blocks.Sources.Ramp dw_FW(
              offset=0,
              duration=10000,
              height=-0.01,
              startTime=5000)
                        annotation (Placement(transformation(extent={{-320,-80},
                      {-300,-60}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400; 30,
                  622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,764100; 90,
                  783800; 100,803100]) annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
                                                                controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              load_start=100,
              Nd_pumpFW=30,
              Nd_pumpMS=20,
              useTS_pumpMS=true,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=1,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              useTS_valveBP=true,
              TS_valveBP=0,
              Td_pumpFW=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              useTS_pumpFW=true,
              load_end=100,
              t_ramp=0,
              t_start_ramp=0,
              useTS_valveTURB=true,
              Kp_pumpMS=4.57e-4,
              Ti_pumpMS=98.66,
              Td_pumpMS=1.128,
              CSmin_pumpMS=-0.5,
              CSmax_pumpMS=0.5,
              Kp_valveTURB=-1.077e-11,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1e-5,
              CSmax_valveTURB=1e-5,
              DT_SH_sp=20,
              Kp_pumpFW=-0.001,
              CSmax_pumpFW=0.3,
              Kp_valveBP=-7.93e-6,
              Ti_valveBP=0.001,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              TS_start=false,
              t_start_ramp_TS=5000,
              Ti_pumpFW=250,
              T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-200,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-138,160},{-128.889,160},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                    140},{210.1,140},{242,140}},       color={0,0,0}));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                    {279,210},{262,210}},color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                    279,60},{262,60}},
                                   color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                    279,0},{262,0}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(points=
                   {{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},{
                    219,-80},{219,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120},{219,-120}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-198.5,-40},{-184,-40},{-184,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(dw_MS.y, controllers.du_w_MS) annotation (Line(points={{
                    -299,52},{-272,52},{-272,-24},{-261.5,-24}}, color={0,0,127}));
            connect(dY_t.y, controllers.du_Y_t) annotation (Line(points={{-299,
                    -10},{-290,-10},{-280,-10},{-280,-34.6667},{-261.5,-34.6667}},
                  color={0,0,127}));
            connect(dw_FW.y, controllers.du_w_FW) annotation (Line(points={{-299,
                    -70},{-280,-70},{-280,-45.3333},{-261.5,-45.3333}},
                  color={0,0,127}));
            connect(dtheta_BP.y, controllers.du_thetaBP) annotation (Line(
                  points={{-299,-130},{-270,-130},{-270,-56},{-261.5,-56}},
                  color={0,0,127}));
            connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                    20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=40000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end test_wFWsensitivity;

          model test_step_smallHEs_notWorking
            "Model of the high pressure parto of the OTSG for to check the sensitivity of step responses against the HEs dimensions"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-158,150},{
                      -138,170}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{262,130},{242,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes         OTSG(
              EVA1(
                Vhot=31.955*0.5,
                Vcold=9.805*0.5,
                Shot=2834.1*0.5,
                Scold=2108.5*0.5,
                Mm=62846*0.5), ECO(
                Vhot=44.506*0.5,
                Vcold=5.73*0.5,
                Shot=2385*0.5,
                Scold=1848*0.5,
                Mm=30279*0.5)) annotation (Placement(transformation(extent={{-160,
                      -160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs(HPH2(nominalHotPressure=7500000, p_start=7500000))
              annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                  IPTurb.Pm))
              annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,210})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,60})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,0})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-80})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-120})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Sources.Step dw_MS(
              offset=0,
              height=10,
              startTime=5000)
              annotation (Placement(transformation(extent={{-320,40},{-300,60}})));
            Modelica.Blocks.Sources.Step dY_t(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
            Modelica.Blocks.Sources.Step dtheta_BP(
              offset=0,
              height=0,
              startTime=5000)
                        annotation (Placement(transformation(extent={{-320,-140},
                      {-300,-120}})));
            Modelica.Blocks.Sources.Ramp dw_FW(
              offset=0,
              duration=0,
              startTime=5000,
              height=00)
                        annotation (Placement(transformation(extent={{-320,-80},
                      {-300,-60}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400; 30,
                  622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,764100; 90,
                  783800; 100,803100]) annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
                                                                controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              load_start=100,
              Nd_pumpFW=30,
              Nd_pumpMS=20,
              useTS_pumpMS=true,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=1,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              useTS_valveBP=true,
              TS_valveBP=0,
              Td_pumpFW=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              useTS_pumpFW=true,
              load_end=100,
              t_ramp=0,
              t_start_ramp=0,
              useTS_valveTURB=true,
              Kp_pumpMS=4.57e-4,
              Ti_pumpMS=98.66,
              Td_pumpMS=1.128,
              CSmin_pumpMS=-0.5,
              CSmax_pumpMS=0.5,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1e-5,
              CSmax_valveTURB=1e-5,
              DT_SH_sp=20,
              CSmax_pumpFW=0.3,
              Kp_valveBP=-7.93e-6,
              Ti_valveBP=0.001,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              TS_start=false,
              t_start_ramp_TS=1e5,
              Kp_valveTURB=-1.077e-11,
              Ti_pumpFW=50,
              Kp_pumpFW=-0.01,
              T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-200,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-138,160},{-128.889,160},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                    140},{210.1,140},{242,140}},       color={0,0,0}));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                    {279,210},{262,210}},color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                    279,60},{262,60}},
                                   color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                    279,0},{262,0}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(points=
                   {{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},{
                    219,-80},{219,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120},{219,-120}}, color={0,0,127}));
            connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                    20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
            connect(dw_MS.y, controllers.du_w_MS) annotation (Line(points={{
                    -299,50},{-270,50},{-270,-24},{-261.5,-24}}, color={0,0,127}));
            connect(dY_t.y, controllers.du_Y_t) annotation (Line(points={{-299,
                    -10},{-280,-10},{-280,-34.6667},{-261.5,-34.6667}}, color={
                    0,0,127}));
            connect(dw_FW.y, controllers.du_w_FW) annotation (Line(points={{-299,
                    -70},{-290,-70},{-280,-70},{-280,-45.3333},{-261.5,-45.3333}},
                                color={0,0,127}));
            connect(dtheta_BP.y, controllers.du_thetaBP) annotation (Line(
                  points={{-299,-130},{-270,-130},{-270,-56},{-261.5,-56}},
                  color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-198.5,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-198.5,-40},{-180,-40},{-180,-200},{100.556,-200},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end test_step_smallHEs_notWorking;

          model test_step_normalHEs
            "Model of the high pressure parto of the OTSG for to check the sensitivity of step responses against the HEs dimensions"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,152},
                      {-140,172}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{262,130},{242,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes         OTSG
                                                     annotation (Placement(
                  transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Sources.RealExpression Power_sensor(y=-(HPTurb.Pm +
                  IPTurb.Pm))
              annotation (Placement(transformation(extent={{-256,6},{-234,34}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,210})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,60})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,0})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-80})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=controllers.load_end - controllers.load_start,
              duration=controllers.t_ramp,
              offset=controllers.load_start,
              startTime=controllers.t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-120})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Sources.Step dw_MS(
              offset=0,
              startTime=5000,
              height=10)
              annotation (Placement(transformation(extent={{-320,40},{-300,60}})));
            Modelica.Blocks.Sources.Step dY_t(
              offset=0,
              height=0,
              startTime=5000)
              annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
            Modelica.Blocks.Sources.Step dtheta_BP(
              offset=0,
              height=0,
              startTime=5000)
                        annotation (Placement(transformation(extent={{-320,-140},
                      {-300,-120}})));
            Modelica.Blocks.Sources.Ramp dw_FW(
              offset=0,
              duration=0,
              startTime=5000,
              height=0) annotation (Placement(transformation(extent={{-320,-80},
                      {-300,-60}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400; 30,
                  622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,764100; 90,
                  783800; 100,803100]) annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.LinearizationSchemes.plant_controller_HPpart_lin_highLoad
                                                                controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_pumpFW=-0.3,
              CSstart_pumpFW=0,
              TS_pumpFW=0,
              CSstart_pumpMS=0,
              TS_pumpMS=0,
              CSstart_valveTURB=0,
              TS_valveTURB=0,
              load_start=100,
              Nd_pumpFW=30,
              Nd_pumpMS=20,
              useTS_pumpMS=true,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=1,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              useTS_valveBP=true,
              TS_valveBP=0,
              Td_pumpFW=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              useTS_pumpFW=true,
              load_end=100,
              t_ramp=0,
              t_start_ramp=0,
              useTS_valveTURB=true,
              Kp_pumpMS=4.57e-4,
              Ti_pumpMS=98.66,
              Td_pumpMS=1.128,
              CSmin_pumpMS=-0.5,
              CSmax_pumpMS=0.5,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1e-5,
              CSmax_valveTURB=1e-5,
              DT_SH_sp=20,
              Kp_pumpFW=-0.001,
              CSmax_pumpFW=0.3,
              Kp_valveBP=-7.93e-6,
              Ti_valveBP=0.001,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              TS_start=false,
              t_start_ramp_TS=1e5,
              Kp_valveTURB=-1.077e-11,
              Ti_pumpFW=50,
              T_FW_sp=518.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-200,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,162},{-128.889,162},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.flange_IP_out, constantSpeed.flange) annotation (Line(points={{210.1,
                    140},{210.1,140},{242,140}},       color={0,0,0}));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(LOAD1.y,IPTurb_sink. u[1]) annotation (Line(points={{279,210},
                    {279,210},{262,210}},color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(LOAD2.y,SP3_sink. u[1]) annotation (Line(points={{279,60},{
                    279,60},{262,60}},
                                   color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1]) annotation (Line(points={{279,0},{
                    279,0},{262,0}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(points=
                   {{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},{
                    219,-80},{219,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120},{219,-120}}, color={0,0,127}));
            connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(points={{-232.9,
                    20},{-230,20},{-230,-18.6667}},         color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-198.5,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-198.5,-40},{-180,-40},{-180,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(dw_MS.y, controllers.du_w_MS) annotation (Line(points={{
                    -299,50},{-270,50},{-270,-24},{-261.5,-24}}, color={0,0,127}));
            connect(dY_t.y, controllers.du_Y_t) annotation (Line(points={{-299,
                    -10},{-280,-10},{-280,-34.6667},{-261.5,-34.6667}}, color={
                    0,0,127}));
            connect(dw_FW.y, controllers.du_w_FW) annotation (Line(points={{-299,
                    -70},{-280,-70},{-280,-45.3333},{-261.5,-45.3333}},
                  color={0,0,127}));
            connect(dtheta_BP.y, controllers.du_thetaBP) annotation (Line(
                  points={{-299,-130},{-288,-130},{-270,-130},{-270,-56},{
                    -261.5,-56}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end test_step_normalHEs;
        end Sensitivity;

        package Drainage
          "Package containing models to test the drainage procedures of MS and FW"
          model test_FWdepressurization_withMS
            "Test that evaluates the depressurization of the FW cycle with MS (at 1%) on hot side"

            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1062.9e3,
              w0=115.85,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{80,-100},{60,-120}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=84.94,
              h=3103000,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{100,-40},{80,-20}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=4732000)
              annotation (Placement(transformation(extent={{-40,10},{-60,30}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=1050000,
              h=519092)   annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));

            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000)  annotation (Placement(transformation(extent={{-40,-160},{-60,-140}})));

            inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-280,240},{-260,260}})));
            ThermoPower.Water.SinkPressure sinkHPH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17350000)
              annotation (Placement(transformation(extent={{40,-160},{60,-140}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=17000000)
              annotation (Placement(transformation(extent={{40,210},{60,230}})));
            ThermoPower.Water.ThroughMassFlow pump_HPH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=24.51)
              annotation (Placement(transformation(extent={{0,-140},{20,-160}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_drainage
              controlSystem(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSstart_valveTURB=0,
              t_ramp=0,
              load_start=100,
              load_end=100,
              t_start_ramp=0,
              Kp_valveBP_SH=-0.00001,
              Ti_valveBP_SH=10,
              Td_valveBP_SH=0,
              Nd_valveBP_SH=20,
              CSmax_valveBP_SH=1,
              CSstart_valveBP_SH=0,
              actuatorGain_valveBP_SH=1,
              Ta_valveBP_SH=0.3,
              useTS_valveBP_SH=true,
              TS_valveBP_SH=0,
              Kp_valveBP_RH=-0.00001,
              Ti_valveBP_RH=10,
              Td_valveBP_RH=0,
              Nd_valveBP_RH=30,
              CSmax_valveBP_RH=0,
              CSstart_valveBP_RH=0,
              actuatorGain_valveBP_RH=1,
              Ta_valveBP_RH=0.3,
              useTS_valveBP_RH=true,
              TS_start=false,
              TS_valveBP_RH=0,
              actuatorGain_valveINT_IPT=1,
              Ta_valveINT_IPT=0.3,
              TS_valveTURB=0.01,
              t_start_drain=0,
              CSmin_valveBP_SH=0,
              CSmin_valveBP_RH=0,
              l_sep_SP=0.5,
              w_SEPmax=100,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Ta_pumpFW=2,
              Kp_pumpFW_high=-0.001,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              TS_pumpFW_high=0,
              useTS_pumpFW_high=true,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=110,
              CSstart_pumpFW_low=47,
              useTS_pumpFW_low=true,
              TS_pumpFW_low=47,
              useTS_valveTURB=false,
              DT_SH_sp(displayUnit="K") = 20,
              Ti_pumpFW_high=50,
              Kp_valveTURB=-1.077e-11,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1,
              CSmax_valveTURB=1,
              Kp_pumpFW_low=17.6,
              Ti_pumpFW_low=50,
              useSEP=true,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              CSstart_pumpFW_high=0,
              p_SH_sp=17100000,
              p_RH_sp=4732000) annotation (Placement(transformation(extent={{-120,
                      -92},{-96,-68}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes_drain OTSG(t_switch=1e5)
              annotation (Placement(transformation(extent={{-40,-134},{26,-26}})));
            ThermoPower.Water.ValveVap valveTURB(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=90,
                  origin={12,200})));
            ThermoPower.Water.ValveVap valveBP_SH(
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CheckValve=true,
              Av=6.9222e-3,
              pnom=17100000,
              dpnom=100000,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=0,
                  origin={40,106})));
            ThermoPower.Water.ValveVap valveBP_RH(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=2.42922e-3,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,60})));
            ThermoPower.Water.ValveVap valveSEC(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=91.28*0.2,
              CheckValve=true,
              Av=1.38203e-3,
              pnom=17100000,
              dpnom=100000)    annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-8,106})));
            ThermoPower.Water.SinkPressure sinkATM(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=92600)
              annotation (Placement(transformation(extent={{-40,96},{-60,116}})));
            Modelica.Blocks.Sources.Step valveTRIP(
              height=1,
              offset=0,
              startTime=controlSystem.t_start_drain)
              annotation (Placement(transformation(extent={{-40,130},{-20,150}})));
            Modelica.Blocks.Sources.Step step(
              offset=84.94,
              startTime=controlSystem.t_start_drain,
              height=-84.93)
              annotation (Placement(transformation(extent={{150,0},{130,20}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{120,0},{100,20}})));
            ThermoPower.Water.SinkPressure cond(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=300000)
                       annotation (Placement(transformation(extent={{-40,50},{-60,70}})));
            ThermoPower.Water.ValveVap valveINT_IPT(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              Av=0.1,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,20})));
            ThermoPower.Water.SensP sensP(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{6,54},{-14,74}})));
          equation
            connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                points={{20,-150},{40,-150}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                points={{-80,-80},{-80,-190},{6,-190},{6,-156}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus,signalBus)  annotation (Line(
                points={{-95.4,-80},{-95.4,-80},{-80,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus, OTSG.signalBus) annotation (Line(
                points={{-95.4,-80},{-42.5667,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-110},{60,-110}},
                                                   color={0,0,255}));
            connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-94.4},{27.8333,-94.4}},
                                                     color={0,0,255}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -25.3333,-135.8},{-25.3333,-150},{-40,-150}},
                                          color={0,0,255}));
            connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                    -3.33333,-135.8},{-3.33333,-150},{0,-150}},
                                                 color={0,0,255}));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,-190},{74,-190},{74,-116}},
                color={255,204,51},
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,-10},
                    {-26,-10},{-26,-24.2},{-25.3333,-24.2}},
                                                   color={0,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,4},{-80,200},{5.6,200}},
                color={255,204,51},
                thickness=0.5));
            connect(sinkATM.flange, valveSEC.outlet)
              annotation (Line(points={{-40,106},{-28,106},{-16,106}}, color={0,0,255}));
            connect(valveTURB.outlet, sinkSH.flange)
              annotation (Line(points={{12,208},{12,220},{40,220}}, color={0,0,255}));
            connect(valveTRIP.y, valveSEC.theta) annotation (Line(points={{-19,140},{-14,140},
                    {-8,140},{-8,112.4}}, color={0,0,127}));
            connect(valveBP_SH.outlet, OTSG.RH_in) annotation (Line(points={{48,106},
                    {60,106},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(sourceRH.flange, OTSG.RH_in) annotation (Line(points={{80,-30},
                    {60,-30},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(OTSG.SH_out, valveTURB.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,105.9},{12,105.9},{12,192}},
                                                          color={0,0,255}));
            connect(OTSG.SH_out, valveBP_SH.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{32,106}},
                                             color={0,0,255}));
            connect(OTSG.SH_out, valveSEC.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{0,106}},
                                           color={0,0,255}));
            connect(firstOrder.u, step.y)
              annotation (Line(points={{122,10},{129,10}}, color={0,0,127}));
            connect(firstOrder.y, sourceRH.in_w0)
              annotation (Line(points={{99,10},{94,10},{94,-24}}, color={0,0,127}));
            connect(cond.flange, valveBP_RH.outlet)
              annotation (Line(points={{-40,60},{-34,60},{-28,60}}, color={0,0,255}));
            connect(sinkRH.flange, valveINT_IPT.outlet)
              annotation (Line(points={{-40,20},{-34,20},{-28,20}}, color={0,0,255}));
            connect(OTSG.RH_out, valveINT_IPT.inlet) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,20},{-12,20}},
                                             color={0,0,255}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,160},{40,160},{40,112.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-20,80},{-20,66.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,40},{-20,40},{-20,26.4}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, valveBP_RH.inlet)
              annotation (Line(points={{-4,60},{-12,60}}, color={0,0,255}));
            connect(OTSG.RH_out, sensP.flange) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,60},{-4,60}},
                                  color={0,0,255}));
            connect(signalBus.valveBP_RH_PV, sensP.p) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-12,80},{-12,70}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -260},{280,260}}), graphics={Text(
                    extent={{-240,208},{-132,84}},
                    lineColor={28,108,200},
                    textString="In 11 min la pressione scende a 80 bar, se si
ricircoli la portata al separatore. Valvole gi� 
tarate correttamente, il loro controllo di fatto 
le porta a chiudersi subito per tenere su la pressione.
Se non ricircolo si riempie il separatore...")}),          Icon(coordinateSystem(
                    extent={{-280,-260},{280,260}})),
              experiment(
                StartTime=-7500,
                StopTime=650,
                __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(revisions="<html>
</html>", info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
          end test_FWdepressurization_withMS;

          model test_FWdepressurization_steamOnly_worseCase_100
            "Test that evaluates the depressurization of the FW cycle with MS (at 1%) on hot side"

            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1062.9e3,
              w0=115.85,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{80,-100},{60,-120}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=84.94,
              h=3103000,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{100,-40},{80,-20}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=4732000)
              annotation (Placement(transformation(extent={{-40,10},{-60,30}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=1050000,
              h=519092)   annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));

            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000)  annotation (Placement(transformation(extent={{-40,-160},{-60,-140}})));

            inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-280,240},{-260,260}})));
            ThermoPower.Water.SinkPressure sinkHPH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17350000)
              annotation (Placement(transformation(extent={{40,-160},{60,-140}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=17000000)
              annotation (Placement(transformation(extent={{40,210},{60,230}})));
            ThermoPower.Water.ThroughMassFlow pump_HPH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=24.51)
              annotation (Placement(transformation(extent={{0,-140},{20,-160}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_drainage
              controlSystem(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSstart_valveTURB=0,
              t_ramp=0,
              load_start=100,
              load_end=100,
              t_start_ramp=0,
              Kp_valveBP_SH=-0.00001,
              Ti_valveBP_SH=10,
              Td_valveBP_SH=0,
              Nd_valveBP_SH=20,
              CSmax_valveBP_SH=1,
              CSstart_valveBP_SH=0,
              actuatorGain_valveBP_SH=1,
              Ta_valveBP_SH=0.3,
              useTS_valveBP_SH=true,
              TS_valveBP_SH=0,
              Kp_valveBP_RH=-0.00001,
              Ti_valveBP_RH=10,
              Td_valveBP_RH=0,
              Nd_valveBP_RH=30,
              CSmax_valveBP_RH=0,
              CSstart_valveBP_RH=0,
              actuatorGain_valveBP_RH=1,
              Ta_valveBP_RH=0.3,
              useTS_valveBP_RH=true,
              TS_start=false,
              TS_valveBP_RH=0,
              actuatorGain_valveINT_IPT=1,
              Ta_valveINT_IPT=0.3,
              TS_valveTURB=0.01,
              t_start_drain=0,
              CSmin_valveBP_SH=0,
              CSmin_valveBP_RH=0,
              l_sep_SP=0.5,
              w_SEPmax=100,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Ta_pumpFW=2,
              Kp_pumpFW_high=-0.001,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              TS_pumpFW_high=0,
              useTS_pumpFW_high=true,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=110,
              CSstart_pumpFW_low=47,
              useTS_pumpFW_low=true,
              TS_pumpFW_low=47,
              useTS_valveTURB=false,
              DT_SH_sp(displayUnit="K") = 20,
              Ti_pumpFW_high=50,
              Kp_valveTURB=-1.077e-11,
              Ti_valveTURB=2.164,
              CSmin_valveTURB=-1,
              CSmax_valveTURB=1,
              Kp_pumpFW_low=17.6,
              Ti_pumpFW_low=50,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              CSstart_pumpFW_high=0,
              useSEP=true,
              p_SH_sp=17100000,
              p_RH_sp=4732000) annotation (Placement(transformation(extent={{-120,
                      -92},{-96,-68}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes_drain OTSG(t_switch=0)
              annotation (Placement(transformation(extent={{-40,-134},{26,-26}})));
            ThermoPower.Water.ValveVap valveTURB(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=90,
                  origin={12,200})));
            ThermoPower.Water.ValveVap valveBP_SH(
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CheckValve=true,
              Av=6.9222e-3,
              pnom=17100000,
              dpnom=100000,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=0,
                  origin={40,106})));
            ThermoPower.Water.ValveVap valveBP_RH(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=2.42922e-3,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,60})));
            ThermoPower.Water.ValveVap valveSEC(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=91.28*0.2,
              CheckValve=true,
              Av=1.38203e-3,
              pnom=17100000,
              dpnom=100000)    annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-8,106})));
            ThermoPower.Water.SinkPressure sinkATM(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=92600)
              annotation (Placement(transformation(extent={{-40,96},{-60,116}})));
            Modelica.Blocks.Sources.Step valveTRIP(
              height=1,
              offset=0,
              startTime=controlSystem.t_start_drain)
              annotation (Placement(transformation(extent={{-40,130},{-20,150}})));
            Modelica.Blocks.Sources.Step step(
              offset=84.94,
              startTime=controlSystem.t_start_drain,
              height=-84.93)
              annotation (Placement(transformation(extent={{150,0},{130,20}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{120,0},{100,20}})));
            ThermoPower.Water.SinkPressure cond(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=300000)
                       annotation (Placement(transformation(extent={{-40,50},{-60,70}})));
            ThermoPower.Water.ValveVap valveINT_IPT(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              Av=0.1,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,20})));
            ThermoPower.Water.SensP sensP(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{6,54},{-14,74}})));
          equation
            connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                points={{20,-150},{40,-150}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                points={{-80,-80},{-80,-190},{6,-190},{6,-156}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus,signalBus)  annotation (Line(
                points={{-95.4,-80},{-95.4,-80},{-80,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus, OTSG.signalBus) annotation (Line(
                points={{-95.4,-80},{-42.5667,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-110},{60,-110}},
                                                   color={0,0,255}));
            connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-94.4},{27.8333,-94.4}},
                                                     color={0,0,255}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -25.3333,-135.8},{-25.3333,-150},{-40,-150}},
                                          color={0,0,255}));
            connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                    -3.33333,-135.8},{-3.33333,-150},{0,-150}},
                                                 color={0,0,255}));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,-190},{74,-190},{74,-116}},
                color={255,204,51},
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,-10},
                    {-26,-10},{-26,-24.2},{-25.3333,-24.2}},
                                                   color={0,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,4},{-80,200},{5.6,200}},
                color={255,204,51},
                thickness=0.5));
            connect(sinkATM.flange, valveSEC.outlet)
              annotation (Line(points={{-40,106},{-28,106},{-16,106}}, color={0,0,255}));
            connect(valveTURB.outlet, sinkSH.flange)
              annotation (Line(points={{12,208},{12,220},{40,220}}, color={0,0,255}));
            connect(valveTRIP.y, valveSEC.theta) annotation (Line(points={{-19,140},{-14,140},
                    {-8,140},{-8,112.4}}, color={0,0,127}));
            connect(valveBP_SH.outlet, OTSG.RH_in) annotation (Line(points={{48,106},
                    {60,106},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(sourceRH.flange, OTSG.RH_in) annotation (Line(points={{80,-30},
                    {60,-30},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(OTSG.SH_out, valveTURB.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,105.9},{12,105.9},{12,192}},
                                                          color={0,0,255}));
            connect(OTSG.SH_out, valveBP_SH.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{32,106}},
                                             color={0,0,255}));
            connect(OTSG.SH_out, valveSEC.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{0,106}},
                                           color={0,0,255}));
            connect(firstOrder.u, step.y)
              annotation (Line(points={{122,10},{129,10}}, color={0,0,127}));
            connect(firstOrder.y, sourceRH.in_w0)
              annotation (Line(points={{99,10},{94,10},{94,-24}}, color={0,0,127}));
            connect(cond.flange, valveBP_RH.outlet)
              annotation (Line(points={{-40,60},{-34,60},{-28,60}}, color={0,0,255}));
            connect(sinkRH.flange, valveINT_IPT.outlet)
              annotation (Line(points={{-40,20},{-34,20},{-28,20}}, color={0,0,255}));
            connect(OTSG.RH_out, valveINT_IPT.inlet) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,20},{-12,20}},
                                             color={0,0,255}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,160},{40,160},{40,112.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-20,80},{-20,66.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,40},{-20,40},{-20,26.4}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, valveBP_RH.inlet)
              annotation (Line(points={{-4,60},{-12,60}}, color={0,0,255}));
            connect(OTSG.RH_out, sensP.flange) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,60},{-4,60}},
                                  color={0,0,255}));
            connect(signalBus.valveBP_RH_PV, sensP.p) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-12,80},{-12,70}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -260},{280,260}}), graphics={Text(
                    extent={{-238,206},{-106,98}},
                    lineColor={28,108,200},
                    textString="In 7 min la pressione scende a 57 bar.
Anche qui se non attivo il ricircolo 
il separatore si riempie."), Text(
                    extent={{124,194},{228,94}},
                    lineColor={255,0,0},
                    lineThickness=0.5,
                    textString="-0.3 bar/s")}),            Icon(coordinateSystem(
                    extent={{-280,-260},{280,260}})),
              experiment(
                StartTime=-7500,
                StopTime=650,
                __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(revisions="<html>
</html>", info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
          end test_FWdepressurization_steamOnly_worseCase_100;

          model test_FWdepressurization_steamOnly_worseCase_50
            "Test that evaluates the depressurization of the FW cycle with MS (at 1%) on hot side"

            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=115.85,
              use_in_w0=true,
              h=1077.2e3)
              annotation (Placement(transformation(extent={{80,-100},{60,-120}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=39.99,
              h=3152000)
              annotation (Placement(transformation(extent={{100,-40},{80,-20}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2266000)
              annotation (Placement(transformation(extent={{-40,10},{-60,30}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=1050000,
              h=519092)   annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));

            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000)  annotation (Placement(transformation(extent={{-40,-160},{-60,-140}})));

            inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-280,240},{-260,260}})));
            ThermoPower.Water.SinkPressure sinkHPH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=9200000)
              annotation (Placement(transformation(extent={{40,-160},{60,-140}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8800000)
              annotation (Placement(transformation(extent={{40,210},{60,230}})));
            ThermoPower.Water.ThroughMassFlow pump_HPH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=24.51)
              annotation (Placement(transformation(extent={{0,-140},{20,-160}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_drainage
              controlSystem(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSstart_valveTURB=0,
              t_ramp=0,
              t_start_ramp=0,
              Kp_valveBP_SH=-0.00001,
              Ti_valveBP_SH=10,
              Td_valveBP_SH=0,
              Nd_valveBP_SH=20,
              CSmax_valveBP_SH=1,
              CSstart_valveBP_SH=0,
              actuatorGain_valveBP_SH=1,
              Ta_valveBP_SH=0.3,
              useTS_valveBP_SH=true,
              TS_valveBP_SH=0,
              Kp_valveBP_RH=-0.00001,
              Ti_valveBP_RH=10,
              Td_valveBP_RH=0,
              Nd_valveBP_RH=30,
              CSmax_valveBP_RH=0,
              CSstart_valveBP_RH=0,
              actuatorGain_valveBP_RH=1,
              Ta_valveBP_RH=0.3,
              useTS_valveBP_RH=true,
              TS_start=false,
              TS_valveBP_RH=0,
              actuatorGain_valveINT_IPT=1,
              Ta_valveINT_IPT=0.3,
              TS_valveTURB=0.01,
              t_start_drain=0,
              CSmin_valveBP_SH=0,
              CSmin_valveBP_RH=0,
              l_sep_SP=0.5,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Ta_pumpFW=2,
              Kp_pumpFW_high=-0.001,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              TS_pumpFW_high=0,
              useTS_pumpFW_high=true,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmax_pumpFW_low=110,
              CSstart_pumpFW_low=47,
              useTS_pumpFW_low=true,
              TS_pumpFW_low=47,
              useTS_valveTURB=false,
              DT_SH_sp(displayUnit="K") = 20,
              Ti_pumpFW_high=50,
              CSmin_valveTURB=-1,
              CSmax_valveTURB=1,
              Kp_pumpFW_low=17.6,
              Ti_pumpFW_low=50,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              CSstart_pumpFW_high=0,
              load_start=50,
              load_end=50,
              Ti_valveTURB=3.626,
              Kp_valveTURB=-1.5e-11,
              CSmin_pumpFW_low=5,
              w_SEPmax=100,
              useSEP=false,
              const(offset=80, height=-80),
              p_SH_sp=8882000,
              p_RH_sp=2266000,
              step4(height=1)) annotation (Placement(transformation(extent={{-120,
                      -92},{-96,-68}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_drain  OTSG(t_switch=0,
                valveLiq(Av=3.7e-5*20))
              annotation (Placement(transformation(extent={{-40,-134},{26,-26}})));
            ThermoPower.Water.ValveVap valveTURB(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=90,
                  origin={12,200})));
            ThermoPower.Water.ValveVap valveBP_SH(
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CheckValve=true,
              Av=6.9222e-3,
              pnom=17100000,
              dpnom=100000,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=0,
                  origin={40,106})));
            ThermoPower.Water.ValveVap valveBP_RH(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=2.42922e-3,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,60})));
            ThermoPower.Water.ValveVap valveSEC(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=91.28*0.2,
              CheckValve=true,
              Av=1.38203e-3,
              pnom=17100000,
              dpnom=100000)    annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-8,106})));
            ThermoPower.Water.SinkPressure sinkATM(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=92600)
              annotation (Placement(transformation(extent={{-40,96},{-60,116}})));
            Modelica.Blocks.Sources.Step valveTRIP(
              height=1,
              offset=0,
              startTime=controlSystem.t_start_drain)
              annotation (Placement(transformation(extent={{-40,130},{-20,150}})));
            Modelica.Blocks.Sources.Step step(
              startTime=controlSystem.t_start_drain,
              offset=39.99,
              height=-39.98)
              annotation (Placement(transformation(extent={{150,0},{130,20}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{120,0},{100,20}})));
            ThermoPower.Water.SinkPressure cond(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=300000)
                       annotation (Placement(transformation(extent={{-40,50},{-60,70}})));
            ThermoPower.Water.ValveVap valveINT_IPT(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              Av=0.1,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,20})));
            ThermoPower.Water.SensP sensP(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{6,54},{-14,74}})));
          equation
            connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                points={{20,-150},{40,-150}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                points={{-80,-80},{-80,-190},{6,-190},{6,-156}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus,signalBus)  annotation (Line(
                points={{-95.4,-80},{-95.4,-80},{-80,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus, OTSG.signalBus) annotation (Line(
                points={{-95.4,-80},{-42.5667,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-110},{60,-110}},
                                                   color={0,0,255}));
            connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-94.4},{27.8333,-94.4}},
                                                     color={0,0,255}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -25.3333,-135.8},{-25.3333,-150},{-40,-150}},
                                          color={0,0,255}));
            connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                    -3.33333,-135.8},{-3.33333,-150},{0,-150}},
                                                 color={0,0,255}));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,-190},{74,-190},{74,-116}},
                color={255,204,51},
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,-10},
                    {-26,-10},{-26,-24.2},{-25.3333,-24.2}},
                                                   color={0,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,4},{-80,200},{5.6,200}},
                color={255,204,51},
                thickness=0.5));
            connect(sinkATM.flange, valveSEC.outlet)
              annotation (Line(points={{-40,106},{-28,106},{-16,106}}, color={0,0,255}));
            connect(valveTURB.outlet, sinkSH.flange)
              annotation (Line(points={{12,208},{12,220},{40,220}}, color={0,0,255}));
            connect(valveTRIP.y, valveSEC.theta) annotation (Line(points={{-19,140},{-14,140},
                    {-8,140},{-8,112.4}}, color={0,0,127}));
            connect(valveBP_SH.outlet, OTSG.RH_in) annotation (Line(points={{48,106},
                    {60,106},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(sourceRH.flange, OTSG.RH_in) annotation (Line(points={{80,-30},
                    {60,-30},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(OTSG.SH_out, valveTURB.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,105.9},{12,105.9},{12,192}},
                                                          color={0,0,255}));
            connect(OTSG.SH_out, valveBP_SH.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{32,106}},
                                             color={0,0,255}));
            connect(OTSG.SH_out, valveSEC.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{0,106}},
                                           color={0,0,255}));
            connect(firstOrder.u, step.y)
              annotation (Line(points={{122,10},{129,10}}, color={0,0,127}));
            connect(firstOrder.y, sourceRH.in_w0)
              annotation (Line(points={{99,10},{94,10},{94,-24}}, color={0,0,127}));
            connect(cond.flange, valveBP_RH.outlet)
              annotation (Line(points={{-40,60},{-34,60},{-28,60}}, color={0,0,255}));
            connect(sinkRH.flange, valveINT_IPT.outlet)
              annotation (Line(points={{-40,20},{-34,20},{-28,20}}, color={0,0,255}));
            connect(OTSG.RH_out, valveINT_IPT.inlet) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,20},{-12,20}},
                                             color={0,0,255}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,160},{40,160},{40,112.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-20,80},{-20,66.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,40},{-20,40},{-20,26.4}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, valveBP_RH.inlet)
              annotation (Line(points={{-4,60},{-12,60}}, color={0,0,255}));
            connect(OTSG.RH_out, sensP.flange) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,60},{-4,60}},
                                  color={0,0,255}));
            connect(signalBus.valveBP_RH_PV, sensP.p) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-12,80},{-12,70}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -260},{280,260}}), graphics={Text(
                    extent={{-238,206},{-140,100}},
                    lineColor={28,108,200},
                    textString="In 1,5 min la pressione scende a 62 bar. 
Il separatore tende a riempirsi molto in 
fretta a causa del liquido che arriva dagli
evaporatori."), Text(
                    extent={{124,210},{228,110}},
                    lineColor={255,0,0},
                    lineThickness=0.5,
                    textString="-0.3 bar/s")}),            Icon(coordinateSystem(
                    extent={{-280,-260},{280,260}})),
              experiment(
                StartTime=-7500,
                StopTime=650,
                __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(revisions="<html>
</html>", info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
          end test_FWdepressurization_steamOnly_worseCase_50;
        end Drainage;

        package Primary_frequency
          "Package containing models to test the primary frequency control capacity of the power plant"

          model test_LP_primaryLoad
            "Test model to check the power output increase against the closure of the steam extraction valves or the reduction of the feedwater mass flow"

            Modelica.SIunits.Power Pm_IPT_LPT = -(IPTurb.Pm + LPTurb.Pm);
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{-58,90},{-18,130}})));
            SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
              annotation (Placement(transformation(extent={{10,90},{50,130}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{160,100},{140,120}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=12600,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{66,140},{86,160}})));
            ThermoPower.Water.SourcePressure sourcePressure(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3554000,
              p0=4732000,
              use_in_p0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-100,140},{-80,160}})));
            ThermoPower.Water.SinkPressure sinkPressure4(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=1815000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-80,70},{-100,90}})));
            inner ThermoPower.System system annotation (Placement(transformation(
                    extent={{-340,220},{-320,240}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
              LPHs(
              SP4(p(start=3.276e5, fixed=true)),
              SP5(p(start=1.893e5, fixed=true)),
              SP6(p(start=0.5515e5, fixed=true))) annotation (Placement(
                  transformation(extent={{-52,-100},{134,-20}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{160,-46},{180,-26}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              p0=900000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{180,-50},{160,-70}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-230,-50})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,0})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{200,-10},{180,10}})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceW_DR(table=[20,2.045;
                  30,3.451; 40,5.095; 50,7.013; 60,9.065; 70,8.388; 80,9.029; 90,
                  8.921; 100,7.484]) annotation (Placement(transformation(extent=
                      {{-200,-60},{-180,-40}})));
            HeatExchangers.Components.Deaerator
                      deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              h_start=1.2e6,
              noInitialPressure=true,
              p_start=1086000,
              w_small=1e4)
              annotation (Placement(transformation(extent={{-146,-112},{-78,-46}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=7.484,
              h=821.9e3,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-180,-90},{-160,-70}})));
            ThermoPower.Water.SinkMassFlow    waterPump(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=91.28,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-112,-206})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-230,-10})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceH_DR(table=[20,565.6e3;
                  30,626.7e3; 40,670.9e3; 50,708.6e3; 60,741.2e3; 70,766.4e3; 80,
                  788.3e3; 90,807.7e3; 100,821.9e3]) annotation (Placement(
                  transformation(extent={{-200,-20},{-180,0}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-150,210})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceH_IPTurb(table=[20,
                  3617e3; 30,3611e3; 40,3604e3; 50,3597e3; 60,3589e3; 70,3579e3;
                  80,3571e3; 90,3562e3; 100,3552e3]) annotation (Placement(
                  transformation(extent={{-120,200},{-100,220}})));
            Auxiliaries.Components.loadCalculator loadCalc(
              t_ramp=0,
              t_start=0,
              load_start=97,
              load_end=97) annotation (Placement(transformation(extent={{-240,-160},
                      {-200,-120}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-150,180})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceP_IPTurb(table=[20,
                  8.839e5; 30,13.32e5; 40,17.87e5; 50,22.66e5; 60,27.45e5; 70,
                  32.69e5; 80,37.23e5; 90,42.09e5; 100,47.32e5]) annotation (
                Placement(transformation(extent={{-120,170},{-100,190}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-150,110})));
            Modelica.Blocks.Tables.CombiTable1D dea_sinkP_SP3(table=[20,3.594e5;
                  30,5.378e5; 40,7.149e5; 50,8.978e5; 60,10.78e5; 70,12.74e5; 80,
                  14.41e5; 90,16.22e5; 100,18.15e5]) annotation (Placement(
                  transformation(extent={{-120,100},{-100,120}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={130,180})));
            Modelica.Blocks.Tables.CombiTable1D dea_sinkP_LPTurb(table=[20,
                  0.051e5; 30,0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,
                  0.0932e5; 80,0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{100,170},{80,190}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={230,-212})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{200,-222},{180,-202}})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
              CSmin=0,
              CSmax=100,
              Ti=10000,
              Kp=-500,
              AntiWindup=true,
              CS_start=91,
              useTS=true)    annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-70,-150})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=2)
                    annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-70,-182})));
            Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
              annotation (Placement(transformation(extent={{-36,-132},{-56,-112}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=0)
              annotation (Placement(transformation(extent={{0,-164},{-20,-144}})));
            Modelica.Mechanics.Rotational.Sensors.PowerSensor powerSensor
              annotation (Placement(transformation(extent={{80,100},{100,120}})));
            Modelica.Blocks.Sources.Ramp ramp1(
              offset=1,
              height=-0.99,
              startTime=0,
              duration=0)
              annotation (Placement(transformation(extent={{-160,10},{-140,30}})));
            ThermoPower.Water.ValveVap valveVap(
              Fxt_full=0.4542722663,
              Av=0.053642779,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=6.877,
              thetanom=1,
              useThetaInput=true,
              pnom=1100000,
              dpnom=10000)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-80,40})));
            ThermoPower.Water.ValveVap valveVap1(
              Fxt_full=0.4542722663,
              Av=0.053642779,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              wnom=2.475,
              useThetaInput=false,
              pnom=340000,
              dpnom=10000)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-12,40})));
            ThermoPower.Water.ValveVap valveVap2(
              Fxt_full=0.4542722663,
              Av=0.053642779,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              wnom=4.9,
              useThetaInput=false,
              pnom=200000,
              dpnom=10000)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={40,40})));
            ThermoPower.Water.ValveVap valveVap3(
              Fxt_full=0.4542722663,
              Av=0.053642779,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              wnom=3.8,
              useThetaInput=false,
              pnom=60000,
              dpnom=10000)
              annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={96,40})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic1(
                                                              k=1,
              T=0.3,
              initType=Modelica.Blocks.Types.Init.SteadyState)
                    annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-110,20})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={110,-230})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceW1(
                                                           table=[20,14.85; 30,
                  22.25; 40,29.67; 50,37.42; 60,45.15; 70,53.51; 80,60.78; 90,
                  68.59; 100,76.94]) annotation (Placement(transformation(
                    extent={{80,-240},{60,-220}})));
            Modelica.Blocks.Math.Product product1
                                                 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={50,-170})));
            Modelica.Blocks.Sources.Ramp ramp2(
              offset=1,
              height=-0.4,
              startTime=0,
              duration=0)
              annotation (Placement(transformation(extent={{100,-200},{80,-180}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic1(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=2)         annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=270,
                  origin={50,-140})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{42,-128},{58,-108}})));
          equation
            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
                points={{-16,110},{8,110}},
                color={0,0,0},
                smooth=Smooth.None));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{-16,122},{8,122}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourcePressure.flange, IPTurb.vap_in) annotation (Line(
                points={{-80,150},{-60,150},{-60,122}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sinkPressure4.flange, IPTurb.SP5) annotation (Line(points={
                    {-80,80},{-44.8,80},{-44.8,88}}, color={0,0,255}));
            connect(LPHs.FW_in,sourcePressure1. flange) annotation (Line(
                points={{137.875,-60},{160,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{179,0},{166,0},{166,-27.2}},  color={0,0,127}));
            connect(cond_sinkP.u[1],LOAD6. y)
              annotation (Line(points={{202,0},{219,0}},   color={0,0,127}));
            connect(LOAD3.y, dea_sourceW_DR.u[1]) annotation (Line(points={{-219,
                    -50},{-212,-50},{-208,-50},{-202,-50}}, color={0,0,127}));
            connect(deaerator.drained_in,sourceMassFlow_DR. flange) annotation (
                Line(
                points={{-143.571,-95.5},{-148,-95.5},{-148,-80},{-160,-80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.drained_out,waterPump. flange) annotation (Line(
                points={{-112,-104.929},{-112,-196}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(points={{
                    -103.257,-60.1429},{-76.143,-60.1429},{-76.143,-60},{
                    -55.875,-60}},
                           color={0,0,255}));
            connect(LOAD2.y, dea_sourceH_DR.u[1]) annotation (Line(points={{-219,
                    -10},{-210.5,-10},{-202,-10}}, color={0,0,127}));
            connect(dea_sourceW_DR.y[1], sourceMassFlow_DR.in_w0) annotation (
                Line(points={{-179,-50},{-174,-50},{-174,-74}}, color={0,0,127}));
            connect(dea_sourceH_DR.y[1], sourceMassFlow_DR.in_h) annotation (Line(
                  points={{-179,-10},{-166,-10},{-166,-74}}, color={0,0,127}));
            connect(LOAD5.y, dea_sourceH_IPTurb.u[1]) annotation (Line(points={{
                    -139,210},{-139,210},{-122,210}}, color={0,0,127}));
            connect(LOAD7.y, dea_sourceP_IPTurb.u[1]) annotation (Line(points={{
                    -139,180},{-139,180},{-122,180}}, color={0,0,127}));
            connect(dea_sourceP_IPTurb.y[1], sourcePressure.in_p0) annotation (
                Line(points={{-99,180},{-94,180},{-94,159.2}}, color={0,0,127}));
            connect(dea_sourceH_IPTurb.y[1], sourcePressure.in_h) annotation (
                Line(points={{-99,210},{-86,210},{-86,159}}, color={0,0,127}));
            connect(dea_sinkP_SP3.y[1], sinkPressure4.in_p0) annotation (Line(
                  points={{-99,110},{-86,110},{-86,88.8}}, color={0,0,127}));
            connect(LOAD8.y, dea_sinkP_SP3.u[1]) annotation (Line(points={{-139,
                    110},{-130.5,110},{-122,110}}, color={0,0,127}));
            connect(LOAD9.y, dea_sinkP_LPTurb.u[1]) annotation (Line(points={{119,
                    180},{119,180},{102,180}}, color={0,0,127}));
            connect(dea_sinkP_LPTurb.y[1], sinkPressure.in_p0) annotation (Line(
                  points={{79,180},{72,180},{72,158.8}}, color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                  points={{137.875,-36},{160,-36}}, color={0,0,255}));
            connect(sinkPressure.flange, LPTurb.vap_out) annotation (Line(
                  points={{66,150},{62,150},{52,150},{52,122}}, color={0,0,255}));
            connect(LOAD4.y,FW_sourceH. u[1]) annotation (Line(points={{219,
                    -212},{219,-212},{202,-212}},
                                          color={0,0,127}));
            connect(FW_sourceH.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-212},{166,-212},{166,-69}}, color={0,0,127}));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{-57,-122},{-64,-122},{-64,-142}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(PID_level.CS,PID_level. TR) annotation (Line(points={{-70,
                    -159},{-70,-164},{-54,-164},{-54,-150},{-62,-150}},
                                                     color={0,0,127}));
            connect(PID_level.TS,booleanStep. y) annotation (Line(points={{-62,
                    -154},{-50,-154},{-21,-154}},
                                color={255,0,255}));
            connect(deaerator.level, PID_level.PV) annotation (Line(points={{
                    -80.4286,-97.8571},{-71,-97.8571},{-71,-142}}, color={0,0,
                    127}));
            connect(waterPump.in_w0, pumpDynamic.y) annotation (Line(points={{
                    -106,-202},{-70,-202},{-70,-193}}, color={0,0,127}));
            connect(PID_level.CS, pumpDynamic.u) annotation (Line(points={{-70,
                    -159},{-70,-164.5},{-70,-170}}, color={0,0,127}));
            connect(LPTurb.flange_LP_out, powerSensor.flange_a) annotation (
                Line(points={{52,110},{66,110},{80,110}}, color={0,0,0}));
            connect(powerSensor.flange_b, constantSpeed.flange) annotation (
                Line(points={{100,110},{120,110},{140,110}}, color={0,0,0}));
            connect(IPTurb.SP4, valveVap.inlet) annotation (Line(points={{-35.6,
                    88},{-35.6,60},{-80,60},{-80,50}}, color={0,0,255}));
            connect(IPTurb.SP3, valveVap1.inlet) annotation (Line(points={{-26,
                    88},{-26,60},{-12,60},{-12,50}}, color={0,0,255}));
            connect(LPTurb.SP2, valveVap2.inlet) annotation (Line(points={{19.2,
                    88},{19.2,60},{40,60},{40,50}}, color={0,0,255}));
            connect(LPTurb.SP1, valveVap3.inlet) annotation (Line(points={{31.6,
                    88},{31.6,70},{96,70},{96,50}}, color={0,0,255}));
            connect(valveVap.outlet, deaerator.steam_in) annotation (Line(
                  points={{-80,30},{-80,-20},{-130,-20},{-130,-74.2857},{
                    -121.229,-74.2857}}, color={0,0,255}));
            connect(valveVap1.outlet, LPHs.SP4) annotation (Line(points={{-12,30},
                    {-12,4},{-13.25,4},{-13.25,-16}},     color={0,0,255}));
            connect(valveVap2.outlet, LPHs.SP5) annotation (Line(points={{40,30},
                    {40,4},{41,4},{41,-16}}, color={0,0,255}));
            connect(valveVap3.outlet, LPHs.SP6) annotation (Line(points={{96,30},
                    {96,-16},{95.25,-16}}, color={0,0,255}));
            connect(pumpDynamic1.y, valveVap.theta) annotation (Line(points={{
                    -99,20},{-94,20},{-94,40},{-88,40}}, color={0,0,127}));
            connect(pumpDynamic1.y, valveVap1.theta) annotation (Line(points={{
                    -99,20},{-40,20},{-40,40},{-20,40}}, color={0,0,127}));
            connect(pumpDynamic1.y, valveVap2.theta) annotation (Line(points={{
                    -99,20},{-40,20},{20,20},{20,40},{32,40}}, color={0,0,127}));
            connect(pumpDynamic1.y, valveVap3.theta) annotation (Line(points={{
                    -99,20},{-10,20},{80,20},{80,40},{88,40}}, color={0,0,127}));
            connect(ramp1.y, pumpDynamic1.u) annotation (Line(points={{-139,20},
                    {-130.5,20},{-122,20}}, color={0,0,127}));
            connect(LOAD10.y, FW_sourceW1.u[1]) annotation (Line(points={{99,-230},{88,-230},
                    {88,-228},{82,-228},{82,-230}}, color={0,0,127}));
            connect(ramp2.y, product1.u2) annotation (Line(points={{79,-190},{68,-190},{56,
                    -190},{56,-182}}, color={0,0,127}));
            connect(FW_sourceW1.y[1], product1.u1)
              annotation (Line(points={{59,-230},{44,-230},{44,-182}}, color={0,0,127}));
            connect(pumpFW_dynamic1.u, product1.y)
              annotation (Line(points={{50,-152},{50,-152},{50,-159}}, color={0,0,127}));
            connect(signalBus.pumpCOND_CS, pumpFW_dynamic1.y) annotation (Line(
                points={{50,-118},{50,-129}},
                color={255,204,51},
                thickness=0.5));
            connect(LPHs.signalBus, signalBus) annotation (Line(
                points={{41,-100},{41,-118},{50,-118}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-340,
                      -240},{340,240}}), graphics={Text(
                    extent={{182,200},{316,112}},
                    lineColor={28,108,200},
                    textString="Riducendo del 40% la portata di alimento al
 97% del carico e chiudendo l'estrazione del
 degasatore ottengo l'extra potenza richiesta 
 in 10s. 
 NB1: con tale riduzione posso garantire 
 extrapotenza per 10 min senza svuotare
 il degasatore!
 NB2: in ogni caso � buona pratica l'uso 
 integrato dei due modi")}),                             Icon(coordinateSystem(extent={{-340,
                      -240},{340,240}})),
              experiment(
                StartTime=-1700,
                StopTime=700,
                __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput);
          end test_LP_primaryLoad;

          model test_LPH_train_primaryLoad_FW_pump
            "Test to check the power increase against a reduction of the FW mass flow"

            parameter Modelica.SIunits.SpecificEnthalpy DH_IPT3 = 263.549e3
              "Nominal enthalpy drop over IPT3";
            parameter Modelica.SIunits.SpecificEnthalpy DH_LPT1 = 106.571e3
              "Nominal enthalpy drop over LPT1";
            parameter Modelica.SIunits.SpecificEnthalpy DH_LPT2 = 193.225e3
              "Nominal enthalpy drop over LPT2";
            parameter Modelica.SIunits.SpecificEnthalpy DH_LPT3 = 197.300e3
              "Nominal enthalpy drop over LPT3";
            parameter Modelica.SIunits.MassFlowRate w_IPT2_nom = 81.93
              "Nominal mass flow rate through IPT2";
            parameter Modelica.SIunits.MassFlowRate w_IPT3_nom = 75.05
              "Nominal mass flow rate through IPT3";
            parameter Modelica.SIunits.MassFlowRate w_LPT1_nom = 73.92
              "Nominal mass flow rate through LPT1";
            parameter Modelica.SIunits.MassFlowRate w_LPT2_nom = 69.02
              "Nominal mass flow rate through LPT2";
            parameter Modelica.SIunits.MassFlowRate w_LPT3_nom = 65.73
              "Nominal mass flow rate through LPT3";
            parameter Modelica.SIunits.Power Pm_IPT1_nom = 23247e3
              "Nominal power of IPT1";
            parameter Modelica.SIunits.Power Pm_IPT2_nom = 10452e3
              "Nominal power of IPT2";
            parameter Modelica.SIunits.Power Pm_IPT3_nom = 19779e3
              "Nominal power of IPT3";
            parameter Modelica.SIunits.Power Pm_LPT1_nom = 7878e3
              "Nominal power of LPT1";
            parameter Modelica.SIunits.Power Pm_LPT2_nom = 13336e3
              "Nominal power of LPT2";
            parameter Modelica.SIunits.Power Pm_LPT3_nom = 12969e3
              "Nominal power of LPT3";

            Modelica.SIunits.MassFlowRate w_IPT3 = w_IPT2_nom - deaerator.ws_in
              "Mass flow rate through IPT3";
            Modelica.SIunits.MassFlowRate w_LPT1 = w_IPT3 - LPHs.LPH3.NusseltCondenser.ws_in
              "Mass flow rate through LPT1";
            Modelica.SIunits.MassFlowRate w_LPT2 = w_LPT1 - LPHs.LPH2.NusseltCondenser.ws_in
              "Mass flow rate through LPT2";
            Modelica.SIunits.MassFlowRate w_LPT3 = w_LPT2 - LPHs.LPH1.NusseltCondenser.ws_in
              "Mass flow rate through LPT3";
            Modelica.SIunits.Power Pm_IPT3 = Pm_IPT3_nom*(w_IPT3/w_IPT3_nom);
            Modelica.SIunits.Power Pm_LPT1 = Pm_LPT1_nom*(w_LPT1/w_LPT1_nom);
            Modelica.SIunits.Power Pm_LPT2 = Pm_LPT2_nom*(w_LPT2/w_LPT2_nom);
            Modelica.SIunits.Power Pm_LPT3 = Pm_LPT3_nom*(w_LPT3/w_LPT3_nom);
            Modelica.SIunits.Power Pm_IPT_LPT = Pm_IPT1_nom + Pm_IPT2_nom + Pm_IPT3 + Pm_LPT1 + Pm_LPT2 + Pm_LPT3;
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
              LPHs(LPH2(NusseltCondenser(noInitialPressure=true)), LPH1(
                  NusseltCondenser(noInitialPressure=true))) annotation (
                Placement(transformation(extent={{-42,-40},{156,40}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,14},{206,34}})));
            ThermoPower.Water.SourcePressure sourceMassFlow(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-74,70},{-54,90}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3318000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,90},{166,110}})));
            ThermoPower.Water.SourcePressure sourceMassFlow_ST1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3218000,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{26,90},{46,110}})));
            ThermoPower.Water.SourcePressure sourceFW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000) annotation (Placement(transformation(extent={{206,10},{186,-10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,160},{-300,180}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              t_ramp=0,
              t_start=0,
              load_start=97,
              load_end=97) annotation (Placement(transformation(extent={{-280,-140},
                      {-240,-100}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={256,-160})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{226,-170},{206,-150}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={276,60})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{246,50},{226,70}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-24,160})));
            Modelica.Blocks.Tables.CombiTable1D SP5_sourceH(table=[20,2839.6e3;
                  30,2832.2e3; 40,2825.5e3; 50,2818.4e3; 60,2811.7e3; 70,
                  2804.5e3; 80,2798.7e3; 90,2792.4e3; 100,2786.2e3])
                                          annotation (Placement(transformation(
                    extent={{6,150},{26,170}})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-24,130})));
            Modelica.Blocks.Tables.CombiTable1D SP5_sourceP(table=[20,0.4008e5;
                  30,0.5888e5; 40,0.7738e5; 50,0.9635e5; 60,1.15e5; 70,1.35e5;
                  80,1.52e5; 90,1.702e5; 100,1.893e5])
                                     annotation (Placement(transformation(extent={{6,120},
                      {26,140}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={116,130})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={116,160})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceP(table=[20,0.1263e5;
                  30,0.1778e5; 40,0.2287e5; 50,0.2814e5; 60,0.3346e5; 70,
                  0.3919e5; 80,0.4414e5; 90,0.4947e5; 100,0.5515e5])
              annotation (Placement(transformation(extent={{146,150},{166,170}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-124,140})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sourceH(table=[20,2944e3;
                  30,2937.3e3; 40,2930.7e3; 50,2923.6e3; 60,2916.5e3; 70,
                  2908.8e3; 80,2902.7e3; 90,2895.9e3; 100,2899e3])
                                                           annotation (Placement(
                  transformation(extent={{-94,130},{-74,150}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-124,110})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sourceP(table=[20,0.6861e5;
                  30,1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5;
                  80,2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{-94,100},{-74,120}})));
            Modelica.Blocks.Tables.CombiTable1D SP6_sourceH(table=[20,2070.9e3;
                  30,2175.2e3; 40,2223.3e3; 50,2252.5e3; 60,2269.5e3; 70,
                  2282.5e3; 80,2284e3; 90,2285.8e3; 100,2287.3e3])
              annotation (Placement(transformation(extent={{146,120},{166,140}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={130,-170})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceW(table=[20,14.85; 30,
                  22.25; 40,29.67; 50,37.42; 60,45.15; 70,53.51; 80,60.78; 90,
                  68.59; 100,76.94]) annotation (Placement(transformation(
                    extent={{108,-180},{88,-160}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={70,-110})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=1,
              height=-0.4,
              startTime=0,
              duration=0)
              annotation (Placement(transformation(extent={{120,-140},{100,-120}})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceW_DR(table=[20,2.045; 30,3.451;
                  40,5.095; 50,7.013; 60,9.065; 70,8.388; 80,9.029; 90,8.921; 100,7.484])
              annotation (Placement(transformation(extent={{-220,-40},{-200,-20}})));
            PreFlexMS.FullScale_245degC.HeatExchangers.Components.Deaerator deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              noInitialPressure=true,
              h_start=782e3,
              p_start=1086000) annotation (Placement(transformation(extent={{-162,
                      -52},{-94,14}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=7.484,
              h=821.9e3,
              use_in_w0=true,
              use_in_h=true)
              annotation (Placement(transformation(extent={{-200,-70},{-180,-50}})));
            ThermoPower.Water.SinkMassFlow    waterPump(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=91.28,
              use_in_w0=true)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-128,-142})));
            Modelica.Blocks.Tables.CombiTable1D dea_sourceH_DR(table=[20,565.6e3; 30,626.7e3;
                  40,670.9e3; 50,708.6e3; 60,741.2e3; 70,766.4e3; 80,788.3e3; 90,807.7e3;
                  100,821.9e3])
              annotation (Placement(transformation(extent={{-220,0},{-200,20}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-250,-30})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-250,10})));
            ThermoPower.Water.SourcePressure sourceMassFlow1(
                                                            redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_h=true,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{-180,30},{-160,50}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-230,100})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sourceH(table=[20,3218e3; 30,3211e3; 40,
                  3203e3; 50,3195e3; 60,3187e3; 70,3178e3; 80,3170e3; 90,3162e3; 100,3153e3])
              annotation (Placement(transformation(extent={{-200,90},{-180,110}})));
            Modelica.Blocks.Sources.Ramp LOAD13(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-230,70})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sourceP(table=[20,2.234e5; 30,3.321e5;
                  40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,8.731e5; 90,9.773e5;
                  100,10.86e5])
              annotation (Placement(transformation(extent={{-200,60},{-180,80}})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
              CSmin=0,
              CSmax=100,
              Ti=10000,
              Kp=-500,
              AntiWindup=true,
              CS_start=91,
              useTS=true)    annotation (
                Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-70,-88})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=2)
                    annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={-70,-120})));
            Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
              annotation (Placement(transformation(extent={{-36,-70},{-56,-50}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=0)
              annotation (Placement(transformation(extent={{0,-102},{-20,-82}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=2)         annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=270,
                  origin={70,-80})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{62,-68},{78,-48}})));
          equation
            connect(LPHs.FW_in, sourceFW.flange) annotation (Line(
                points={{160.125,0},{186,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(LOAD4.y, FW_sourceH.u[1]) annotation (Line(points={{245,-160},{245,-160},{228,
                    -160}},               color={0,0,127}));
            connect(FW_sourceH.y[1], sourceFW.in_h)
              annotation (Line(points={{205,-160},{192,-160},{192,-9}}, color={0,0,127}));
            connect(cond_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{225,60},{192,60},{192,32.8}}, color={0,0,127}));
            connect(LOAD7.y,SP5_sourceH. u[1]) annotation (Line(points={{-13,160},{-4,160},
                    {4,160}},             color={0,0,127}));
            connect(LOAD8.y,SP5_sourceP. u[1]) annotation (Line(points={{-13,130},{-4,130},
                    {4,130}},             color={0,0,127}));
            connect(LOAD10.y,SP6_sourceP. u[1]) annotation (Line(points={{127,160},{136,160},
                    {144,160}},         color={0,0,127}));
            connect(SP5_sourceH.y[1], sourceMassFlow_ST1.in_h) annotation (Line(
                  points={{27,160},{32,160},{40,160},{40,109}},    color={0,0,127}));
            connect(LOAD11.y,SP4_sourceH. u[1]) annotation (Line(points={{-113,140},{-104,
                    140},{-96,140}},             color={0,0,127}));
            connect(LOAD12.y,SP4_sourceP. u[1]) annotation (Line(points={{-113,110},{-96,110}},
                                          color={0,0,127}));
            connect(SP4_sourceH.y[1], sourceMassFlow.in_h) annotation (Line(
                  points={{-73,140},{-60,140},{-60,89}},    color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD6.y)
              annotation (Line(points={{248,60},{265,60}}, color={0,0,127}));
            connect(SP5_sourceP.y[1], sourceMassFlow_ST1.in_p0) annotation (Line(
                  points={{27,130},{27,130},{32,130},{32,109.2}},    color={0,0,
                    127}));
            connect(SP6_sourceP.y[1], sourceMassFlow_ST.in_p0) annotation (Line(
                  points={{167,160},{180,160},{180,109.2}},
                                                         color={0,0,127}));
            connect(LOAD9.y,SP6_sourceH. u[1]) annotation (Line(points={{127,130},{144,130}},
                                        color={0,0,127}));
            connect(SP6_sourceH.y[1], sourceMassFlow_ST.in_h) annotation (Line(
                  points={{167,130},{172,130},{172,109}},
                                                       color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                  points={{160.125,24},{186,24}}, color={0,0,255}));
            connect(SP4_sourceP.y[1], sourceMassFlow.in_p0) annotation (Line(
                  points={{-73,110},{-68,110},{-68,89.2}},    color={0,0,127}));
            connect(sourceMassFlow.flange,LPHs. SP4) annotation (Line(points={{-54,80},{-30,
                    80},{-0.75,80},{-0.75,44}},                 color={0,0,255}));
            connect(sourceMassFlow_ST1.flange,LPHs. SP5) annotation (Line(
                  points={{46,100},{57,100},{57,44}},color={0,0,255}));
            connect(sourceMassFlow_ST.flange,LPHs. SP6) annotation (Line(points={{166,100},
                    {140,100},{114.75,100},{114.75,44}},        color={0,0,255}));
            connect(LOAD1.y, FW_sourceW.u[1]) annotation (Line(points={{119,
                    -170},{108,-170},{108,-168},{106,-168},{106,-170},{110,-170}},
                                          color={0,0,127}));
            connect(ramp.y, product.u2) annotation (Line(points={{99,-130},{88,
                    -130},{76,-130},{76,-122}},
                                     color={0,0,127}));
            connect(FW_sourceW.y[1], product.u1)
              annotation (Line(points={{87,-170},{64,-170},{64,-122}}, color={0,0,127}));
            connect(deaerator.drained_in,sourceMassFlow_DR. flange) annotation (
                Line(
                points={{-159.571,-35.5},{-164,-35.5},{-164,-60},{-180,-60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(dea_sourceW_DR.y[1], sourceMassFlow_DR.in_w0) annotation (Line(points=
                   {{-199,-30},{-194,-30},{-194,-54}}, color={0,0,127}));
            connect(dea_sourceH_DR.y[1], sourceMassFlow_DR.in_h) annotation (Line(points={
                    {-199,10},{-186,10},{-186,-54}}, color={0,0,127}));
            connect(LOAD5.y, dea_sourceH_DR.u[1]) annotation (Line(points={{-239,10},{-230.5,
                    10},{-222,10}}, color={0,0,127}));
            connect(deaerator.water_in,LPHs. FW_out) annotation (Line(points={{
                    -119.257,-0.142857},{-83.6285,-0.142857},{-83.6285,0},{
                    -46.125,0}},                                    color={0,0,255}));
            connect(deaerator.drained_out, waterPump.flange)
              annotation (Line(points={{-128,-44.9286},{-128,-132}}, color={0,0,255}));
            connect(LOAD2.y, dea_sourceW_DR.u[1]) annotation (Line(points={{-239,-30},{-230.5,
                    -30},{-222,-30}}, color={0,0,127}));
            connect(LOAD3.y, SP3_sourceH.u[1]) annotation (Line(points={{-219,100},{-210,100},
                    {-202,100}}, color={0,0,127}));
            connect(SP3_sourceH.y[1], sourceMassFlow1.in_h) annotation (Line(points={{-179,
                    100},{-166,100},{-166,49}}, color={0,0,127}));
            connect(sourceMassFlow1.flange, deaerator.steam_in) annotation (Line(points={{-160,40},
                    {-150,40},{-150,38},{-150,-14.2857},{-137.229,-14.2857}},
                  color={0,0,255}));
            connect(LOAD13.y, SP3_sourceP.u[1])
              annotation (Line(points={{-219,70},{-202,70},{-202,70}}, color={0,0,127}));
            connect(SP3_sourceP.y[1], sourceMassFlow1.in_p0) annotation (Line(points={{-179,
                    70},{-179,70},{-174,70},{-174,49.2}}, color={0,0,127}));
            connect(PID_level.CS,pumpDynamic. u) annotation (Line(
                points={{-70,-97},{-70,-108}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{-57,-60},{-64,-60},{-64,-80}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.level,PID_level. PV) annotation (Line(
                points={{-96.4286,-37.8571},{-71,-37.8571},{-71,-80}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(pumpDynamic.y, waterPump.in_w0) annotation (Line(points={{-70,-131},{-70,
                    -138},{-122,-138}}, color={0,0,127}));
            connect(PID_level.CS, PID_level.TR) annotation (Line(points={{-70,-97},{-70,-102},
                    {-54,-102},{-54,-88},{-62,-88}}, color={0,0,127}));
            connect(PID_level.TS, booleanStep.y) annotation (Line(points={{-62,-92},{-50,-92},
                    {-21,-92}}, color={255,0,255}));
            connect(pumpFW_dynamic.u, product.y)
              annotation (Line(points={{70,-92},{70,-92},{70,-99}},    color={0,0,127}));
            connect(signalBus.pumpCOND_CS, pumpFW_dynamic.y) annotation (Line(
                points={{70,-58},{70,-69}},
                color={255,204,51},
                thickness=0.5));
            connect(LPHs.signalBus, signalBus) annotation (Line(
                points={{57,-40},{57,-58},{70,-58}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-320,
                      -180},{320,180}}), graphics={Text(
                    extent={{184,178},{318,90}},
                    lineColor={28,108,200},
                    textString="Riducendo del 40% la portata di alimento al
 97% del carico ottengo l'extra potenza
 richiesta in 10s. 
 NB1: tale tempo corrisponde al tempo di
 risposta della pompa, stimato avendo una
 costante di tempo di 2s.
 NB2: con tale riduzione posso garantire 
 extrapotenza per 10 min senza svuotare
 il degasatore!")}),
              Icon(coordinateSystem(extent={{-320,-180},{320,180}})),
              experiment(
                StartTime=-700,
                StopTime=700,
                __Dymola_NumberOfIntervals=7000),
              __Dymola_experimentSetupOutput);
          end test_LPH_train_primaryLoad_FW_pump;

        end Primary_frequency;

        package Transition_low_to_high
          "Package containing models for hot start ramp"

          model Plant_HP_fullyDecentralized_40_100
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=8830000)))
              annotation (Placement(transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100]) annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_fullyDecentralized
              controllers(
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Ta_pumpFW=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              CSmax_pumpFW_high=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpMS=false,
              useTS_valveTURB_high=true,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              actuatorGain_pumpHPH=1,
              Ta_pumpHPH=2,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              Td_valveBP=0,
              Nd_valveBP=20,
              CSstart_valveBP=0,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              Kp_valveTURB_low=-1.518e-11*0.1,
              TS_pumpFW_high=-0.2,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              useTS_valveTURB_low=false,
              Kp_pumpMS_low=0.000147*0.8,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,-60; 20000,-60; 20007.3469387755,-59.9383617825101;
                  20014.693877551,-59.7537004146974; 20022.0408163265,-59.446774709732;
                  20029.387755102,-59.0188458911709; 20036.7346938776,-58.4716724103201;
                  20044.0816326531,-57.8075027203807; 20051.4285714286,-57.0290660370726;
                  20058.7755102041,-56.1395611237017; 20066.1224489796,-55.1426431467552;
                  20073.4693877551,-54.0424086560387; 20080.8163265306,-52.843378751074;
                  20088.1632653061,-51.5504805029318; 20095.5102040816,-50.1690267078395;
                  20102.8571428571,-48.704694055762; 20110.2040816327,-47.1634998036651;
                  20117.5510204082,-45.5517770493158; 20124.8979591837,-43.8761487072251;
                  20132.2448979592,-42.1435002936718; 20139.5918367347,-40.3609516326392;
                  20146.9387755102,-38.535827598931; 20154.2857142857,-36.6756280186894;
                  20161.6326530612,-34.7879968510014; 20168.9795918367,-32.8806907772305;
                  20176.3265306122,-30.9615473271496; 20183.6734693878,-29.0384526728504;
                  20191.0204081633,-27.1193092227695; 20198.3673469388,-25.2120031489986;
                  20205.7142857143,-23.3243719813106; 20213.0612244898,-21.464172401069;
                  20220.4081632653,-19.6390483673608; 20227.7551020408,-17.8564997063282;
                  20235.1020408163,-16.1238512927749; 20242.4489795918,-14.4482229506843;
                  20249.7959183674,-12.8365001963349; 20257.1428571429,-11.295305944238;
                  20264.4897959184,-9.83097329216049; 20271.8367346939,-8.44951949706817;
                  20279.1836734694,-7.15662124892597; 20286.5306122449,-5.9575913439613;
                  20293.8775510204,-4.85735685324477; 20301.2244897959,-3.86043887629832;
                  20308.5714285714,-2.97093396292743; 20315.9183673469,-2.19249727961935;
                  20323.2653061225,-1.52832758967995; 20330.612244898,-0.981154108829117;
                  20337.9591836735,-0.553225290268046; 20345.306122449,-0.246299585302623;
                  20352.6530612245,-0.0616382174899144; 20360,0; 25000,0])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {214,-80},{219,-80}},           color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_fullyDecentralized_40_100;

          model Plant_HP_staticDecoupled_wMS_w_FW_40_100
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100]) annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              control_wBP(table_T_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              useTS_pumpSEP=false,
              useTS_valveTURB_high=true,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              TS_pumpFW_high=-0.2,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=2.4e-3,
              dec_wFW_wMS=74,
              l_min=0.2,
              l_max=0.3,
              useTS_valveTURB_low=false,
              Ti_valveTURB_low=3.626,
              Kp_pumpMS_low=0.000147,
              Kp_valveTURB_low=-1.518e-11*0.05,
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,-60; 20000,-60; 20007.3469387755,-59.9383617825101;
                  20014.693877551,-59.7537004146974; 20022.0408163265,-59.446774709732;
                  20029.387755102,-59.0188458911709; 20036.7346938776,-58.4716724103201;
                  20044.0816326531,-57.8075027203807; 20051.4285714286,-57.0290660370726;
                  20058.7755102041,-56.1395611237017; 20066.1224489796,-55.1426431467552;
                  20073.4693877551,-54.0424086560387; 20080.8163265306,-52.843378751074;
                  20088.1632653061,-51.5504805029318; 20095.5102040816,-50.1690267078395;
                  20102.8571428571,-48.704694055762; 20110.2040816327,-47.1634998036651;
                  20117.5510204082,-45.5517770493158; 20124.8979591837,-43.8761487072251;
                  20132.2448979592,-42.1435002936718; 20139.5918367347,-40.3609516326392;
                  20146.9387755102,-38.535827598931; 20154.2857142857,-36.6756280186894;
                  20161.6326530612,-34.7879968510014; 20168.9795918367,-32.8806907772305;
                  20176.3265306122,-30.9615473271496; 20183.6734693878,-29.0384526728504;
                  20191.0204081633,-27.1193092227695; 20198.3673469388,-25.2120031489986;
                  20205.7142857143,-23.3243719813106; 20213.0612244898,-21.464172401069;
                  20220.4081632653,-19.6390483673608; 20227.7551020408,-17.8564997063282;
                  20235.1020408163,-16.1238512927749; 20242.4489795918,-14.4482229506843;
                  20249.7959183674,-12.8365001963349; 20257.1428571429,-11.295305944238;
                  20264.4897959184,-9.83097329216049; 20271.8367346939,-8.44951949706817;
                  20279.1836734694,-7.15662124892597; 20286.5306122449,-5.9575913439613;
                  20293.8775510204,-4.85735685324477; 20301.2244897959,-3.86043887629832;
                  20308.5714285714,-2.97093396292743; 20315.9183673469,-2.19249727961935;
                  20323.2653061225,-1.52832758967995; 20330.612244898,-0.981154108829117;
                  20337.9591836735,-0.553225290268046; 20345.306122449,-0.246299585302623;
                  20352.6530612245,-0.0616382174899144; 20360,0; 25000,0])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {214,-80},{219,-80}},           color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_staticDecoupled_wMS_w_FW_40_100;

          model Plant_HP_4th_orderFW_20_100
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                  annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              D=[0],
              load_switch=55,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              useTS_pumpMS=false,
              useTS_pumpSEP=false,
              useTS_valveTURB_high=true,
              l_min=0.2,
              l_max=0.3,
              useTS_valveTURB_low=false,
              DT_sh_sp=20,
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.484,
              B=[0.015625; 0; 0; 0; 0],
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.Ramp load_pre(
              duration=2000,
              startTime=100,
              height=-20,
              offset=20)
              annotation (Placement(transformation(extent={{-320,60},{-300,80}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-280,30},{-260,50}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load(table=[
                  5000,20; 5080,35; 5160,47; 5240,60; 5300,70; 5360,80; 5440,90;
                  5540,100]) annotation (Placement(transformation(extent={{-320,0},
                      {-300,20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {219,-80}},                     color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(load_pre.y,add. u1) annotation (Line(points={{-299,70},{
                    -298,70},{-298,46},{-282,46}},
                                                 color={0,0,127}));
            connect(splineSignal_load.y, add.u2) annotation (Line(points={{-299,
                    10},{-290,10},{-290,34},{-282,34}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-259,40},{-240,40},
                    {-240,-12},{-300,-12},{-300,-40},{-289.2,-40}}, color={0,0,
                    127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_4th_orderFW_20_100;

          model Plant_HP_4th_orderFW_40_100
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                  annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_valveTURB_low=-1.518e-11*0.1,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              useTS_pumpSEP=false,
              Kp_valveTURB_high=-1.077e-11*0.5,
              useTS_valveTURB_high=true,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              l_min=0.2,
              l_max=0.3,
              Kp_pumpMS_low=0.000147*0.6,
              useTS_valveTURB_low=false,
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,-60; 20000,-60; 20007.3469387755,-59.9383617825101;
                  20014.693877551,-59.7537004146974; 20022.0408163265,-59.446774709732;
                  20029.387755102,-59.0188458911709; 20036.7346938776,-58.4716724103201;
                  20044.0816326531,-57.8075027203807; 20051.4285714286,-57.0290660370726;
                  20058.7755102041,-56.1395611237017; 20066.1224489796,-55.1426431467552;
                  20073.4693877551,-54.0424086560387; 20080.8163265306,-52.843378751074;
                  20088.1632653061,-51.5504805029318; 20095.5102040816,-50.1690267078395;
                  20102.8571428571,-48.704694055762; 20110.2040816327,-47.1634998036651;
                  20117.5510204082,-45.5517770493158; 20124.8979591837,-43.8761487072251;
                  20132.2448979592,-42.1435002936718; 20139.5918367347,-40.3609516326392;
                  20146.9387755102,-38.535827598931; 20154.2857142857,-36.6756280186894;
                  20161.6326530612,-34.7879968510014; 20168.9795918367,-32.8806907772305;
                  20176.3265306122,-30.9615473271496; 20183.6734693878,-29.0384526728504;
                  20191.0204081633,-27.1193092227695; 20198.3673469388,-25.2120031489986;
                  20205.7142857143,-23.3243719813106; 20213.0612244898,-21.464172401069;
                  20220.4081632653,-19.6390483673608; 20227.7551020408,-17.8564997063282;
                  20235.1020408163,-16.1238512927749; 20242.4489795918,-14.4482229506843;
                  20249.7959183674,-12.8365001963349; 20257.1428571429,-11.295305944238;
                  20264.4897959184,-9.83097329216049; 20271.8367346939,-8.44951949706817;
                  20279.1836734694,-7.15662124892597; 20286.5306122449,-5.9575913439613;
                  20293.8775510204,-4.85735685324477; 20301.2244897959,-3.86043887629832;
                  20308.5714285714,-2.97093396292743; 20315.9183673469,-2.19249727961935;
                  20323.2653061225,-1.52832758967995; 20330.612244898,-0.981154108829117;
                  20337.9591836735,-0.553225290268046; 20345.306122449,-0.246299585302623;
                  20352.6530612245,-0.0616382174899144; 20360,0; 25000,0])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {219,-80}},                     color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{-299,
                    -40},{-289.2,-40}},                   color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_4th_orderFW_40_100;

          model Plant_HP_10th_orderFW_40_100
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100]) annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_10thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              control_wBP(table_T_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              Kp_valveTURB_low=-1.518e-11*0.1,
              useTS_pumpSEP=false,
              useTS_valveTURB_high=true,
              useTS_valveTURB_low=false,
              A=[-0.00826701880345483,9.43250838340711e-06,-0.0113552737182845,
                  -0.0138396129545222,0.0392727574923542,0.0218572119428319,-0.105992047623591,
                  -0.398263220659893,-0.194053684777024,-0.841970157975721,-0.543993105593968,
                  0.67278246575916,-0.380547418743879,-0.163985208024919,
                  0.436999028418906,-0.225132045831548,-0.175117844260931,
                  0.0460150975286926; 0,-0.0108606555057044,1,0,0,0,0,0,0,0,0,0,
                  0,0,0,0,0,0; 0,-9.36167120482709e-05,-0.0108606555057044,-0.0205782815349691,
                  0.0583951200794353,0.0324997427606611,-0.157600808897867,-0.592182216850568,
                  -0.28854068183568,-1.25193522476402,-0.808869678420953,
                  1.00036807659847,-0.565840384846779,-0.243831513886708,
                  0.649778940123739,-0.334751458504577,-0.260384760241492,
                  0.0684203839309744; 0,0,0,-0.045010047558481,
                  0.0711709467828456,0.0396101156968038,-0.192081098005201,-0.721741285639752,
                  -0.351668315497568,-1.52583666470836,-0.98583615820714,
                  1.21923104269668,-0.689636323424518,-0.297177566810467,
                  0.791939160417045,-0.407989198520364,-0.317352372749679,
                  0.0833895622954311; 0,0,0,0,-0.2,0.112401876636035,-0.545069750549526,
                  -2.04808982565427,-0.997931410196544,-4.32987638476217,-2.79751352120092,
                  3.45981966578992,-1.95698537067252,-0.843302666907442,
                  2.24729078031005,-1.15775353730211,-0.900552841728778,
                  0.236635090026266; 0,0,0,0,0,-1.04328573447507,1,0,0,0,0,0,0,
                  0,0,0,0,0; 0,0,0,0,0,-0.334649542989399,-1.04328573447507,-5.64383226346336,
                  -2.74995628562899,-11.9316524749212,-7.70898662288162,
                  9.53407492726171,-5.39277967000254,-2.32385256727521,
                  6.19276169063817,-3.19037118641861,-2.48161438987611,
                  0.652085049702912; 0,0,0,0,0,0,0,-6.9835004164999,
                  24.4753121985028,0,0,0,0,0,0,0,0,0; 0,0,0,0,0,0,0,-24.4753121985028,
                  -6.9835004164999,-48.8440350102004,-31.5579097943583,
                  39.0291864866035,-22.0761641824168,-9.51304409788249,
                  25.3510123147763,-13.06026992091,-10.1588661248471,
                  2.66940937680366; 0.198841363451337,-0.000245596025959061,
                  0.29565943495941,0.360344651102706,-1.02255230279395,-0.569100410358232,
                  2.75973522858558,10.369655695381,5.05261292826275,
                  21.918031482177,14.151651709721,-17.4940955320443,
                  9.88629672355252,4.26699883027104,-11.3516143425471,
                  5.83804990536625,4.54333140680033,-1.19602614169308;
                  1.04797429050729,-0.00129439024450688,1.55824462881036,
                  1.8991618419971,-5.38926360907467,-2.99938900247249,
                  14.5449192158288,54.6522734583406,26.6293107067734,
                  115.551717173136,74.530014823476,-92.3292819607109,
                  52.2363872998101,22.146963300625,-59.577944391706,
                  31.0414733943376,24.0797857084477,-6.26907258131803;
                  1.01814538798911,-0.00125754750821686,1.51389170187953,
                  1.84510525495644,-5.23586688904441,-2.91401621901848,
                  14.1309214857759,53.0966844022421,25.8713502106107,
                  112.249981545055,72.6119399941614,-89.7505889704599,
                  50.79837425297,21.9494727926064,-58.5005100040441,
                  30.1929023581392,23.4544494432086,-6.14302240915466; -0.0281004323163195,
                  3.47078413909017e-05,-0.0417828453625116,-0.0509242156818015,
                  0.144507969950579,0.0804257589310632,-0.390008153513846,-1.46544865189935,
                  -0.714039599944483,-3.10179815611907,-2.0182041421944,
                  2.54056146610873,-1.51842068675625,-0.509513026978294,
                  1.80543703401938,-1.28641833086766,-0.917965243913387,
                  0.16055740393882; -0.0824041175217926,0.000101780250521007,-0.122527598895612,
                  -0.149334537152698,0.423767563594652,0.235847392528754,-1.1436933551356,
                  -4.29740729871742,-2.09391095648259,-9.10488121894468,-5.55986954910803,
                  7.24817418490053,-4.31341407815564,-1.88202110982804,
                  5.10539217797251,-2.64813852309889,-1.84671447478929,
                  0.467865586295458; 0.609129434477465,-0.000752357385836209,
                  0.905721331260271,1.10387763256758,-3.13248056195783,-1.74337876740239,
                  8.45415626767854,31.7663407644017,15.4781439948204,
                  67.1699200568904,43.0124695266567,-53.6403115417686,
                  30.5734615650991,12.9159487585775,-35.2759047355519,
                  18.7693361814706,14.6534514649151,-3.71096258080218;
                  1.31788461859283,-0.00162776607130932,1.95957729775985,
                  2.38829921922497,-6.77729184797419,-3.7718946612913,
                  18.2910263036483,68.7282037491694,33.4878052849923,
                  145.34025205016,93.8362132682321,-116.168063322419,
                  65.7931818494065,28.7827761770325,-75.5505996456078,
                  37.8829985692954,29.1664645585148,-7.908613867848; -0.335304954191868,
                  0.000414147050716947,-0.498568665868762,-0.607646943443171,
                  1.72432358688299,0.959670481601986,-4.65372434759549,-17.4862858892843,
                  -8.52018974852281,-36.9739416245018,-24.1198731430933,
                  29.4845669850745,-16.4474840361134,-7.20725206475585,
                  18.8031987205012,-8.67504096201164,-9.51917816924227,
                  2.76058792390043; 0.0354424503802169,-4.37762285097323e-05,
                  0.0526997736844446,0.0642295807814143,-0.182264688915294,-0.101439221223299,
                  0.491908610984849,1.84833779584004,0.900602268522568,
                  3.90866555845146,2.54047199354431,-3.09499795517087,
                  1.69971713905518,0.803476837830201,-1.90049980769868,
                  0.69055915025261,0.833661871962516,-0.306473003941568],
              B=[0.349555620805269; 0; 0.519758319882152; 0.633472311966374;
                  1.79760839900131; 0; 4.95359146472753; 0; 20.2782804341591; -9.10144659637365;
                  -47.9682993209758; -46.6029588375603; 1.28622425245332;
                  3.77183430010749; -27.8813166533769; -60.3227430556238;
                  15.3477127751825; -1.62228604642973],
              C=[0.532463714014785,-0.000657664833209802,0.791726218778057,
                  0.964942343590728,-2.73822301089423,-1.52395514135992,
                  7.39010658549292,27.7681931403996,13.5300472626276,
                  58.7048684193927,37.9289495980825,-46.9085581634177,
                  26.5329904309306,11.4335763193488,-30.468978288271,
                  15.6969305887333,12.2097795365357,-3.20832065143729],
              D=[-24.3721425637798],
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              l_min=0.2,
              l_max=0.3,
              Kp_pumpMS_low=0.000147*0.8,
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,-60; 20000,-60; 20007.3469387755,-59.9383617825101;
                  20014.693877551,-59.7537004146974; 20022.0408163265,-59.446774709732;
                  20029.387755102,-59.0188458911709; 20036.7346938776,-58.4716724103201;
                  20044.0816326531,-57.8075027203807; 20051.4285714286,-57.0290660370726;
                  20058.7755102041,-56.1395611237017; 20066.1224489796,-55.1426431467552;
                  20073.4693877551,-54.0424086560387; 20080.8163265306,-52.843378751074;
                  20088.1632653061,-51.5504805029318; 20095.5102040816,-50.1690267078395;
                  20102.8571428571,-48.704694055762; 20110.2040816327,-47.1634998036651;
                  20117.5510204082,-45.5517770493158; 20124.8979591837,-43.8761487072251;
                  20132.2448979592,-42.1435002936718; 20139.5918367347,-40.3609516326392;
                  20146.9387755102,-38.535827598931; 20154.2857142857,-36.6756280186894;
                  20161.6326530612,-34.7879968510014; 20168.9795918367,-32.8806907772305;
                  20176.3265306122,-30.9615473271496; 20183.6734693878,-29.0384526728504;
                  20191.0204081633,-27.1193092227695; 20198.3673469388,-25.2120031489986;
                  20205.7142857143,-23.3243719813106; 20213.0612244898,-21.464172401069;
                  20220.4081632653,-19.6390483673608; 20227.7551020408,-17.8564997063282;
                  20235.1020408163,-16.1238512927749; 20242.4489795918,-14.4482229506843;
                  20249.7959183674,-12.8365001963349; 20257.1428571429,-11.295305944238;
                  20264.4897959184,-9.83097329216049; 20271.8367346939,-8.44951949706817;
                  20279.1836734694,-7.15662124892597; 20286.5306122449,-5.9575913439613;
                  20293.8775510204,-4.85735685324477; 20301.2244897959,-3.86043887629832;
                  20308.5714285714,-2.97093396292743; 20315.9183673469,-2.19249727961935;
                  20323.2653061225,-1.52832758967995; 20330.612244898,-0.981154108829117;
                  20337.9591836735,-0.553225290268046; 20345.306122449,-0.246299585302623;
                  20352.6530612245,-0.0616382174899144; 20360,0; 25000,0])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {214,-80},{219,-80}},           color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}},                color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_10th_orderFW_40_100;

        end Transition_low_to_high;

        package Transition_high_to_low
          "Package containing models for hot shut down ramp"

          model Plant_HP_fullyDecentralized_100_20
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
              valveLiq(Av=3.702e-4), separator(w_small=1e4))
                                     annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_fullyDecentralized
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=4,
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=200,
              CSstart_pumpFW_low=143,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=0.000147,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              useTS_valveTURB_high=true,
              useTS_pumpSEP=false,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              use_valveSEP=true,
              useTS_valveTURB_low=false,
              Kp_valveTURB_low=-1.518e-11*0.1,
              DT_sh_sp=20,
              T_FW_sp=558.15,
              l_max=6)            annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 20000,0; 20018.3673469388,-0.0616382174899144;
                  20036.7346938776,-0.246299585302623; 20055.1020408163,-0.553225290268046;
                  20073.4693877551,-0.981154108829117; 20091.8367346939,-1.52832758967995;
                  20110.2040816327,-2.19249727961935; 20128.5714285714,-2.97093396292743;
                  20146.9387755102,-3.86043887629832; 20165.306122449,-4.85735685324478;
                  20183.6734693878,-5.9575913439613; 20202.0408163265,-7.15662124892597;
                  20220.4081632653,-8.44951949706817; 20238.7755102041,-9.83097329216049;
                  20257.1428571429,-11.295305944238; 20275.5102040816,-12.8365001963349;
                  20293.8775510204,-14.4482229506843; 20312.2448979592,-16.1238512927749;
                  20330.612244898,-17.8564997063282; 20348.9795918367,-19.6390483673608;
                  20367.3469387755,-21.464172401069; 20385.7142857143,-23.3243719813106;
                  20404.0816326531,-25.2120031489986; 20422.4489795918,-27.1193092227695;
                  20440.8163265306,-29.0384526728504; 20459.1836734694,-30.9615473271497;
                  20477.5510204082,-32.8806907772305; 20495.9183673469,-34.7879968510014;
                  20514.2857142857,-36.6756280186894; 20532.6530612245,-38.535827598931;
                  20551.0204081633,-40.3609516326392; 20569.387755102,-42.1435002936718;
                  20587.7551020408,-43.8761487072251; 20606.1224489796,-45.5517770493158;
                  20624.4897959184,-47.1634998036651; 20642.8571428571,-48.704694055762;
                  20661.2244897959,-50.1690267078395; 20679.5918367347,-51.5504805029318;
                  20697.9591836735,-52.843378751074; 20716.3265306122,-54.0424086560387;
                  20734.693877551,-55.1426431467552; 20753.0612244898,-56.1395611237017;
                  20771.4285714286,-57.0290660370726; 20789.7959183674,-57.8075027203807;
                  20808.1632653061,-58.4716724103201; 20826.5306122449,-59.0188458911709;
                  20844.8979591837,-59.446774709732; 20863.2653061225,-59.7537004146974;
                  20881.6326530612,-59.9383617825101; 20900,-60; 25000,-60])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_fullyDecentralized_100_20;

          model Plant_HP_staticDecoupled_wMS_w_FW_100_20
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
                                                separator(w_small=1e4))
              annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=4,
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=200,
              CSstart_pumpFW_low=143,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=0.000147,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              useTS_pumpSEP=false,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              use_valveSEP=false,
              dec_wMS_wFW=2.43e-3,
              dec_wFW_wMS=74,
              useTS_valveTURB_high=true,
              useTS_valveTURB_low=false,
              Kp_valveTURB_low=-1.518e-11*0.1,
              l_min=0.2,
              l_max=3,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              DT_sh_sp=20,
              T_FW_sp=558.15)     annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 20000,0; 20018.3673469388,-0.0616382174899144;
                  20036.7346938776,-0.246299585302623; 20055.1020408163,-0.553225290268046;
                  20073.4693877551,-0.981154108829117; 20091.8367346939,-1.52832758967995;
                  20110.2040816327,-2.19249727961935; 20128.5714285714,-2.97093396292743;
                  20146.9387755102,-3.86043887629832; 20165.306122449,-4.85735685324478;
                  20183.6734693878,-5.9575913439613; 20202.0408163265,-7.15662124892597;
                  20220.4081632653,-8.44951949706817; 20238.7755102041,-9.83097329216049;
                  20257.1428571429,-11.295305944238; 20275.5102040816,-12.8365001963349;
                  20293.8775510204,-14.4482229506843; 20312.2448979592,-16.1238512927749;
                  20330.612244898,-17.8564997063282; 20348.9795918367,-19.6390483673608;
                  20367.3469387755,-21.464172401069; 20385.7142857143,-23.3243719813106;
                  20404.0816326531,-25.2120031489986; 20422.4489795918,-27.1193092227695;
                  20440.8163265306,-29.0384526728504; 20459.1836734694,-30.9615473271497;
                  20477.5510204082,-32.8806907772305; 20495.9183673469,-34.7879968510014;
                  20514.2857142857,-36.6756280186894; 20532.6530612245,-38.535827598931;
                  20551.0204081633,-40.3609516326392; 20569.387755102,-42.1435002936718;
                  20587.7551020408,-43.8761487072251; 20606.1224489796,-45.5517770493158;
                  20624.4897959184,-47.1634998036651; 20642.8571428571,-48.704694055762;
                  20661.2244897959,-50.1690267078395; 20679.5918367347,-51.5504805029318;
                  20697.9591836735,-52.843378751074; 20716.3265306122,-54.0424086560387;
                  20734.693877551,-55.1426431467552; 20753.0612244898,-56.1395611237017;
                  20771.4285714286,-57.0290660370726; 20789.7959183674,-57.8075027203807;
                  20808.1632653061,-58.4716724103201; 20826.5306122449,-59.0188458911709;
                  20844.8979591837,-59.446774709732; 20863.2653061225,-59.7537004146974;
                  20881.6326530612,-59.9383617825101; 20900,-60; 25000,-60])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_staticDecoupled_wMS_w_FW_100_20;

          model Plant_HP_4th_orderFW_100_20
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
                                                separator(w_small=1e4))
              annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 20000,0; 20018.3673469388,-0.0616382174899144;
                  20036.7346938776,-0.246299585302623; 20055.1020408163,-0.553225290268046;
                  20073.4693877551,-0.981154108829117; 20091.8367346939,-1.52832758967995;
                  20110.2040816327,-2.19249727961935; 20128.5714285714,-2.97093396292743;
                  20146.9387755102,-3.86043887629832; 20165.306122449,-4.85735685324478;
                  20183.6734693878,-5.9575913439613; 20202.0408163265,-7.15662124892597;
                  20220.4081632653,-8.44951949706817; 20238.7755102041,-9.83097329216049;
                  20257.1428571429,-11.295305944238; 20275.5102040816,-12.8365001963349;
                  20293.8775510204,-14.4482229506843; 20312.2448979592,-16.1238512927749;
                  20330.612244898,-17.8564997063282; 20348.9795918367,-19.6390483673608;
                  20367.3469387755,-21.464172401069; 20385.7142857143,-23.3243719813106;
                  20404.0816326531,-25.2120031489986; 20422.4489795918,-27.1193092227695;
                  20440.8163265306,-29.0384526728504; 20459.1836734694,-30.9615473271497;
                  20477.5510204082,-32.8806907772305; 20495.9183673469,-34.7879968510014;
                  20514.2857142857,-36.6756280186894; 20532.6530612245,-38.535827598931;
                  20551.0204081633,-40.3609516326392; 20569.387755102,-42.1435002936718;
                  20587.7551020408,-43.8761487072251; 20606.1224489796,-45.5517770493158;
                  20624.4897959184,-47.1634998036651; 20642.8571428571,-48.704694055762;
                  20661.2244897959,-50.1690267078395; 20679.5918367347,-51.5504805029318;
                  20697.9591836735,-52.843378751074; 20716.3265306122,-54.0424086560387;
                  20734.693877551,-55.1426431467552; 20753.0612244898,-56.1395611237017;
                  20771.4285714286,-57.0290660370726; 20789.7959183674,-57.8075027203807;
                  20808.1632653061,-58.4716724103201; 20826.5306122449,-59.0188458911709;
                  20844.8979591837,-59.446774709732; 20863.2653061225,-59.7537004146974;
                  20881.6326530612,-59.9383617825101; 20900,-60; 25000,-60])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_valveTURB_low=-1.518e-11*0.1,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              Kp_valveTURB_high=-1.077e-11*0.5,
              useTS_valveTURB_high=true,
              load_switch=55,
              l_min=0.2,
              Kp_pumpMS_low=0.000147,
              CSmin_pumpMS_low=-150,
              use_valveSEP=false,
              l_max=3,
              load_min=55,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=true,
              useTS_pumpSEP=true,
              Kp_pumpFW_low=15.73*1,
              TS_pumpFW_low=20,
              DT_sh_sp=20,
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (
                Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_4th_orderFW_100_20;

          model Plant_HP_10th_orderFW_100_20
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
                                                separator(w_small=1e4))
              annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 20000,0; 20018.3673469388,-0.0616382174899144;
                  20036.7346938776,-0.246299585302623; 20055.1020408163,-0.553225290268046;
                  20073.4693877551,-0.981154108829117; 20091.8367346939,-1.52832758967995;
                  20110.2040816327,-2.19249727961935; 20128.5714285714,-2.97093396292743;
                  20146.9387755102,-3.86043887629832; 20165.306122449,-4.85735685324478;
                  20183.6734693878,-5.9575913439613; 20202.0408163265,-7.15662124892597;
                  20220.4081632653,-8.44951949706817; 20238.7755102041,-9.83097329216049;
                  20257.1428571429,-11.295305944238; 20275.5102040816,-12.8365001963349;
                  20293.8775510204,-14.4482229506843; 20312.2448979592,-16.1238512927749;
                  20330.612244898,-17.8564997063282; 20348.9795918367,-19.6390483673608;
                  20367.3469387755,-21.464172401069; 20385.7142857143,-23.3243719813106;
                  20404.0816326531,-25.2120031489986; 20422.4489795918,-27.1193092227695;
                  20440.8163265306,-29.0384526728504; 20459.1836734694,-30.9615473271497;
                  20477.5510204082,-32.8806907772305; 20495.9183673469,-34.7879968510014;
                  20514.2857142857,-36.6756280186894; 20532.6530612245,-38.535827598931;
                  20551.0204081633,-40.3609516326392; 20569.387755102,-42.1435002936718;
                  20587.7551020408,-43.8761487072251; 20606.1224489796,-45.5517770493158;
                  20624.4897959184,-47.1634998036651; 20642.8571428571,-48.704694055762;
                  20661.2244897959,-50.1690267078395; 20679.5918367347,-51.5504805029318;
                  20697.9591836735,-52.843378751074; 20716.3265306122,-54.0424086560387;
                  20734.693877551,-55.1426431467552; 20753.0612244898,-56.1395611237017;
                  20771.4285714286,-57.0290660370726; 20789.7959183674,-57.8075027203807;
                  20808.1632653061,-58.4716724103201; 20826.5306122449,-59.0188458911709;
                  20844.8979591837,-59.446774709732; 20863.2653061225,-59.7537004146974;
                  20881.6326530612,-59.9383617825101; 20900,-60; 25000,-60])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_10thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_valveTURB_low=-1.518e-11*0.1,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              Kp_valveTURB_high=-1.077e-11*0.5,
              useTS_valveTURB_high=true,
              load_switch=55,
              l_min=0.2,
              Kp_pumpMS_low=0.000147,
              CSmin_pumpMS_low=-150,
              use_valveSEP=false,
              l_max=3,
              load_min=55,
              dec_wMS_wFW=2.43e-3,
              dec_wFW_wMS=74,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=true,
              useTS_pumpSEP=true,
              Kp_pumpFW_low=15.73*1,
              TS_pumpFW_low=20,
              A=[-0.00826701880345483,9.43250838340711e-06,-0.0113552737182845,
                  -0.0138396129545222,0.0392727574923542,0.0218572119428319,-0.105992047623591,
                  -0.398263220659893,-0.194053684777024,-0.841970157975721,-0.543993105593968,
                  0.67278246575916,-0.380547418743879,-0.163985208024919,
                  0.436999028418906,-0.225132045831548,-0.175117844260931,
                  0.0460150975286926; 0,-0.0108606555057044,1,0,0,0,0,0,0,0,0,0,
                  0,0,0,0,0,0; 0,-9.36167120482709e-05,-0.0108606555057044,-0.0205782815349691,
                  0.0583951200794353,0.0324997427606611,-0.157600808897867,-0.592182216850568,
                  -0.28854068183568,-1.25193522476402,-0.808869678420953,
                  1.00036807659847,-0.565840384846779,-0.243831513886708,
                  0.649778940123739,-0.334751458504577,-0.260384760241492,
                  0.0684203839309744; 0,0,0,-0.045010047558481,
                  0.0711709467828456,0.0396101156968038,-0.192081098005201,-0.721741285639752,
                  -0.351668315497568,-1.52583666470836,-0.98583615820714,
                  1.21923104269668,-0.689636323424518,-0.297177566810467,
                  0.791939160417045,-0.407989198520364,-0.317352372749679,
                  0.0833895622954311; 0,0,0,0,-0.2,0.112401876636035,-0.545069750549526,
                  -2.04808982565427,-0.997931410196544,-4.32987638476217,-2.79751352120092,
                  3.45981966578992,-1.95698537067252,-0.843302666907442,
                  2.24729078031005,-1.15775353730211,-0.900552841728778,
                  0.236635090026266; 0,0,0,0,0,-1.04328573447507,1,0,0,0,0,0,0,
                  0,0,0,0,0; 0,0,0,0,0,-0.334649542989399,-1.04328573447507,-5.64383226346336,
                  -2.74995628562899,-11.9316524749212,-7.70898662288162,
                  9.53407492726171,-5.39277967000254,-2.32385256727521,
                  6.19276169063817,-3.19037118641861,-2.48161438987611,
                  0.652085049702912; 0,0,0,0,0,0,0,-6.9835004164999,
                  24.4753121985028,0,0,0,0,0,0,0,0,0; 0,0,0,0,0,0,0,-24.4753121985028,
                  -6.9835004164999,-48.8440350102004,-31.5579097943583,
                  39.0291864866035,-22.0761641824168,-9.51304409788249,
                  25.3510123147763,-13.06026992091,-10.1588661248471,
                  2.66940937680366; 0.198841363451337,-0.000245596025959061,
                  0.29565943495941,0.360344651102706,-1.02255230279395,-0.569100410358232,
                  2.75973522858558,10.369655695381,5.05261292826275,
                  21.918031482177,14.151651709721,-17.4940955320443,
                  9.88629672355252,4.26699883027104,-11.3516143425471,
                  5.83804990536625,4.54333140680033,-1.19602614169308;
                  1.04797429050729,-0.00129439024450688,1.55824462881036,
                  1.8991618419971,-5.38926360907467,-2.99938900247249,
                  14.5449192158288,54.6522734583406,26.6293107067734,
                  115.551717173136,74.530014823476,-92.3292819607109,
                  52.2363872998101,22.146963300625,-59.577944391706,
                  31.0414733943376,24.0797857084477,-6.26907258131803;
                  1.01814538798911,-0.00125754750821686,1.51389170187953,
                  1.84510525495644,-5.23586688904441,-2.91401621901848,
                  14.1309214857759,53.0966844022421,25.8713502106107,
                  112.249981545055,72.6119399941614,-89.7505889704599,
                  50.79837425297,21.9494727926064,-58.5005100040441,
                  30.1929023581392,23.4544494432086,-6.14302240915466; -0.0281004323163195,
                  3.47078413909017e-05,-0.0417828453625116,-0.0509242156818015,
                  0.144507969950579,0.0804257589310632,-0.390008153513846,-1.46544865189935,
                  -0.714039599944483,-3.10179815611907,-2.0182041421944,
                  2.54056146610873,-1.51842068675625,-0.509513026978294,
                  1.80543703401938,-1.28641833086766,-0.917965243913387,
                  0.16055740393882; -0.0824041175217926,0.000101780250521007,-0.122527598895612,
                  -0.149334537152698,0.423767563594652,0.235847392528754,-1.1436933551356,
                  -4.29740729871742,-2.09391095648259,-9.10488121894468,-5.55986954910803,
                  7.24817418490053,-4.31341407815564,-1.88202110982804,
                  5.10539217797251,-2.64813852309889,-1.84671447478929,
                  0.467865586295458; 0.609129434477465,-0.000752357385836209,
                  0.905721331260271,1.10387763256758,-3.13248056195783,-1.74337876740239,
                  8.45415626767854,31.7663407644017,15.4781439948204,
                  67.1699200568904,43.0124695266567,-53.6403115417686,
                  30.5734615650991,12.9159487585775,-35.2759047355519,
                  18.7693361814706,14.6534514649151,-3.71096258080218;
                  1.31788461859283,-0.00162776607130932,1.95957729775985,
                  2.38829921922497,-6.77729184797419,-3.7718946612913,
                  18.2910263036483,68.7282037491694,33.4878052849923,
                  145.34025205016,93.8362132682321,-116.168063322419,
                  65.7931818494065,28.7827761770325,-75.5505996456078,
                  37.8829985692954,29.1664645585148,-7.908613867848; -0.335304954191868,
                  0.000414147050716947,-0.498568665868762,-0.607646943443171,
                  1.72432358688299,0.959670481601986,-4.65372434759549,-17.4862858892843,
                  -8.52018974852281,-36.9739416245018,-24.1198731430933,
                  29.4845669850745,-16.4474840361134,-7.20725206475585,
                  18.8031987205012,-8.67504096201164,-9.51917816924227,
                  2.76058792390043; 0.0354424503802169,-4.37762285097323e-05,
                  0.0526997736844446,0.0642295807814143,-0.182264688915294,-0.101439221223299,
                  0.491908610984849,1.84833779584004,0.900602268522568,
                  3.90866555845146,2.54047199354431,-3.09499795517087,
                  1.69971713905518,0.803476837830201,-1.90049980769868,
                  0.69055915025261,0.833661871962516,-0.306473003941568],
              B=[0.349555620805269; 0; 0.519758319882152; 0.633472311966374;
                  1.79760839900131; 0; 4.95359146472753; 0; 20.2782804341591; -9.10144659637365;
                  -47.9682993209758; -46.6029588375603; 1.28622425245332;
                  3.77183430010749; -27.8813166533769; -60.3227430556238;
                  15.3477127751825; -1.62228604642973],
              C=[0.532463714014785,-0.000657664833209802,0.791726218778057,
                  0.964942343590728,-2.73822301089423,-1.52395514135992,
                  7.39010658549292,27.7681931403996,13.5300472626276,
                  58.7048684193927,37.9289495980825,-46.9085581634177,
                  26.5329904309306,11.4335763193488,-30.468978288271,
                  15.6969305887333,12.2097795365357,-3.20832065143729],
              D=[-24.3721425637798],
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (
                Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_10th_orderFW_100_20;
        end Transition_high_to_low;

        package DT_sh_testCases
          "Package containing models for comparison between the different degree of superheating control solutions"

          model Plant_HP_fullyDecentralized_70_90
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
              separator(w_small=1e4),
              valveLiq(Av=3.702e-4)) annotation (Placement(transformation(
                    extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_fullyDecentralized
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=4,
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=200,
              CSstart_pumpFW_low=143,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=0.000147,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              useTS_valveTURB_high=true,
              useTS_pumpSEP=false,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              use_valveSEP=true,
              useTS_valveTURB_low=false,
              Kp_valveTURB_low=-1.518e-11*0.1,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              DT_sh_sp=20,
              T_FW_sp=558.15)     annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 5000,0; 5360,-30; 20000,-30; 20002.4489795918,-29.9794539275034;
                  20004.8979591837,-29.9179001382325; 20007.3469387755,-29.8155915699107;
                  20009.7959183674,-29.6729486303903; 20012.2448979592,-29.4905574701067;
                  20014.693877551,-29.2691675734602; 20017.1428571429,-29.0096886790242;
                  20019.5918367347,-28.7131870412339; 20022.0408163265,-28.3808810489184;
                  20024.4897959184,-28.0141362186796; 20026.9387755102,-27.6144595836913;
                  20029.387755102,-27.1834935009773; 20031.8367346939,-26.7230089026132;
                  20034.2857142857,-26.2348980185873; 20036.7346938776,-25.7211666012217;
                  20039.1836734694,-25.1839256831053; 20041.6326530612,-24.6253829024083;
                  20044.0816326531,-24.0478334312239; 20046.5306122449,-23.4536505442131;
                  20048.9795918367,-22.8452758663103; 20051.4285714286,-22.2252093395632;
                  20053.8775510204,-21.5959989503338; 20056.3265306122,-20.9602302590768;
                  20058.7755102041,-20.3205157757166; 20061.2244897959,-19.6794842242835;
                  20063.6734693878,-19.0397697409232; 20066.1224489796,-18.4040010496662;
                  20068.5714285714,-17.7747906604369; 20071.0204081633,-17.1547241336897;
                  20073.4693877551,-16.5463494557869; 20075.9183673469,-15.9521665687761;
                  20078.3673469388,-15.3746170975917; 20080.8163265306,-14.8160743168947;
                  20083.2653061225,-14.2788333987783; 20085.7142857143,-13.7651019814127;
                  20088.1632653061,-13.2769910973868; 20090.612244898,-12.8165064990227;
                  20093.0612244898,-12.3855404163087; 20095.5102040816,-11.9858637813204;
                  20097.9591836735,-11.6191189510816; 20100.4081632653,-11.2868129587661;
                  20102.8571428571,-10.9903113209758; 20105.306122449,-10.7308324265398;
                  20107.7551020408,-10.5094425298933; 20110.2040816327,-10.3270513696097;
                  20112.6530612245,-10.1844084300893; 20115.1020408163,-10.0820998617675;
                  20117.5510204082,-10.0205460724966; 20120,-10; 25000,-10])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_fullyDecentralized_70_90;

          model Plant_HP_staticDecoupled_wMS_w_FW_70_90
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
              separator(w_small=1e4),
              valveLiq(Av=3.7e-4)) annotation (Placement(transformation(extent=
                      {{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=4,
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=200,
              CSstart_pumpFW_low=143,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              useTS_pumpMS=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              load_switch=55,
              Kp_pumpMS_high=0.0004566,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=0.000147,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_valveTURB_high=-1.077e-11,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              useTS_pumpSEP=false,
              Kp_pumpFW_high=-0.0007,
              Ti_pumpFW_high=475,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=2.43e-3,
              dec_wFW_wMS=74,
              useTS_valveTURB_high=true,
              useTS_valveTURB_low=false,
              Kp_valveTURB_low=-1.518e-11*0.1,
              l_min=0.2,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              use_valveSEP=true,
              l_max=0.3,
              DT_sh_sp=20,
              T_FW_sp=558.15)     annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 5000,0; 5360,-30; 20000,-30; 20002.4489795918,-29.9794539275034;
                  20004.8979591837,-29.9179001382325; 20007.3469387755,-29.8155915699107;
                  20009.7959183674,-29.6729486303903; 20012.2448979592,-29.4905574701067;
                  20014.693877551,-29.2691675734602; 20017.1428571429,-29.0096886790242;
                  20019.5918367347,-28.7131870412339; 20022.0408163265,-28.3808810489184;
                  20024.4897959184,-28.0141362186796; 20026.9387755102,-27.6144595836913;
                  20029.387755102,-27.1834935009773; 20031.8367346939,-26.7230089026132;
                  20034.2857142857,-26.2348980185873; 20036.7346938776,-25.7211666012217;
                  20039.1836734694,-25.1839256831053; 20041.6326530612,-24.6253829024083;
                  20044.0816326531,-24.0478334312239; 20046.5306122449,-23.4536505442131;
                  20048.9795918367,-22.8452758663103; 20051.4285714286,-22.2252093395632;
                  20053.8775510204,-21.5959989503338; 20056.3265306122,-20.9602302590768;
                  20058.7755102041,-20.3205157757166; 20061.2244897959,-19.6794842242835;
                  20063.6734693878,-19.0397697409232; 20066.1224489796,-18.4040010496662;
                  20068.5714285714,-17.7747906604369; 20071.0204081633,-17.1547241336897;
                  20073.4693877551,-16.5463494557869; 20075.9183673469,-15.9521665687761;
                  20078.3673469388,-15.3746170975917; 20080.8163265306,-14.8160743168947;
                  20083.2653061225,-14.2788333987783; 20085.7142857143,-13.7651019814127;
                  20088.1632653061,-13.2769910973868; 20090.612244898,-12.8165064990227;
                  20093.0612244898,-12.3855404163087; 20095.5102040816,-11.9858637813204;
                  20097.9591836735,-11.6191189510816; 20100.4081632653,-11.2868129587661;
                  20102.8571428571,-10.9903113209758; 20105.306122449,-10.7308324265398;
                  20107.7551020408,-10.5094425298933; 20110.2040816327,-10.3270513696097;
                  20112.6530612245,-10.1844084300893; 20115.1020408163,-10.0820998617675;
                  20117.5510204082,-10.0205460724966; 20120,-10; 25000,-10])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-289.2,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_staticDecoupled_wMS_w_FW_70_90;

          model Plant_HP_4th_orderFW_70_90
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
              separator(w_small=1e4),
              valveLiq(Av=3.7e-4)) annotation (Placement(transformation(extent=
                      {{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_valveTURB_low=-1.518e-11*0.1,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              useTS_valveTURB_high=true,
              load_switch=55,
              l_min=0.2,
              Kp_pumpMS_low=0.000147,
              CSmin_pumpMS_low=-150,
              load_min=55,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=true,
              useTS_pumpSEP=true,
              TS_pumpFW_low=20,
              use_valveSEP=true,
              l_max=0.5,
              DT_sh_sp=20,
              Kp_pumpFW_low=15.73,
              Kp_valveTURB_high=-1.077e-11,
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 5000,0; 5360,-30; 20000,-30; 20002.4489795918,-29.9794539275034;
                  20004.8979591837,-29.9179001382325; 20007.3469387755,-29.8155915699107;
                  20009.7959183674,-29.6729486303903; 20012.2448979592,-29.4905574701067;
                  20014.693877551,-29.2691675734602; 20017.1428571429,-29.0096886790242;
                  20019.5918367347,-28.7131870412339; 20022.0408163265,-28.3808810489184;
                  20024.4897959184,-28.0141362186796; 20026.9387755102,-27.6144595836913;
                  20029.387755102,-27.1834935009773; 20031.8367346939,-26.7230089026132;
                  20034.2857142857,-26.2348980185873; 20036.7346938776,-25.7211666012217;
                  20039.1836734694,-25.1839256831053; 20041.6326530612,-24.6253829024083;
                  20044.0816326531,-24.0478334312239; 20046.5306122449,-23.4536505442131;
                  20048.9795918367,-22.8452758663103; 20051.4285714286,-22.2252093395632;
                  20053.8775510204,-21.5959989503338; 20056.3265306122,-20.9602302590768;
                  20058.7755102041,-20.3205157757166; 20061.2244897959,-19.6794842242835;
                  20063.6734693878,-19.0397697409232; 20066.1224489796,-18.4040010496662;
                  20068.5714285714,-17.7747906604369; 20071.0204081633,-17.1547241336897;
                  20073.4693877551,-16.5463494557869; 20075.9183673469,-15.9521665687761;
                  20078.3673469388,-15.3746170975917; 20080.8163265306,-14.8160743168947;
                  20083.2653061225,-14.2788333987783; 20085.7142857143,-13.7651019814127;
                  20088.1632653061,-13.2769910973868; 20090.612244898,-12.8165064990227;
                  20093.0612244898,-12.3855404163087; 20095.5102040816,-11.9858637813204;
                  20097.9591836735,-11.6191189510816; 20100.4081632653,-11.2868129587661;
                  20102.8571428571,-10.9903113209758; 20105.306122449,-10.7308324265398;
                  20107.7551020408,-10.5094425298933; 20110.2040816327,-10.3270513696097;
                  20112.6530612245,-10.1844084300893; 20115.1020408163,-10.0820998617675;
                  20117.5510204082,-10.0205460724966; 20120,-10; 25000,-10])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (
                Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(loadCalculator_smooth.y, gain.u) annotation (Line(points={{
                    -299,-40},{-294,-40},{-294,-40},{-289.2,-40}}, color={0,0,
                    127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_4th_orderFW_70_90;

          model Plant_HP_10th_orderFW_70_90
            "Model of the high pressure parto of the OTSG for linearization at 100% load"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},{
                      -140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(
                                                separator(w_small=1e4))
              annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs annotation (Placement(transformation(extent={{20,-160},{120,
                      -104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{180,200},{200,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{260,50},{240,70}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{200,
                      -130},{180,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Auxiliaries.Components.powerSensor powerSensor annotation (
                Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{140,200},{160,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_10thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_valveTURB_low=-1.518e-11*0.1,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              Kp_valveTURB_high=-1.077e-11*0.5,
              useTS_valveTURB_high=true,
              load_switch=55,
              l_min=0.2,
              Kp_pumpMS_low=0.000147,
              CSmin_pumpMS_low=-150,
              use_valveSEP=false,
              l_max=3,
              load_min=55,
              dec_wMS_wFW=2.43e-3,
              dec_wFW_wMS=74,
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=true,
              useTS_pumpSEP=true,
              Kp_pumpFW_low=15.73*1,
              TS_pumpFW_low=20,
              A=[-0.00826701880345483,9.43250838340711e-06,-0.0113552737182845,
                  -0.0138396129545222,0.0392727574923542,0.0218572119428319,-0.105992047623591,
                  -0.398263220659893,-0.194053684777024,-0.841970157975721,-0.543993105593968,
                  0.67278246575916,-0.380547418743879,-0.163985208024919,
                  0.436999028418906,-0.225132045831548,-0.175117844260931,
                  0.0460150975286926; 0,-0.0108606555057044,1,0,0,0,0,0,0,0,0,0,
                  0,0,0,0,0,0; 0,-9.36167120482709e-05,-0.0108606555057044,-0.0205782815349691,
                  0.0583951200794353,0.0324997427606611,-0.157600808897867,-0.592182216850568,
                  -0.28854068183568,-1.25193522476402,-0.808869678420953,
                  1.00036807659847,-0.565840384846779,-0.243831513886708,
                  0.649778940123739,-0.334751458504577,-0.260384760241492,
                  0.0684203839309744; 0,0,0,-0.045010047558481,
                  0.0711709467828456,0.0396101156968038,-0.192081098005201,-0.721741285639752,
                  -0.351668315497568,-1.52583666470836,-0.98583615820714,
                  1.21923104269668,-0.689636323424518,-0.297177566810467,
                  0.791939160417045,-0.407989198520364,-0.317352372749679,
                  0.0833895622954311; 0,0,0,0,-0.2,0.112401876636035,-0.545069750549526,
                  -2.04808982565427,-0.997931410196544,-4.32987638476217,-2.79751352120092,
                  3.45981966578992,-1.95698537067252,-0.843302666907442,
                  2.24729078031005,-1.15775353730211,-0.900552841728778,
                  0.236635090026266; 0,0,0,0,0,-1.04328573447507,1,0,0,0,0,0,0,
                  0,0,0,0,0; 0,0,0,0,0,-0.334649542989399,-1.04328573447507,-5.64383226346336,
                  -2.74995628562899,-11.9316524749212,-7.70898662288162,
                  9.53407492726171,-5.39277967000254,-2.32385256727521,
                  6.19276169063817,-3.19037118641861,-2.48161438987611,
                  0.652085049702912; 0,0,0,0,0,0,0,-6.9835004164999,
                  24.4753121985028,0,0,0,0,0,0,0,0,0; 0,0,0,0,0,0,0,-24.4753121985028,
                  -6.9835004164999,-48.8440350102004,-31.5579097943583,
                  39.0291864866035,-22.0761641824168,-9.51304409788249,
                  25.3510123147763,-13.06026992091,-10.1588661248471,
                  2.66940937680366; 0.198841363451337,-0.000245596025959061,
                  0.29565943495941,0.360344651102706,-1.02255230279395,-0.569100410358232,
                  2.75973522858558,10.369655695381,5.05261292826275,
                  21.918031482177,14.151651709721,-17.4940955320443,
                  9.88629672355252,4.26699883027104,-11.3516143425471,
                  5.83804990536625,4.54333140680033,-1.19602614169308;
                  1.04797429050729,-0.00129439024450688,1.55824462881036,
                  1.8991618419971,-5.38926360907467,-2.99938900247249,
                  14.5449192158288,54.6522734583406,26.6293107067734,
                  115.551717173136,74.530014823476,-92.3292819607109,
                  52.2363872998101,22.146963300625,-59.577944391706,
                  31.0414733943376,24.0797857084477,-6.26907258131803;
                  1.01814538798911,-0.00125754750821686,1.51389170187953,
                  1.84510525495644,-5.23586688904441,-2.91401621901848,
                  14.1309214857759,53.0966844022421,25.8713502106107,
                  112.249981545055,72.6119399941614,-89.7505889704599,
                  50.79837425297,21.9494727926064,-58.5005100040441,
                  30.1929023581392,23.4544494432086,-6.14302240915466; -0.0281004323163195,
                  3.47078413909017e-05,-0.0417828453625116,-0.0509242156818015,
                  0.144507969950579,0.0804257589310632,-0.390008153513846,-1.46544865189935,
                  -0.714039599944483,-3.10179815611907,-2.0182041421944,
                  2.54056146610873,-1.51842068675625,-0.509513026978294,
                  1.80543703401938,-1.28641833086766,-0.917965243913387,
                  0.16055740393882; -0.0824041175217926,0.000101780250521007,-0.122527598895612,
                  -0.149334537152698,0.423767563594652,0.235847392528754,-1.1436933551356,
                  -4.29740729871742,-2.09391095648259,-9.10488121894468,-5.55986954910803,
                  7.24817418490053,-4.31341407815564,-1.88202110982804,
                  5.10539217797251,-2.64813852309889,-1.84671447478929,
                  0.467865586295458; 0.609129434477465,-0.000752357385836209,
                  0.905721331260271,1.10387763256758,-3.13248056195783,-1.74337876740239,
                  8.45415626767854,31.7663407644017,15.4781439948204,
                  67.1699200568904,43.0124695266567,-53.6403115417686,
                  30.5734615650991,12.9159487585775,-35.2759047355519,
                  18.7693361814706,14.6534514649151,-3.71096258080218;
                  1.31788461859283,-0.00162776607130932,1.95957729775985,
                  2.38829921922497,-6.77729184797419,-3.7718946612913,
                  18.2910263036483,68.7282037491694,33.4878052849923,
                  145.34025205016,93.8362132682321,-116.168063322419,
                  65.7931818494065,28.7827761770325,-75.5505996456078,
                  37.8829985692954,29.1664645585148,-7.908613867848; -0.335304954191868,
                  0.000414147050716947,-0.498568665868762,-0.607646943443171,
                  1.72432358688299,0.959670481601986,-4.65372434759549,-17.4862858892843,
                  -8.52018974852281,-36.9739416245018,-24.1198731430933,
                  29.4845669850745,-16.4474840361134,-7.20725206475585,
                  18.8031987205012,-8.67504096201164,-9.51917816924227,
                  2.76058792390043; 0.0354424503802169,-4.37762285097323e-05,
                  0.0526997736844446,0.0642295807814143,-0.182264688915294,-0.101439221223299,
                  0.491908610984849,1.84833779584004,0.900602268522568,
                  3.90866555845146,2.54047199354431,-3.09499795517087,
                  1.69971713905518,0.803476837830201,-1.90049980769868,
                  0.69055915025261,0.833661871962516,-0.306473003941568],
              B=[0.349555620805269; 0; 0.519758319882152; 0.633472311966374;
                  1.79760839900131; 0; 4.95359146472753; 0; 20.2782804341591; -9.10144659637365;
                  -47.9682993209758; -46.6029588375603; 1.28622425245332;
                  3.77183430010749; -27.8813166533769; -60.3227430556238;
                  15.3477127751825; -1.62228604642973],
              C=[0.532463714014785,-0.000657664833209802,0.791726218778057,
                  0.964942343590728,-2.73822301089423,-1.52395514135992,
                  7.39010658549292,27.7681931403996,13.5300472626276,
                  58.7048684193927,37.9289495980825,-46.9085581634177,
                  26.5329904309306,11.4335763193488,-30.468978288271,
                  15.6969305887333,12.2097795365357,-3.20832065143729],
              D=[-24.3721425637798],
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));
            Modelica.Blocks.Sources.TimeTable loadCalculator_smooth(
              offset=100,
              startTime=0,
              table=[0,0; 5000,0; 5360,-30; 20000,-30; 20002.4489795918,-29.9794539275034;
                  20004.8979591837,-29.9179001382325; 20007.3469387755,-29.8155915699107;
                  20009.7959183674,-29.6729486303903; 20012.2448979592,-29.4905574701067;
                  20014.693877551,-29.2691675734602; 20017.1428571429,-29.0096886790242;
                  20019.5918367347,-28.7131870412339; 20022.0408163265,-28.3808810489184;
                  20024.4897959184,-28.0141362186796; 20026.9387755102,-27.6144595836913;
                  20029.387755102,-27.1834935009773; 20031.8367346939,-26.7230089026132;
                  20034.2857142857,-26.2348980185873; 20036.7346938776,-25.7211666012217;
                  20039.1836734694,-25.1839256831053; 20041.6326530612,-24.6253829024083;
                  20044.0816326531,-24.0478334312239; 20046.5306122449,-23.4536505442131;
                  20048.9795918367,-22.8452758663103; 20051.4285714286,-22.2252093395632;
                  20053.8775510204,-21.5959989503338; 20056.3265306122,-20.9602302590768;
                  20058.7755102041,-20.3205157757166; 20061.2244897959,-19.6794842242835;
                  20063.6734693878,-19.0397697409232; 20066.1224489796,-18.4040010496662;
                  20068.5714285714,-17.7747906604369; 20071.0204081633,-17.1547241336897;
                  20073.4693877551,-16.5463494557869; 20075.9183673469,-15.9521665687761;
                  20078.3673469388,-15.3746170975917; 20080.8163265306,-14.8160743168947;
                  20083.2653061225,-14.2788333987783; 20085.7142857143,-13.7651019814127;
                  20088.1632653061,-13.2769910973868; 20090.612244898,-12.8165064990227;
                  20093.0612244898,-12.3855404163087; 20095.5102040816,-11.9858637813204;
                  20097.9591836735,-11.6191189510816; 20100.4081632653,-11.2868129587661;
                  20102.8571428571,-10.9903113209758; 20105.306122449,-10.7308324265398;
                  20107.7551020408,-10.5094425298933; 20110.2040816327,-10.3270513696097;
                  20112.6530612245,-10.1844084300893; 20115.1020408163,-10.0820998617675;
                  20117.5510204082,-10.0205460724966; 20120,-10; 25000,-10])
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(
                points={{-82.2222,-164},{-82,-164},{-82,-172},{-82,-180},{
                    81.1111,-180},{81.1111,-162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{201,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0, HPH1_sinkP.y[1]) annotation (Line(
                  points={{146,-91.2},{146,-80},{179,-80}}, color={0,0,127}));
            connect(sourcePressure1.in_h, HPH1_FW_source.y[1]) annotation (Line(
                  points={{146,-131},{146,-120},{179,-120}}, color={0,0,127}));
            connect(constantSpeed.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140}}, color={0,0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}}, color={0,0,0}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{161,
                    210},{170,210},{178,210}}, color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    272,60},{279,60}}, color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y)
              annotation (Line(points={{262,0},{279,0}}, color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {210,-80},{219,-80}}, color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{202,-120},{219,-120}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (
                Line(
                points={{-213.818,-40},{-200,-40},{-200,120},{-6,120},{-6,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-200,-40},{-200,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.u, loadCalculator_smooth.y) annotation (Line(points={{
                    -289.2,-40},{-299,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the adopted control system, involving only the high pressure part of the power plant.</p>
</html>"));
          end Plant_HP_10th_orderFW_70_90;
        end DT_sh_testCases;

        package LoadRamps
          "Package containing generic load ramps for control testing"

          model Plant_Full_60_100_aggressive "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-480,260},{-460,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                   annotation (Placement(transformation(extent={{-240,
                      -160},{-100,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs annotation (Placement(transformation(extent={{-60,-160},{60,
                      -100}})));

            Control.Schemes.PlantControlSchemes.plantController
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_pumpSEP=false,
              Kp_valveTURB_low=-1.518e-11,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=100,
              CSstart_pumpCOND=77,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              useTS_pumpCOND=false,
              staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6])), control_wMS_high(table_P_MEC_high(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6]))),
              useTS_pumpMS=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              CSmin_pumpFW_high=-0.1,
              CSmax_pumpFW_high=0.1,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=20,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              useTS_valveDEA=true,
              TS_valveDEA=1,
              Kp_pumpMS_low=0.000147,
              Kp_pumpCOND=1560,
              Ti_pumpCOND=128,
              DT_sh_sp=20,
              Kp_pumpMS_high=0.0004566,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              useTS_valveTURB_high=true,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-340,
                      -60},{-292,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-368,-46},{-356,-34}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
              LPHs annotation (Placement(transformation(extent={{170,-112},{328,
                      -52}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-162},{380,-142}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-20},{380,0}})));
            SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
              annotation (Placement(transformation(extent={{230,102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              h_start=1e6,
              w_small=100,
              p_start=1086000)
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-20},{420,0}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
            Modelica.Blocks.Sources.Ramp ramp_smooth(
              height=-40,
              duration=2500,
              offset=100,
              startTime=1000)
              annotation (Placement(transformation(extent={{-440,-20},{-420,0}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-480,-98},{-460,-78}})));
            Modelica.Blocks.Math.MultiSum add3_1(nu=5) annotation (Placement(
                  transformation(extent={{-400,-50},{-380,-30}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth1(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=5000) annotation (Placement(transformation(extent={{-440,
                      -60},{-420,-40}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth2(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=6000) annotation (Placement(transformation(extent={{-440,
                      -98},{-420,-78}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth3(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=7000) annotation (Placement(transformation(extent={{-440,
                      -140},{-420,-120}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth4(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=8000) annotation (Placement(transformation(extent={{-440,
                      -180},{-420,-160}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},
                    {49.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-99,140}},          color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-59.8,140}},         color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-355.4,
                    -40},{-342.182,-40}}, color={0,0,127}));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-82},{331.292,-82},{360,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-152},{366,-152},{366,-91}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-10},{366,-10},{366,-31.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,27.1},{249,27.1},{249,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{127.714,-82},{166.708,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                    419,-10}},           color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                    419,-152}},            color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},
                    {-289.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
                  points={{140.1,140},{140.1,140},{225.8,140}}, color={0,0,0}));
            connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    136,-220},{136,-120},{137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    136,-220},{136,-160},{249,-160},{249,-112}},
                color={255,204,51},
                thickness=0.5));
            connect(realExpression.y, ramp_smooth1.u) annotation (Line(points={{
                    -459,-88},{-450,-88},{-450,-50},{-442,-50}}, color={0,0,127}));
            connect(add3_1.y, gain.u) annotation (Line(points={{-378.3,-40},{
                    -369.2,-40}},       color={0,0,127}));
            connect(ramp_smooth.y, add3_1.u[1]) annotation (Line(points={{-419,-10},
                    {-410,-10},{-410,-34.4},{-400,-34.4}}, color={0,0,127}));
            connect(ramp_smooth1.y, add3_1.u[2]) annotation (Line(points={{-419,-50},
                    {-410,-50},{-410,-37.2},{-400,-37.2}}, color={0,0,127}));
            connect(realExpression.y, ramp_smooth2.u) annotation (Line(points={{
                    -459,-88},{-450,-88},{-442,-88}}, color={0,0,127}));
            connect(realExpression.y, ramp_smooth3.u) annotation (Line(points={{
                    -459,-88},{-450,-88},{-450,-130},{-442,-130}}, color={0,0,127}));
            connect(realExpression.y, ramp_smooth4.u) annotation (Line(points={{
                    -459,-88},{-450,-88},{-450,-170},{-442,-170}}, color={0,0,127}));
            connect(ramp_smooth2.y, add3_1.u[3]) annotation (Line(points={{-419,-88},
                    {-406,-88},{-406,-40},{-400,-40}}, color={0,0,127}));
            connect(ramp_smooth3.y, add3_1.u[4]) annotation (Line(points={{-419,
                    -130},{-412,-130},{-412,-42.8},{-400,-42.8}}, color={0,0,127}));
            connect(ramp_smooth4.y, add3_1.u[5]) annotation (Line(points={{-419,
                    -170},{-408,-170},{-408,-45.6},{-400,-45.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-480,-280},{480,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-480,
                      -280},{480,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_Full_60_100_aggressive;

          model Plant_HP_60_100_aggressive "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{24,102},{100,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{134,102},{216,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,
                      -190},{-160,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                   annotation (Placement(transformation(extent={{-160,
                      -160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                      -100}})));

            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_pumpSEP=false,
              Kp_valveTURB_low=-1.518e-11,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              Kp_pumpMS_low=0.000147,
              DT_sh_sp=20,
              Kp_pumpMS_high=0.0004566,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSmin_valveTURB_high=-1e-5,
              CSmax_valveTURB_high=1e-5,
              useTS_pumpMS=false,
              useTS_valveTURB_high=true,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-212,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
              annotation (Placement(transformation(extent={{-18,130},{2,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{340,220},{320,240}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{340,70},{320,90}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{340,10},{320,30}})));
            Modelica.Blocks.Sources.Ramp ramp_smooth(
              height=-40,
              duration=2500,
              offset=100,
              startTime=1000)
              annotation (Placement(transformation(extent={{-360,-20},{-340,0}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-400,-98},{-380,-78}})));
            Modelica.Blocks.Math.MultiSum add3_1(nu=5) annotation (Placement(
                  transformation(extent={{-320,-50},{-300,-30}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth1(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=5000) annotation (Placement(transformation(extent={{-360,
                      -60},{-340,-40}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth2(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=6000) annotation (Placement(transformation(extent={{-360,
                      -98},{-340,-78}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth3(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=7000) annotation (Placement(transformation(extent={{-360,
                      -140},{-340,-120}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth4(
              sigType=2,
              height=10,
              duration=60,
              offset=0,
              startTime=8000) annotation (Placement(transformation(extent={{-360,
                      -180},{-340,-160}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,190},{280,210}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{306,220},{286,240}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,50},{266,70}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,-10},{266,10}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{306,70},{286,90}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{306,10},{286,30}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{246,
                      -110},{226,-90}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{246,-70},{226,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{103.8,140},{129.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{20.2,48},{20.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},
                    {129.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-26,140},{-19,140}},           color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{3,140},{20.2,140}},            color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-262.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},
                    {-209.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(realExpression.y, ramp_smooth1.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-50},{-362,-50}},      color={0,0,127}));
            connect(add3_1.y, gain.u) annotation (Line(points={{-298.3,-40},{
                    -289.2,-40}},       color={0,0,127}));
            connect(ramp_smooth.y, add3_1.u[1]) annotation (Line(points={{-339,
                    -10},{-330,-10},{-330,-34.4},{-320,-34.4}},
                                                           color={0,0,127}));
            connect(ramp_smooth1.y, add3_1.u[2]) annotation (Line(points={{-339,
                    -50},{-330,-50},{-330,-37.2},{-320,-37.2}},
                                                           color={0,0,127}));
            connect(realExpression.y, ramp_smooth2.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-362,-88}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth3.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-130},{-362,-130}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth4.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-170},{-362,-170}},      color={0,0,127}));
            connect(ramp_smooth2.y, add3_1.u[3]) annotation (Line(points={{-339,
                    -88},{-326,-88},{-326,-40},{-320,-40}},
                                                       color={0,0,127}));
            connect(ramp_smooth3.y, add3_1.u[4]) annotation (Line(points={{-339,
                    -130},{-332,-130},{-332,-42.8},{-320,-42.8}}, color={0,0,127}));
            connect(ramp_smooth4.y, add3_1.u[5]) annotation (Line(points={{-339,
                    -170},{-328,-170},{-328,-45.6},{-320,-45.6}}, color={0,0,127}));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                    {220.1,200},{220.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                    {266,230},{266,208.8}},          color={0,0,127}));
            connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                    {252,80},{252,68.8}},     color={0,0,127}));
            connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                    {252,20},{252,8.8}},           color={0,0,127}));
            connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                    -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                    -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
                  points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
            connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
                  points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                    {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                    {179.92,0},{179.92,98.2}},  color={0,0,255}));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                    {314,230},{319,230}},          color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                    314,80},{319,80}},      color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                    {314,20},{319,20}},     color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                    {259,-60}},          color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                    -100},{254,-100},{259,-100}},            color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_60_100_aggressive;

          model Plant_HP_60_100_sweet "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{24,102},{100,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{134,102},{216,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,
                      -190},{-160,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                   annotation (Placement(transformation(extent={{-160,
                      -160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                      -100}})));

            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_pumpSEP=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              DT_sh_sp=20,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSmin_valveTURB_high=-1e-5,
              CSmax_valveTURB_high=1e-5,
              useTS_pumpMS=false,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.484,
              B=[0.015625; 0; 0; 0; 0],
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              useTS_valveTURB_high=false,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-212,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
              annotation (Placement(transformation(extent={{-18,130},{2,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{340,220},{320,240}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{340,70},{320,90}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{340,10},{320,30}})));
            Auxiliaries.Components.Ramp_smooth
                                         ramp_smooth(
              height=-40,
              duration=2500,
              offset=100,
              startTime=1000,
              sigType=2)
              annotation (Placement(transformation(extent={{-360,-20},{-340,0}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-400,-98},{-380,-78}})));
            Modelica.Blocks.Math.MultiSum add3_1(nu=5) annotation (Placement(
                  transformation(extent={{-320,-50},{-300,-30}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth1(
              sigType=2,
              height=10,
              offset=0,
              startTime=5000,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -60},{-340,-40}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth2(
              sigType=2,
              height=10,
              offset=0,
              startTime=6000,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -98},{-340,-78}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth3(
              sigType=2,
              height=10,
              offset=0,
              startTime=7000,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -140},{-340,-120}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth4(
              sigType=2,
              height=10,
              offset=0,
              startTime=8000,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -180},{-340,-160}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,190},{280,210}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{306,220},{286,240}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,50},{266,70}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,-10},{266,10}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{306,70},{286,90}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{306,10},{286,30}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{246,
                      -110},{226,-90}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{246,-70},{226,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{103.8,140},{129.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{20.2,48},{20.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},
                    {129.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-26,140},{-19,140}},           color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{3,140},{20.2,140}},            color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-262.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},
                    {-209.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(realExpression.y, ramp_smooth1.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-50},{-362,-50}},      color={0,0,127}));
            connect(add3_1.y, gain.u) annotation (Line(points={{-298.3,-40},{
                    -289.2,-40}},       color={0,0,127}));
            connect(ramp_smooth.y, add3_1.u[1]) annotation (Line(points={{-339,
                    -10},{-330,-10},{-330,-34.4},{-320,-34.4}},
                                                           color={0,0,127}));
            connect(ramp_smooth1.y, add3_1.u[2]) annotation (Line(points={{-339,
                    -50},{-330,-50},{-330,-37.2},{-320,-37.2}},
                                                           color={0,0,127}));
            connect(realExpression.y, ramp_smooth2.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-362,-88}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth3.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-130},{-362,-130}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth4.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-170},{-362,-170}},      color={0,0,127}));
            connect(ramp_smooth2.y, add3_1.u[3]) annotation (Line(points={{-339,
                    -88},{-326,-88},{-326,-40},{-320,-40}},
                                                       color={0,0,127}));
            connect(ramp_smooth3.y, add3_1.u[4]) annotation (Line(points={{-339,
                    -130},{-332,-130},{-332,-42.8},{-320,-42.8}}, color={0,0,127}));
            connect(ramp_smooth4.y, add3_1.u[5]) annotation (Line(points={{-339,
                    -170},{-328,-170},{-328,-45.6},{-320,-45.6}}, color={0,0,127}));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                    {220.1,200},{220.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                    {266,230},{266,208.8}},          color={0,0,127}));
            connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                    {252,80},{252,68.8}},     color={0,0,127}));
            connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                    {252,20},{252,8.8}},           color={0,0,127}));
            connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                    -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                    -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
                  points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
            connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
                  points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                    {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                    {179.92,0},{179.92,98.2}},  color={0,0,255}));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                    {314,230},{319,230}},          color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                    314,80},{319,80}},      color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                    {314,20},{319,20}},     color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                    {259,-60}},          color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                    -100},{254,-100},{259,-100}},            color={0,0,127}));
            connect(realExpression.y, ramp_smooth.u) annotation (Line(points={{
                    -379,-88},{-370,-88},{-370,-10},{-362,-10}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_60_100_sweet;

          model Plant_HP_100_60_aggressive "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{24,102},{100,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{134,102},{216,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,
                      -190},{-160,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(w_small=1e4),
                valveLiq(Av=3.702e-5*10))
                                   annotation (Placement(transformation(extent={{-160,
                      -160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                      -100}})));

            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_pumpSEP=false,
              Kp_valveTURB_low=-1.518e-11,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              Kp_pumpMS_low=0.000147,
              DT_sh_sp=20,
              Kp_pumpMS_high=0.0004566,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSmin_valveTURB_high=-1e-5,
              CSmax_valveTURB_high=1e-5,
              useTS_pumpMS=false,
              l_max=1,
              useTS_valveTURB_high=false,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-212,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
              annotation (Placement(transformation(extent={{-18,130},{2,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{340,220},{320,240}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{340,70},{320,90}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{340,10},{320,30}})));
            Modelica.Blocks.Sources.Ramp ramp_smooth(
              duration=2500,
              offset=100,
              startTime=1000,
              height=0)
              annotation (Placement(transformation(extent={{-360,-20},{-340,0}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-400,-98},{-380,-78}})));
            Modelica.Blocks.Math.MultiSum add3_1(nu=5) annotation (Placement(
                  transformation(extent={{-320,-50},{-300,-30}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth1(
              sigType=2,
              offset=0,
              startTime=5000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -60},{-340,-40}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth2(
              sigType=2,
              offset=0,
              startTime=6000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -98},{-340,-78}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth3(
              sigType=2,
              offset=0,
              startTime=7000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -140},{-340,-120}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth4(
              sigType=2,
              offset=0,
              startTime=8000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -180},{-340,-160}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,190},{280,210}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{306,220},{286,240}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,50},{266,70}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,-10},{266,10}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{306,70},{286,90}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{306,10},{286,30}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{246,
                      -110},{226,-90}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{246,-70},{226,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{103.8,140},{129.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{20.2,48},{20.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},
                    {129.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-26,140},{-19,140}},           color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{3,140},{20.2,140}},            color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-262.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},
                    {-209.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(realExpression.y, ramp_smooth1.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-50},{-362,-50}},      color={0,0,127}));
            connect(add3_1.y, gain.u) annotation (Line(points={{-298.3,-40},{
                    -289.2,-40}},       color={0,0,127}));
            connect(ramp_smooth.y, add3_1.u[1]) annotation (Line(points={{-339,
                    -10},{-330,-10},{-330,-34.4},{-320,-34.4}},
                                                           color={0,0,127}));
            connect(ramp_smooth1.y, add3_1.u[2]) annotation (Line(points={{-339,
                    -50},{-330,-50},{-330,-37.2},{-320,-37.2}},
                                                           color={0,0,127}));
            connect(realExpression.y, ramp_smooth2.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-362,-88}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth3.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-130},{-362,-130}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth4.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-170},{-362,-170}},      color={0,0,127}));
            connect(ramp_smooth2.y, add3_1.u[3]) annotation (Line(points={{-339,
                    -88},{-326,-88},{-326,-40},{-320,-40}},
                                                       color={0,0,127}));
            connect(ramp_smooth3.y, add3_1.u[4]) annotation (Line(points={{-339,
                    -130},{-332,-130},{-332,-42.8},{-320,-42.8}}, color={0,0,127}));
            connect(ramp_smooth4.y, add3_1.u[5]) annotation (Line(points={{-339,
                    -170},{-328,-170},{-328,-45.6},{-320,-45.6}}, color={0,0,127}));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                    {220.1,200},{220.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                    {266,230},{266,208.8}},          color={0,0,127}));
            connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                    {252,80},{252,68.8}},     color={0,0,127}));
            connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                    {252,20},{252,8.8}},           color={0,0,127}));
            connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                    -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                    -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
                  points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
            connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
                  points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                    {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                    {179.92,0},{179.92,98.2}},  color={0,0,255}));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                    {314,230},{319,230}},          color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                    314,80},{319,80}},      color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                    {314,20},{319,20}},     color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                    {259,-60}},          color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                    -100},{254,-100},{259,-100}},            color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_100_60_aggressive;

          model Plant_HP_100_60_sweet "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{24,102},{100,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{134,102},{216,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,
                      -190},{-160,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(w_small=1e4),
                valveLiq(Av=3.702e-5*10))
                                   annotation (Placement(transformation(extent={{-160,
                      -160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
              HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                      -100}})));

            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_pumpSEP=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              DT_sh_sp=20,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSmin_valveTURB_high=-1e-5,
              CSmax_valveTURB_high=1e-5,
              useTS_pumpMS=false,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.484,
              B=[0.015625; 0; 0; 0; 0],
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              useTS_valveTURB_high=false,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -60},{-212,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
              annotation (Placement(transformation(extent={{-18,130},{2,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{340,220},{320,240}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{340,70},{320,90}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{340,10},{320,30}})));
            Modelica.Blocks.Sources.Ramp ramp_smooth(
              duration=2500,
              offset=100,
              startTime=1000,
              height=0)
              annotation (Placement(transformation(extent={{-360,-20},{-340,0}})));
            Modelica.Blocks.Sources.RealExpression realExpression(y=time)
              annotation (Placement(transformation(extent={{-400,-98},{-380,-78}})));
            Modelica.Blocks.Math.MultiSum add3_1(nu=5) annotation (Placement(
                  transformation(extent={{-320,-50},{-300,-30}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth1(
              sigType=2,
              offset=0,
              startTime=5000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -60},{-340,-40}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth2(
              sigType=2,
              offset=0,
              startTime=6000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -98},{-340,-78}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth3(
              sigType=2,
              offset=0,
              startTime=7000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -140},{-340,-120}})));
            Auxiliaries.Components.Ramp_smooth ramp_smooth4(
              sigType=2,
              offset=0,
              startTime=8000,
              height=-10,
              duration=300)   annotation (Placement(transformation(extent={{-360,
                      -180},{-340,-160}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,190},{280,210}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{306,220},{286,240}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,50},{266,70}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{246,-10},{266,10}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{306,70},{286,90}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{306,10},{286,30}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{246,
                      -110},{226,-90}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{246,-70},{226,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{103.8,140},{129.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{20.2,48},{20.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},
                    {129.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-26,140},{-19,140}},           color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{3,140},{20.2,140}},            color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-262.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},
                    {-209.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(realExpression.y, ramp_smooth1.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-50},{-362,-50}},      color={0,0,127}));
            connect(add3_1.y, gain.u) annotation (Line(points={{-298.3,-40},{
                    -289.2,-40}},       color={0,0,127}));
            connect(ramp_smooth.y, add3_1.u[1]) annotation (Line(points={{-339,
                    -10},{-330,-10},{-330,-34.4},{-320,-34.4}},
                                                           color={0,0,127}));
            connect(ramp_smooth1.y, add3_1.u[2]) annotation (Line(points={{-339,
                    -50},{-330,-50},{-330,-37.2},{-320,-37.2}},
                                                           color={0,0,127}));
            connect(realExpression.y, ramp_smooth2.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-362,-88}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth3.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-130},{-362,-130}},      color={0,0,127}));
            connect(realExpression.y, ramp_smooth4.u) annotation (Line(points={{-379,
                    -88},{-370,-88},{-370,-170},{-362,-170}},      color={0,0,127}));
            connect(ramp_smooth2.y, add3_1.u[3]) annotation (Line(points={{-339,
                    -88},{-326,-88},{-326,-40},{-320,-40}},
                                                       color={0,0,127}));
            connect(ramp_smooth3.y, add3_1.u[4]) annotation (Line(points={{-339,
                    -130},{-332,-130},{-332,-42.8},{-320,-42.8}}, color={0,0,127}));
            connect(ramp_smooth4.y, add3_1.u[5]) annotation (Line(points={{-339,
                    -170},{-328,-170},{-328,-45.6},{-320,-45.6}}, color={0,0,127}));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                    {220.1,200},{220.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                    {266,230},{266,208.8}},          color={0,0,127}));
            connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                    {252,80},{252,68.8}},     color={0,0,127}));
            connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                    {252,20},{252,8.8}},           color={0,0,127}));
            connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                    -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                    -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
                thickness=0.5));
            connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
                  points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
            connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
                  points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                    {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                    {179.92,0},{179.92,98.2}},  color={0,0,255}));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                    {314,230},{319,230}},          color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                    314,80},{319,80}},      color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                    {314,20},{319,20}},     color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                    {259,-60}},          color={0,0,127}));
            connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                    -100},{254,-100},{259,-100}},            color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_100_60_sweet;
        end LoadRamps;

        package HotStart_shutDown
          "Package containing the models for the hot start ramp simulation/optimization"

          model Plant_HP_4th_orderFW_20_100
            "Model of the high pressure part of the OTSG"

            parameter Modelica.SIunits.Time t_end = 5360 "Integral end time";
            parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
              "Feedwater inlet temperature lower bound";

            Real errDT_sh "Quadratic integral error on degree of superheating";
            Real errT_FWupperBound
              "Quadratic integral error on feedwater inlet temperature (upper bound)";
            Real errT_FWlowerBound
              "Quadratic integral error on feedwater inlet temperature (lower bound)";
            Real errT_MSlowerBound
              "Quadratic integral error on molten salt temperature (lower bound)";
            Real M_MStot "Molten salt hot flow total mass";

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
              annotation (Placement(transformation(extent={{18,42},{94,118}})));
            SteamTurbine.Corps.IPT IPTurb
              annotation (Placement(transformation(extent={{124,42},{206,118}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,280},{-300,300}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,30},
                      {-140,50}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,
                      -250},{-160,-230}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG
                                     annotation (Placement(transformation(
                    extent={{-160,-220},{-20,20}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
                                                                           HPHs
                                                        annotation (Placement(
                  transformation(extent={{20,-220},{120,-164}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-170},{160,-150}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-210},{140,-190}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,110},{234,130}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-90},{220,-70}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,140},{240,160}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_H_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                  annotation (Placement(
                  transformation(extent={{200,-190},{180,-170}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{260,-70},{240,-50}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{200,-150},{180,-130}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder_hotStart
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              useTS_valveBP=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              useTS_pumpFW_high=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_pumpMS_high=0.0004566,
              useTS_pumpMS=false,
              useTS_pumpSEP=false,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              l_min=0.2,
              l_max=0.3,
              useTS_valveTURB_low=false,
              Kp_valveTURB_high=-1.077e-11,
              CSmax_pumpMS_high=50,
              CSmax_pumpMS_low=50,
              useTS_valveTURB_high=false,
              Kp_pumpMS_low=0.000147*0.3,
              Kp_valveTURB_low=-1.518e-11,
              DT_sh_sp=20)    annotation (Placement(transformation(extent={{-260,
                      -120},{-212,-80}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-36,74},{-24,86}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-16,70},{4,90}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,140},{280,160}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-70},{280,-50}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-150},{220,-130}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-190},{220,-170}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-286,-106},{-274,-94}})));
            ThermoPower.Water.Mixer desSH(
              noInitialPressure=true,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
              V=0.5,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              hstart=3400000) annotation (Placement(transformation(extent={{-54,94},
                      {-34,114}})));

            ThermoPower.Water.SensT sensT_SH(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                  transformation(extent={{-28,98},{-8,118}})));
            ThermoPower.Water.ValveLiq valveSH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=2.2,
              CheckValve=true,
              Av=0.8*2.9e-4,
              pnom=8700000,
              dpnom=200000) annotation (Placement(transformation(extent={{-140,
                      100},{-120,120}})));
            ThermoPower.Water.SourcePressure sourcePressure(
              use_in_p0=true,
              use_in_h=true,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{-220,120},{-200,140}})));
            Modelica.Blocks.Tables.CombiTable1D DES_P_source(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  86.44e5; 30,89.06e5; 40,92.25e5; 50,99.52e5; 60,120e5; 70,
                  132.8e5; 80,148.8e5; 90,164.2e5; 100,178.7e5]) annotation (
                Placement(transformation(extent={{-260,140},{-240,160}})));
            Modelica.Blocks.Sources.RealExpression LOAD6(y=gain.y)
              annotation (Placement(transformation(extent={{-300,160},{-280,180}})));
            Modelica.Blocks.Tables.CombiTable1D DES_H_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-260,180},{-240,200}})));
            ThermoPower.Water.ValveLiq valveRH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=2,
              CheckValve=true,
              Av=0.9*4.8e-5,
              pnom=8700000,
              dpnom=7200000) annotation (Placement(transformation(extent={{-140,
                      190},{-120,210}})));
            ThermoPower.Water.Mixer desRH(
              noInitialPressure=true,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
              V=0.5,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              hstart=3400000) annotation (Placement(transformation(extent={{-72,
                      184},{-52,204}})));

            ThermoPower.Water.SensT sensT_RH(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                  transformation(extent={{-42,188},{-22,208}})));
            Modelica.Blocks.Sources.Ramp SP(
              startTime=5000,
              height=50,
              duration=2160,
              offset=773.15)
              annotation (Placement(transformation(extent={{80,160},{60,180}})));
            IndustrialControlSystems.Controllers.PI PI_valveSH(
              CSmin=0,
              CSmax=1,
              CS_start=0.5,
              AntiWindup=true,
              useTS=true,
              Ti=0.5,
              Kp=-0.01) annotation (Placement(transformation(extent={{-20,140},
                      {-40,160}})));
            IndustrialControlSystems.Controllers.PI PI_valveRH(
              CSmin=0,
              CSmax=1,
              CS_start=0.5,
              AntiWindup=true,
              useTS=true,
              Ti=0.5,
              Kp=-0.01) annotation (Placement(transformation(extent={{-32,220},
                      {-52,240}})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=0.5)
              annotation (Placement(transformation(extent={{-100,220},{-120,240}})));
            Modelica.Blocks.Continuous.FirstOrder valveSH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=1,
              T=0.5) annotation (Placement(transformation(extent={{-100,140},{
                      -120,160}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-66,220},{-86,240}})));
            Modelica.Blocks.Nonlinear.Limiter valveSH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-54,140},{-74,160}})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{20,200},{0,220}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=7400)
              annotation (Placement(transformation(extent={{20,250},{0,270}})));
            Modelica.Blocks.Sources.Ramp load_pre(
              duration=2000,
              startTime=100,
              height=-20,
              offset=20)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-320,-110},{-300,-90}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load(table=[
                  5000,20; 5080,35; 5160,47; 5240,60; 5300,70; 5360,80; 5440,90;
                  5540,100]) annotation (Placement(transformation(extent={{-360,
                      -140},{-340,-120}})));
          equation
            if time >= 5000 and time <= t_end then
              der(M_MStot) = OTSG.pumpMS.w;
              der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
              der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
              der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
            else
              der(M_MStot) = 0;
              der(errT_FWupperBound) = 0;
              der(errT_FWlowerBound) = 0;
              der(errT_MSlowerBound) = 0;
            end if;

            if gain.y >= controllers.load_switch then
              der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - controllers.DT_sh_sp)^2;
            else
              der(errDT_sh) = 0;
            end if;

            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,80},{119.9,80}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-240},{-128.889,-240},{-128.889,-224}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,40},{-128.889,40},{-128.889,24}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,-12},{14.2,-12},{14.2,49.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-192},{-16.1111,-192},{17.2222,-192}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{36.6667,-132},{36.6667,
                    -161.2}},
                color={0,0,255},
                thickness=0.5));

            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -192},{122.778,-192},{136,-192},{136,-200},{140,-200}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -175.2},{122.778,-175.2},{136,-175.2},{136,-160},{140,-160}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,120},
                    {210.1,120},{210.1,102.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,150},
                    {220,150},{220,128.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,0},
                    {206,0},{206,-11.2}},     color={0,0,127}));
            connect(HPH1_H_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-180},{146,-180},{146,-191}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,38.2},{151.06,-12},{92.2222,-12},{92.2222,
                    -161.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-80},{186,-80},{169.92,-80},{169.92,38.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,38.2},{189.6,-20},{200,-20}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points={{239,-60},
                    {206,-60},{206,-71.2}},        color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,38.2},{56,38.2},{56,-161.2},{56.1111,-161.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-140},{162,-140},{146,-140},{146,-151.2}},
                                                                      color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-209.818,-100},{-165.444,-100}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,150},
                    {279,150}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,0},{
                    279,0}},           color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,-60},
                    {279,-60}},      color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,
                    -140},{219,-140}},              color={0,0,127}));
            connect(HPH1_H_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -180},{219,-180}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,80},{-20,80},{-17,80}},    color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,80},{14.2,80}},              color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-209.818,-100},{-190,-100},{-190,-280},{100.556,-280},
                    {100.556,-221.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,70},{-6,60},{-190,60},{-190,-100},{-209.818,-100}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-224},{-82.2222,-240},{81.1111,-240},{81.1111,
                    -222.8}}, color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-273.4,
                    -100},{-262.182,-100}},
                                          color={0,0,127}));
            connect(desSH.in2, OTSG.SH_out) annotation (Line(points={{-52,98},{
                    -52,24},{-51.1111,24}}, color={0,0,255}));
            connect(sensT_SH.outlet, HPTurb.vap_in) annotation (Line(points={{
                    -12,104},{14.2,104},{14.2,102.8}}, color={0,0,255}));
            connect(desSH.out, sensT_SH.inlet) annotation (Line(points={{-34,104},
                    {-24,104}},                color={0,0,255}));
            connect(valveSH.outlet, desSH.in1) annotation (Line(points={{-120,
                    110},{-52,110}},           color={0,0,255}));
            connect(sourcePressure.flange, valveSH.inlet) annotation (Line(
                  points={{-200,130},{-170,130},{-170,110},{-140,110}}, color={
                    0,0,255}));
            connect(DES_H_source.y[1], sourcePressure.in_h) annotation (Line(
                  points={{-239,190},{-206,190},{-206,139}}, color={0,0,127}));
            connect(DES_P_source.y[1], sourcePressure.in_p0) annotation (Line(
                  points={{-239,150},{-214,150},{-214,139.2}}, color={0,0,127}));
            connect(LOAD6.y, DES_H_source.u[1]) annotation (Line(points={{-279,
                    170},{-274,170},{-270,170},{-270,190},{-262,190}}, color={0,
                    0,127}));
            connect(LOAD6.y, DES_P_source.u[1]) annotation (Line(points={{-279,
                    170},{-270,170},{-270,150},{-262,150}}, color={0,0,127}));
            connect(sourcePressure.flange, valveRH.inlet) annotation (Line(
                  points={{-200,130},{-200,130},{-170,130},{-170,200},{-140,200}},
                  color={0,0,255}));
            connect(valveRH.outlet, desRH.in1) annotation (Line(points={{-120,
                    200},{-120,200},{-70,200}}, color={0,0,255}));
            connect(OTSG.RH_out, desRH.in2) annotation (Line(points={{-82.2222,
                    24},{-82.2222,188},{-70,188}}, color={0,0,255}));
            connect(desRH.out, sensT_RH.inlet)
              annotation (Line(points={{-52,194},{-38,194}}, color={0,0,255}));
            connect(sensT_RH.outlet, IPTurb.vap_in) annotation (Line(points={{
                    -26,194},{-26,192},{119.9,192},{119.9,102.8}}, color={0,0,
                    255}));
            connect(sensT_SH.T, PI_valveSH.PV) annotation (Line(points={{-10,
                    114},{0,114},{0,149},{-22,149}}, color={0,0,127}));
            connect(SP.y, PI_valveSH.SP) annotation (Line(points={{59,170},{59,
                    170},{0,170},{0,156},{-22,156}}, color={0,0,127}));
            connect(sensT_RH.T, PI_valveRH.PV) annotation (Line(points={{-24,
                    204},{-22,204},{-22,229},{-34,229}}, color={0,0,127}));
            connect(SP.y, PI_valveRH.SP) annotation (Line(points={{59,170},{28,
                    170},{28,236},{-34,236}}, color={0,0,127}));
            connect(valveRH_dynamic.y, valveRH.theta) annotation (Line(points={
                    {-121,230},{-130,230},{-130,208}}, color={0,0,127}));
            connect(valveSH_dynamic.y, valveSH.theta) annotation (Line(points={
                    {-121,150},{-130,150},{-130,118}}, color={0,0,127}));
            connect(valveRH_dynamic.u, valveRH_lim.y)
              annotation (Line(points={{-98,230},{-87,230}}, color={0,0,127}));
            connect(valveRH_lim.u, PI_valveRH.CS)
              annotation (Line(points={{-64,230},{-51,230}}, color={0,0,127}));
            connect(valveSH_dynamic.u, valveSH_lim.y)
              annotation (Line(points={{-98,150},{-75,150}}, color={0,0,127}));
            connect(valveSH_lim.u, PI_valveSH.CS) annotation (Line(points={{-52,
                    150},{-46,150},{-39,150}}, color={0,0,127}));
            connect(booleanStep.y, PI_valveRH.TS) annotation (Line(points={{-1,
                    260},{-22,260},{-46,260},{-46,238}}, color={255,0,255}));
            connect(booleanStep.y, PI_valveSH.TS) annotation (Line(points={{-1,
                    260},{-16,260},{-16,180},{-34,180},{-34,158}}, color={255,0,
                    255}));
            connect(const.y, PI_valveRH.TR) annotation (Line(points={{-1,210},{
                    -8,210},{-8,252},{-42,252},{-42,238}}, color={0,0,127}));
            connect(const.y, PI_valveSH.TR) annotation (Line(points={{-1,210},{
                    -8,210},{-8,172},{-30,172},{-30,158}}, color={0,0,127}));
            connect(load_pre.y,add. u1) annotation (Line(points={{-339,-70},{
                    -330,-70},{-330,-94},{-322,-94}},
                                                 color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-299,-100},{-292,
                    -100},{-287.2,-100}}, color={0,0,127}));
            connect(splineSignal_load.y, add.u2) annotation (Line(points={{-339,
                    -130},{-330,-130},{-330,-106},{-322,-106}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-300},{320,300}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -300},{320,300}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_4th_orderFW_20_100;

          model Plant_Full_20_100
            "Model of the full steam cycle, for hot start-up optimization"

            parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
            parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
              "Feedwater inlet temperature upper bound";
            parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
              "Feedwater inlet temperature upper bound";

            Real errDT_sh "Quadratic integral error on degree of superheating";
            Real errT_FWupperBound
              "Quadratic integral error on feedwater inlet temperature (upper bound)";
            Real errT_FWlowerBound
              "Quadratic integral error on feedwater inlet temperature (lower bound)";
            Real errT_MSupperBound
              "Quadratic integral error on molten salt temperature (upper bound)";
            Real errT_MSlowerBound
              "Quadratic integral error on molten salt temperature (lower bound)";
            Real M_MStot "Molten salt hot flow total mass";
            Real eta_I = P_net/Q_in
              "Power plant first principle net efficiency";
            Real Q_in = OTSG.Q_tot "Global thermal input";
            Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
              "Auxiliaries consumption, as function of load";
            Real P_gross = powerSensor.gain.y "Gross electrical power";
            Real P_net = P_gross - P_aux "Net pelectrical power";

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=8830000)))
              annotation (Placement(transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb(
              pressDrop_IPT1_HPH1(pin(start=1100000, fixed=false)),
              vap_in(p(start=2215000)),
              pressDrop_IPT2_DEA(pin(start=280000)),
              SP4(p(start=230000))) annotation (Placement(transformation(extent=
                     {{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init20_5nodes OTSG(
              valveLiq(Av=3.705e-5),
              PDSteamECO2(pin(start=8600000)),
              PDSteamECO1(pin(start=8650000, fixed=true)),
              PDSteamEVA2(pin(start=8510000, fixed=false)),
              valveVap(inlet(p(start=8500000, fixed=true)))) annotation (
                Placement(transformation(extent={{-240,-160},{-100,80}})));

            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
                                                                           HPHs(
              HPH2(
                NusseltCondenser(w_cond(start=6.022)),
                pressDropLin(inlet(m_flow(start=6.022, fixed=true)), R=0.5e5),
                sub_SP(hstart={7e5,6.5e5,6e5,5.5e5,5e5}),
                nominalColdInletTemperature_des=473.15,
                nominalColdOutletTemperature_des=479.15,
                nominalHotInletTemperature_des=700.15,
                nominalHotOutletTemperature_des=473.15,
                nominalColdInletTemperature_cond=423.15,
                nominalColdOutletTemperature_cond=473.15,
                nominalColdInletTemperature_sub=413.15,
                nominalColdOutletTemperature_sub=422.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=414.15),
              SP1(p(start=1800000, fixed=true)),
              SP2(p(start=450000, fixed=true)),
              DPSteamHPH2(w(start=20, fixed=true)),
              HPH1(
                tubeWalls_cond(initOpt=ThermoPower.Choices.Init.Options.fixedState,
                    Tvolstart={433.15,433.15,433.15,433.15,433.15,433.15,433.15,
                      433.15,433.15}),
                NusseltCondenser(w_cond(start=0.8), ws_in(start=0.3, fixed=true)),
                pressDropLin(R=0.5e5),
                pressDropLin1(R=0.1e5),
                wnom=15,
                CSmin=0.01,
                nominalHotPressure=360000,
                nominalColdInletTemperature_des=428.15,
                nominalColdOutletTemperature_des=433.15,
                nominalHotInletTemperature_des=706.15,
                nominalColdInletTemperature_cond=408.15,
                nominalColdOutletTemperature_cond=413.15,
                nominalColdInletTemperature_sub=406.15,
                nominalColdOutletTemperature_sub=408.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=407.15,
                Kp=-10)) annotation (Placement(transformation(extent={{-60,-160},
                      {60,-100}})));

            Control.Schemes.PlantControlSchemes.plantController_hotStart
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmax_pumpCOND=100,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              useTS_pumpCOND=false,
              TS_pumpCOND=37.42,
              Kp_valveTURB_low=-1.518e-11,
              Ti_valveTURB_low=3.626,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=10,
              CSstart_pumpCOND=14,
              CSmin_pumpCOND=5,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              CSmax_pumpMS_high=80,
              control_wBP(table_thetaBP(table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0.1; 70,0.145652;
                      80,0.208685; 90,0.349201; 100,0.866205])),
              CSmin_pumpSEP=-0.3,
              Kp_pumpFW_low=5*15.73,
              Ti_pumpFW_low=0.2*714.2,
              useTS_pumpSEP=false,
              CSmax_pumpSEP=1,
              useTS_valveDEA=true,
              TS_valveDEA=1,
              staticDecoupled_4th(
                control_wMS_low(table_P_MEC_low(table=[20,20.254e6; 30,32.237e6; 40,44.345e6;
                        50,56.908e6; 60,69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6;
                        100,114.430e6])),
                control_wMS_high(table_P_MEC_high(table=[20,20.254e6; 30,32.237e6; 40,44.345e6;
                        50,56.908e6; 60,69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6;
                        100,114.430e6])),
                pumpMS_lim(uMax=700)),
              useTS_pumpMS=false,
              useTS_valveTURB_high=false,
              Kp_pumpMS_low=0.1*0.000147,
              Kp_pumpMS_high=0.1*0.0004566,
              Ti_pumpCOND=200,
              Kp_pumpCOND=400,
              DT_sh_sp=20)    annotation (Placement(transformation(extent={{-340,-60},{-292,
                      -20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-364,-46},{-352,-34}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_20_dp
                                                                        LPHs(
              SP4(p(start=70000, fixed=true)),
              LPH2(
                tubeWalls_cond(Tvolstart={349.15,348.95,347.15}),
                NusseltCondenser(ws_in(start=2.021, fixed=true)),
                p_start=96350,
                nominalColdInletTemperature_cond=323.55,
                nominalColdOutletTemperature_cond=348.85),
              LPH3(
                NusseltCondenser(ws_in(start=2, fixed=true)),
                zl_start=0.05,
                nominalHotPressure=70000,
                nominalColdInletTemperature_des=358.15,
                nominalColdOutletTemperature_des=363.15,
                nominalHotInletTemperature_des=499.15,
                nominalHotOutletTemperature_des=453.15,
                p_start=70000,
                nominalColdInletTemperature_cond=353.15,
                nominalColdOutletTemperature_cond=358.15,
                nominalColdInletTemperature_sub=348.15,
                nominalColdOutletTemperature_sub=353.15,
                nominalHotInletTemperature_sub=353.15,
                nominalHotOutletTemperature_sub=350.15),
              LPH1(
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                tubeWalls_cond(Tvolstart={333.15,331.15,328.15}),
                NusseltCondenser(
                  wd_out(start=4.62, fixed=false),
                  noInitialPressure=true,
                  ws_in(start=0.4, fixed=true)),
                zl_start=0.05,
                p_start=35000,
                nominalColdInletTemperature_cond=308.15,
                nominalColdOutletTemperature_cond=323.55,
                Kp=-5,
                Ti=5)) annotation (Placement(transformation(extent={{170,-112},
                      {328,-52}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-162},{380,-142}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-20},{380,0}})));
            SteamTurbine.Corps.LPT LPTurb(
              w_seal_1=0.0182,
              w_seal_2=0.0076,
              LPT1(hout(start=2818.4e3, fixed=false), pout(start=40000, fixed=
                      true))) annotation (Placement(transformation(extent={{230,
                      102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              h_start=1.2e6,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              w_small=1e4,
              zl_start=2.1,
              p_start=224000,
              valveVap(Av=0.1))
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-20},{420,0}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load(table=[
                  5000,20; 5080,35; 5160,47; 5240,60; 5300,70; 5360,80; 5440,90;
                  5540,100]) annotation (Placement(transformation(extent={{-400,
                      -50},{-380,-30}})));
          equation
            if time >= 5000 and time <= t_end then
              der(M_MStot) = OTSG.pumpMS.w;
              der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
              der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
              der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
              der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
            else
              der(M_MStot) = 0;
              der(errT_FWupperBound) = 0;
              der(errT_FWlowerBound) = 0;
              der(errT_MSupperBound) = 0;
              der(errT_MSlowerBound) = 0;
            end if;

            if gain.y >= controllers.load_switch then
              der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - controllers.DT_sh_sp)^2;
            else
              der(errDT_sh) = 0;
            end if;

            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},
                    {49.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-102,140},{-99,140}},
                                                                       color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-77,140},{-59.8,140}},
                                                                       color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-351.4,
                    -40},{-351.4,-40},{-342.182,-40}},
                                          color={0,0,127}));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-82},{331.292,-82},{360,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-152},{366,-152},{366,-91}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-10},{366,-10},{366,-31.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{182,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{127.714,-82},{166.708,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                    406,-10},{410,-10},{419,-10}},
                                         color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                    419,-152}},            color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},
                    {-289.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
              annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                                 color={0,0,0}));
            connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,-220},{137.143,-220},{
                    137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    249,-220},{249,-112}},
                color={255,204,51},
                thickness=0.5));
            connect(splineSignal_load.y, gain.u) annotation (Line(points={{-379,
                    -40},{-365.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(
                StopTime=10000,
                __Dymola_NumberOfIntervals=5000,
                Tolerance=1e-006),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),    __Dymola_experimentFlags(
                Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                      false),
                Evaluate=false,
                OutputCPUtime=false,
                OutputFlatModelica=false));
          end Plant_Full_20_100;

          model Plant_Full_20_100_des
            "Model of the full steam cycle, for hot start-up optimization, with desuperheating process"

            parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
            parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
              "Feedwater inlet temperature upper bound";
            parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
              "Feedwater inlet temperature upper bound";

            Real errDT_sh "Quadratic integral error on degree of superheating";
            Real errT_FWupperBound
              "Quadratic integral error on feedwater inlet temperature (upper bound)";
            Real errT_FWlowerBound
              "Quadratic integral error on feedwater inlet temperature (lower bound)";
            Real errT_MSupperBound
              "Quadratic integral error on molten salt temperature (upper bound)";
            Real errT_MSlowerBound
              "Quadratic integral error on molten salt temperature (lower bound)";
            Real M_MStot "Molten salt hot flow total mass";
            Real eta_I = P_net/Q_in
              "Power plant first principle net efficiency";
            Real Q_in = OTSG.Q_tot "Global thermal input";
            Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
              "Auxiliaries consumption, as function of load";
            Real P_gross = powerSensor.gain.y "Gross electrical power";
            Real P_net = P_gross - P_aux "Net pelectrical power";

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=8830000)))
              annotation (Placement(transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb(
              pressDrop_IPT1_HPH1(pin(start=1100000, fixed=false)),
              vap_in(p(start=2215000)),
              pressDrop_IPT2_DEA(pin(start=280000)),
              SP4(p(start=230000))) annotation (Placement(transformation(extent=
                     {{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-442,260},{-422,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init20_5nodes OTSG(
              RH(coldFluid(noInitialPressure=true), nominalColdPressure=800000),
              valveLiq(Av=3.705e-5),
              PDSteamECO2(pin(start=8600000)),
              PDSteamECO1(pin(start=8650000, fixed=true)),
              PDSteamEVA1(pin(start=8544000, fixed=true)),
              PDSteamEVA2(pin(start=8510000, fixed=false)),
              EVA2(nominalColdPressure=8520000),
              separator(zl_start=3),
              valveVap(inlet(p(start=8500000, fixed=true)))) annotation (
                Placement(transformation(extent={{-240,-160},{-100,80}})));

            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
                                                                           HPHs(
              HPH2(
                NusseltCondenser(w_cond(start=6.022)),
                pressDropLin(inlet(m_flow(start=6.022, fixed=true)), R=0.5e5),
                sub_SP(hstart={7e5,6.5e5,6e5,5.5e5,5e5}),
                nominalColdInletTemperature_des=473.15,
                nominalColdOutletTemperature_des=479.15,
                nominalHotInletTemperature_des=700.15,
                nominalHotOutletTemperature_des=473.15,
                nominalColdInletTemperature_cond=423.15,
                nominalColdOutletTemperature_cond=473.15,
                nominalColdInletTemperature_sub=413.15,
                nominalColdOutletTemperature_sub=422.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=414.15),
              SP1(p(start=1800000, fixed=true)),
              SP2(p(start=450000, fixed=true)),
              DPSteamHPH2(w(start=20, fixed=true)),
              HPH1(
                tubeWalls_cond(initOpt=ThermoPower.Choices.Init.Options.fixedState,
                    Tvolstart={433.15,433.15,433.15,433.15,433.15,433.15,433.15,
                      433.15,433.15}),
                NusseltCondenser(w_cond(start=0.8), ws_in(start=0.3, fixed=true)),
                pressDropLin(R=0.5e5),
                pressDropLin1(R=0.1e5),
                CSmin=0.01,
                wnom=15,
                nominalHotPressure=360000,
                nominalColdInletTemperature_des=428.15,
                nominalColdOutletTemperature_des=433.15,
                nominalHotInletTemperature_des=706.15,
                nominalColdInletTemperature_cond=408.15,
                nominalColdOutletTemperature_cond=413.15,
                nominalColdInletTemperature_sub=406.15,
                nominalColdOutletTemperature_sub=408.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=407.15,
                Kp=-20,
                Ti=100)) annotation (Placement(transformation(extent={{-60,-160},
                      {60,-100}})));

            Control.Schemes.PlantControlSchemes.plantController_hotStart
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmax_pumpCOND=100,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              useTS_pumpCOND=false,
              TS_pumpCOND=37.42,
              Kp_valveTURB_low=-1.518e-11,
              Ti_valveTURB_low=3.626,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=10,
              CSstart_pumpCOND=14,
              CSmin_pumpCOND=5,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              CSmax_pumpMS_high=80,
              control_wBP(table_thetaBP(table=[4,0; 20,0; 30,0; 40,0; 50,0; 60,0.1; 70,0.145652;
                      80,0.208685; 90,0.349201; 100,0.866205])),
              CSmin_pumpSEP=-0.3,
              Kp_pumpFW_low=5*15.73,
              Ti_pumpFW_low=0.2*714.2,
              useTS_pumpSEP=false,
              CSmax_pumpSEP=1,
              TS_valveDEA=1,
              staticDecoupled_4th(
                control_wMS_low(table_P_MEC_low(table=[20,20.254e6; 30,32.237e6; 40,44.345e6;
                        50,56.908e6; 60,69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6;
                        100,114.430e6])),
                control_wMS_high(table_P_MEC_high(table=[20,20.254e6; 30,32.237e6; 40,44.345e6;
                        50,56.908e6; 60,69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6;
                        100,114.430e6])),
                pumpMS_lim(uMax=700)),
              useTS_pumpMS=false,
              useTS_valveTURB_high=false,
              Kp_pumpMS_low=0.1*0.000147,
              Kp_pumpMS_high=0.1*0.0004566,
              Kp_pumpCOND=400,
              Ti_pumpCOND=200,
              useTS_valveDEA=true,
              DT_sh_sp=20)    annotation (Placement(transformation(extent={{-340,-60},{-292,
                      -20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-366,-46},{-354,-34}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_20_dp
                                                                        LPHs(
              SP4(p(start=70000, fixed=true)),
              LPH3(
                NusseltCondenser(ws_in(start=2, fixed=true)),
                zl_start=0.05,
                nominalHotPressure=70000,
                nominalColdInletTemperature_des=358.15,
                nominalColdOutletTemperature_des=363.15,
                nominalHotInletTemperature_des=499.15,
                nominalHotOutletTemperature_des=453.15,
                p_start=70000,
                nominalColdInletTemperature_cond=353.15,
                nominalColdOutletTemperature_cond=358.15,
                nominalColdInletTemperature_sub=348.15,
                nominalColdOutletTemperature_sub=353.15,
                nominalHotInletTemperature_sub=353.15,
                nominalHotOutletTemperature_sub=350.15),
              LPH2(
                tubeWalls_cond(Tvolstart={349.15,348.95,347.15}),
                NusseltCondenser(ws_in(start=2.021, fixed=true)),
                p_start=96350,
                nominalColdInletTemperature_cond=323.55,
                nominalColdOutletTemperature_cond=348.85,
                Kp=-1),
              LPH1(
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                tubeWalls_cond(Tvolstart={333.15,331.15,328.15}),
                NusseltCondenser(
                  wd_out(start=4.62, fixed=false),
                  noInitialPressure=true,
                  ws_in(start=0.4, fixed=true)),
                zl_start=0.05,
                Ti=10,
                p_start=35000,
                nominalColdInletTemperature_cond=308.15,
                nominalColdOutletTemperature_cond=323.55,
                Kp=-5)) annotation (Placement(transformation(extent={{170,-112},
                      {328,-52}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-162},{380,-142}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-20},{380,0}})));
            SteamTurbine.Corps.LPT LPTurb(
              w_seal_1=0.0182,
              w_seal_2=0.0076,
              LPT1(hout(start=2818.4e3, fixed=false), pout(start=40000, fixed=
                      true))) annotation (Placement(transformation(extent={{230,
                      102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              h_start=1.2e6,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              w_small=1e4,
              zl_start=2.1,
              valveVap(Av=0.1),
              p_start=240000)
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-20},{420,0}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{-240,210},{-220,230}})));
            HeatExchangers.Components.Desuperheaters_controlled
              desuperheaters_controlled(
              t_start=5090,
              t_end=7400,
              T_start=773.15,
              T_end=823.15,
              TS_valves=0.001)
                            annotation (Placement(transformation(extent={{-188,
                      180},{-108,260}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load(table=[
                  5000,20; 5077,35; 5154,46; 5231,57; 5308,68; 5385,79; 5462,90;
                  5540,100]) annotation (Placement(transformation(extent={{-440,
                      -70},{-420,-50}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load1(table=[
                  10000,0; 10300,-14; 10600,-27; 10900,-40; 11200,-60; 11500,-75;
                  11800,-80])
                             annotation (Placement(transformation(extent={{-440,
                      -30},{-420,-10}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-400,-50},{-380,-30}})));
          equation
            if time >= 5000 and time <= t_end then
              der(M_MStot) = OTSG.pumpMS.w;
              der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
              der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
              der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
              der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
            else
              der(M_MStot) = 0;
              der(errT_FWupperBound) = 0;
              der(errT_FWlowerBound) = 0;
              der(errT_MSupperBound) = 0;
              der(errT_MSlowerBound) = 0;
            end if;

            if gain.y >= controllers.load_switch then
              der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - controllers.DT_sh_sp)^2;
            else
              der(errDT_sh) = 0;
            end if;

            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-102,140},{-99,140}},
                                                                       color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-77,140},{-59.8,140}},
                                                                       color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-353.4,
                    -40},{-353.4,-40},{-342.182,-40}},
                                          color={0,0,127}));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-82},{331.292,-82},{360,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-152},{366,-152},{366,-91}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-10},{366,-10},{366,-31.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{182,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{127.714,-82},{166.708,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                    406,-10},{410,-10},{419,-10}},
                                         color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                    419,-152}},            color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},
                    {-289.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
              annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                                 color={0,0,0}));
            connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,-220},{137.143,-220},{
                    137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    249,-220},{249,-112}},
                color={255,204,51},
                thickness=0.5));
            connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
                Line(
                points={{-132,178},{-132,178},{-132,84},{-131.111,84}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
                Line(
                points={{-162.222,84},{-162.222,130},{-162,130},{-162,178}},
                color={0,0,255},
                thickness=0.5));
            connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
              annotation (Line(
                points={{-106,204},{-106,204},{-59.8,204},{-59.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
              annotation (Line(
                points={{-106,236},{49.9,236},{49.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
                  points={{-219,220},{-192,220}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-379,-40},{-367.2,
                    -40},{-367.2,-40}}, color={0,0,127}));
            connect(splineSignal_load1.y, add.u1) annotation (Line(points={{
                    -419,-20},{-410,-20},{-410,-34},{-402,-34}}, color={0,0,127}));
            connect(splineSignal_load.y, add.u2) annotation (Line(points={{-419,
                    -60},{-410,-60},{-410,-46},{-402,-46}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=15000, __Dymola_NumberOfIntervals=7500),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),    __Dymola_experimentFlags(
                Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                      false),
                Evaluate=false,
                OutputCPUtime=false,
                OutputFlatModelica=false));
          end Plant_Full_20_100_des;

          model Plant_Full_100_20 "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                   annotation (Placement(transformation(extent=
                      {{-240,-160},{-100,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs(HPH1(Kp=-8, wnom=15)) annotation (Placement(transformation(
                    extent={{-60,-160},{60,-100}})));

            Control.Schemes.PlantControlSchemes.plantController
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              Kp_valveTURB_low=-1.518e-11,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=100,
              CSstart_pumpCOND=77,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              useTS_pumpCOND=false,
              useTS_pumpMS=false,
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              CSmin_pumpFW_high=-0.1,
              CSmax_pumpFW_high=0.1,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=20,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              TS_valveDEA=1,
              Kp_pumpMS_high=0.1*0.0004566,
              Kp_pumpMS_low=0.1*0.000147,
              useTS_valveTURB_high=false,
              TS_pumpFW_low=55,
              staticDecoupled_4th(control_wMS_high(table_P_MEC_high(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6]))),
              control_wHPH(table_w_HPH(table=[20,0.5; 30,0.6; 40,0.7; 50,0.8;
                      60,1; 70,1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveDEA=true,
              Ti_pumpCOND=1000,
              Kp_pumpCOND=500,
              Kp_pumpFW_low=2*15.73,
              Ti_pumpFW_low=0.5*714.2,
              DT_sh_sp=20,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-340,
                      -60},{-292,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-368,-46},{-356,-34}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100
              LPHs annotation (Placement(transformation(extent={{170,-112},{328,
                      -52}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-162},{380,-142}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-20},{380,0}})));
            SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
              annotation (Placement(transformation(extent={{230,102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              h_start=1e6,
              w_small=100,
              p_start=1086000)
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-20},{420,0}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load(table=[
                  5000,100; 5300,80; 5600,70; 5900,60; 6200,50; 6500,40; 6800,
                  20])       annotation (Placement(transformation(extent={{-420,50},
                      {-400,70}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load1(table=[
                  5000,100; 5300,86; 5600,73; 5900,60; 6200,47; 6500,34; 6800,
                  20])       annotation (Placement(transformation(extent={{-420,
                      -50},{-400,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},
                    {49.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-99,140}},          color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-70,140},{-59.8,140}},
                                                                       color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-355.4,
                    -40},{-342.182,-40}}, color={0,0,127}));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-82},{331.292,-82},{360,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-152},{366,-152},{366,-91}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-10},{366,-10},{366,-31.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,27.1},{249,27.1},{249,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{127.714,-82},{166.708,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                    419,-10}},           color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                    419,-152}},            color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},
                    {-289.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
                  points={{140.1,140},{140.1,140},{225.8,140}}, color={0,0,0}));
            connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    136,-220},{136,-120},{137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    136,-220},{136,-160},{249,-160},{249,-112}},
                color={255,204,51},
                thickness=0.5));
            connect(splineSignal_load1.y, gain.u) annotation (Line(points={{
                    -399,-40},{-384,-40},{-369.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_Full_100_20;

          model Plant_Full_100_20_sweet "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
                  transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                    extent={{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init100_5nodes OTSG
                                   annotation (Placement(transformation(extent=
                      {{-240,-160},{-100,80}})));
            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100_dp
              HPHs(HPH1(wnom=15, pressDrop_des_cond(R=0.15e5)))
                                         annotation (Placement(transformation(
                    extent={{-60,-160},{60,-100}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-368,-46},{-356,-34}})));
            HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_100_dp
              LPHs annotation (Placement(transformation(extent={{170,-112},{328,
                      -52}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-162},{380,-142}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-20},{380,0}})));
            SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
              annotation (Placement(transformation(extent={{230,102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              zl_start=2,
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              h_start=1e6,
              w_small=100,
              p_start=1086000)
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-20},{420,0}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
            Auxiliaries.Components.Spline.SplineSignal splineSignal_load1(table=[
                  5000,100; 5300,80; 5600,67; 5900,54; 6200,41; 6500,30; 6800,
                  25; 7500,20])
                             annotation (Placement(transformation(extent={{-420,
                      -50},{-400,-30}})));
            Control.Schemes.PlantControlSchemes.plantController
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              DT_sh_sp=20,
              control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
              dec_wMS_wFW=1e-3,
              dec_wFW_wMS=80,
              useTS_valveBP=false,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSmin_valveTURB_high=-1e-5,
              CSmax_valveTURB_high=1e-5,
              useTS_pumpMS=false,
              l_max=1,
              useTS_pumpCOND=false,
              useTS_valveDEA=true,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.484,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.015625; 0; 0; 0; 0],
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              Kp_pumpCOND=1560,
              Ti_pumpCOND=128,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=100,
              CSstart_pumpCOND=77,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=20,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              TS_valveDEA=1,
              staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6])), control_wMS_high(table_P_MEC_high(table=[
                        20,20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6]))),
              control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,
                      1; 80,1; 90,6.743; 100,24.51])),
              useTS_valveTURB_high=false,
              TS_pumpFW_low=38,
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=500,
              CSmin_pumpSEP=-0.5,
              CSmax_pumpSEP=0.5,
              control_wSEP(const2(k=1)),
              useTS_pumpSEP=false,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-340,
                      -60},{-292,-20}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},
                    {49.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-99,140}},          color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-70,140},{-59.8,140}},
                                                                       color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-82},{331.292,-82},{360,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-152},{366,-152},{366,-91}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-10},{366,-10},{366,-31.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,27.1},{249,27.1},{249,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{127.714,-82},{166.708,-82}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                    419,-10}},           color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                    419,-152}},            color={0,0,127}));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
                  points={{140.1,140},{140.1,140},{225.8,140}}, color={0,0,0}));
            connect(splineSignal_load1.y, gain.u) annotation (Line(points={{
                    -399,-40},{-384,-40},{-369.2,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (
                Line(
                points={{-289.818,-40},{-268,-40},{-268,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-268,-40},{-268,-220},{36.6667,-220},{
                    36.6667,-161.2}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, deaerator.signalBus) annotation (
                Line(
                points={{-289.818,-40},{-268,-40},{-268,-220},{137.143,-220},{
                    137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-268,-40},{-268,-220},{249,-220},{249,
                    -112}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-355.4,
                    -40},{-342.182,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_Full_100_20_sweet;

          model Plant_HP_20_100_des_warmkeepingB
            "Model of the HP steam cycle, with desuperheating process, starting from warmkeeping configuration B"

            parameter Modelica.SIunits.Time t_end = 20000 "Integral end time";
            parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
              "Feedwater inlet temperature upper bound";
            parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
              "Feedwater inlet temperature upper bound";

            //parameter Modelica.SIunits.Time t_start_high = load.startTime + load.duration/load.height*(controllers.load_switch - load.offset - 20);
            //parameter Modelica.SIunits.Time time_high[controllers.n] = linspace(t_start_high,load.startTime + load.duration,controllers.n);

            Real errDT_sh "Quadratic integral error on degree of superheating";
            Real errT_FWupperBound
              "Quadratic integral error on feedwater inlet temperature (upper bound)";
            Real errT_FWlowerBound
              "Quadratic integral error on feedwater inlet temperature (lower bound)";
            Real errT_MSupperBound
              "Quadratic integral error on molten salt temperature (upper bound)";
            Real errT_MSlowerBound
              "Quadratic integral error on molten salt temperature (lower bound)";
            Real M_MStot "Molten salt hot flow total mass";
            Real eta_I = P_net/Q_in
              "Power plant first principle net efficiency";
            Real Q_in = OTSG.Q_tot "Global thermal input";
            Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
              "Auxiliaries consumption, as function of load";
            Real P_gross = powerSensor.gain.y "Gross electrical power";
            Real P_net = P_gross - P_aux "Net pelectrical power";

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
              annotation (Placement(transformation(extent={{64,102},{140,178}})));
            SteamTurbine.Corps.IPT IPTurb
              annotation (Placement(transformation(extent={{174,102},{256,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-340,260},{-320,280}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},{-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_warm
                                                   OTSG      annotation (
                Placement(transformation(extent={{-120,-160},{20,80}})));

            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
                                                                           HPHs(HPH1(Ti=
                    100))
                         annotation (Placement(transformation(extent={{60,-160},{180,-100}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-118,130},{-98,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
              annotation (Placement(transformation(extent={{-90,130},{-70,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-246,-46},{-234,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{360,200},{340,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{360,50},{340,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{360,-10},{340,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{-120,210},{-100,230}})));
            HeatExchangers.Components.Desuperheaters_controlled
              desuperheaters_controlled(
              TS_valves=0.001,
              T_start1=733.15,
              T_end1=773.15,
              t_start1=20000,
              t_end1=21000,
              T_start2=773.15,
              T_end2=823.15,
              t_start2=22222,
              t_end2=33333) annotation (Placement(transformation(extent={{-68,180},{12,260}})));
            Modelica.Blocks.Sources.Ramp load_pre(
              duration=2000,
              startTime=100,
              height=-30,
              offset=30)
              annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
            Auxiliaries.Components.Spline.SplineSignal
                                         LOAD(table=[5000 + 20000,20; 5077 + 20000,35; 5154
                   + 20000,46; 5231 + 20000,57; 5308 + 20000,68; 5385 + 20000,79; 5462 + 20000,
                  90; 5540 + 20000,100])
              annotation (Placement(transformation(extent={{-320,-80},{-300,-60}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-280,-50},{-260,-30}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{320,200},{300,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{320,50},{300,70}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{320,-10},{300,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-90},{240,-70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{260,-130},
                      {240,-110}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{274,170},{294,190}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,30},{280,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,-30},{280,-10}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{220,-150},{200,-130}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{300,-130},{280,-110}})));
            Modelica.Blocks.Sources.RealExpression LOAD6(y=gain.y)
              annotation (Placement(transformation(extent={{300,-90},{280,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder_hotStart
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              useTS_pumpMS=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              DT_sh_sp=20,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.848,
              B=[0.015625; 0; 0; 0; 0],
              useTS_valveTURB_high=true,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              control_wSEP(T_FW_SP(startTime=20000)),
              control_wBP(T_FW_SP(startTime=20000)))
                              annotation (Placement(transformation(extent={{-220,-60},{-172,
                      -20}})));
            HeatExchangers.Components.MSmixer_warm MSmixer
              annotation (Placement(transformation(extent={{-300,46},{-180,154}})));
          equation
            if time >= 5000 and time <= t_end then
              der(M_MStot) = MSmixer.sensW.w;
              der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
              der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
              der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
              der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
            else
              der(M_MStot) = 0;
              der(errT_FWupperBound) = 0;
              der(errT_FWlowerBound) = 0;
              der(errT_MSupperBound) = 0;
              der(errT_MSlowerBound) = 0;
            end if;

            if gain.y >= controllers.load_switch then
              der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
            else
              der(errDT_sh) = 0;
            end if;

            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{143.8,140},{169.9,140}},
                color={0,0,0},
                thickness=0.5));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{23.8889,-132},{23.8889,-130},{56.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{23.8889,-72},{23.8889,-72},{80,-72},{80,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{201.06,98.2},{201.06,48},{146.667,48},{146.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{102,98.2},{102,98.2},{102,-97},{103.333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-98,140},{-94,140},{-91,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-69,140},{-69,140},{60.2,140}},color={0,0,0},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -42.2222,-164},{-42.2222,-180},{133.333,-180},{133.333,-163}},
                              color={0,0,255},
                thickness=0.5));

            connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
                Line(
                points={{-12,178},{-12,178},{-12,84},{-11.1111,84}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
                Line(
                points={{-42.2222,84},{-42.2222,130},{-42,130},{-42,178}},
                color={0,0,255},
                thickness=0.5));
            connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
                  points={{-99,220},{-72,220}},   color={0,0,127}));
            connect(add.y, gain.u)
              annotation (Line(points={{-259,-40},{-247.2,-40}}, color={0,0,127}));
            connect(load_pre.y, add.u1) annotation (Line(points={{-299,-10},{-290,-10},{-290,
                    -34},{-282,-34}}, color={0,0,127}));
            connect(LOAD.y, add.u2) annotation (Line(points={{-299,-70},{-290,-70},{-290,-46},
                    {-282,-46}}, color={0,0,127}));
            connect(LOAD6.y, HPH1_sinkP.u[1])
              annotation (Line(points={{279,-80},{262,-80},{262,-80}}, color={0,0,127}));
            connect(LOAD5.y, HPH1_FW_source.u[1])
              annotation (Line(points={{279,-120},{262,-120}}, color={0,0,127}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{339,210},{330.5,210},
                    {322,210}}, color={0,0,127}));
            connect(LOAD2.y, SP3_sink.u[1]) annotation (Line(points={{339,60},{331.5,60},{
                    331.5,60},{322,60}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1])
              annotation (Line(points={{339,0},{330.5,0},{322,0}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(
                points={{260,40},{239.6,40},{239.6,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{260,-20},{219.92,-20},{219.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(
                points={{274,180},{260.1,180},{260.1,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(sinkPressure_DR.flange, HPHs.DR_out) annotation (Line(
                points={{200,-100},{192,-100},{192,-112},{183.333,-112}},
                color={0,0,255},
                thickness=0.5));
            connect(sourcePressure1.flange, HPHs.FW_in) annotation (Line(
                points={{200,-140},{194,-140},{194,-130},{183.333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points={{239,
                    -80},{206,-80},{206,-91.2}}, color={0,0,127}));
            connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(points={{239,
                    -120},{206,-120},{206,-131}}, color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{299,210},
                    {290,210},{280,210},{280,188.8}}, color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0)
              annotation (Line(points={{299,60},{266,60},{266,48.8}}, color={0,0,127}));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0)
              annotation (Line(points={{299,0},{266,0},{266,-11.2}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-233.4,
                    -40},{-222.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,120},{
                    -80,120},{-80,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,-220},{
                    156.667,-220},{156.667,-161.2}},
                color={255,204,51},
                thickness=0.5));
            connect(MSmixer.flangeB, OTSG.MS_in) annotation (Line(
                points={{-180,100},{-88.8889,100},{-88.8889,84}},
                color={0,0,255},
                thickness=0.5));
            connect(controllers.signalBus, MSmixer.signalBus) annotation (Line(
                points={{-169.818,-40},{-150,-40},{-150,20},{-240,20},{-240,46}},
                color={255,204,51},
                thickness=0.5));
            connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
              annotation (Line(
                points={{14,204},{32,204},{60.2,204},{60.2,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
              annotation (Line(
                points={{14,236},{169.9,236},{169.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPTurb.vap_out, OTSG.RH_in) annotation (Line(
                points={{60.2,109.6},{60.2,48},{23.8889,48}},
                color={0,0,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-340,-280},{360,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-340,
                      -280},{360,280}}, preserveAspectRatio=false)),
              experiment(
                StopTime=20000,
                __Dymola_NumberOfIntervals=5000,
                Tolerance=1e-006),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),    __Dymola_experimentFlags(
                Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                      false),
                Evaluate=false,
                OutputCPUtime=false,
                OutputFlatModelica=false));
          end Plant_HP_20_100_des_warmkeepingB;

          model Plant_HP_20_100_des_warmkeepingB_turbByPass
            "Model of the HP steam cycle, with desuperheating process, starting from warmkeeping configuration B"

            parameter Modelica.SIunits.Time t_end = 20000 "Integral end time";
            parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
              "Feedwater inlet temperature upper bound";
            parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
              "Feedwater inlet temperature lower bound";
            parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
              "Feedwater inlet temperature upper bound";

            //parameter Modelica.SIunits.Time t_start_high = load.startTime + load.duration/load.height*(controllers.load_switch - load.offset - 20);
            //parameter Modelica.SIunits.Time time_high[controllers.n] = linspace(t_start_high,load.startTime + load.duration,controllers.n);

            Real errDT_sh "Quadratic integral error on degree of superheating";
            Real errT_FWupperBound
              "Quadratic integral error on feedwater inlet temperature (upper bound)";
            Real errT_FWlowerBound
              "Quadratic integral error on feedwater inlet temperature (lower bound)";
            Real errT_MSupperBound
              "Quadratic integral error on molten salt temperature (upper bound)";
            Real errT_MSlowerBound
              "Quadratic integral error on molten salt temperature (lower bound)";
            Real M_MStot "Molten salt hot flow total mass";
            Real eta_I = P_net/Q_in
              "Power plant first principle net efficiency";
            Real Q_in = OTSG.Q_tot "Global thermal input";
            Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
              "Auxiliaries consumption, as function of load";
            Real P_gross = powerSensor.gain.y "Gross electrical power";
            Real P_net = P_gross - P_aux "Net pelectrical power";

            SteamTurbine.Corps.HPT_valves
                                   HPTurb(w_seal=0.022,
              t_step1=20000,
              t_step2=20000)
              annotation (Placement(transformation(extent={{64,102},{140,178}})));
            SteamTurbine.Corps.IPT_valves
                                   IPTurb(t_step1=20000, t_step2=20000)
              annotation (Placement(transformation(extent={{174,102},{256,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-340,260},{-320,280}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},{-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_warm
                                                   OTSG      annotation (
                Placement(transformation(extent={{-120,-160},{20,80}})));

            HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
                                                                           HPHs(HPH1(Ti=
                    100))
                         annotation (Placement(transformation(extent={{60,-160},{180,-100}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-118,130},{-98,150}})));
            Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
              annotation (Placement(transformation(extent={{-90,130},{-70,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-246,-46},{-234,-34}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{360,200},{340,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{360,50},{340,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{360,-10},{340,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{-120,210},{-100,230}})));
            HeatExchangers.Components.Desuperheaters_controlled
              desuperheaters_controlled(
              TS_valves=0.001,
              T_start1=733.15,
              T_end1=773.15,
              t_start1=20000,
              t_end1=21000,
              T_start2=773.15,
              T_end2=823.15,
              t_start2=22222,
              t_end2=33333) annotation (Placement(transformation(extent={{-68,180},{12,260}})));
            Modelica.Blocks.Sources.Ramp load_pre(
              duration=2000,
              startTime=100,
              height=-30,
              offset=30)
              annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
            Auxiliaries.Components.Spline.SplineSignal
                                         LOAD(table=[5000 + 20000,20; 5077 + 20000,35; 5154
                   + 20000,46; 5231 + 20000,57; 5308 + 20000,68; 5385 + 20000,79; 5462 + 20000,
                  90; 5540 + 20000,100])
              annotation (Placement(transformation(extent={{-320,-80},{-300,-60}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-280,-50},{-260,-30}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5])
              annotation (Placement(transformation(extent={{320,200},{300,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5])
              annotation (Placement(transformation(extent={{320,50},{300,70}})));
            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{320,-10},{300,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
                  transformation(extent={{260,-90},{240,-70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100])
                                       annotation (Placement(transformation(extent={{260,-130},
                      {240,-110}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{274,170},{294,190}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,30},{280,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{260,-30},{280,-10}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              p0=18380000,
              use_in_h=true)
              annotation (Placement(transformation(extent={{220,-150},{200,-130}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{300,-130},{280,-110}})));
            Modelica.Blocks.Sources.RealExpression LOAD6(y=gain.y)
              annotation (Placement(transformation(extent={{300,-90},{280,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder_hotStart
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              l_sp=4,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              D=[0],
              load_switch=55,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              useTS_pumpMS=false,
              CSmin_pumpMS_high=-100,
              CSmax_pumpMS_high=100,
              DT_sh_sp=20,
              Kp_pumpMS_high=4e-4,
              Ti_pumpMS_high=16,
              Td_pumpMS_high=0,
              Kp_pumpMS_low=8.6e-5,
              Ti_pumpMS_low=571.4,
              Td_pumpMS_low=0,
              Kp_valveTURB_high=-2e-13,
              Ti_valveTURB_high=100,
              Kp_valveTURB_low=-1e-12,
              Ti_valveTURB_low=9.848,
              B=[0.015625; 0; 0; 0; 0],
              useTS_valveTURB_high=true,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
                  -2.78018594921513e-08],
              Kp_pumpFW_low=15.73,
              Ti_pumpFW_low=714.2,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              control_wSEP(T_FW_SP(startTime=20000)),
              control_wBP(T_FW_SP(startTime=20000)))
                              annotation (Placement(transformation(extent={{-220,-60},{-172,
                      -20}})));
            HeatExchangers.Components.MSmixer_warm MSmixer
              annotation (Placement(transformation(extent={{-300,46},{-180,154}})));
            Auxiliaries.Components.ThreeWayValve_2in threeWayValve_2in_SH(
                valve2(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                pnom=17000000,
                wnom=91.3,
                rhonom=27.7), valve1(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                pnom=8500000,
                wnom=17,
                rhonom=27)) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={60,204})));
            Auxiliaries.Components.ThreeWayValve_2in threeWayValve_2in_RH(
                valve2(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                pnom=4600000,
                wnom=85,
                rhonom=50), valve1(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                pnom=900000,
                wnom=16,
                rhonom=50)) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={168,236})));
            ThermoPower.Water.SourcePressure sourceMassFlow(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3540e3,
              p0=3261000) annotation (Placement(transformation(extent={{100,210},
                      {80,230}})));
            ThermoPower.Water.SourcePressure sourceMassFlow1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3617e3,
              p0=860000) annotation (Placement(transformation(extent={{200,244},
                      {180,264}})));
          protected
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              T=0.3,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,202},{76,206}})));
            Modelica.Blocks.Sources.Step step1(
              startTime=5000,
              height=1,
              offset=0)
              annotation (Placement(transformation(extent={{90,202},{86,206}})));
          protected
            Modelica.Blocks.Continuous.FirstOrder firstOrder1(
              k=1,
              T=0.3,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{188,234},{184,238}})));
            Modelica.Blocks.Sources.Step step3(
              startTime=5000,
              height=1,
              offset=0)
              annotation (Placement(transformation(extent={{196,234},{192,238}})));
          public
            ThermoPower.Water.ValveVap valveVap(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              CheckValve=true,
              wnom=17,
              pnom=8500000,
              dpnom=500000,
              rhonom=27) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={30,174})));
            ThermoPower.Water.SinkPressure sourceMassFlow3(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, p0=860000)
              annotation (Placement(transformation(extent={{140,250},{160,270}})));
            ThermoPower.Water.ValveVap valveVap1(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
              CheckValve=true,
              wnom=16,
              rhonom=50,
              pnom=1000000,
              dpnom=140000) annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=270,
                  origin={120,250})));
            Auxiliaries.Components.ThreeWayValve_2out threeWayValve_2out_SH(
                valve2(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                wnom=16,
                rhonom=50,
                pnom=8500000), valve1(
                CvData=ThermoPower.Choices.Valve.CvTypes.OpPoint,
                rhonom=27,
                wnom=85,
                pnom=4600000)) annotation (Placement(transformation(
                  extent={{10,10},{-10,-10}},
                  rotation=90,
                  origin={60,80})));
          protected
            Modelica.Blocks.Continuous.FirstOrder firstOrder2(
              k=1,
              T=0.3,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{42,78},{46,82}})));
            Modelica.Blocks.Sources.Step step2(
              startTime=5000,
              height=-1,
              offset=1)
              annotation (Placement(transformation(extent={{32,78},{36,82}})));
          public
            ThermoPower.Water.SinkPressure sourceMassFlow2(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph, p0=860000)
              annotation (Placement(transformation(extent={{80,70},{100,90}})));
          equation
            if time >= 5000 and time <= t_end then
              der(M_MStot) = MSmixer.sensW.w;
              der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
              der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
              der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
              der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
            else
              der(M_MStot) = 0;
              der(errT_FWupperBound) = 0;
              der(errT_FWlowerBound) = 0;
              der(errT_MSupperBound) = 0;
              der(errT_MSlowerBound) = 0;
            end if;

            if gain.y >= controllers.load_switch then
              der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
            else
              der(errDT_sh) = 0;
            end if;

            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{143.8,140},{169.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{23.8889,-132},{23.8889,-130},{56.6667,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{23.8889,-72},{23.8889,-72},{80,-72},{80,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{201.06,98.2},{201.06,48},{146.667,48},{146.667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{102,98.2},{102,98.2},{102,-97},{103.333,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-98,140},{-94,140},{-91,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-69,140},{-69,140},{60.2,140}},color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -42.2222,-164},{-42.2222,-180},{133.333,-180},{133.333,-163}},
                              color={0,0,255},
                thickness=0.5));

            connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
                Line(
                points={{-12,178},{-12,178},{-12,84},{-11.1111,84}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
                Line(
                points={{-42.2222,84},{-42.2222,130},{-42,130},{-42,178}},
                color={0,0,255},
                thickness=0.5));
            connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
                  points={{-99,220},{-72,220}},   color={0,0,127}));
            connect(add.y, gain.u)
              annotation (Line(points={{-259,-40},{-247.2,-40}}, color={0,0,127}));
            connect(load_pre.y, add.u1) annotation (Line(points={{-299,-10},{-290,-10},{-290,
                    -34},{-282,-34}}, color={0,0,127}));
            connect(LOAD.y, add.u2) annotation (Line(points={{-299,-70},{-290,-70},{-290,-46},
                    {-282,-46}}, color={0,0,127}));
            connect(LOAD6.y, HPH1_sinkP.u[1])
              annotation (Line(points={{279,-80},{262,-80},{262,-80}}, color={0,0,127}));
            connect(LOAD5.y, HPH1_FW_source.u[1])
              annotation (Line(points={{279,-120},{262,-120}}, color={0,0,127}));
            connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{339,210},{330.5,210},
                    {322,210}}, color={0,0,127}));
            connect(LOAD2.y, SP3_sink.u[1]) annotation (Line(points={{339,60},{331.5,60},{
                    331.5,60},{322,60}}, color={0,0,127}));
            connect(LOAD3.y, SP4_sinkP.u[1])
              annotation (Line(points={{339,0},{330.5,0},{322,0}}, color={0,0,127}));
            connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(
                points={{260,40},{239.6,40},{239.6,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{260,-20},{219.92,-20},{219.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(
                points={{274,180},{260.1,180},{260.1,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(sinkPressure_DR.flange, HPHs.DR_out) annotation (Line(
                points={{200,-100},{192,-100},{192,-112},{183.333,-112}},
                color={0,0,255},
                thickness=0.5));
            connect(sourcePressure1.flange, HPHs.FW_in) annotation (Line(
                points={{200,-140},{194,-140},{194,-130},{183.333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points={{239,
                    -80},{206,-80},{206,-91.2}}, color={0,0,127}));
            connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(points={{239,
                    -120},{206,-120},{206,-131}}, color={0,0,127}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{299,210},
                    {290,210},{280,210},{280,188.8}}, color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0)
              annotation (Line(points={{299,60},{266,60},{266,48.8}}, color={0,0,127}));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0)
              annotation (Line(points={{299,0},{266,0},{266,-11.2}}, color={0,0,127}));
            connect(gain.y, controllers.load) annotation (Line(points={{-233.4,
                    -40},{-222.182,-40}}, color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,120},{
                    -80,120},{-80,130}},
                color={255,204,51},
                thickness=0.5));

            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,-220},{
                    156.667,-220},{156.667,-161.2}},
                color={255,204,51},
                thickness=0.5));
            connect(MSmixer.flangeB, OTSG.MS_in) annotation (Line(
                points={{-180,100},{-88.8889,100},{-88.8889,84}},
                color={0,0,255},
                thickness=0.5));
            connect(controllers.signalBus, MSmixer.signalBus) annotation (Line(
                points={{-169.818,-40},{-150,-40},{-150,20},{-240,20},{-240,46}},
                color={255,204,51},
                thickness=0.5));
            connect(desuperheaters_controlled.SH_out, threeWayValve_2in_SH.inlet2)
              annotation (Line(points={{14,204},{32,204},{50,204}}, color={0,0,
                    255}));
            connect(threeWayValve_2in_SH.outlet, HPTurb.vap_in) annotation (
                Line(points={{60,194},{60,162.8},{60.2,162.8}}, color={0,0,255}));
            connect(desuperheaters_controlled.RH_out, threeWayValve_2in_RH.inlet2)
              annotation (Line(points={{14,236},{158,236}}, color={0,0,255}));
            connect(threeWayValve_2in_RH.outlet, IPTurb.vap_in) annotation (
                Line(points={{168,226},{168,162.8},{169.9,162.8}}, color={0,0,
                    255}));
            connect(sourceMassFlow1.flange, threeWayValve_2in_RH.inlet1)
              annotation (Line(points={{180,254},{168,254},{168,246}}, color={0,
                    0,255}));
            connect(sourceMassFlow.flange, threeWayValve_2in_SH.inlet1)
              annotation (Line(points={{80,220},{60,220},{60,214}}, color={0,0,
                    255}));
            connect(threeWayValve_2in_SH.theta, firstOrder.y)
              annotation (Line(points={{68,204},{75.8,204}}, color={0,0,127}));
            connect(threeWayValve_2in_RH.theta, firstOrder1.y) annotation (Line(
                  points={{176,236},{183.8,236}}, color={0,0,127}));
            connect(firstOrder1.u, step3.y) annotation (Line(points={{188.4,236},
                    {191.8,236}}, color={0,0,127}));
            connect(firstOrder.u, step1.y) annotation (Line(points={{80.4,204},
                    {85.8,204}}, color={0,0,127}));
            connect(desuperheaters_controlled.SH_out, valveVap.inlet)
              annotation (Line(points={{14,204},{30,204},{30,184}}, color={0,0,
                    255}));
            connect(firstOrder.y, valveVap.theta) annotation (Line(points={{
                    75.8,204},{72,204},{72,174},{38,174}}, color={0,0,127}));
            connect(valveVap1.outlet, sourceMassFlow3.flange) annotation (Line(
                  points={{120,260},{130,260},{140,260}}, color={0,0,255}));
            connect(desuperheaters_controlled.RH_out, valveVap1.inlet)
              annotation (Line(points={{14,236},{120,236},{120,240}}, color={0,
                    0,255}));
            connect(firstOrder1.y, valveVap1.theta) annotation (Line(points={{
                    183.8,236},{180,236},{180,208},{132,208},{132,250},{128,250}},
                  color={0,0,127}));
            connect(threeWayValve_2out_SH.theta, firstOrder2.y) annotation (
                Line(points={{52,80},{52,80},{46.2,80}}, color={0,0,127}));
            connect(firstOrder2.u, step2.y) annotation (Line(points={{41.6,80},
                    {41.6,80},{36.2,80}}, color={0,0,127}));
            connect(valveVap.outlet, OTSG.RH_in) annotation (Line(points={{30,164},
                    {30,164},{30,84},{30,48},{23.8889,48}},      color={0,0,255}));
            connect(threeWayValve_2out_SH.outlet1, OTSG.RH_in) annotation (Line(
                  points={{60,70},{60,70},{60,50},{60,48},{23.8889,48}}, color=
                    {0,0,255}));
            connect(HPTurb.vap_out, threeWayValve_2out_SH.inlet) annotation (
                Line(points={{60.2,109.6},{60.2,100.8},{60,100.8},{60,90}},
                  color={0,0,255}));
            connect(threeWayValve_2out_SH.outlet2, sourceMassFlow2.flange)
              annotation (Line(points={{70,80},{75,80},{80,80}}, color={0,0,255}));
            annotation (Diagram(coordinateSystem(extent={{-340,-280},{360,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-340,
                      -280},{360,280}}, preserveAspectRatio=false)),
              experiment(
                StopTime=20000,
                __Dymola_NumberOfIntervals=5000,
                Tolerance=1e-006),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),    __Dymola_experimentFlags(
                Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                      false),
                Evaluate=false,
                OutputCPUtime=false,
                OutputFlatModelica=false));
          end Plant_HP_20_100_des_warmkeepingB_turbByPass;
        end HotStart_shutDown;

        package Old "package containing old test model"

          model test_FWdepressurization_steamOnly_worseCase_100
            "Test that evaluates the depressurization of the FW cycle with no heat flux across HEs tubes"

            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=1062.9e3,
              w0=115.85,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{80,-100},{60,-120}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=84.94,
              h=3103000,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{100,-40},{80,-20}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=4732000)
              annotation (Placement(transformation(extent={{-40,10},{-60,30}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=1050000,
              h=519092)   annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));

            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000)  annotation (Placement(transformation(extent={{-40,-160},{-60,-140}})));

            inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-280,240},{-260,260}})));
            ThermoPower.Water.SinkPressure sinkHPH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17350000)
              annotation (Placement(transformation(extent={{40,-160},{60,-140}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=17000000)
              annotation (Placement(transformation(extent={{40,210},{60,230}})));
            ThermoPower.Water.ThroughMassFlow pump_HPH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=24.51)
              annotation (Placement(transformation(extent={{0,-140},{20,-160}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_drainage
              controlSystem(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              t_ramp=0,
              load_start=100,
              load_end=100,
              t_start_ramp=0,
              Kp_valveTURB=-2.215e-11,
              Ti_valveTURB=0.161,
              DT_SH_sp(displayUnit="K") = 293.15,
              Kp_valveBP_SH=-0.00001,
              Ti_valveBP_SH=10,
              Td_valveBP_SH=0,
              Nd_valveBP_SH=20,
              CSmax_valveBP_SH=1,
              CSstart_valveBP_SH=0,
              actuatorGain_valveBP_SH=1,
              Ta_valveBP_SH=0.3,
              useTS_valveBP_SH=true,
              TS_valveBP_SH=0,
              Kp_valveBP_RH=-0.00001,
              Ti_valveBP_RH=10,
              Td_valveBP_RH=0,
              Nd_valveBP_RH=30,
              CSmax_valveBP_RH=0,
              CSstart_valveBP_RH=0,
              actuatorGain_valveBP_RH=1,
              Ta_valveBP_RH=0.3,
              useTS_valveBP_RH=true,
              TS_start=false,
              TS_valveBP_RH=0,
              actuatorGain_valveINT_IPT=1,
              Ta_valveINT_IPT=0.3,
              TS_valveTURB=0.01,
              t_start_drain=0,
              CSmin_valveBP_SH=0,
              CSmin_valveBP_RH=0,
              l_sep_SP=0.5,
              w_SEPmax=100,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Ta_pumpFW=2,
              step1(height=-0.99),
              step3(height=-0.99),
              step4(height=-0.99),
              useSEP=true,
              useTS_valveTURB=true,
              Kp_pumpFW_high=-0.001,
              Ti_pumpFW_high=150,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              CSstart_pumpFW_high=0.3,
              useTS_pumpFW_high=true,
              TS_pumpFW_high=0,
              l_sp=4,
              Kp_pumpFW_low=1,
              Ti_pumpFW_low=20,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=110,
              CSstart_pumpFW_low=47,
              useTS_pumpFW_low=true,
              TS_pumpFW_low=47,
              p_SH_sp=17100000,
              p_RH_sp=4732000) annotation (Placement(transformation(extent={{-136,
                      -92},{-98,-68}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            HeatExchangers.OTSG.Old.OTSG_init100_5nodes_drainage OTSG(t_switch=
                  0, separator(w_small=1e4, H=8)) annotation (Placement(
                  transformation(extent={{-40,-134},{26,-26}})));
            ThermoPower.Water.ValveVap valveTURB(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=90,
                  origin={12,200})));
            ThermoPower.Water.ValveVap valveBP_SH(
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CheckValve=true,
              Av=6.9222e-3,
              pnom=17100000,
              dpnom=100000,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=0,
                  origin={40,106})));
            ThermoPower.Water.ValveVap valveBP_RH(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=2.42922e-3,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,60})));
            ThermoPower.Water.ValveVap valveSEC(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=91.28*0.2,
              CheckValve=true,
              Av=1.38203e-3,
              pnom=17100000,
              dpnom=100000)    annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-8,106})));
            ThermoPower.Water.SinkPressure sinkATM(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=92600)
              annotation (Placement(transformation(extent={{-40,96},{-60,116}})));
            Modelica.Blocks.Sources.Step valveTRIP(
              height=1,
              offset=0,
              startTime=controlSystem.t_start_drain)
              annotation (Placement(transformation(extent={{-40,130},{-20,150}})));
            Modelica.Blocks.Sources.Step step(
              offset=84.94,
              startTime=controlSystem.t_start_drain,
              height=-84.93)
              annotation (Placement(transformation(extent={{150,0},{130,20}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{120,0},{100,20}})));
            ThermoPower.Water.SinkPressure cond(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=300000)
                       annotation (Placement(transformation(extent={{-40,50},{-60,70}})));
            ThermoPower.Water.ValveVap valveINT_IPT(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              Av=0.1,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,20})));
            ThermoPower.Water.SensP sensP(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{6,54},{-14,74}})));
          equation
            connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                points={{20,-150},{40,-150}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                points={{-80,-80},{-80,-190},{6,-190},{6,-156}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus,signalBus)  annotation (Line(
                points={{-97.05,-80},{-97.05,-80},{-80,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus, OTSG.signalBus) annotation (Line(
                points={{-97.05,-80},{-42.5667,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-110},{60,-110}},
                                                   color={0,0,255}));
            connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-94.4},{27.8333,-94.4}},
                                                     color={0,0,255}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -25.3333,-135.8},{-25.3333,-150},{-40,-150}},
                                          color={0,0,255}));
            connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                    -3.33333,-135.8},{-3.33333,-150},{0,-150}},
                                                 color={0,0,255}));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,-190},{74,-190},{74,-116}},
                color={255,204,51},
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,-10},
                    {-26,-10},{-26,-24.2},{-25.3333,-24.2}},
                                                   color={0,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,4},{-80,200},{5.6,200}},
                color={255,204,51},
                thickness=0.5));
            connect(sinkATM.flange, valveSEC.outlet)
              annotation (Line(points={{-40,106},{-28,106},{-16,106}}, color={0,0,255}));
            connect(valveTURB.outlet, sinkSH.flange)
              annotation (Line(points={{12,208},{12,220},{40,220}}, color={0,0,255}));
            connect(valveTRIP.y, valveSEC.theta) annotation (Line(points={{-19,140},{-14,140},
                    {-8,140},{-8,112.4}}, color={0,0,127}));
            connect(valveBP_SH.outlet, OTSG.RH_in) annotation (Line(points={{48,106},
                    {60,106},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(sourceRH.flange, OTSG.RH_in) annotation (Line(points={{80,-30},
                    {60,-30},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(OTSG.SH_out, valveTURB.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,105.9},{12,105.9},{12,192}},
                                                          color={0,0,255}));
            connect(OTSG.SH_out, valveBP_SH.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{32,106}},
                                             color={0,0,255}));
            connect(OTSG.SH_out, valveSEC.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{0,106}},
                                           color={0,0,255}));
            connect(firstOrder.u, step.y)
              annotation (Line(points={{122,10},{129,10}}, color={0,0,127}));
            connect(firstOrder.y, sourceRH.in_w0)
              annotation (Line(points={{99,10},{94,10},{94,-24}}, color={0,0,127}));
            connect(cond.flange, valveBP_RH.outlet)
              annotation (Line(points={{-40,60},{-34,60},{-28,60}}, color={0,0,255}));
            connect(sinkRH.flange, valveINT_IPT.outlet)
              annotation (Line(points={{-40,20},{-34,20},{-28,20}}, color={0,0,255}));
            connect(OTSG.RH_out, valveINT_IPT.inlet) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,20},{-12,20}},
                                             color={0,0,255}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,160},{40,160},{40,112.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-20,80},{-20,66.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,40},{-20,40},{-20,26.4}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, valveBP_RH.inlet)
              annotation (Line(points={{-4,60},{-12,60}}, color={0,0,255}));
            connect(OTSG.RH_out, sensP.flange) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,60},{-4,60}},
                                  color={0,0,255}));
            connect(signalBus.valveBP_RH_PV, sensP.p) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-12,80},{-12,70}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -260},{280,260}}), graphics={Text(
                    extent={{-240,180},{-132,56}},
                    lineColor={28,108,200},
                    textString="In 5 min la pressione scende a 65 bar. Anche qui
se non attivo il ricircolo il separatore si riempie.")}),  Icon(coordinateSystem(
                    extent={{-280,-260},{280,260}})),
              experiment(
                StartTime=-10000,
                StopTime=400,
                __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(revisions="<html>
</html>", info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
          end test_FWdepressurization_steamOnly_worseCase_100;

          model test_FWdepressurization_steamOnly_worseCase_50
            "Test that evaluates the depressurization of the FW cycle with no heat flux across HEs tubes"

            ThermoPower.Water.SourceMassFlow sourceFW(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=115.85,
              use_in_w0=true,
              h=1077.2e3)
              annotation (Placement(transformation(extent={{80,-100},{60,-120}})));
            ThermoPower.Water.SourceMassFlow sourceRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=84.94,
              h=3103000,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{100,-38},{80,-18}})));
            ThermoPower.Water.SinkPressure sinkRH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=2266000)
              annotation (Placement(transformation(extent={{-40,10},{-60,30}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=1050000,
              h=519092)   annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));

            ThermoPower.Water.SinkPressure sinkMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000)  annotation (Placement(transformation(extent={{-40,-160},{-60,-140}})));

            inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                  ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-280,240},{-260,260}})));
            ThermoPower.Water.SinkPressure sinkHPH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              p0=17350000)
              annotation (Placement(transformation(extent={{40,-160},{60,-140}})));
            ThermoPower.Water.SinkPressure sinkSH(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=8830000)
              annotation (Placement(transformation(extent={{40,210},{60,230}})));
            ThermoPower.Water.ThroughMassFlow pump_HPH(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              w0=24.51)
              annotation (Placement(transformation(extent={{0,-140},{20,-160}})));
            Control.Schemes.PlantControlSchemes.plant_controller_HPpart_drainage
              controlSystem(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Td_valveTURB=0,
              Nd_valveTURB=1,
              actuatorGain_valveTURB=1,
              CSmin_valveTURB=-0.9,
              CSmax_valveTURB=0.65,
              CSstart_valveTURB=0,
              t_ramp=0,
              t_start_ramp=0,
              Kp_valveTURB=-2.215e-11,
              Ti_valveTURB=0.161,
              DT_SH_sp(displayUnit="K") = 293.15,
              Kp_valveBP_SH=-0.00001,
              Ti_valveBP_SH=10,
              Td_valveBP_SH=0,
              Nd_valveBP_SH=20,
              CSmax_valveBP_SH=1,
              CSstart_valveBP_SH=0,
              actuatorGain_valveBP_SH=1,
              Ta_valveBP_SH=0.3,
              useTS_valveBP_SH=true,
              TS_valveBP_SH=0,
              Kp_valveBP_RH=-0.00001,
              Ti_valveBP_RH=10,
              Td_valveBP_RH=0,
              Nd_valveBP_RH=30,
              CSmax_valveBP_RH=0,
              CSstart_valveBP_RH=0,
              actuatorGain_valveBP_RH=1,
              Ta_valveBP_RH=0.3,
              useTS_valveBP_RH=true,
              TS_start=false,
              TS_valveBP_RH=0,
              actuatorGain_valveINT_IPT=1,
              Ta_valveINT_IPT=0.3,
              TS_valveTURB=0.01,
              t_start_drain=0,
              CSmin_valveBP_SH=0,
              CSmin_valveBP_RH=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              Ta_pumpFW=2,
              step1(height=-0.99),
              step3(height=-0.99),
              step4(height=-0.99),
              load_start=50,
              load_end=50,
              useTS_valveTURB=true,
              Kp_pumpFW_high=-0.001,
              Ti_pumpFW_high=150,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.3,
              CSmax_pumpFW_high=0.3,
              CSstart_pumpFW_high=0.3,
              useTS_pumpFW_high=true,
              TS_pumpFW_high=0,
              l_sp=4,
              Ti_pumpFW_low=20,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              CSmax_pumpFW_low=110,
              CSstart_pumpFW_low=47,
              useTS_pumpFW_low=true,
              TS_pumpFW_low=47,
              Kp_pumpFW_low=10,
              l_sep_SP=4,
              const(k=80),
              const3(k=0),
              useSEP=true,
              p_SH_sp=17100000,
              p_RH_sp=4732000,
              w_SEPmax=100,
              pumpHPH_lim(uMin=20)) annotation (Placement(transformation(extent=
                     {{-136,-92},{-98,-68}})));
            Modelica.Icons.SignalBus signalBus
              annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})));
            HeatExchangers.OTSG.Old.OTSG_init50_5nodes_drainage OTSG(t_switch=0,
                separator(w_small=1e4)) annotation (Placement(transformation(
                    extent={{-40,-134},{26,-26}})));
            ThermoPower.Water.ValveVap valveTURB(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              Av=0.053642779,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              pnom=17100000,
              dpnom=100000) annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=90,
                  origin={12,200})));
            ThermoPower.Water.ValveVap valveBP_SH(
              Fxt_full=0.4542722663,
              wnom=91.28,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              CheckValve=true,
              Av=6.9222e-3,
              pnom=17100000,
              dpnom=100000,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{-8,-8},{8,8}},
                  rotation=0,
                  origin={40,106})));
            ThermoPower.Water.ValveVap valveBP_RH(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              Av=2.42922e-3,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96,
              thetanom=1)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,60})));
            ThermoPower.Water.ValveVap valveSEC(
              thetanom=0.8,
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              wnom=91.28*0.2,
              CheckValve=true,
              Av=1.38203e-3,
              pnom=17100000,
              dpnom=100000)    annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-8,106})));
            ThermoPower.Water.SinkPressure sinkATM(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=92600)
              annotation (Placement(transformation(extent={{-40,96},{-60,116}})));
            Modelica.Blocks.Sources.Step valveTRIP(
              height=1,
              offset=0,
              startTime=controlSystem.t_start_drain)
              annotation (Placement(transformation(extent={{-40,130},{-20,150}})));
            Modelica.Blocks.Sources.Step step(
              offset=84.94,
              startTime=controlSystem.t_start_drain,
              height=-84.93)
              annotation (Placement(transformation(extent={{150,0},{130,20}})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{120,0},{100,20}})));
            ThermoPower.Water.SinkPressure cond(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=false,
              p0=300000)
                       annotation (Placement(transformation(extent={{-40,50},{-60,70}})));
            ThermoPower.Water.ValveVap valveINT_IPT(
              Fxt_full=0.4542722663,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              thetanom=1,
              Av=0.1,
              pnom=4780000,
              dpnom=100000,
              wnom=84.96)   annotation (Placement(transformation(
                  extent={{8,-8},{-8,8}},
                  rotation=0,
                  origin={-20,20})));
            ThermoPower.Water.SensP sensP(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph)
              annotation (Placement(transformation(extent={{6,54},{-14,74}})));
          equation
            connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
                points={{20,-150},{40,-150}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
                points={{-80,-80},{-80,-190},{6,-190},{6,-156}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus,signalBus)  annotation (Line(
                points={{-97.05,-80},{-97.05,-80},{-80,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(controlSystem.signalBus, OTSG.signalBus) annotation (Line(
                points={{-97.05,-80},{-42.5667,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-110},{60,-110}},
                                                   color={0,0,255}));
            connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{27.8333,
                    -121.4},{40,-121.4},{40,-94.4},{27.8333,-94.4}},
                                                     color={0,0,255}));
            connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                    -25.3333,-135.8},{-25.3333,-150},{-40,-150}},
                                          color={0,0,255}));
            connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                    -3.33333,-135.8},{-3.33333,-150},{0,-150}},
                                                 color={0,0,255}));
            connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,-190},{74,-190},{74,-116}},
                color={255,204,51},
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,-10},
                    {-26,-10},{-26,-24.2},{-25.3333,-24.2}},
                                                   color={0,0,255}));
            connect(signalBus.valveTURB_CS, valveTURB.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,4},{-80,200},{5.6,200}},
                color={255,204,51},
                thickness=0.5));
            connect(sinkATM.flange, valveSEC.outlet)
              annotation (Line(points={{-40,106},{-28,106},{-16,106}}, color={0,0,255}));
            connect(valveTURB.outlet, sinkSH.flange)
              annotation (Line(points={{12,208},{12,220},{40,220}}, color={0,0,255}));
            connect(valveTRIP.y, valveSEC.theta) annotation (Line(points={{-19,140},{-14,140},
                    {-8,140},{-8,112.4}}, color={0,0,127}));
            connect(valveBP_SH.outlet, OTSG.RH_in) annotation (Line(points={{48,106},
                    {60,106},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(sourceRH.flange, OTSG.RH_in) annotation (Line(points={{80,-28},
                    {60,-28},{60,-40.4},{27.8333,-40.4}},
                                                 color={0,0,255}));
            connect(OTSG.SH_out, valveTURB.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,105.9},{12,105.9},{12,192}},
                                                          color={0,0,255}));
            connect(OTSG.SH_out, valveBP_SH.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{32,106}},
                                             color={0,0,255}));
            connect(OTSG.SH_out, valveSEC.inlet) annotation (Line(points={{11.3333,
                    -24.2},{11.3333,106},{0,106}},
                                           color={0,0,255}));
            connect(firstOrder.u, step.y)
              annotation (Line(points={{122,10},{129,10}}, color={0,0,127}));
            connect(firstOrder.y, sourceRH.in_w0)
              annotation (Line(points={{99,10},{94,10},{94,-22}}, color={0,0,127}));
            connect(cond.flange, valveBP_RH.outlet)
              annotation (Line(points={{-40,60},{-34,60},{-28,60}}, color={0,0,255}));
            connect(sinkRH.flange, valveINT_IPT.outlet)
              annotation (Line(points={{-40,20},{-34,20},{-28,20}}, color={0,0,255}));
            connect(OTSG.RH_out, valveINT_IPT.inlet) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,20},{-12,20}},
                                             color={0,0,255}));
            connect(signalBus.valveBP_SH_CS, valveBP_SH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,160},{40,160},{40,112.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveBP_RH_CS, valveBP_RH.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-20,80},{-20,66.4}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveINT_IPT_CS, valveINT_IPT.theta) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,40},{-20,40},{-20,26.4}},
                color={255,204,51},
                thickness=0.5));
            connect(sensP.flange, valveBP_RH.inlet)
              annotation (Line(points={{-4,60},{-12,60}}, color={0,0,255}));
            connect(OTSG.RH_out, sensP.flange) annotation (Line(points={{
                    -3.33333,-24.2},{-3.33333,60},{-4,60}},
                                  color={0,0,255}));
            connect(signalBus.valveBP_RH_PV, sensP.p) annotation (Line(
                points={{-80,-80},{-80,-80},{-80,80},{-12,80},{-12,70}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -260},{280,260}}), graphics={Text(
                    extent={{-240,180},{-132,56}},
                    lineColor={28,108,200},
                    textString="In 6.5 min la pressione scende a 65 bar. 
 Valvole gi� tarate correttamente, il loro controllo di
 fatto le porta a chiudersi subito per tenere su
 la pressione.")}),                                        Icon(coordinateSystem(
                    extent={{-280,-260},{280,260}})),
              experiment(
                StartTime=-10000,
                StopTime=85,
                __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput,
              Documentation(revisions="<html>
</html>", info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
          end test_FWdepressurization_steamOnly_worseCase_50;

          model Plant_HP_4th_orderFW_20_limitCycle
            "Model of the high pressure part of the OTSG"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=88.3e5,
                    fixed=true))) annotation (Placement(transformation(extent={
                      {18,102},{94,178}})));
            SteamTurbine.Corps.IPT IPTurb(vap_in(p(start=2215000)),
                pressDrop_IPT1_HPH1(pin(start=1100000, fixed=true)))
              annotation (Placement(transformation(extent={{124,102},{206,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,260},{-300,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-160,90},
                      {-140,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-140,-190},
                      {-160,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG(
              PDSteamEVA1(pin(start=9000000, fixed=true)),
              PDSteamECO2(pin(start=90.74e5, fixed=true)),
              PDSteamECO1(pin(start=92.49e5, fixed=true)),
              valveVap(inlet(p(start=8882000))),
              RH(coldFluid(noInitialPressure=true)),
              valveLiq(Av=3.705e-5),
              separator(zl_start=1))
              annotation (Placement(transformation(extent={{-160,-160},{-20,80}})));
            HeatExchangers.FeedwaterTrain.Old.HPH_train_controlledLevel_50 HPHs(
              SP1(p(start=3941000, fixed=true)),
              SP2(p(start=1000000, fixed=true)),
              DPSteamHPH2(w(start=46.95, fixed=true)),
              HPH1(
                NusseltCondenser(w_cond(start=1), ws_in(start=1, fixed=true)),
                Kp=-1,
                pressDropLin(R=0.5e5)),
              HPH2(
                NusseltCondenser(w_cond(start=6.022)),
                Kp=-10,
                pressDropLin(inlet(m_flow(start=6.022, fixed=true)), R=0.5e5)))
              annotation (Placement(transformation(extent={{20,-160},{120,-104}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{140,-110},{160,-90}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=768600,
              use_in_h=true,
              p0=18380000)
              annotation (Placement(transformation(extent={{160,-150},{140,-130}})));
            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=450000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{214,170},{234,190}})));

            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=508800,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,30},{220,50}})));
            ThermoPower.Water.SinkPressure sinkPressure2(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{200,-30},{220,-10}})));
            Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
                  30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
                  2.753e5; 90,3.09e5; 100,3.448e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,200},{240,220}})));
            Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
                  1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
                  2.633e5; 90,2.946e5; 100,3.276e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{260,50},{240,70}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_P_source(table=[20,565400;
                  30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
                  764100; 90,783800; 100,803100], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                  annotation (Placement(
                  transformation(extent={{200,-130},{180,-110}})));

            Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{260,-10},{240,10}})));
            Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                          table=[20,2.234e5; 30,
                  3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
                  8.731e5; 90,9.773e5; 100,10.86e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
                                                     annotation (Placement(
                  transformation(extent={{200,-90},{180,-70}})));
            Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              DT_sh_sp=293.15,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Ti_valveTURB_low=3.626,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              CSmax_pumpMS_high=50,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              Kp_pumpMS_high=0.0004566,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_pumpMS=false,
              useTS_valveTURB_high=false,
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              Kp_pumpMS_low=0.3*0.000147,
              Kp_valveTURB_low=-1.518e-11,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-264,
                      -60},{-216,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-44,130},{-24,150}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-16,130},{4,150}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{300,200},{280,220}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{300,50},{280,70}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{300,-10},{280,10}})));
            Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
              annotation (Placement(transformation(extent={{240,-90},{220,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
              annotation (Placement(transformation(extent={{240,-130},{220,-110}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-288,-46},{-276,-34}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1e6,
              offset=50,
              startTime=15000,
              height=-30)      annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{97.8,140},{119.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-140,-180},{-128.889,-180},{-128.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-140,100},{-128.889,100},{-128.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-16.1111,48},{14.2,48},{14.2,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-51.1111,84},{-51.1111,162.8},{14.2,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-16.1111,-132},{-16.1111,-132},{17.2222,-132}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-16.1111,-72},{-16.1111,-72},{36.6667,-72},{36.6667,
                    -101.2}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-82.2222,84},{-82,84},{-82,168},{-82,200},{119.9,200},
                    {119.9,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.FW_in, sourcePressure1.flange) annotation (Line(points={{122.778,
                    -132},{122.778,-132},{136,-132},{136,-140},{140,-140}}, color={0,0,255},
                thickness=0.5));

            connect(HPHs.DR_out, sinkPressure_DR.flange) annotation (Line(points={{122.778,
                    -115.2},{122.778,-115.2},{136,-115.2},{136,-100},{140,-100}},
                                                                            color={0,127,0},
                thickness=0.5));

            connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{214,180},
                    {210.1,180},{210.1,162.8}}, color={0,0,255}));
            connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{239,210},
                    {220,210},{220,188.8}},          color={0,0,127}));
            connect(SP3_sink.y[1], sinkPressure1.in_p0) annotation (Line(points={{239,60},
                    {206,60},{206,48.8}},     color={0,0,127}));
            connect(HPH1_P_source.y[1], sourcePressure1.in_h) annotation (Line(
                  points={{179,-120},{146,-120},{146,-131}}, color={0,0,127}));
            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{151.06,98.2},{151.06,48},{92.2222,48},{92.2222,-101.2}},
                color={0,127,0},
                thickness=0.5));

            connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
                points={{200,-20},{186,-20},{169.92,-20},{169.92,98.2}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP3, sinkPressure1.flange) annotation (Line(
                points={{189.6,98.2},{189.6,40},{200,40}},
                color={0,127,0},
                thickness=0.5));
            connect(SP4_sinkP.y[1], sinkPressure2.in_p0) annotation (Line(points=
                    {{239,0},{206,0},{206,-11.2}}, color={0,0,127}));
            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{56,98.2},{56,98.2},{56,-101.2},{56.1111,-101.2}},
                color={0,127,0},
                thickness=0.5));
            connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(
                  points={{179,-80},{162,-80},{146,-80},{146,-91.2}}, color={0,0,
                    127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-213.818,-40},{-165.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{262,210},
                    {279,210}},                color={0,0,127}));
            connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{262,60},{
                    279,60}},          color={0,0,127}));
            connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{262,0},{
                    279,0}},         color={0,0,127}));
            connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{202,-80},
                    {219,-80}},                     color={0,0,127}));
            connect(HPH1_P_source.u[1], LOAD5.y) annotation (Line(points={{202,
                    -120},{219,-120}}, color={0,0,127}));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-24,140},{-17,140},{-17,140}}, color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{5,140},{14.2,140}},            color={0,
                    0,0}));
            connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
                points={{-213.818,-40},{-190,-40},{-190,-220},{100.556,-220},{
                    100.556,-161.12}},
                color={255,204,51},
                thickness=0.5));
            connect(powerSensor.signalBus, controllers.signalBus) annotation (
                Line(
                points={{-6,130},{-6,120},{-190,120},{-190,-40},{-213.818,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -82.2222,-164},{-82.2222,-180},{81.1111,-180},{81.1111,
                    -162.8}}, color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-275.4,
                    -40},{-266.182,-40}}, color={0,0,127}));
            connect(ramp.y, gain.u)
              annotation (Line(points={{-299,-40},{-289.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-280},{320,280}},
                    preserveAspectRatio=false), graphics={Text(
                    extent={{-286,234},{-136,156}},
                    lineColor={28,108,200},
                    textString="SOLVED")}),                Icon(coordinateSystem(extent={{-320,
                      -280},{320,280}}, preserveAspectRatio=false)),
              experiment(StopTime=1.03e+006, __Dymola_NumberOfIntervals=10000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Plant_HP_4th_orderFW_20_limitCycle;

          model Plant_Full_20 "Model of the full steam cycle"

            SteamTurbine.Corps.HPT HPTurb(w_seal=0.022, vap_in(p(start=8830000)))
              annotation (Placement(transformation(extent={{-56,102},{20,178}})));
            SteamTurbine.Corps.IPT IPTurb(
              pressDrop_IPT1_HPH1(pin(start=1100000, fixed=false)),
              vap_in(p(start=2215000)),
              pressDrop_IPT2_DEA(pin(start=280000)),
              SP4(p(start=230000)))
              annotation (Placement(transformation(extent={{54,102},{136,178}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-240,90},{
                      -220,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                      -240,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes OTSG(
              RH(coldFluid(noInitialPressure=true), nominalColdPressure=800000),
              valveLiq(Av=3.705e-5),
              PDSteamECO2(pin(start=8600000)),
              PDSteamEVA2(pin(start=8510000, fixed=false)),
              EVA2(nominalColdPressure=8520000),
              separator(zl_start=1),
              valveVap(inlet(p(start=8500000))),
              PDSteamEVA1(pin(start=8544000)),
              PDSteamECO1(pin(start=8650000)))
                                     annotation (Placement(transformation(extent={{
                      -240,-160},{-100,80}})));
            HeatExchangers.FeedwaterTrain.Old.HPH_train_controlledLevel_50 HPHs(
              HPH1(
                tubeWalls_cond(initOpt=ThermoPower.Choices.Init.Options.fixedState,
                    Tvolstart={433.15,433.15,433.15,433.15,433.15,433.15,433.15,
                      433.15,433.15}),
                NusseltCondenser(w_cond(start=0.8), ws_in(start=0.3, fixed=true)),
                Kp=-10,
                Ti=100,
                nominalHotPressure=360000,
                nominalColdInletTemperature_des=428.15,
                nominalColdOutletTemperature_des=433.15,
                nominalHotInletTemperature_des=706.15,
                nominalColdInletTemperature_cond=408.15,
                nominalColdOutletTemperature_cond=413.15,
                nominalColdInletTemperature_sub=406.15,
                nominalColdOutletTemperature_sub=408.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=407.15,
                wnom=10),
              SP1(p(start=1800000)),
              SP2(p(start=400000)),
              DPSteamHPH2(w(start=46.95)),
              HPH2(
                sub_SP(hstart={7e5,6.5e5,6e5,5.5e5,5e5}),
                nominalColdInletTemperature_des=473.15,
                nominalColdOutletTemperature_des=479.15,
                nominalHotInletTemperature_des=700.15,
                nominalHotOutletTemperature_des=473.15,
                nominalColdInletTemperature_cond=423.15,
                nominalColdOutletTemperature_cond=473.15,
                nominalColdInletTemperature_sub=413.15,
                nominalColdOutletTemperature_sub=422.15,
                nominalHotInletTemperature_sub=423.15,
                nominalHotOutletTemperature_sub=414.15,
                NusseltCondenser(ws_in(start=6.022))))
              annotation (Placement(transformation(extent={{-60,-160},{60,-100}})));

            Control.Schemes.PlantControlSchemes.plantController
              controllers(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              actuatorGain_valveTURB=1,
              Td_valveBP=0,
              Nd_valveBP=20,
              actuatorGain_valveBP=1,
              Ta_valveBP=0.3,
              TS_valveBP=0,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Ta_valveTURB=0.3,
              DT_sh_sp=293.15,
              l_sp=4,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=10,
              TS_pumpFW_low=0,
              Kp_valveBP=-7.925e-6,
              Ti_valveBP=0.001,
              CSstart_valveBP=0,
              useTS_pumpFW_low=false,
              CSmin_valveBP=-1,
              CSmax_valveBP=1,
              Ti_pumpMS_high=98.66,
              Td_pumpMS_high=1.128,
              Nd_pumpMS_high=20,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=29.12,
              Td_pumpMS_low=4.26,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-50,
              CSmax_pumpMS_low=50,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_valveTURB_high=2.164,
              Td_valveTURB_high=0,
              Nd_valveTURB_high=20,
              CSmin_valveTURB_high=-0.1e-5,
              CSmax_valveTURB_high=0.1e-5,
              CSstart_valveTURB_high=0,
              TS_valveTURB_high=0,
              Td_valveTURB_low=0,
              Nd_valveTURB_low=20,
              CSstart_valveTURB_low=0,
              TS_valveTURB_low=0,
              Td_pumpSEP=0,
              Nd_pumpSEP=20,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              CSmin_pumpSEP=-0.2,
              CSmax_pumpSEP=0.2,
              CSmax_pumpFW_low=100,
              Kp_pumpSEP=0.01523,
              Ti_pumpSEP=2.267,
              Kp_pumpFW_low=15.73,
              CSstart_pumpFW_low=45,
              A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
                  0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
                  0],
              B=[0.03125; 0; 0; 0; 0],
              C=[-0.016,-0.0065016832,-0.0006317243326464,-3.0435043330687e-05,
                  -6.95046487303782e-08],
              D=[0],
              load_switch=55,
              CSmin_pumpMS_high=-50,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              TS_pumpFW_high=0,
              use_valveSEP=true,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              l_min=0.2,
              l_max=0.3,
              Kp_valveTURB_high=-1.077e-11,
              control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                      0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
              useTS_valveTURB_high=false,
              useTS_valveTURB_low=false,
              useTS_pumpFW_high=false,
              useTS_valveBP=false,
              useTS_pumpSEP=false,
              Td_pumpCOND=0,
              Nd_pumpCOND=20,
              CSmax_pumpCOND=100,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              useTS_pumpCOND=false,
              staticDecoupled_4th(control_wMS_low(table_P_MEC_low(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6])), control_wMS_high(table_P_MEC_high(table=[20,
                        20.254e6; 30,32.237e6; 40,44.345e6; 50,56.908e6; 60,
                        69.243e6; 70,81.234e6; 80,91.839e6; 90,102.755e6; 100,
                        114.430e6])),
                pumpMS_lim(uMax=700)),
              TS_pumpCOND=37.42,
              Kp_valveTURB_low=-1.518e-11,
              Kp_pumpMS_low=0.1*0.000147,
              Ti_valveTURB_low=3.626,
              CSmin_valveTURB_low=-0.1e-5,
              CSmax_valveTURB_low=0.1e-5,
              useTS_valveDEA=false,
              Td_valveDEA=0,
              Nd_valveDEA=20,
              CSmin_valveDEA=0,
              CSmax_valveDEA=1,
              CSstart_valveDEA=0.5,
              actuatorGain_valveDEA=1,
              Ta_valveDEA=0.3,
              TS_valveDEA=0,
              useTS_pumpMS=false,
              Kp_valveDEA=0.0001,
              Ti_valveDEA=10,
              CSstart_pumpCOND=14,
              CSmin_pumpCOND=5,
              Kp_pumpCOND=100,
              Ti_pumpCOND=100,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              CSmax_pumpMS_high=80,
              Kp_pumpMS_high=0.1*0.0004566,
              T_FW_sp=1104.45)
                              annotation (Placement(transformation(extent={{-340,
                      -60},{-292,-20}})));

            Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                              w_fixed=314.1592654)
              annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
            Auxiliaries.Components.powerSensor powerSensor
              annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-364,-46},{-352,-34}})));
            HeatExchangers.FeedwaterTrain.Old.LPH_train_controlledLevel LPHs(
              SP4(p(start=70000, fixed=true)),
              LPH2(
                tubeWalls_cond(Tvolstart={349.15,348.95,347.15}),
                NusseltCondenser(ws_in(start=2.021, fixed=true)),
                p_start=96350,
                nominalColdInletTemperature_cond=323.55,
                nominalColdOutletTemperature_cond=348.85),
              LPH3(
                NusseltCondenser(ws_in(start=2, fixed=true)),
                zl_start=0.05,
                nominalHotPressure=70000,
                nominalColdInletTemperature_des=358.15,
                nominalColdOutletTemperature_des=363.15,
                nominalHotInletTemperature_des=499.15,
                nominalHotOutletTemperature_des=453.15,
                p_start=70000,
                nominalColdInletTemperature_cond=353.15,
                nominalColdOutletTemperature_cond=358.15,
                nominalColdInletTemperature_sub=348.15,
                nominalColdOutletTemperature_sub=353.15,
                nominalHotInletTemperature_sub=353.15,
                nominalHotOutletTemperature_sub=350.15),
              LPH1(
                initOpt=ThermoPower.Choices.Init.Options.fixedState,
                tubeWalls_cond(Tvolstart={333.15,331.15,328.15}),
                NusseltCondenser(
                  wd_out(start=4.62, fixed=false),
                  noInitialPressure=true,
                  ws_in(start=0.4, fixed=true)),
                zl_start=0.05,
                p_start=35000,
                nominalColdInletTemperature_cond=308.15,
                nominalColdOutletTemperature_cond=323.55,
                Kp=-5,
                Ti=5))
              annotation (Placement(transformation(extent={{170,-160},{328,-100}})));
            ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              p0=900000,
              use_in_p0=true)
              annotation (Placement(transformation(extent={{360,-90},{380,-70}})));
            ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
                Medium = Modelica.Media.Water.WaterIF97_ph,
              h=742500,
              use_in_h=true,
              p0=900000)
              annotation (Placement(transformation(extent={{380,-120},{360,-140}})));
            Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
                  30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
                  211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
                  transformation(extent={{400,-210},{380,-190}})));
            Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
                  30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
                  0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
               Placement(transformation(extent={{400,-60},{380,-40}})));
            SteamTurbine.Corps.LPT LPTurb(
              w_seal_1=0.0182,
              w_seal_2=0.0076,
              LPT1(hout(start=2818.4e3, fixed=false), pout(start=40000, fixed=true)))
              annotation (Placement(transformation(extent={{230,102},{314,178}})));
            ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                           redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=900000)
              annotation (Placement(transformation(extent={{360,154},{380,174}})));
            Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
                  0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
                  0.1028e5; 90,0.1137e5; 100,0.126e5])
              annotation (Placement(transformation(extent={{400,190},{380,210}})));
            HeatExchangers.Components.Deaerator_controlled
                                                deaerator(
              L=12,
              H=2.677,
              h_start=1.2e6,
              w_small=1e4,
              zl_start=2.1,
              p_start=224000)
              annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
            Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
              annotation (Placement(transformation(extent={{440,190},{420,210}})));
            Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
              annotation (Placement(transformation(extent={{440,-60},{420,-40}})));
            Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
              annotation (Placement(transformation(extent={{440,-210},{420,-190}})));
            Modelica.Blocks.Sources.Constant load(k=20) annotation (Placement(
                  transformation(extent={{-400,-50},{-380,-30}})));
          equation
            connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
                points={{23.8,140},{49.9,140}},
                color={0,0,0},
                smooth=Smooth.None));

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-220,-180},{-208.889,-180},{-208.889,-164}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-220,100},{-208.889,100},{-208.889,84}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
                points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
                points={{-131.111,84},{-131.111,162.8},{-59.8,162.8}},
                color={0,0,255},
                smooth=Smooth.None,
                thickness=0.5));
            connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
                points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
                points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
                color={0,0,255},
                thickness=0.5));

            connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
                points={{-162.222,84},{-164,84},{-164,168},{-164,200},{49.9,200},
                    {49.9,162.8}},
                color={0,0,255},
                thickness=0.5));

            connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
                points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
                color={0,127,0},
                thickness=0.5));

            connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
                points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
              annotation (Line(points={{-106,140},{-99,140}},          color={0,
                    0,0}));
            connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
              annotation (Line(points={{-77,140},{-70,140},{-59.8,140}},
                                                                       color={0,
                    0,0}));
            connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                    -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                              color={0,0,255},
                thickness=0.5));
            connect(gain.y, controllers.load) annotation (Line(points={{-351.4,
                    -40},{-351.4,-40},{-342.182,-40}},
                                          color={0,0,127}));
            connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
                points={{331.292,-130},{331.292,-130},{360,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
                  points={{379,-200},{366,-200},{366,-139}},
                                                         color={0,0,127}));
            connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
                  points={{379,-50},{366,-50},{366,-71.2}},
                                                         color={0,0,127}));
            connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
                points={{331.292,-112},{348,-112},{348,-80},{360,-80}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
                points={{140.1,162.8},{182,162.8},{225.8,162.8}},
                color={0,0,255},
                thickness=0.5));
            connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
                points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
                points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
                points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-97}},
                color={0,127,0},
                thickness=0.5));
            connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
                  points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
            connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
                points={{318.2,162.8},{360,162.8},{360,164}},
                color={0,0,255},
                thickness=0.5));
            connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
                points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
                color={0,127,0},
                thickness=0.5));
            connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
                points={{99.92,98.2},{99.92,-94},{111.857,-94}},
                color={0,127,0},
                thickness=0.5));
            connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
                points={{127.714,-82},{128,-82},{128,-82},{138,-82},{152,-82},{
                    152,-130},{166.708,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
                points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
                color={0,0,255},
                thickness=0.5));
            connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                    419,200}},           color={0,0,127}));
            connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-50},{
                    406,-50},{410,-50},{419,-50}},
                                         color={0,0,127}));
            connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-200},{
                    419,-200}},            color={0,0,127}));
            connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
                color={255,204,51},
                thickness=0.5));

            connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
                points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},
                    {-289.818,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
              annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                                 color={0,0,0}));
            connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
                points={{-289.818,-40},{-270,-40},{-270,-220},{137.143,-220},{
                    137.143,-120}},
                color={255,204,51},
                thickness=0.5));
            connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
                points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{
                    249,-220},{249,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(load.y, gain.u)
              annotation (Line(points={{-379,-40},{-365.2,-40}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                      -280},{440,280}}, preserveAspectRatio=false)),
              experiment(StopTime=5000),
              __Dymola_experimentSetupOutput(equidistant=false),
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),    __Dymola_experimentFlags(
                Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                      false),
                Evaluate=false,
                OutputCPUtime=false,
                OutputFlatModelica=false));
          end Plant_Full_20;
        end Old;
      end Test;

    end Plants;

    package Optimization "Package containing models for optimization purposes"

      model Plant_Full_20_100_des
        "Model of the full steam cycle, for hot start-up optimization, with desuperheating process"

        parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
        parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
          "Feedwater inlet temperature upper bound";
        parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
          "Feedwater inlet temperature upper bound";

        Real errDT_sh "Quadratic integral error on degree of superheating";
        Real errT_FWupperBound
          "Quadratic integral error on feedwater inlet temperature (upper bound)";
        Real errT_FWlowerBound
          "Quadratic integral error on feedwater inlet temperature (lower bound)";
        Real errT_MSupperBound
          "Quadratic integral error on molten salt temperature (upper bound)";
        Real errT_MSlowerBound
          "Quadratic integral error on molten salt temperature (lower bound)";
        Real M_MStot "Molten salt hot flow total mass";
        Real eta_I = P_net/Q_in "Power plant first principle net efficiency";
        Real Q_in = OTSG.Q_tot "Global thermal input";
        Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
          "Auxiliaries consumption, as function of load";
        Real P_gross = powerSensor.gain.y "Gross electrical power";
        Real P_net = P_gross - P_aux "Net pelectrical power";

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{-56,102},{20,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{54,102},{136,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-442,260},{-422,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-240,90},{
                  -220,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                  -240,-170}})));
        HeatExchangers.OTSG.OTSG_init20_5nodes OTSG      annotation (
            Placement(transformation(extent={{-240,-160},{-100,80}})));

        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
                                                                       HPHs
                     annotation (Placement(transformation(extent={{-60,-160},
                  {60,-100}})));

        Control.Schemes.PlantControlSchemes.plantController_hotStart_FF
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          load_switch=55,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          useTS_valveTURB_low=false,
          useTS_valveBP=false,
          Td_pumpCOND=0,
          Nd_pumpCOND=20,
          CSmax_pumpCOND=100,
          actuatorGain_pumpCOND=1,
          Ta_pumpCOND=2,
          useTS_pumpCOND=false,
          TS_pumpCOND=37.42,
          Kp_valveTURB_low=-1.518e-11,
          Ti_valveTURB_low=3.626,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_pumpCOND=14,
          CSmin_pumpCOND=5,
          CSmin_pumpSEP=-0.3,
          useTS_pumpSEP=false,
          CSmax_pumpSEP=1,
          Kp_pumpCOND=400,
          Ti_pumpCOND=200,
          n=10,
          Kp_pumpFW_low=15.73,
          time_vec={5000,5060,5120,5180,5240,5300,5360,5420,5480,5540},
          wMS_vec={124,185.9,247.9,309.9,371.9,433.9,495.8,557.8,619.8,619.8},
          wFW_vec={17.67,26.99,36.63,46.96,57.44,66.02,74.71,83.33,91.3,91.3},
          thetaBP_vec={0,0,0,0,0,0,0.1,0.2,0.4,0.6},
          CSstart_pumpFW_low=17,
          CSmin_pumpFW_low=5,
          control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,1;
                  80,1; 90,6.743; 100,24.51])),
          Ti_pumpFW_low=50,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-340,-60},{-292,
                  -20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
          annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-366,-46},{-354,-34}})));
        HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_20_dp
                                                                    LPHs
                    annotation (Placement(transformation(extent={{170,-112},
                  {328,-52}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=742500,
          use_in_h=true,
          p0=900000)
          annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
        Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
              30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
              211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
              transformation(extent={{400,-162},{380,-142}})));
        Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
              30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
              0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
           Placement(transformation(extent={{400,-20},{380,0}})));
        SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{230,102},{314,178}})));
        ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                       redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=900000)
          annotation (Placement(transformation(extent={{360,154},{380,174}})));
        Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
              0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
              0.1028e5; 90,0.1137e5; 100,0.126e5])
          annotation (Placement(transformation(extent={{400,190},{380,210}})));
        HeatExchangers.Components.Deaerator_controlled
                                            deaerator(
          L=12,
          H=2.677,
          h_start=1.2e6,
          initOpt=ThermoPower.Choices.Init.Options.fixedState,
          w_small=1e4,
          zl_start=2,
          p_start=220000)
          annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{440,190},{420,210}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{440,-20},{420,0}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{-240,210},{-220,230}})));
        HeatExchangers.Components.Desuperheaters_controlled
          desuperheaters_controlled(
          TS_valves=0.001,
          T_start1=773.15,
          T_end1=823.15,
          t_start1=5090,
          t_end1=7400,
          T_start2=823.15,
          T_end2=823.15,
          t_start2=50000,
          t_end2=60000) annotation (Placement(transformation(extent={{-188,
                  180},{-108,260}})));
        Modelica.Blocks.Sources.Ramp load_pre(
          duration=2000,
          startTime=100,
          height=0,
          offset=20)
          annotation (Placement(transformation(extent={{-440,-20},{-420,0}})));
        Modelica.Blocks.Sources.Ramp LOAD(
          height=80,
          duration=540,
          startTime=5000,
          offset=0) annotation (Placement(transformation(extent={{-440,-80},{-420,
                  -60}})));
        Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                extent={{-400,-50},{-380,-30}})));
      equation
        if time >= 5000 and time <= t_end then
          der(M_MStot) = OTSG.pumpMS.w;
          der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
          der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
          der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
          der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
        else
          der(M_MStot) = 0;
          der(errT_FWupperBound) = 0;
          der(errT_FWlowerBound) = 0;
          der(errT_MSupperBound) = 0;
          der(errT_MSlowerBound) = 0;
        end if;

        if gain.y >= controllers.load_switch then
          der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
        else
          der(errDT_sh) = 0;
        end if;

        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{23.8,140},{49.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-220,-180},{-208.889,-180},{-208.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-220,100},{-208.889,100},{-208.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-106,140},{-102,140},{-99,140}},
                                                                   color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{-77,140},{-77,140},{-59.8,140}},
                                                                   color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-353.4,-40},
                {-353.4,-40},{-342.182,-40}},
                                      color={0,0,127}));
        connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
            points={{331.292,-82},{331.292,-82},{360,-82}},
            color={0,0,255},
            thickness=0.5));
        connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
              points={{379,-152},{366,-152},{366,-91}},
                                                     color={0,0,127}));
        connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
              points={{379,-10},{366,-10},{366,-31.2}},
                                                     color={0,0,127}));
        connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
            points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{140.1,162.8},{182,162.8},{225.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
            points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
            points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
            points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
              points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
        connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
            points={{318.2,162.8},{360,162.8},{360,164}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
            points={{99.92,98.2},{99.92,-94},{111.857,-94}},
            color={0,127,0},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{127.714,-82},{127.714,-82},{166.708,-82}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
            points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                419,200}},           color={0,0,127}));
        connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                406,-10},{410,-10},{419,-10}},
                                     color={0,0,127}));
        connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                419,-152}},            color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},{
                -289.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
          annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                             color={0,0,0}));
        connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
            points={{-289.818,-40},{-270,-40},{-270,-220},{137.143,-220},{
                137.143,-120}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
            points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{249,
                -220},{249,-112}},
            color={255,204,51},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
            Line(
            points={{-132,178},{-132,178},{-132,84},{-131.111,84}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
            Line(
            points={{-162.222,84},{-162.222,130},{-162,130},{-162,178}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
          annotation (Line(
            points={{-106,204},{-106,204},{-59.8,204},{-59.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
          annotation (Line(
            points={{-106,236},{49.9,236},{49.9,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
              points={{-219,220},{-192,220}}, color={0,0,127}));
        connect(add.y, gain.u) annotation (Line(points={{-379,-40},{-367.2,-40},
                {-367.2,-40}}, color={0,0,127}));
        connect(load_pre.y, add.u1) annotation (Line(points={{-419,-10},{-410,
                -10},{-410,-34},{-402,-34}}, color={0,0,127}));
        connect(LOAD.y, add.u2) annotation (Line(points={{-419,-70},{-410,-70},
                {-410,-46},{-402,-46}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=3, __Dymola_NumberOfIntervals=7500),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_Full_20_100_des;

      model Plant_Full_20_100_des_FF
        "Model of the full steam cycle, for hot start-up optimization, with desuperheating process"

        parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
        parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
          "Feedwater inlet temperature upper bound";
        parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
          "Feedwater inlet temperature upper bound";

        Real errDT_sh "Quadratic integral error on degree of superheating";
        Real errT_FWupperBound
          "Quadratic integral error on feedwater inlet temperature (upper bound)";
        Real errT_FWlowerBound
          "Quadratic integral error on feedwater inlet temperature (lower bound)";
        Real errT_MSupperBound
          "Quadratic integral error on molten salt temperature (upper bound)";
        Real errT_MSlowerBound
          "Quadratic integral error on molten salt temperature (lower bound)";
        Real M_MStot "Molten salt hot flow total mass";
        Real eta_I = P_net/Q_in "Power plant first principle net efficiency";
        Real Q_in = OTSG.Q_tot "Global thermal input";
        Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
          "Auxiliaries consumption, as function of load";
        Real P_gross = powerSensor.gain.y "Gross electrical power";
        Real P_net = P_gross - P_aux "Net pelectrical power";

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{-56,102},{20,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{54,102},{136,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-442,260},{-422,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-240,90},{
                  -220,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-220,-190},{
                  -240,-170}})));
        HeatExchangers.OTSG.OTSG_init20_5nodes OTSG      annotation (
            Placement(transformation(extent={{-240,-160},{-100,80}})));

        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
                                                                       HPHs
                     annotation (Placement(transformation(extent={{-60,-160},
                  {60,-100}})));

        Control.Schemes.PlantControlSchemes.plantController_hotStart_FF
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          load_switch=55,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          useTS_valveTURB_low=false,
          useTS_valveBP=false,
          Td_pumpCOND=0,
          Nd_pumpCOND=20,
          CSmax_pumpCOND=100,
          actuatorGain_pumpCOND=1,
          Ta_pumpCOND=2,
          useTS_pumpCOND=false,
          TS_pumpCOND=37.42,
          Kp_valveTURB_low=-1.518e-11,
          Ti_valveTURB_low=3.626,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_pumpCOND=14,
          CSmin_pumpCOND=5,
          CSmin_pumpSEP=-0.3,
          useTS_pumpSEP=false,
          CSmax_pumpSEP=1,
          Kp_pumpCOND=400,
          Ti_pumpCOND=200,
          n=10,
          Kp_pumpFW_low=15.73,
          time_vec={5000,5060,5120,5180,5240,5300,5360,5420,5480,5540},
          wMS_vec={124,185.9,247.9,309.9,371.9,433.9,495.8,557.8,619.8,619.8},
          wFW_vec={17.67,26.99,36.63,46.96,57.44,66.02,74.71,83.33,91.3,91.3},
          thetaBP_vec={0,0,0,0,0,0,0.1,0.2,0.4,0.6},
          CSstart_pumpFW_low=17,
          CSmin_pumpFW_low=5,
          control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,1;
                  80,1; 90,6.743; 100,24.51])),
          Ti_pumpFW_low=50,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-340,-60},{-292,
                  -20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-126,130},{-106,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
          annotation (Placement(transformation(extent={{-98,130},{-78,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-366,-46},{-354,-34}})));
        HeatExchangers.FeedwaterTrain.LP_train.LPH_train_controlledLevel_20_dp
                                                                    LPHs
                    annotation (Placement(transformation(extent={{170,-112},
                  {328,-52}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{360,-50},{380,-30}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=742500,
          use_in_h=true,
          p0=900000)
          annotation (Placement(transformation(extent={{380,-72},{360,-92}})));
        Modelica.Blocks.Tables.CombiTable1D FW_sourceH(table=[20,148.1e3;
              30,159.7e3; 40,170e3; 50,183.4e3; 60,193e3; 70,203e3; 80,
              211.5e3; 90,229.3e3; 100,229.4e3]) annotation (Placement(
              transformation(extent={{400,-162},{380,-142}})));
        Modelica.Blocks.Tables.CombiTable1D cond_sinkP(table=[20,0.0497e5;
              30,0.0556e5; 40,0.0618e5; 50,0.0688e5; 60,0.0764e5; 70,
              0.0852e5; 80,0.0935e5; 90,0.103e5; 100,0.1139e5]) annotation (
           Placement(transformation(extent={{400,-20},{380,0}})));
        SteamTurbine.Corps.LPT LPTurb(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{230,102},{314,178}})));
        ThermoPower.Water.SinkPressure sinkPressure_TUR(
                                                       redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=900000)
          annotation (Placement(transformation(extent={{360,154},{380,174}})));
        Modelica.Blocks.Tables.CombiTable1D turb_sinkP(table=[20,0.051e5; 30,
              0.0579e5; 40,0.0655e5; 50,0.0739e5; 60,0.0829e5; 70,0.0932e5; 80,
              0.1028e5; 90,0.1137e5; 100,0.126e5])
          annotation (Placement(transformation(extent={{400,190},{380,210}})));
        HeatExchangers.Components.Deaerator_controlled
                                            deaerator(
          L=12,
          H=2.677,
          h_start=1.2e6,
          initOpt=ThermoPower.Choices.Init.Options.fixedState,
          w_small=1e4,
          zl_start=2,
          p_start=220000)
          annotation (Placement(transformation(extent={{90,-126},{150,-70}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{440,190},{420,210}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{440,-20},{420,0}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{440,-162},{420,-142}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{-240,210},{-220,230}})));
        HeatExchangers.Components.Desuperheaters_controlled
          desuperheaters_controlled(
          TS_valves=0.001,
          T_start1=773.15,
          T_end1=823.15,
          t_start1=5090,
          t_end1=7400,
          T_start2=823.15,
          T_end2=823.15,
          t_start2=50000,
          t_end2=60000) annotation (Placement(transformation(extent={{-188,
                  180},{-108,260}})));
        Modelica.Blocks.Sources.Ramp load_pre(
          duration=2000,
          startTime=100,
          height=0,
          offset=20)
          annotation (Placement(transformation(extent={{-440,-20},{-420,0}})));
        Modelica.Blocks.Sources.Ramp load1(
          height=80,
          duration=540,
          startTime=5000,
          offset=0) annotation (Placement(transformation(extent={{-440,-80},{
                  -420,-60}})));
        Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                extent={{-400,-50},{-380,-30}})));
      equation
        if time >= 5000 and time <= t_end then
          der(M_MStot) = OTSG.pumpMS.w;
          der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
          der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
          der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
          der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
        else
          der(M_MStot) = 0;
          der(errT_FWupperBound) = 0;
          der(errT_FWlowerBound) = 0;
          der(errT_MSupperBound) = 0;
          der(errT_MSlowerBound) = 0;
        end if;

        if gain.y >= controllers.load_switch then
          der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
        else
          der(errDT_sh) = 0;
        end if;

        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{23.8,140},{49.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-220,-180},{-208.889,-180},{-208.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-220,100},{-208.889,100},{-208.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-96.1111,48},{-59.8,48},{-59.8,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-96.1111,-132},{-96.1111,-130},{-63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-96.1111,-72},{-96.1111,-72},{-40,-72},{-40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{81.06,98.2},{81.06,48},{26.6667,48},{26.6667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{-18,98.2},{-18,98.2},{-18,-97},{-16.6667,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-106,140},{-102,140},{-99,140}},
                                                                   color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{-77,140},{-77,140},{-59.8,140}},
                                                                   color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -162.222,-164},{-162.222,-180},{13.3333,-180},{13.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-353.4,-40},
                {-353.4,-40},{-342.182,-40}},
                                      color={0,0,127}));
        connect(LPHs.FW_in, sourcePressure1.flange) annotation (Line(
            points={{331.292,-82},{331.292,-82},{360,-82}},
            color={0,0,255},
            thickness=0.5));
        connect(FW_sourceH.y[1],sourcePressure1. in_h) annotation (Line(
              points={{379,-152},{366,-152},{366,-91}},
                                                     color={0,0,127}));
        connect(cond_sinkP.y[1],sinkPressure_DR. in_p0) annotation (Line(
              points={{379,-10},{366,-10},{366,-31.2}},
                                                     color={0,0,127}));
        connect(LPHs.drained_out, sinkPressure_DR.flange) annotation (Line(
            points={{331.292,-64},{348,-64},{348,-40},{360,-40}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
            points={{140.1,162.8},{182,162.8},{225.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(IPTurb.SP3, LPHs.SP4) annotation (Line(
            points={{119.6,98.2},{119.6,48},{202.917,48},{202.917,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP2, LPHs.SP5) annotation (Line(
            points={{249.32,98.2},{249.32,47.1},{249,47.1},{249,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(LPTurb.SP1, LPHs.SP6) annotation (Line(
            points={{275.36,98.2},{275.36,48},{295.083,48},{295.083,-49}},
            color={0,127,0},
            thickness=0.5));
        connect(turb_sinkP.y[1], sinkPressure_TUR.in_p0) annotation (Line(
              points={{379,200},{366,200},{366,172.8}}, color={0,0,127}));
        connect(LPTurb.vap_out, sinkPressure_TUR.flange) annotation (Line(
            points={{318.2,162.8},{360,162.8},{360,164}},
            color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out, deaerator.drained_in) annotation (Line(
            points={{63.3333,-112},{63.3333,-112},{92.1429,-112}},
            color={0,127,0},
            thickness=0.5));
        connect(IPTurb.SP4, deaerator.steam_in) annotation (Line(
            points={{99.92,98.2},{99.92,-94},{111.857,-94}},
            color={0,127,0},
            thickness=0.5));
        connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
            points={{127.714,-82},{127.714,-82},{166.708,-82}},
            color={0,0,255},
            thickness=0.5));
        connect(deaerator.drained_out, HPHs.FW_in) annotation (Line(
            points={{120,-120},{120,-120},{120,-130},{63.3333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(turb_sinkP.u[1], LOAD1.y) annotation (Line(points={{402,200},{
                419,200}},           color={0,0,127}));
        connect(cond_sinkP.u[1], LOAD2.y) annotation (Line(points={{402,-10},{
                406,-10},{410,-10},{419,-10}},
                                     color={0,0,127}));
        connect(FW_sourceH.u[1], LOAD3.y) annotation (Line(points={{402,-152},{
                419,-152}},            color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-289.818,-40},{-289.818,-40},{-245.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-289.818,-40},{-270,-40},{-270,120},{-88,120},{-88,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{36.6667,-161.2},{36.6667,-220},{-270,-220},{-270,-40},{
                -289.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in)
          annotation (Line(points={{140.1,140},{182,140},{225.8,140}},
                                                             color={0,0,0}));
        connect(controllers.signalBus, deaerator.signalBus) annotation (Line(
            points={{-289.818,-40},{-270,-40},{-270,-220},{137.143,-220},{
                137.143,-120}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, LPHs.signalBus) annotation (Line(
            points={{-289.818,-40},{-289.818,-40},{-270,-40},{-270,-220},{249,
                -220},{249,-112}},
            color={255,204,51},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
            Line(
            points={{-132,178},{-132,178},{-132,84},{-131.111,84}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
            Line(
            points={{-162.222,84},{-162.222,130},{-162,130},{-162,178}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
          annotation (Line(
            points={{-106,204},{-106,204},{-59.8,204},{-59.8,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
          annotation (Line(
            points={{-106,236},{49.9,236},{49.9,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
              points={{-219,220},{-192,220}}, color={0,0,127}));
        connect(add.y, gain.u) annotation (Line(points={{-379,-40},{-367.2,-40},
                {-367.2,-40}}, color={0,0,127}));
        connect(load_pre.y, add.u1) annotation (Line(points={{-419,-10},{-410,
                -10},{-410,-34},{-402,-34}}, color={0,0,127}));
        connect(load1.y, add.u2) annotation (Line(points={{-419,-70},{-410,-70},
                {-410,-46},{-402,-46}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=3, __Dymola_NumberOfIntervals=7500),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_Full_20_100_des_FF;

      model Plant_HP_20_100_des
        "Model of the full steam cycle, for hot start-up optimization, with desuperheating process"

        parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
        parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
          "Feedwater inlet temperature upper bound";
        parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
          "Feedwater inlet temperature upper bound";

        //parameter Modelica.SIunits.Time t_start_high = load.startTime + load.duration/load.height*(controllers.load_switch - load.offset - 20);
        //parameter Modelica.SIunits.Time time_high[controllers.n] = linspace(t_start_high,load.startTime + load.duration,controllers.n);

        Real errDT_sh "Quadratic integral error on degree of superheating";
        Real errT_FWupperBound
          "Quadratic integral error on feedwater inlet temperature (upper bound)";
        Real errT_FWlowerBound
          "Quadratic integral error on feedwater inlet temperature (lower bound)";
        Real errT_MSupperBound
          "Quadratic integral error on molten salt temperature (upper bound)";
        Real errT_MSlowerBound
          "Quadratic integral error on molten salt temperature (lower bound)";
        Real M_MStot "Molten salt hot flow total mass";
        Real eta_I = P_net/Q_in "Power plant first principle net efficiency";
        Real Q_in = OTSG.Q_tot "Global thermal input";
        Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
          "Auxiliaries consumption, as function of load";
        Real P_gross = powerSensor.gain.y "Gross electrical power";
        Real P_net = P_gross - P_aux "Net pelectrical power";

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{64,102},{140,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{174,102},{256,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-340,260},{-320,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-120,90},{-100,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-100,-190},{-120,-170}})));
        HeatExchangers.OTSG.OTSG_init50_5nodes OTSG      annotation (
            Placement(transformation(extent={{-120,-160},{20,80}})));

        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_50_dp
                                                                       HPHs(HPH1(Ti=
                100))
                     annotation (Placement(transformation(extent={{60,-160},{180,-100}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-6,130},{14,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
          annotation (Placement(transformation(extent={{22,130},{42,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-246,-46},{-234,-34}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{360,200},{340,220}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{360,50},{340,70}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{360,-10},{340,10}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{-120,210},{-100,230}})));
        HeatExchangers.Components.Desuperheaters_controlled
          desuperheaters_controlled(
          TS_valves=0.001,
          T_start1=773.15,
          T_end1=823.15,
          t_start1=5090,
          t_end1=7400,
          T_start2=823.15,
          T_end2=823.15,
          t_start2=50000,
          t_end2=60000) annotation (Placement(transformation(extent={{-68,180},{12,260}})));
        Modelica.Blocks.Sources.Ramp load_pre(
          duration=2000,
          startTime=100,
          height=-30,
          offset=30)
          annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
        Auxiliaries.Components.Spline.SplineSignal
                                     LOAD(table=[5000,20; 5077,35; 5154,46;
              5231,57; 5308,68; 5385,79; 5462,90; 5540,100])
          annotation (Placement(transformation(extent={{-320,-80},{-300,-60}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-280,-50},{-260,-30}})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
              30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
              2.753e5; 90,3.09e5; 100,3.448e5])
          annotation (Placement(transformation(extent={{320,200},{300,220}})));
        Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
              1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
              2.633e5; 90,2.946e5; 100,3.276e5])
          annotation (Placement(transformation(extent={{320,50},{300,70}})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{320,-10},{300,10}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                      table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{260,-90},{240,-70}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
              30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
              764100; 90,783800; 100,803100])
                                   annotation (Placement(transformation(extent={{260,-130},
                  {240,-110}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{274,170},{294,190}})));
        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,30},{280,50}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,-30},{280,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{220,-150},{200,-130}})));
        Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
          annotation (Placement(transformation(extent={{300,-130},{280,-110}})));
        Modelica.Blocks.Sources.RealExpression LOAD6(y=gain.y)
          annotation (Placement(transformation(extent={{300,-90},{280,-70}})));
        Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder_hotStart
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSmin_valveTURB_high=-0.1e-5,
          CSmax_valveTURB_high=0.1e-5,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_valveBP=false,
          useTS_pumpSEP=false,
          useTS_pumpMS=false,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          DT_sh_sp=20,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.848,
          B=[0.015625; 0; 0; 0; 0],
          useTS_valveTURB_high=true,
          CSmin_pumpFW_high=-0.3,
          CSmax_pumpFW_high=0.3,
          C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
              -2.78018594921513e-08],
          Kp_pumpFW_low=15.73,
          Ti_pumpFW_low=714.2,
          dec_wMS_wFW=0,
          dec_wFW_wMS=0)  annotation (Placement(transformation(extent={{-220,-60},{-172,
                  -20}})));
      equation
        if time >= 5000 and time <= t_end then
          der(M_MStot) = OTSG.pumpMS.w;
          der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
          der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
          der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
          der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
        else
          der(M_MStot) = 0;
          der(errT_FWupperBound) = 0;
          der(errT_FWlowerBound) = 0;
          der(errT_MSupperBound) = 0;
          der(errT_MSlowerBound) = 0;
        end if;

        if gain.y >= controllers.load_switch then
          der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
        else
          der(errDT_sh) = 0;
        end if;

        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{143.8,140},{169.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-100,-180},{-88.8889,-180},{-88.8889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-100,100},{-88.8889,100},{-88.8889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{23.8889,48},{60.2,48},{60.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{23.8889,-132},{23.8889,-130},{56.6667,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{23.8889,-72},{23.8889,-72},{80,-72},{80,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{201.06,98.2},{201.06,48},{146.667,48},{146.667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{102,98.2},{102,98.2},{102,-97},{103.333,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{14,140},{18,140},{21,140}},    color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{43,140},{43,140},{60.2,140}},  color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -42.2222,-164},{-42.2222,-180},{133.333,-180},{133.333,-163}},
                          color={0,0,255},
            thickness=0.5));

        connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
            Line(
            points={{-12,178},{-12,178},{-12,84},{-11.1111,84}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
            Line(
            points={{-42.2222,84},{-42.2222,130},{-42,130},{-42,178}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
          annotation (Line(
            points={{14,204},{14,204},{60.2,204},{60.2,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
          annotation (Line(
            points={{14,236},{169.9,236},{169.9,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
              points={{-99,220},{-72,220}},   color={0,0,127}));
        connect(add.y, gain.u)
          annotation (Line(points={{-259,-40},{-247.2,-40}}, color={0,0,127}));
        connect(load_pre.y, add.u1) annotation (Line(points={{-299,-10},{-290,-10},{-290,
                -34},{-282,-34}}, color={0,0,127}));
        connect(LOAD.y, add.u2) annotation (Line(points={{-299,-70},{-290,-70},{-290,-46},
                {-282,-46}}, color={0,0,127}));
        connect(LOAD6.y, HPH1_sinkP.u[1])
          annotation (Line(points={{279,-80},{262,-80},{262,-80}}, color={0,0,127}));
        connect(LOAD5.y, HPH1_FW_source.u[1])
          annotation (Line(points={{279,-120},{262,-120}}, color={0,0,127}));
        connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{339,210},{330.5,210},
                {322,210}}, color={0,0,127}));
        connect(LOAD2.y, SP3_sink.u[1]) annotation (Line(points={{339,60},{331.5,60},{
                331.5,60},{322,60}}, color={0,0,127}));
        connect(LOAD3.y, SP4_sinkP.u[1])
          annotation (Line(points={{339,0},{330.5,0},{322,0}}, color={0,0,127}));
        connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(
            points={{260,40},{239.6,40},{239.6,98.2}},
            color={0,127,0},
            thickness=0.5));
        connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
            points={{260,-20},{219.92,-20},{219.92,98.2}},
            color={0,127,0},
            thickness=0.5));
        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(
            points={{274,180},{260.1,180},{260.1,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(sinkPressure_DR.flange, HPHs.DR_out) annotation (Line(
            points={{200,-100},{192,-100},{192,-112},{183.333,-112}},
            color={0,0,255},
            thickness=0.5));
        connect(sourcePressure1.flange, HPHs.FW_in) annotation (Line(
            points={{200,-140},{194,-140},{194,-130},{183.333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points={{239,
                -80},{206,-80},{206,-91.2}}, color={0,0,127}));
        connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(points={{239,
                -120},{206,-120},{206,-131}}, color={0,0,127}));
        connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{299,210},
                {290,210},{280,210},{280,188.8}}, color={0,0,127}));
        connect(SP3_sink.y[1], sinkPressure1.in_p0)
          annotation (Line(points={{299,60},{266,60},{266,48.8}}, color={0,0,127}));
        connect(SP4_sinkP.y[1], sinkPressure2.in_p0)
          annotation (Line(points={{299,0},{266,0},{266,-11.2}}, color={0,0,127}));
        connect(gain.y, controllers.load) annotation (Line(points={{-233.4,-40},
                {-222.182,-40}},      color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-169.818,-40},{-169.818,-40},{-125.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,120},{32,120},
                {32,130}},
            color={255,204,51},
            thickness=0.5));

        connect(controllers.signalBus, HPHs.signalBus) annotation (Line(
            points={{-169.818,-40},{-169.818,-40},{-150,-40},{-150,-220},{
                156.667,-220},{156.667,-161.2}},
            color={255,204,51},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-340,-280},{360,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-340,
                  -280},{360,280}}, preserveAspectRatio=false)),
          experiment(
            StopTime=10000,
            __Dymola_NumberOfIntervals=5000,
            Tolerance=1e-006),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_HP_20_100_des;

      model Plant_HP_20_100_des_FF
        "Model of the full steam cycle, for hot start-up optimization, with desuperheating process"

        parameter Modelica.SIunits.Time t_end = 5540 "Integral end time";
        parameter Modelica.SIunits.Temperature T_inFW_min = 518.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_inFW_max = 558.15
          "Feedwater inlet temperature upper bound";
        parameter Modelica.SIunits.Temperature T_outMS_min = 533.15
          "Feedwater inlet temperature lower bound";
        parameter Modelica.SIunits.Temperature T_outMS_max = 563.15
          "Feedwater inlet temperature upper bound";

        parameter Modelica.SIunits.Time t_start_high = load.startTime + load.duration/load.height*(controllers.load_switch - load.offset - 20);
        parameter Modelica.SIunits.Time time_high[controllers.n] = linspace(t_start_high,load.startTime + load.duration,controllers.n);

        Real errDT_sh "Quadratic integral error on degree of superheating";
        Real errT_FWupperBound
          "Quadratic integral error on feedwater inlet temperature (upper bound)";
        Real errT_FWlowerBound
          "Quadratic integral error on feedwater inlet temperature (lower bound)";
        Real errT_MSupperBound
          "Quadratic integral error on molten salt temperature (upper bound)";
        Real errT_MSlowerBound
          "Quadratic integral error on molten salt temperature (lower bound)";
        Real M_MStot "Molten salt hot flow total mass";
        Real eta_I = P_net/Q_in "Power plant first principle net efficiency";
        Real Q_in = OTSG.Q_tot "Global thermal input";
        Real P_aux = (1.35*(gain.y/100)^2 + 1.4563*(gain.y/100) + 3.0135)*1e6
          "Auxiliaries consumption, as function of load";
        Real P_gross = powerSensor.gain.y "Gross electrical power";
        Real P_net = P_gross - P_aux "Net pelectrical power";

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022)
          annotation (Placement(transformation(extent={{64,102},{140,178}})));
        SteamTurbine.Corps.IPT IPTurb
          annotation (Placement(transformation(extent={{174,102},{256,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-340,260},{-320,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322) annotation (Placement(transformation(extent={{-120,90},{-100,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=261078) annotation (Placement(transformation(extent={{-100,-190},{-120,-170}})));
        HeatExchangers.OTSG.OTSG_init20_5nodes OTSG      annotation (
            Placement(transformation(extent={{-120,-160},{20,80}})));

        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_20_dp
                                                                       HPHs
                     annotation (Placement(transformation(extent={{60,-160},{180,-100}})));

        Control.Schemes.PlantControlSchemes.plantController_HPpart_hotStart_FF
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          useTS_valveTURB_low=false,
          useTS_pumpCOND=false,
          Kp_valveTURB_low=-1.518e-11,
          Ti_valveTURB_low=3.626,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSmax_pumpSEP=1,
          n=10,
          Kp_pumpFW_low=15.73,
          time_vec={5000,5060,5120,5180,5240,5300,5360,5420,5480,5540},
          wMS_vec={124,185.9,247.9,309.9,371.9,433.9,495.8,557.8,619.8,619.8},
          CSstart_pumpFW_low=17,
          CSmin_pumpFW_low=5,
          control_wHPH(table_w_HPH(table=[20,1; 30,1; 40,1; 50,1; 60,1; 70,1; 80,1; 90,
                  6.743; 100,24.51])),
          useTS_pumpSEP=false,
          thetaBP_vec={0,0,0,0,0,0,0.05,0.1,0.2,0.6},
          load_switch=55,
          useTS_valveBP=true,
          time_high=time_high,
          Ti_pumpFW_low=250,
          CSmin_pumpSEP=-1,
          wFW_vec={52.94,46.14,50,59,66,69,72,76,81,91},
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-220,-60},{-172,
                  -20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-6,130},{14,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=0.985)
          annotation (Placement(transformation(extent={{22,130},{42,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-246,-46},{-234,-34}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{360,200},{340,220}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{360,50},{340,70}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{360,-10},{340,10}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{-120,210},{-100,230}})));
        HeatExchangers.Components.Desuperheaters_controlled
          desuperheaters_controlled(
          TS_valves=0.001,
          T_start1=773.15,
          T_end1=823.15,
          t_start1=5090,
          t_end1=7400,
          T_start2=823.15,
          T_end2=823.15,
          t_start2=50000,
          t_end2=60000) annotation (Placement(transformation(extent={{-68,180},{12,260}})));
        Modelica.Blocks.Sources.Ramp load_pre(
          duration=2000,
          startTime=100,
          offset=30,
          height=-10)
          annotation (Placement(transformation(extent={{-320,-20},{-300,0}})));
        Modelica.Blocks.Sources.Ramp load(
          height=80,
          duration=540,
          startTime=5000,
          offset=0)
          annotation (Placement(transformation(extent={{-320,-80},{-300,-60}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-280,-50},{-260,-30}})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
              30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
              2.753e5; 90,3.09e5; 100,3.448e5])
          annotation (Placement(transformation(extent={{320,200},{300,220}})));
        Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
              1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
              2.633e5; 90,2.946e5; 100,3.276e5])
          annotation (Placement(transformation(extent={{320,50},{300,70}})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{320,-10},{300,10}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                      table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{260,-90},{240,-70}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
              30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
              764100; 90,783800; 100,803100])
                                   annotation (Placement(transformation(extent={{260,-130},
                  {240,-110}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{274,170},{294,190}})));
        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,30},{280,50}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,-30},{280,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{200,-110},{220,-90}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{220,-150},{200,-130}})));
        Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
          annotation (Placement(transformation(extent={{300,-130},{280,-110}})));
        Modelica.Blocks.Sources.RealExpression LOAD6(y=gain.y)
          annotation (Placement(transformation(extent={{300,-90},{280,-70}})));
        Modelica.Blocks.Tables.CombiTable1D table_P_MEC_low(smoothness=
              Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
              14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
              82.3774e6]) annotation (Placement(transformation(extent={{-220,40},
                  {-200,60}})));
      equation
        if time >= 5000 and time <= t_end then
          der(M_MStot) = OTSG.pumpMS.w;
          der(errT_FWupperBound) = (max(0,OTSG.T_inFW - T_inFW_max))^2;
          der(errT_FWlowerBound) = (min(0,OTSG.T_inFW - T_inFW_min))^2;
          der(errT_MSupperBound) = (max(0,OTSG.T_outMS - T_outMS_max))^2;
          der(errT_MSlowerBound) = (min(0,OTSG.T_outMS - T_outMS_min))^2;
        else
          der(M_MStot) = 0;
          der(errT_FWupperBound) = 0;
          der(errT_FWlowerBound) = 0;
          der(errT_MSupperBound) = 0;
          der(errT_MSlowerBound) = 0;
        end if;

        if gain.y >= controllers.load_switch then
          der(errDT_sh) = (OTSG.sensDT_sh.DT_sh - 20)^2;
        else
          der(errDT_sh) = 0;
        end if;

        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{143.8,140},{169.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-100,-180},{-88.8889,-180},{-88.8889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-100,100},{-88.8889,100},{-88.8889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{23.8889,48},{60.2,48},{60.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{23.8889,-132},{23.8889,-130},{56.6667,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{23.8889,-72},{23.8889,-72},{80,-72},{80,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{201.06,98.2},{201.06,48},{146.667,48},{146.667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{102,98.2},{102,98.2},{102,-97},{103.333,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{14,140},{18,140},{21,140}},    color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{43,140},{43,140},{60.2,140}},  color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -42.2222,-164},{-42.2222,-180},{133.333,-180},{133.333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-233.4,-40},
                {-233.4,-40},{-222.182,-40}},
                                      color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-169.818,-40},{-169.818,-40},{-125.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-169.818,-40},{-150,-40},{-150,120},{32,120},{32,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{156.667,-161.2},{156.667,-220},{-150,-220},{-150,-40},{
                -169.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(desuperheaters_controlled.SH_in, OTSG.SH_out) annotation (
            Line(
            points={{-12,178},{-12,178},{-12,84},{-11.1111,84}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.RH_out, desuperheaters_controlled.RH_in) annotation (
            Line(
            points={{-42.2222,84},{-42.2222,130},{-42,130},{-42,178}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.SH_out, HPTurb.vap_in)
          annotation (Line(
            points={{14,204},{14,204},{60.2,204},{60.2,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(desuperheaters_controlled.RH_out, IPTurb.vap_in)
          annotation (Line(
            points={{14,236},{169.9,236},{169.9,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(LOAD4.y, desuperheaters_controlled.load) annotation (Line(
              points={{-99,220},{-72,220}},   color={0,0,127}));
        connect(add.y, gain.u)
          annotation (Line(points={{-259,-40},{-247.2,-40}}, color={0,0,127}));
        connect(load_pre.y, add.u1) annotation (Line(points={{-299,-10},{-290,-10},{-290,
                -34},{-282,-34}}, color={0,0,127}));
        connect(load.y, add.u2) annotation (Line(points={{-299,-70},{-290,-70},{-290,-46},
                {-282,-46}}, color={0,0,127}));
        connect(LOAD6.y, HPH1_sinkP.u[1])
          annotation (Line(points={{279,-80},{262,-80},{262,-80}}, color={0,0,127}));
        connect(LOAD5.y, HPH1_FW_source.u[1])
          annotation (Line(points={{279,-120},{262,-120}}, color={0,0,127}));
        connect(LOAD1.y, IPTurb_sink.u[1]) annotation (Line(points={{339,210},{330.5,210},
                {322,210}}, color={0,0,127}));
        connect(LOAD2.y, SP3_sink.u[1]) annotation (Line(points={{339,60},{331.5,60},{
                331.5,60},{322,60}}, color={0,0,127}));
        connect(LOAD3.y, SP4_sinkP.u[1])
          annotation (Line(points={{339,0},{330.5,0},{322,0}}, color={0,0,127}));
        connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(
            points={{260,40},{239.6,40},{239.6,98.2}},
            color={0,127,0},
            thickness=0.5));
        connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(
            points={{260,-20},{219.92,-20},{219.92,98.2}},
            color={0,127,0},
            thickness=0.5));
        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(
            points={{274,180},{260.1,180},{260.1,162.8}},
            color={0,0,255},
            thickness=0.5));
        connect(sinkPressure_DR.flange, HPHs.DR_out) annotation (Line(
            points={{200,-100},{192,-100},{192,-112},{183.333,-112}},
            color={0,0,255},
            thickness=0.5));
        connect(sourcePressure1.flange, HPHs.FW_in) annotation (Line(
            points={{200,-140},{194,-140},{194,-130},{183.333,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(HPH1_sinkP.y[1], sinkPressure_DR.in_p0) annotation (Line(points={{239,
                -80},{206,-80},{206,-91.2}}, color={0,0,127}));
        connect(HPH1_FW_source.y[1], sourcePressure1.in_h) annotation (Line(points={{239,
                -120},{206,-120},{206,-131}}, color={0,0,127}));
        connect(IPTurb_sink.y[1], sinkPressure.in_p0) annotation (Line(points={{299,210},
                {290,210},{280,210},{280,188.8}}, color={0,0,127}));
        connect(SP3_sink.y[1], sinkPressure1.in_p0)
          annotation (Line(points={{299,60},{266,60},{266,48.8}}, color={0,0,127}));
        connect(SP4_sinkP.y[1], sinkPressure2.in_p0)
          annotation (Line(points={{299,0},{266,0},{266,-11.2}}, color={0,0,127}));
        connect(gain.y, table_P_MEC_low.u[1]) annotation (Line(points={{-233.4,
                -40},{-230,-40},{-230,50},{-222,50}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-340,-280},{360,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-340,
                  -280},{360,280}}, preserveAspectRatio=false)),
          experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"),__Dymola_experimentFlags(
            Advanced(GenerateVariableDependencies=false, OutputModelicaCode=
                  false),
            Evaluate=false,
            OutputCPUtime=false,
            OutputFlatModelica=false));
      end Plant_HP_20_100_des_FF;

    end Optimization;

    package MachineLearning
      "Package containing models used for machine learning algorithm test"
      model Plant_HP_init100
        "Model of the high-pressure steam cycle with tunable parameters for machine learning test"

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
              transformation(extent={{24,102},{100,178}})));
        SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                extent={{134,102},{216,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-440,260},{-420,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322,
          p0=1050000)
                    annotation (Placement(transformation(extent={{-160,90},
                  {-140,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=100000) annotation (Placement(transformation(extent={{-140,
                  -190},{-160,-170}})));
        OTSG_init100_5nodes_ML                  OTSG(separator(w_small=1e4))
                               annotation (Placement(transformation(extent={{-160,
                  -160},{-20,80}})));
        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
          HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                  -100}})));

        Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Ti_pumpFW_low=714.2,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          Kp_pumpFW_low=15.73,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_pumpSEP=false,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          DT_sh_sp=20,
          control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
          dec_wMS_wFW=1e-3,
          dec_wFW_wMS=80,
          useTS_valveBP=false,
          CSmin_pumpFW_high=-0.2,
          CSmax_pumpFW_high=0.2,
          CSmin_valveTURB_high=-1e-5,
          CSmax_valveTURB_high=1e-5,
          useTS_pumpMS=false,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.484,
          B=[0.015625; 0; 0; 0; 0],
          C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
              -2.78018594921513e-08],
          useTS_valveTURB_high=false,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                  -60},{-212,-20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
          annotation (Placement(transformation(extent={{-18,130},{2,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-288,-46},{-276,-34}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{340,220},{320,240}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{340,70},{320,90}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{340,10},{320,30}})));
        Modelica.Blocks.Sources.Ramp ramp_smooth(
          duration=2500,
          offset=100,
          startTime=1000,
          height=0)
          annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,190},{280,210}})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
              30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
              2.753e5; 90,3.09e5; 100,3.448e5])
          annotation (Placement(transformation(extent={{306,220},{286,240}})));
        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{246,50},{266,70}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{246,-10},{266,10}})));
        Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
              1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
              2.633e5; 90,2.946e5; 100,3.276e5])
          annotation (Placement(transformation(extent={{306,70},{286,90}})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{306,10},{286,30}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
              30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
              764100; 90,783800; 100,803100])
                                   annotation (Placement(transformation(extent={{246,
                  -110},{226,-90}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                      table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{246,-70},{226,-50}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
        Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
          annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{103.8,140},{129.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-140,-180},{-128.889,-180},{-128.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-140,100},{-128.889,100},{-128.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-16.1111,48},{20.2,48},{20.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},{
                129.9,162.8}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-26,140},{-19,140}},           color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{3,140},{20.2,140}},            color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-275.4,-40},
                {-262.182,-40}},      color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},{
                -209.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                {220.1,200},{220.1,162.8}}, color={0,0,255}));
        connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                {266,230},{266,208.8}},          color={0,0,127}));
        connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                {252,80},{252,68.8}},     color={0,0,127}));
        connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                {252,20},{252,8.8}},           color={0,0,127}));
        connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
            thickness=0.5));
        connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
              points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
        connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
              points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
        connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
        connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                {179.92,0},{179.92,98.2}},  color={0,0,255}));
        connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                {314,230},{319,230}},          color={0,0,127}));
        connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                314,80},{319,80}},      color={0,0,127}));
        connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                {314,20},{319,20}},     color={0,0,127}));
        connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                {259,-60}},          color={0,0,127}));
        connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                -100},{254,-100},{259,-100}},            color={0,0,127}));
        connect(ramp_smooth.y, gain.u)
          annotation (Line(points={{-299,-40},{-289.2,-40}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-440,-280},{440,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-440,
                  -280},{440,280}}, preserveAspectRatio=false)),
          experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
      end Plant_HP_init100;

      model test_OTSG_100_ML "Test model of the OTSG at 100% load"
          extends Modelica.Icons.Example;
        ThermoPower.Water.SourceMassFlow sourceFW(
          allowFlowReversal=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=1062.9e3,
          w0=115.85,
          use_in_w0=true)
          annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
        ThermoPower.Water.SourceMassFlow sourceRH(
          allowFlowReversal=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_w0=false,
          w0=84.94,
          h=3103000)
          annotation (Placement(transformation(extent={{80,30},{60,50}})));
        ThermoPower.Water.SinkPressure sinkRH(
          allowFlowReversal=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=false,
          p0=4732000)
          annotation (Placement(transformation(extent={{20,90},{40,110}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=519092,
          p0=100000)  annotation (Placement(transformation(extent={{-60,90},{
                  -40,110}})));

        ThermoPower.Water.SinkPressure sinkMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=100000)  annotation (Placement(transformation(extent={{-30,-70},
                  {-50,-50}})));

        ThermoPower.Water.SinkPressure sinkHPH(
          allowFlowReversal=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          p0=17400000)
          annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
        ThermoPower.Water.SinkPressure sinkSH(
          allowFlowReversal=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=false,
          p0=17000000)
          annotation (Placement(transformation(extent={{40,70},{60,90}})));
        ThermoPower.Water.ThroughMassFlow pump_HPH(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_w0=true,
          w0=24.51)
          annotation (Placement(transformation(extent={{0,-50},{20,-70}})));
        Control.Schemes.PlantControlSchemes.plant_controller_HPpart_highLoad_steadyStateInit
          controllers(
          Ta_pumpFW=5,
          actuatorGain_pumpHPH=1,
          Ta_pumpHPH=5,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          CSstart_pumpFW=0,
          TS_pumpFW=0,
          CSmin_pumpHPH=-0.5,
          CSmax_pumpHPH=0.5,
          CSstart_pumpHPH=0,
          TS_pumpHPH=0,
          CSstart_pumpMS=0,
          TS_pumpMS=0,
          CSstart_valveTURB=0,
          TS_valveTURB=0,
          t_ramp=0,
          load_start=100,
          load_end=100,
          Kp_pumpHPH=0.6461,
          Ti_pumpHPH=19.05,
          useTS_pumpHPH=true,
          useTS_pumpMS=true,
          t_start_ramp=0,
          CSmin_valveBP=0.1,
          CSmax_valveBP=1,
          CSstart_valveBP=0.6,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          useTS_valveBP=true,
          TS_valveBP=0,
          Kp_valveTURB=-1.077e-11,
          Ti_valveTURB=2.164,
          useTS_valveTURB=false,
          useTS_pumpFW=false,
          Ti_pumpFW=100,
          Kp_pumpFW=-0.02,
          DT_SH_sp=20,
          Kp_pumpMS=4.57e-4,
          Ti_pumpMS=98.66,
          CSmin_pumpMS=-0 - 5,
          CSmax_pumpMS=0.5,
          Ta_pumpMS=2,
          CSmin_valveTURB=-0.5,
          CSmax_valveTURB=0.5,
          Ta_valveTURB=0.3,
          Kp_valveBP=-7.93e-6,
          Ti_valveBP=0.001,
          CSmin_pumpFW=-1,
          CSmax_pumpFW=1,
          T_FW_sp=518.15,
          T_MS_sp=558.15) annotation (Placement(transformation(extent={{-92,
                  -2},{-68,22}})));
        Modelica.Icons.SignalBus signalBus
          annotation (Placement(transformation(extent={{-70,-30},{-50,-10}}),
              iconTransformation(extent={{-120,-120},{-100,-100}})));
        Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
          annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
        OTSG_init100_5nodes_ML OTSG
          annotation (Placement(transformation(extent={{-40,-40},{20,60}})));
        inner ThermoPower.System system(allowFlowReversal=false, initOpt=
              ThermoPower.Choices.Init.Options.fixedState) annotation (
            Placement(transformation(extent={{-120,100},{-100,120}})));
      equation
        connect(pump_HPH.outlet, sinkHPH.flange) annotation (Line(
            points={{20,-60},{40,-60}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
            points={{-60,-20},{-60,-80},{6,-80},{6,-66}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, signalBus) annotation (Line(
            points={{-67.4,10},{-60,10},{-60,-20}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-67.4,10},{-42.3333,10}},
            color={255,204,51},
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                               color={0,0,255}));
        connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},{
                -6.66667,100},{-6.66667,61.6667}},
                                     color={0,0,255}));
        connect(sinkSH.flange, OTSG.SH_out) annotation (Line(points={{40,80},{
                6.66667,80},{6.66667,61.6667}},
                                      color={0,0,255}));
        connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                               color={0,0,255}));
        connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                 color={0,0,255}));
        connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{-26.6667,
                -41.6667},{-26.6667,-60},{-30,-60}},
                                      color={0,0,255}));
        connect(OTSG.MS_HPH_out, pump_HPH.inlet) annotation (Line(points={{
                -6.66667,-41.6667},{-6.66667,-60},{0,-60}},
                                             color={0,0,255}));
        connect(OTSG.RH_in, sourceRH.flange) annotation (Line(points={{21.6667,
                46.6667},{40,46.6667},{40,40},{60,40}},         color={0,0,
                255}));
        connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
              points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
        connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
            points={{-60,-20},{-60,-80},{74,-80},{74,-26}},
            color={255,204,51},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                  -120},{120,120}})),                  Icon(coordinateSystem(
                extent={{-120,-120},{120,120}})),
          experiment(StopTime=10000),
          __Dymola_experimentSetupOutput,
          Documentation(revisions="<html>
</html>",
      info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
      end test_OTSG_100_ML;

      model OTSG_init100_5nodes_ML
        "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, separator valve for drainage during transition and HE hot and cold bypass"
        extends HeatExchangers.BaseClasses.BaseOTSG;

        //Heat exchangers parameter
        parameter Integer Nhex_mono = 5
          "Number of nodes for single phase heat exchangers";
        parameter Integer Nhex_bi = 10
          "Number of nodes for biphase heat exchangers";
        parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
        //inner ThermoPower.System system "System wide properties";

        HeatExchangers.Components.HE HPH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.536143, gamma_nom=3958.9),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447465, gamma_nom=2197.5),
          Nhex=Nhex_mono*2,
          Vhot=3.789,
          Vcold=0.781,
          Shot=314.9,
          Scold=248,
          Mm=3802,
          nominalColdFlow=24.51,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                1.29502e+006,1.30052e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
              558.906,561.752,563.806,565.297,566.385,567.182}),
          nominalColdPressure=17350000,
          nominalHotPressure=250000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=564.15,
          nominalHotInletTemperature=569.15,
          nominalHotOutletTemperature=563.15,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                103396,100624},
            noInitialPressure=true))          annotation (Placement(
              transformation(extent={{-76,-264},{-44,-296}})));

        HeatExchangers.Components.HE ECO(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          Vhot=44.506,
          Vcold=5.73,
          Shot=2385,
          Scold=1848.4,
          Mm=30279,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                1.64439e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
              620.01}),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.728761, gamma_nom=4499),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.461561, gamma_nom=2204.3),
          nominalColdPressure=17350000,
          nominalHotPressure=450000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=621.59,
          nominalHotInletTemperature=626.65,
          nominalHotOutletTemperature=569.15,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={196390,188158,176706,156967,110743},
            noInitialPressure=true))          annotation (Placement(
              transformation(extent={{-44,-196},{-76,-164}})));

        HeatExchangers.Components.HE_2ph EVA1(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          Vhot=31.955,
          Vcold=9.805,
          Shot=2834.1,
          Scold=2108.5,
          Mm=62846,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,1.94183e+006,
                2.2136e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
              626.498,627.06,627.186,627.848,629.177,631.842}),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              alpha=1.6,
              gamma_nom_liq=3875*0.75,
              gamma_nom_2ph=10000*0.75,
              gamma_nom_vap=3875*0.75),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447498, gamma_nom=2147.7),
          nominalColdPressure=17300000,
          nominalHotPressure=600000,
          nominalColdInletTemperature=621.55,
          nominalColdOutletTemperature=626.9,
          nominalHotInletTemperature=689.01,
          nominalHotOutletTemperature=626.65,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                194368,192799},
            noInitialPressure=true))
          annotation (Placement(transformation(extent={{-76,-116},{-44,-84}})));
        HeatExchangers.Components.HE_2ph EVA2(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.389637, gamma_nom=2650),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              gamma_nom_liq=2000,
              gamma_nom_2ph=5000,
              gamma_nom_vap=2000,
              alpha=1.1),
          Vhot=4.495,
          Vcold=1.028,
          Shot=489,
          Scold=354.5,
          Mm=7374,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,2.72547e+006,
                2.78281e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
              653.806,658.116,678.213,683.393,689.164,695.453}),
          nominalColdPressure=17250000,
          nominalHotPressure=700000,
          nominalColdInletTemperature=626.69,
          nominalColdOutletTemperature=646.74,
          nominalHotInletTemperature=734.05,
          nominalHotOutletTemperature=689.01,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                284059,275898},
            noInitialPressure=true))
          annotation (Placement(transformation(extent={{-44,-36},{-76,-4}})));

        HeatExchangers.Components.nonEquilibriumVessel separator(
          redeclare package Medium = coldMedium,
          H=8,
          D=0.56,
          gamma=0,
          zl_start=0.25,
          noInitialLevel=false,
          hv_start=2.7e6,
          hl_start=1.7e6,
          p_start=17200000,
          noInitialPressure=false)
          annotation (Placement(transformation(extent={{-28,28},{28,84}})));
        ThermoPower.Water.ThroughMassFlow pumpSEP(
          redeclare package Medium = coldMedium,
          allowFlowReversal=false,
          w0=0,
          use_in_w0=true) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={0,-50})));

        HeatExchangers.Components.HE SH(
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.847436, gamma_nom=1996.5),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.28867, gamma_nom=2848.1),
          Vhot=12.281,
          Vcold=2.339,
          Shot=1193.5,
          Scold=835.5,
          Mm=19349,
          nominalColdFlow=91.28,
          nominalHotFlow=381.3,
          tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
              824.786}),
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                3.42217e+006},
            noInitialPressure=false),
          nominalColdPressure=17150000,
          nominalHotPressure=850000,
          nominalColdInletTemperature=646.55,
          nominalColdOutletTemperature=823.96,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=733.58,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={519092,501167,469703,420819,359564},
            noInitialPressure=true))  annotation (Placement(transformation(
              extent={{-16,-16},{16,16}},
              rotation=0,
              origin={0,140})));
        HeatExchangers.Components.HE RH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.798347, gamma_nom=963.6),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.320782, gamma_nom=2690.3),
          Vhot=9.255,
          Vcold=4.618,
          Shot=1371.1,
          Scold=1154.6,
          Mm=15054,
          nominalColdFlow=84.94,
          nominalHotFlow=238.6,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                3.55697e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
              829.056}),
          nominalColdPressure=4781000,
          nominalHotPressure=1050000,
          nominalColdInletTemperature=633.15,
          nominalColdOutletTemperature=826.06,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=734.05,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={519092,502650,475154,429572,356689},
            noInitialPressure=true))          annotation (Placement(
              transformation(
              extent={{-16,16},{16,-16}},
              rotation=-90,
              origin={140,170})));
        ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
          annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={96,262})));

        ThermoPower.Water.PressDrop PDSteamEVA1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=160.88)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-60})));
        ThermoPower.Water.PressDrop PDSteamECO2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=590.03)          annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-140})));
        ThermoPower.Water.PressDrop PDSteamEVA2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=92.917)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,12})));

        //Overall parameter and variables:
        Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
        Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
        Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
        Modelica.SIunits.Temperature T_RH = sensT_RH.T;
        Modelica.SIunits.Length sep_lev = separator.zl;
        Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
        Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
        Real x_EVA1_out = EVA1.coldFluid.x[end];
        Real x_EVA2_out = EVA2.coldFluid.x[end];
        Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
        Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
        Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
        Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

        ThermoPower.Water.PressDrop PDSteamRH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=84.86,
          dpnom=(0.5)*10^5,
          rhonom=12.775,
          redeclare package Medium = coldMedium)
                                         annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={100,190})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={50,-50}),iconTransformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={-194,0})));
        ThermoPower.Water.SensT sensT_FW(
          redeclare package Medium = coldMedium)
          annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
        ThermoPower.Water.SensT sensT_MS(
          redeclare package Medium = hotMedium)
          annotation (Placement(transformation(extent={{-2,-286},{18,-266}})));
        ThermoPower.Water.ThroughMassFlow pumpMS(
          use_in_w0=true,
          redeclare package Medium = hotMedium,
          w0=619.8) annotation (Placement(transformation(
              extent={{10,10},{-10,-10}},
              rotation=90,
              origin={-100,256})));
        ThermoPower.Water.SensP sensP(
          redeclare package Medium = coldMedium) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={4,240})));
        ThermoPower.Water.PressDrop PDSteamECO1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=820.48)                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-214})));
        ThermoPower.Water.PressDrop PDSteamHPH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=24.51,
          dpnom=(0.5)*10^5,
          rhonom=747.38)       annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=90,
              origin={-60,-246})));
        ThermoPower.Water.ValveVap valveVap(
          thetanom=0.8,
          Fxt_full=0.4542722663,
          Av=0.053642779,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          pnom=17100000,
          dpnom=100000)
          annotation (Placement(transformation(extent={{-10,10},{10,-10}},
              rotation=90,
              origin={0,280})));
        Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-40,238})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = coldMedium,
          Av=3.702e-5,
          pnom=17200000,
          dpnom=17000000,
          wnom=4.45)
          annotation (Placement(transformation(extent={{60,10},{80,30}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              coldMedium, p0=101325)
          annotation (Placement(transformation(extent={{100,10},{120,30}})));
        Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-64,36})));
        ThermoPower.Water.ThroughMassFlow SH_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=270,
              origin={-40,160})));
        Modelica.Blocks.Sources.Step SH_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-72,154},{-64,162}})));
        ThermoPower.Water.PressDrop PDSteamSH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          rhonom=92,
          dpnom=(1)*10^5) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,104})));
        ThermoPower.Water.ThroughMassFlow valveRH(
          redeclare package Medium = hotMedium,
          use_in_w0=true,
          w0=238.6)
          annotation (Placement(transformation(extent={{-46,200},{-26,220}})));
        Modelica.Blocks.Math.Gain SH_wnom(k=SH.nominalColdFlow)
          annotation (Placement(transformation(extent={{-56,154},{-48,162}})));
        ThermoPower.Water.ThroughMassFlow RH_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,-6},{-6,6}},
              rotation=0,
              origin={140,220})));
        Modelica.Blocks.Sources.Step RH_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{178,226},{170,234}})));
        Modelica.Blocks.Math.Gain RH_wnom_cold(k=RH.nominalColdFlow)
          annotation (Placement(transformation(extent={{162,226},{154,234}})));
        ThermoPower.Water.ThroughMassFlow EVA2_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=270,
              origin={-120,-20})));
        Modelica.Blocks.Sources.Step EVA2_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-152,-26},{-144,-18}})));
        Modelica.Blocks.Math.Gain EVA2_wnom_cold(k=EVA2.nominalColdFlow)
          annotation (Placement(transformation(extent={{-136,-26},{-128,-18}})));
        ThermoPower.Water.ThroughMassFlow EVA1_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=270,
              origin={-140,-100})));
        Modelica.Blocks.Sources.Step EVA1_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-172,-106},{-164,-98}})));
        Modelica.Blocks.Math.Gain EVA1_wnom_cold(k=EVA1.nominalColdFlow)
          annotation (Placement(transformation(extent={{-156,-106},{-148,-98}})));
        ThermoPower.Water.ThroughMassFlow ECO_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=270,
              origin={-120,-180})));
        Modelica.Blocks.Sources.Step ECO_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-152,-186},{-144,-178}})));
        Modelica.Blocks.Math.Gain ECO_wnom_cold(k=ECO.nominalColdFlow)
          annotation (Placement(transformation(extent={{-136,-186},{-128,-178}})));
        ThermoPower.Water.ThroughMassFlow HPH_bp_cold(redeclare package Medium
            = coldMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-120,-280})));
        Modelica.Blocks.Sources.Step HPH_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-152,-282},{-144,-274}})));
        Modelica.Blocks.Math.Gain HPH_wnom_cold(k=HPH.nominalColdFlow)
          annotation (Placement(transformation(extent={{-136,-282},{-128,-274}})));
        ThermoPower.Water.ThroughMassFlow EVA2_bp_hot(redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-20,-46})));
        Modelica.Blocks.Sources.Step EVA2_bp_hot_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-52,-48},{-44,-40}})));
        Modelica.Blocks.Math.Gain EVA2_wnom_hot(k=EVA2.nominalHotFlow)
          annotation (Placement(transformation(extent={{-36,-48},{-28,-40}})));
        ThermoPower.Water.ThroughMassFlow EVA1_bp_hot(redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-88,-110})));
        Modelica.Blocks.Sources.Step EVA1_bp_hot_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-120,-112},{-112,-104}})));
        Modelica.Blocks.Math.Gain EVA1_wnom_hot(k=EVA1.nominalHotFlow)
          annotation (Placement(transformation(extent={{-104,-112},{-96,-104}})));
        ThermoPower.Water.ThroughMassFlow ECO_bp_hot(redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-14,-208})));
        Modelica.Blocks.Sources.Step ECO_bp_hot_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-46,-210},{-38,-202}})));
        Modelica.Blocks.Math.Gain ECO_wnom_hot(k=ECO.nominalHotFlow)
          annotation (Placement(transformation(extent={{-30,-210},{-22,-202}})));
        ThermoPower.Water.ThroughMassFlow HPH_bp_hot(redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{6,6},{-6,-6}},
              rotation=180,
              origin={-58,-336})));
        Modelica.Blocks.Sources.Step HPH_bp_hot_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-92,-332},{-84,-324}})));
        Modelica.Blocks.Math.Gain HPH_wnom_hot(k=HPH.nominalHotFlow)
          annotation (Placement(transformation(extent={{-76,-332},{-68,-324}})));
        ThermoPower.Water.ThroughMassFlow SH_bp_hot( redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-56,126})));
        Modelica.Blocks.Sources.Step SH_bp_hot_w( startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-88,124},{-80,132}})));
        Modelica.Blocks.Math.Gain SH_wnom_hot(k=SH.nominalHotFlow)
          annotation (Placement(transformation(extent={{-72,124},{-64,132}})));
        ThermoPower.Water.ThroughMassFlow RH_bp_hot( redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,-6},{6,6}},
              rotation=270,
              origin={58,178})));
        Modelica.Blocks.Sources.Step RH_bp_hot_w( startTime=5000, height=0)
          annotation (Placement(transformation(extent={{92,176},{84,184}})));
        Modelica.Blocks.Math.Gain RH_wnom_hot(k=RH.nominalHotFlow)
          annotation (Placement(transformation(extent={{76,176},{68,184}})));
        ThermoPower.Water.ThroughMassFlow SHRH_bp_hot(redeclare package Medium
            = hotMedium, use_in_w0=true) annotation (Placement(transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-120,170})));
        Modelica.Blocks.Sources.Step SHRH_bp_hot_pos(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-152,168},{-144,176}})));
        Modelica.Blocks.Math.Gain pumpMS_wnom(k=pumpMS.w0) annotation (
            Placement(transformation(extent={{-138,168},{-130,176}})));
        ThermoPower.Water.ThroughMassFlow ECOHPH_bp_cold1(redeclare package
            Medium = coldMedium, use_in_w0=true) annotation (Placement(
              transformation(
              extent={{-6,6},{6,-6}},
              rotation=270,
              origin={-10,-250})));
        Modelica.Blocks.Sources.Step ECOHPH_bp_cold_w(startTime=5000, height=0)
          annotation (Placement(transformation(extent={{-42,-252},{-34,-244}})));
        Modelica.Blocks.Math.Gain ECO_wnom_cold1(k=ECO.nominalColdFlow)
          annotation (Placement(transformation(extent={{-26,-252},{-18,-244}})));
      equation
        connect(RH.inletCold, RH_in) annotation (Line(
            points={{156,170},{174,170},{174,180},{190,180}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(HPH.outletCold, MS_HPH_out) annotation (Line(
            points={{-60,-296},{-60,-310}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(RH_out, sensT_RH.outlet) annotation (Line(
            points={{100,310},{100,268}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
            points={{-60,-164},{-60,-150}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
            points={{0,38},{0,-40},{1.77636e-015,-40}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
            points={{-60,-50},{-60,-36}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
            points={{-60,-84},{-60,-70}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(pumpSEP.outlet, SEP_out) annotation (Line(
            points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
            points={{100,256},{100,200}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
            points={{124,170},{100,170},{100,180}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));

        connect(sensT_FW.inlet, FW_in) annotation (Line(
            points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                -210},{190,-210}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_MS.outlet, MS_out) annotation (Line(
            points={{14,-280},{20,-280},{20,-310}},
            color={255,0,0},
            thickness=0.5));
        connect(MS_in, pumpMS.inlet) annotation (Line(
            points={{-100,310},{-100,266}},
            color={255,0,0},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
            points={{50,-50},{50,-50},{50,260},{-94,260}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
            points={{50,-50},{50,-50},{50,192},{50,232},{10,232}},
            color={255,204,51},
            thickness=0.5));
        connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
            points={{-60,-116},{-60,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
            points={{-60,-196},{-60,-200},{-60,-204}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
            points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
            color={0,0,255},
            thickness=0.5));
        connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
            points={{-60,-256},{-60,-264}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
            points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
            points={{50,-50},{50,-50},{50,280},{8,280}},
            color={255,204,51},
            thickness=0.5));
        connect(SH_out, valveVap.outlet) annotation (Line(
            points={{0,310},{0,290}},
            color={0,0,255},
            thickness=0.5));
        connect(valveVap.inlet, sensP.flange) annotation (Line(
            points={{-4.44089e-016,270},{-4.44089e-016,240},{0,240}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
            points={{50,-50},{50,-50},{50,-220},{82,-220}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
            points={{50,-50},{50,-50},{50,260},{-40,260},{-40,250}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
            points={{50,-50},{50,-50},{50,44},{50,42},{10,42}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
            points={{50,-50},{50,-50},{50,8},{50,-218},{68,-218},{68,-220},{82,-220}},
            color={255,204,51},
            thickness=0.5));
        connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(points={{-60,-4},
                {-60,-4},{-60,2}},          color={0,0,255},
            thickness=0.5));
        connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
            points={{50,-50},{50,-50},{50,-48},{50,-46},{6,-46}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
            points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
            color={255,204,51},
            thickness=0.5));
        connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
            points={{-60,42},{-60,48},{-10,48}},
            color={0,0,255},
            thickness=0.5));
        connect(sensDT_sh.inlet, PDSteamEVA2.outlet)
          annotation (Line(points={{-60,30},{-60,22}}, color={0,0,255},
            thickness=0.5));
        connect(separator.drained_out, valveLiq.inlet)
          annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255},
            thickness=0.5));
        connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(points=
               {{80,20},{90,20},{100,20}}, color={0,0,255}));
        connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
            points={{50,-50},{50,-50},{50,84},{-70,84},{-70,44}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
            points={{50,-50},{50,-50},{50,-258},{50,-270},{16,-270}},
            color={255,204,51},
            thickness=0.5));
        connect(RH_in, RH_in)
          annotation (Line(points={{190,180},{190,180}}, color={0,0,255}));
        connect(PDSteamSH.outlet, SH.inletCold)
          annotation (Line(points={{0,114},{0,124}}, color={0,0,255},
            thickness=0.5));
        connect(PDSteamSH.inlet, separator.steam_out)
          annotation (Line(points={{0,94},{0,87},{0,80}}, color={0,0,255},
            thickness=0.5));
        connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,227},{-40,221.5},
                {-40,216}}, color={0,0,127}));
        connect(pumpMS.outlet, valveRH.inlet) annotation (Line(points={{-100,246},{-100,
                246},{-100,208},{-100,210},{-46,210}}, color={255,0,0},
            thickness=0.5));
        connect(SH_bp_cold_w.y, SH_wnom.u)
          annotation (Line(points={{-63.6,158},{-60,158},{-56.8,158}},
                                                             color={0,0,127}));
        connect(SH.outletCold, sensP.flange)
          annotation (Line(points={{0,156},{0,156},{0,240}}, color={0,0,255},
            thickness=0.5));
        connect(RH.outletHot, EVA2.inletHot) annotation (Line(points={{140,154},{140,154},
                {140,-18},{140,-20},{-44,-20}}, color={255,0,0},
            thickness=0.5));
        connect(SH.outletHot, EVA2.inletHot) annotation (Line(points={{16,140},{16,140},
                {140,140},{140,80},{140,-20},{-44,-20}},          color={255,0,0},
            thickness=0.5));
        connect(pumpMS.outlet, SH.inletHot) annotation (Line(
            points={{-100,246},{-100,246},{-100,158},{-100,140},{-16,140}},
            color={255,0,0},
            thickness=0.5));
        connect(RH_wnom_hot.u, RH_bp_hot_w.y) annotation (Line(points={{76.8,180},{80,
                180},{83.6,180}}, color={0,0,127}));
        connect(RH_bp_hot.in_w0, RH_wnom_hot.y) annotation (Line(points={{61.6,180.4},
                {64.8,180.4},{64.8,180},{67.6,180}}, color={0,0,127}));
        connect(valveRH.outlet, RH.inletHot) annotation (Line(
            points={{-26,210},{-26,210},{140,210},{140,186}},
            color={255,0,0},
            thickness=0.5));
        connect(EVA2_bp_hot_w.y, EVA2_wnom_hot.u)
          annotation (Line(points={{-43.6,-44},{-36.8,-44}}, color={0,0,127}));
        connect(EVA2_wnom_hot.y, EVA2_bp_hot.in_w0) annotation (Line(points={{-27.6,-44},
                {-23.6,-44},{-23.6,-43.6}}, color={0,0,127}));
        connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
            points={{-76,-20},{-88,-20},{-100,-20},{-100,-100},{-76,-100}},
            color={255,0,0},
            thickness=0.5));
        connect(EVA1_bp_hot_w.y, EVA1_wnom_hot.u)
          annotation (Line(points={{-111.6,-108},{-104.8,-108}}, color={0,0,127}));
        connect(EVA1_wnom_hot.y, EVA1_bp_hot.in_w0) annotation (Line(points={{-95.6,-108},
                {-95.6,-107.6},{-91.6,-107.6}}, color={0,0,127}));
        connect(ECO.outletHot, HPH.inletHot) annotation (Line(
            points={{-76,-180},{-100,-180},{-100,-280},{-76,-280}},
            color={255,0,0},
            thickness=0.5));
        connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
            points={{-44,-280},{-21,-280},{2,-280}},
            color={255,0,0},
            thickness=0.5));
        connect(RH_bp_cold_w.y, RH_wnom_cold.u) annotation (Line(points={{169.6,230},{
                162.8,230},{162.8,230}}, color={0,0,127}));
        connect(RH_wnom_cold.y, RH_bp_cold.in_w0) annotation (Line(points={{153.6,230},
                {142.4,230},{142.4,223.6}}, color={0,0,127}));
        connect(SH_bp_hot_w.y, SH_wnom_hot.u)
          annotation (Line(points={{-79.6,128},{-72.8,128}}, color={0,0,127}));
        connect(SH_wnom_hot.y, SH_bp_hot.in_w0) annotation (Line(points={{-63.6,128},{
                -59.6,128},{-59.6,128.4}}, color={0,0,127}));
        connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
            points={{-44,-100},{-14,-100},{-14,-180},{-44,-180}},
            color={255,0,0},
            thickness=0.5));
        connect(ECO_wnom_hot.y, ECO_bp_hot.in_w0) annotation (Line(points={{-21.6,-206},
                {-17.6,-206},{-17.6,-205.6}}, color={0,0,127}));
        connect(HPH_wnom_hot.y, HPH_bp_hot.in_w0) annotation (Line(points={{-67.6,-328},
                {-60.4,-328},{-60.4,-332.4}}, color={0,0,127}));
        connect(HPH_bp_hot_w.y, HPH_wnom_hot.u)
          annotation (Line(points={{-83.6,-328},{-76.8,-328}}, color={0,0,127}));
        connect(SH.inletHot, SH_bp_hot.inlet)
          annotation (Line(points={{-16,140},{-56,140},{-56,132}}, color={0,0,255}));
        connect(SH_bp_hot.outlet, SH.outletHot) annotation (Line(points={{-56,120},{-56,
                90},{30,90},{30,140},{16,140}}, color={0,0,255}));
        connect(SH.inletCold, SH_bp_cold.inlet) annotation (Line(points={{0,124},{0,120},
                {-40,120},{-40,154}}, color={0,0,255}));
        connect(SH_bp_cold.outlet, SH.outletCold) annotation (Line(points={{-40,166},{
                -40,180},{0,180},{0,156}}, color={0,0,255}));
        connect(RH.inletCold, RH_bp_cold.inlet) annotation (Line(points={{156,170},{160,
                170},{160,220},{146,220}}, color={0,0,255}));
        connect(RH_bp_cold.outlet, RH.outletCold) annotation (Line(points={{134,220},{
                120,220},{120,170},{124,170}}, color={0,0,255}));
        connect(RH.inletHot, RH_bp_hot.inlet) annotation (Line(points={{140,186},{140,
                186},{140,208},{140,210},{58,210},{58,184}}, color={0,0,255}));
        connect(RH_bp_hot.outlet, RH.outletHot) annotation (Line(points={{58,172},{58,
                172},{58,152},{58,140},{140,140},{140,154}}, color={0,0,255}));
        connect(EVA2.inletCold, EVA2_bp_cold.inlet) annotation (Line(points={{-60,-36},
                {-60,-40},{-120,-40},{-120,-26}}, color={0,0,255}));
        connect(EVA2_bp_cold.outlet, EVA2.outletCold) annotation (Line(points={{-120,-14},
                {-120,-2},{-60,-2},{-60,-4}}, color={0,0,255}));
        connect(EVA2.inletHot, EVA2_bp_hot.inlet)
          annotation (Line(points={{-44,-20},{-20,-20},{-20,-40}}, color={0,0,255}));
        connect(EVA2_bp_hot.outlet, EVA2.outletHot) annotation (Line(points={{-20,-52},
                {-20,-76},{-100,-76},{-100,-20},{-76,-20}}, color={0,0,255}));
        connect(EVA1.inletCold, EVA1_bp_cold.inlet) annotation (Line(points={{-60,-116},
                {-60,-116},{-60,-120},{-140,-120},{-140,-106}}, color={0,0,255}));
        connect(EVA1_bp_cold.outlet, EVA1.outletCold) annotation (Line(points={{-140,-94},
                {-140,-80},{-60,-80},{-60,-84}}, color={0,0,255}));
        connect(ECO_wnom_cold.y, ECO_bp_cold.in_w0) annotation (Line(points={{-127.6,-182},
                {-123.6,-182},{-123.6,-182.4}}, color={0,0,127}));
        connect(ECO_bp_cold_w.y, ECO_wnom_cold.u) annotation (Line(points={{-143.6,-182},
                {-136.8,-182},{-136.8,-182}}, color={0,0,127}));
        connect(ECO.inletCold, ECO_bp_cold.inlet) annotation (Line(points={{-60,-196},
                {-60,-200},{-120,-200},{-120,-186}}, color={0,0,255}));
        connect(ECO_bp_cold.outlet, ECO.outletCold) annotation (Line(points={{-120,-174},
                {-120,-160},{-60,-160},{-60,-164}}, color={0,0,255}));
        connect(HPH_wnom_cold.y, HPH_bp_cold.in_w0) annotation (Line(points={{-127.6,-278},
                {-123.6,-278},{-123.6,-277.6}}, color={0,0,127}));
        connect(HPH_bp_cold_w.y, HPH_wnom_cold.u)
          annotation (Line(points={{-143.6,-278},{-136.8,-278}}, color={0,0,127}));
        connect(HPH.inletCold, HPH_bp_cold.inlet) annotation (Line(points={{-60,-264},
                {-60,-260},{-120,-260},{-120,-274}}, color={0,0,255}));
        connect(HPH_bp_cold.outlet, HPH.outletCold) annotation (Line(points={{-120,-286},
                {-120,-298},{-60,-298},{-60,-296}}, color={0,0,255}));
        connect(EVA1.inletHot, EVA1_bp_hot.inlet) annotation (Line(points={{-76,-100},
                {-88,-100},{-88,-104}}, color={0,0,255}));
        connect(EVA1.outletHot, EVA1_bp_hot.outlet) annotation (Line(points={{-44,-100},
                {-14,-100},{-14,-126},{-88,-126},{-88,-116}}, color={0,0,255}));
        connect(ECO_bp_hot_w.y, ECO_wnom_hot.u)
          annotation (Line(points={{-37.6,-206},{-30.8,-206}}, color={0,0,127}));
        connect(ECO.inletHot, ECO_bp_hot.inlet) annotation (Line(points={{-44,-180},{-14,
                -180},{-14,-202}}, color={0,0,255}));
        connect(ECO_bp_hot.outlet, ECO.outletHot) annotation (Line(points={{-14,-214},
                {-14,-228},{-88,-228},{-88,-180},{-76,-180}}, color={0,0,255}));
        connect(HPH.inletHot, HPH_bp_hot.inlet) annotation (Line(points={{-76,-280},{-100,
                -280},{-100,-336},{-64,-336}}, color={0,0,255}));
        connect(HPH_bp_hot.outlet, HPH.outletHot) annotation (Line(points={{-52,-336},
                {-40,-336},{-26,-336},{-26,-280},{-44,-280}}, color={0,0,255}));
        connect(SH_wnom.y, SH_bp_cold.in_w0) annotation (Line(points={{-47.6,158},{-43.6,
                158},{-43.6,157.6}}, color={0,0,127}));
        connect(EVA2_bp_cold_w.y, EVA2_wnom_cold.u) annotation (Line(points={{
                -143.6,-22},{-136.8,-22},{-136.8,-22}}, color={0,0,127}));
        connect(EVA2_wnom_cold.y, EVA2_bp_cold.in_w0) annotation (Line(points={
                {-127.6,-22},{-123.6,-22},{-123.6,-22.4}}, color={0,0,127}));
        connect(EVA1_bp_cold_w.y, EVA1_wnom_cold.u) annotation (Line(points={{
                -163.6,-102},{-156.8,-102},{-156.8,-102}}, color={0,0,127}));
        connect(EVA1_wnom_cold.y, EVA1_bp_cold.in_w0) annotation (Line(points={
                {-147.6,-102},{-143.6,-102},{-143.6,-102.4}}, color={0,0,127}));
        connect(pumpMS.outlet, SHRH_bp_hot.inlet) annotation (Line(points={{
                -100,246},{-100,210},{-120,210},{-120,176}}, color={0,0,255}));
        connect(SHRH_bp_hot.outlet, EVA2.inletHot) annotation (Line(points={{
                -120,164},{-120,164},{-120,100},{-30,100},{-30,-20},{-44,-20}},
              color={0,0,255}));
        connect(pumpMS_wnom.y, SHRH_bp_hot.in_w0) annotation (Line(points={{
                -129.6,172},{-123.6,172},{-123.6,172.4}}, color={0,0,127}));
        connect(SHRH_bp_hot_pos.y, pumpMS_wnom.u) annotation (Line(points={{
                -143.6,172},{-138.8,172}}, color={0,0,127}));
        connect(ECO_wnom_cold1.y, ECOHPH_bp_cold1.in_w0) annotation (Line(
              points={{-17.6,-248},{-13.6,-248},{-13.6,-247.6}}, color={0,0,127}));
        connect(ECOHPH_bp_cold_w.y, ECO_wnom_cold1.u) annotation (Line(points={
                {-33.6,-248},{-26.8,-248}}, color={0,0,127}));
        connect(sensT_FW.outlet, ECOHPH_bp_cold1.inlet) annotation (Line(points=
               {{84,-230},{38,-230},{-10,-230},{-10,-244}}, color={0,0,255}));
        connect(ECOHPH_bp_cold1.outlet, MS_HPH_out) annotation (Line(points={{
                -10,-256},{-10,-298},{-60,-298},{-60,-310}}, color={0,0,255}));
        annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(
                extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
          Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
      end OTSG_init100_5nodes_ML;

      model OTSG_init100_5nodes_ML2
        "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes, separator valve for drainage during transition and HE hot and cold bypass"
        extends HeatExchangers.BaseClasses.BaseOTSG;

        //Heat exchangers parameter
        parameter Integer Nhex_mono = 5
          "Number of nodes for single phase heat exchangers";
        parameter Integer Nhex_bi = 10
          "Number of nodes for biphase heat exchangers";
        parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
        //inner ThermoPower.System system "System wide properties";

        HeatExchangers.Components.HE HPH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.536143, gamma_nom=3958.9),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447465, gamma_nom=2197.5),
          Nhex=Nhex_mono*2,
          Vhot=3.789,
          Vcold=0.781,
          Shot=314.9,
          Scold=248,
          Mm=3802,
          nominalColdFlow=24.51,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                1.29502e+006,1.30052e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
              558.906,561.752,563.806,565.297,566.385,567.182}),
          nominalColdPressure=17350000,
          nominalHotPressure=250000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=564.15,
          nominalHotInletTemperature=569.15,
          nominalHotOutletTemperature=563.15,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                103396,100624},
            noInitialPressure=true))          annotation (Placement(
              transformation(extent={{-76,-264},{-44,-296}})));

        HeatExchangers.Components.HE ECO(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          Vhot=44.506,
          Vcold=5.73,
          Shot=2385,
          Scold=1848.4,
          Mm=30279,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                1.64439e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
              620.01}),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.728761, gamma_nom=4499),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.461561, gamma_nom=2204.3),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={196390,188158,176706,156967,110743},
            noInitialPressure=false),
          nominalColdPressure=17350000,
          nominalHotPressure=450000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=621.59,
          nominalHotInletTemperature=626.65,
          nominalHotOutletTemperature=569.15) annotation (Placement(
              transformation(extent={{-44,-196},{-76,-164}})));

        HeatExchangers.Components.HE_2ph EVA1(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          Vhot=31.955,
          Vcold=9.805,
          Shot=2834.1,
          Scold=2108.5,
          Mm=62846,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,1.94183e+006,
                2.2136e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
              626.498,627.06,627.186,627.848,629.177,631.842}),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              alpha=1.6,
              gamma_nom_liq=3875*0.75,
              gamma_nom_2ph=10000*0.75,
              gamma_nom_vap=3875*0.75),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447498, gamma_nom=2147.7),
          nominalColdPressure=17300000,
          nominalHotPressure=600000,
          nominalColdInletTemperature=621.55,
          nominalColdOutletTemperature=626.9,
          nominalHotInletTemperature=689.01,
          nominalHotOutletTemperature=626.65,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                194368,192799},
            noInitialPressure=false))
          annotation (Placement(transformation(extent={{-76,-116},{-44,-84}})));
        HeatExchangers.Components.HE_2ph EVA2(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.389637, gamma_nom=2650),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              gamma_nom_liq=2000,
              gamma_nom_2ph=5000,
              gamma_nom_vap=2000,
              alpha=1.1),
          Vhot=4.495,
          Vcold=1.028,
          Shot=489,
          Scold=354.5,
          Mm=7374,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,2.72547e+006,
                2.78281e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
              653.806,658.116,678.213,683.393,689.164,695.453}),
          nominalColdPressure=17250000,
          nominalHotPressure=700000,
          nominalColdInletTemperature=626.69,
          nominalColdOutletTemperature=646.74,
          nominalHotInletTemperature=734.05,
          nominalHotOutletTemperature=689.01,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                284059,275898},
            noInitialPressure=false))
          annotation (Placement(transformation(extent={{-44,-36},{-76,-4}})));

        HeatExchangers.Components.nonEquilibriumVessel separator(
          redeclare package Medium = coldMedium,
          H=8,
          D=0.56,
          gamma=0,
          zl_start=0.25,
          hv_start=2.7e6,
          hl_start=1.7e6,
          noInitialPressure=false,
          p_start=17200000,
          noInitialLevel=true)
          annotation (Placement(transformation(extent={{-28,28},{28,84}})));
        ThermoPower.Water.ThroughMassFlow pumpSEP(
          redeclare package Medium = coldMedium,
          allowFlowReversal=false,
          w0=0,
          use_in_w0=true) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={0,-50})));

        HeatExchangers.Components.HE SH(
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.847436, gamma_nom=1996.5),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.28867, gamma_nom=2848.1),
          Vhot=12.281,
          Vcold=2.339,
          Shot=1193.5,
          Scold=835.5,
          Mm=19349,
          nominalColdFlow=91.28,
          nominalHotFlow=381.3,
          tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
              824.786}),
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                3.42217e+006},
            noInitialPressure=false),
          nominalColdPressure=17150000,
          nominalHotPressure=850000,
          nominalColdInletTemperature=646.55,
          nominalColdOutletTemperature=823.96,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=733.58,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={519092,501167,469703,420819,359564},
            noInitialPressure=false)) annotation (Placement(transformation(
              extent={{-16,-16},{16,16}},
              rotation=0,
              origin={0,140})));
        HeatExchangers.Components.HE RH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.798347, gamma_nom=963.6),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.320782, gamma_nom=2690.3),
          Vhot=9.255,
          Vcold=4.618,
          Shot=1371.1,
          Scold=1154.6,
          Mm=15054,
          nominalColdFlow=84.94,
          nominalHotFlow=238.6,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                3.55697e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
              829.056}),
          nominalColdPressure=4781000,
          nominalHotPressure=1050000,
          nominalColdInletTemperature=633.15,
          nominalColdOutletTemperature=826.06,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=734.05,
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            hstart={519092,502650,475154,429572,356689},
            noInitialPressure=false))         annotation (Placement(
              transformation(
              extent={{-16,16},{16,-16}},
              rotation=-90,
              origin={140,160})));
        ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
          annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={96,262})));

        ThermoPower.Water.PressDrop PDSteamEVA1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=160.88)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-60})));
        ThermoPower.Water.PressDrop PDSteamECO2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=590.03)          annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-140})));
        ThermoPower.Water.PressDrop PDSteamEVA2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=92.917)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,12})));

        //Overall parameter and variables:
        Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
        Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
        Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
        Modelica.SIunits.Temperature T_RH = sensT_RH.T;
        Modelica.SIunits.Length sep_lev = separator.zl;
        Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
        Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
        Real x_EVA1_out = EVA1.coldFluid.x[end];
        Real x_EVA2_out = EVA2.coldFluid.x[end];
        Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
        Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
        Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
        Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

        ThermoPower.Water.PressDrop PDSteamRH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=84.86,
          dpnom=(0.5)*10^5,
          rhonom=12.775,
          redeclare package Medium = coldMedium)
                                         annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={100,180})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={50,-50}),iconTransformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={-194,0})));
        ThermoPower.Water.SensT sensT_FW(
          redeclare package Medium = coldMedium)
          annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
        ThermoPower.Water.SensT sensT_MS(
          redeclare package Medium = hotMedium)
          annotation (Placement(transformation(extent={{-2,-286},{18,-266}})));
        ThermoPower.Water.ThroughMassFlow pumpMS(
          use_in_w0=true,
          redeclare package Medium = hotMedium,
          w0=619.8) annotation (Placement(transformation(
              extent={{10,10},{-10,-10}},
              rotation=90,
              origin={-100,256})));
        ThermoPower.Water.SensP sensP(
          redeclare package Medium = coldMedium) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={4,240})));
        ThermoPower.Water.PressDrop PDSteamSH2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          rhonom=50.66,
          dpnom=(0.5)*10^5)
                       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,174})));
        ThermoPower.Water.PressDrop PDSteamECO1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=820.48)                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-214})));
        ThermoPower.Water.PressDrop PDSteamHPH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=24.51,
          dpnom=(0.5)*10^5,
          rhonom=747.38)       annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=90,
              origin={-60,-246})));
        ThermoPower.Water.ValveVap valveVap(
          thetanom=0.8,
          Fxt_full=0.4542722663,
          Av=0.053642779,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          pnom=17100000,
          dpnom=100000)
          annotation (Placement(transformation(extent={{-10,10},{10,-10}},
              rotation=90,
              origin={0,280})));
        Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-40,238})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = coldMedium,
          Av=3.702e-5,
          pnom=17200000,
          dpnom=17000000,
          wnom=4.45)
          annotation (Placement(transformation(extent={{60,10},{80,30}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              coldMedium, p0=101325)
          annotation (Placement(transformation(extent={{100,10},{120,30}})));
        Auxiliaries.Components.SensDT_sh sensDT_sh annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-64,36})));
        ThermoPower.Water.PressDrop PDSteamSH1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          dpnom=(0.5)*10^5,
          rhonom=92)   annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,104})));
        ThermoPower.Water.PressDrop PDMSSH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          wnom=381.2,
          dpnom=2*10^5,
          rhonom=1730)  annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,140})));
        ThermoPower.Water.PressDrop PDMSRH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          rhonom=1796.9,
          dpnom=2*10^5,
          wnom=238.6) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={140,110})));
        ThermoPower.Water.PressDrop PDMSEVA2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          wnom=619.8,
          rhonom=1840,
          dpnom=1*10^5) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-100,-70})));
        ThermoPower.Water.PressDrop PDMSEVA1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          wnom=619.8,
          rhonom=1865,
          dpnom=1.5*10^5) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-20,-140})));
        ThermoPower.Water.PressDrop PDMSECO(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          wnom=619.8,
          dpnom=2*10^5,
          rhonom=1901) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-100,-220})));
        ThermoPower.Water.PressDrop PDMSSEP(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          rhonom=1796.9,
          wnom=619.8,
          dpnom=1.5*10^5)
                        annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=0,
              origin={98,-20})));
        ThermoPower.Water.PressDrop PDMSECO1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = hotMedium,
          wnom=619.8,
          dpnom=1.5*10^5,
          rhonom=1905) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-20,-280})));
      equation
        connect(RH.inletCold, RH_in) annotation (Line(
            points={{156,160},{174,160},{174,180},{190,180}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(HPH.outletCold, MS_HPH_out) annotation (Line(
            points={{-60,-296},{-60,-310}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(RH_out, sensT_RH.outlet) annotation (Line(
            points={{100,310},{100,268}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
            points={{-60,-164},{-60,-150}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(separator.drained_out, pumpSEP.inlet) annotation (Line(
            points={{0,38},{0,-40},{1.77636e-015,-40}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
            points={{-60,-50},{-60,-36}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
            points={{-60,-84},{-60,-70}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(pumpSEP.outlet, SEP_out) annotation (Line(
            points={{-1.77636e-015,-60},{-1.77636e-015,-80},{190,-80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
            points={{100,256},{100,190}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
            points={{124,160},{100,160},{100,170}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));

        connect(sensT_FW.inlet, FW_in) annotation (Line(
            points={{96,-230},{96,-230},{130,-230},{130,-230},{160,-230},{160,
                -210},{190,-210}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_MS.outlet, MS_out) annotation (Line(
            points={{14,-280},{20,-280},{20,-310}},
            color={255,0,0},
            thickness=0.5));
        connect(MS_in, pumpMS.inlet) annotation (Line(
            points={{-100,310},{-100,266}},
            color={255,0,0},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
            points={{50,-50},{50,-50},{50,260},{-94,260}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.valveTURB_PV, sensP.p) annotation (Line(
            points={{50,-50},{50,-50},{50,192},{50,232},{10,232}},
            color={255,204,51},
            thickness=0.5));
        connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
            points={{-60,-116},{-60,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
            points={{-60,-196},{-60,-204}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
            points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
            color={0,0,255},
            thickness=0.5));
        connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
            points={{-60,-256},{-60,-264}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
            points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
            points={{50,-50},{50,-50},{50,280},{8,280}},
            color={255,204,51},
            thickness=0.5));
        connect(SH_out, valveVap.outlet) annotation (Line(
            points={{0,310},{0,290}},
            color={0,0,255},
            thickness=0.5));
        connect(valveVap.inlet, sensP.flange) annotation (Line(
            points={{-4.44089e-016,270},{-4.44089e-016,240},{0,240}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
            points={{50,-50},{50,-50},{50,-220},{82,-220}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
            points={{50,-50},{50,-50},{50,260},{-40,260},{-40,250}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
            points={{50,-50},{50,-50},{50,44},{50,42},{10,42}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
            points={{50,-50},{50,-50},{50,8},{50,-218},{68,-218},{68,-220},{
                82,-220}},
            color={255,204,51},
            thickness=0.5));
        connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(points={{-60,-4},
                {-60,-4},{-60,2}},          color={0,0,255}));
        connect(signalBus.pumpSEP_CS, pumpSEP.in_w0) annotation (Line(
            points={{50,-50},{50,-50},{50,-48},{50,-46},{6,-46}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
            points={{50,-50},{50,-50},{50,42},{70,42},{70,28}},
            color={255,204,51},
            thickness=0.5));
        connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
            points={{-60,42},{-60,48},{-10,48}},
            color={0,0,255},
            thickness=0.5));
        connect(sensDT_sh.inlet, PDSteamEVA2.outlet)
          annotation (Line(points={{-60,30},{-60,22}}, color={0,0,255}));
        connect(separator.drained_out, valveLiq.inlet)
          annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255},
            thickness=0.5));
        connect(valveLiq.outlet, sinkPressure.flange) annotation (Line(points=
               {{80,20},{90,20},{100,20}}, color={0,0,255}));
        connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
            points={{50,-50},{50,-50},{50,84},{-70,84},{-70,44}},
            color={255,204,51},
            thickness=0.5));
        connect(signalBus.pumpHPH_PV, sensT_MS.T) annotation (Line(
            points={{50,-50},{50,-50},{50,-258},{50,-270},{16,-270}},
            color={255,204,51},
            thickness=0.5));
        connect(RH_in, RH_in)
          annotation (Line(points={{190,180},{190,180}}, color={0,0,255}));
        connect(PDSteamSH2.inlet, SH.outletCold) annotation (Line(points={{
                -4.44089e-016,164},{0,164},{0,156}}, color={0,0,255}));
        connect(PDSteamSH2.outlet, sensP.flange)
          annotation (Line(points={{0,184},{0,240}}, color={0,0,255}));
        connect(PDSteamSH1.outlet, SH.inletCold)
          annotation (Line(points={{0,114},{0,124}}, color={0,0,255}));
        connect(PDSteamSH1.inlet, separator.steam_out)
          annotation (Line(points={{0,94},{0,87},{0,80}}, color={0,0,255}));
        connect(RH.outletHot, PDMSRH.inlet)
          annotation (Line(points={{140,144},{140,120}}, color={0,0,255}));
        connect(pumpMS.outlet, RH.inletHot) annotation (Line(points={{-100,246},
                {-100,246},{-100,206},{-100,210},{140,210},{140,176}},
                                                                 color={0,0,255}));
        connect(EVA2.outletHot, PDMSEVA2.inlet) annotation (Line(points={{-76,-20},
                {-100,-20},{-100,-60}},
                                  color={0,0,255}));
        connect(PDMSEVA2.outlet, EVA1.inletHot) annotation (Line(points={{-100,-80},{-100,
                -100},{-76,-100}}, color={0,0,255}));
        connect(EVA1.outletHot, PDMSEVA1.inlet) annotation (Line(points={{-44,-100},{-20,
                -100},{-20,-130}}, color={0,0,255}));
        connect(PDMSEVA1.outlet, ECO.inletHot) annotation (Line(points={{-20,-150},{-20,
                -180},{-44,-180}}, color={0,0,255}));
        connect(ECO.outletHot, PDMSECO.inlet) annotation (Line(points={{-76,-180},{-100,
                -180},{-100,-210}}, color={0,0,255}));
        connect(PDMSECO.outlet, HPH.inletHot) annotation (Line(points={{-100,-230},{-100,
                -280},{-76,-280}}, color={0,0,255}));
        connect(PDMSRH.outlet, PDMSSEP.inlet) annotation (Line(points={{140,100},{140,
                100},{140,-20},{108,-20}}, color={0,0,255}));
        connect(PDMSSEP.outlet, EVA2.inletHot)
          annotation (Line(points={{88,-20},{-44,-20}}, color={0,0,255}));
        connect(pumpMS.outlet, PDMSSH.inlet) annotation (Line(points={{-100,246},
                {-100,246},{-100,144},{-100,140},{-80,140}}, color={0,0,255}));
        connect(PDMSSH.outlet, SH.inletHot) annotation (Line(points={{-60,140},
                {-16,140},{-16,140}}, color={0,0,255}));
        connect(SH.outletHot, PDMSSEP.inlet) annotation (Line(points={{16,140},
                {100,140},{100,80},{140,80},{140,-20},{108,-20}}, color={0,0,
                255}));
        connect(HPH.outletHot, PDMSECO1.inlet)
          annotation (Line(points={{-44,-280},{-30,-280}}, color={0,0,255}));
        connect(PDMSECO1.outlet, sensT_MS.inlet)
          annotation (Line(points={{-10,-280},{2,-280}}, color={0,0,255}));
        annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(
                extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
          Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
      end OTSG_init100_5nodes_ML2;

      model Plant_HP_init100_test_FMU
        "Model of the high-pressure steam cycle with tunable parameters for machine learning test"

        SteamTurbine.Corps.HPT HPTurb(w_seal=0.022) annotation (Placement(
              transformation(extent={{24,102},{100,178}})));
        SteamTurbine.Corps.IPT IPTurb annotation (Placement(transformation(
                extent={{134,102},{216,178}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-380,260},{-360,280}})));
        ThermoPower.Water.SourcePressure sourceMS(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          h=518322,
          p0=1050000)
                    annotation (Placement(transformation(extent={{-160,90},
                  {-140,110}})));
        ThermoPower.Water.SinkPressure sinkMS3(
          allowFlowReversal=false,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=100000) annotation (Placement(transformation(extent={{-140,
                  -190},{-160,-170}})));
        HeatExchangers.OTSG.OTSG_init100_5nodes OTSG(separator(w_small=1e4))
                               annotation (Placement(transformation(extent={{-160,
                  -160},{-20,80}})));
        HeatExchangers.FeedwaterTrain.HP_train.HPH_train_controlledLevel_100
          HPHs annotation (Placement(transformation(extent={{20,-160},{140,
                  -100}})));

        Control.Schemes.PlantControlSchemes.plantController_staticDecoupled_4thOrder
          controllers(
          actuatorGain_pumpHPH=1,
          actuatorGain_pumpFW=1,
          actuatorGain_pumpMS=1,
          actuatorGain_valveTURB=1,
          Td_valveBP=0,
          Nd_valveBP=20,
          actuatorGain_valveBP=1,
          Ta_valveBP=0.3,
          TS_valveBP=0,
          Ta_pumpFW=2,
          Ta_pumpHPH=2,
          Ta_pumpMS=2,
          Ta_valveTURB=0.3,
          l_sp=4,
          Ti_pumpFW_low=714.2,
          Td_pumpFW_low=0,
          Nd_pumpFW_low=20,
          CSmin_pumpFW_low=10,
          TS_pumpFW_low=0,
          Kp_valveBP=-7.925e-6,
          Ti_valveBP=0.001,
          CSstart_valveBP=0,
          useTS_pumpFW_low=false,
          CSmin_valveBP=-1,
          CSmax_valveBP=1,
          Nd_pumpMS_high=20,
          CSstart_pumpMS_high=0,
          TS_pumpMS_high=0,
          Nd_pumpMS_low=20,
          CSmin_pumpMS_low=-50,
          CSmax_pumpMS_low=50,
          CSstart_pumpMS_low=0,
          TS_pumpMS_low=0,
          Td_valveTURB_high=0,
          Nd_valveTURB_high=20,
          CSstart_valveTURB_high=0,
          TS_valveTURB_high=0,
          Td_valveTURB_low=0,
          Nd_valveTURB_low=20,
          CSmin_valveTURB_low=-0.1e-5,
          CSmax_valveTURB_low=0.1e-5,
          CSstart_valveTURB_low=0,
          TS_valveTURB_low=0,
          Td_pumpSEP=0,
          Nd_pumpSEP=20,
          CSstart_pumpSEP=0,
          actuatorGain_pumpSEP=1,
          Ta_pumpSEP=2,
          TS_pumpSEP=0,
          CSmin_pumpSEP=-0.2,
          CSmax_pumpSEP=0.2,
          CSmax_pumpFW_low=100,
          Kp_pumpSEP=0.01523,
          Ti_pumpSEP=2.267,
          Kp_pumpFW_low=15.73,
          CSstart_pumpFW_low=45,
          A=[-0.074997,-0.02785398576,-0.0049549758956544,-0.000161251055558656,
              0; 0.0625,0,0,0,0; 0,0.0625,0,0,0; 0,0,0.125,0,0; 0,0,0,0.25,
              0],
          D=[0],
          load_switch=55,
          TS_pumpFW_high=0,
          use_valveSEP=true,
          load_min=55,
          actuatorGain_valveSEP=1,
          Ta_valveSEP=0.3,
          l_min=0.2,
          l_max=0.3,
          control_wHPH(table_w_HPH(table=[20,0.1; 30,0.1; 40,0.1; 50,0.1; 60,
                  0.1; 70,0.1; 80,0.1; 90,6.743; 100,24.51])),
          useTS_valveTURB_low=false,
          useTS_pumpFW_high=false,
          useTS_pumpSEP=false,
          CSmin_pumpMS_high=-100,
          CSmax_pumpMS_high=100,
          DT_sh_sp=20,
          control_wBP(table_thetaBP(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)),
          dec_wMS_wFW=1e-3,
          dec_wFW_wMS=80,
          useTS_valveBP=false,
          CSmin_pumpFW_high=-0.2,
          CSmax_pumpFW_high=0.2,
          CSmin_valveTURB_high=-1e-5,
          CSmax_valveTURB_high=1e-5,
          useTS_pumpMS=false,
          Kp_pumpMS_high=4e-4,
          Ti_pumpMS_high=16,
          Td_pumpMS_high=0,
          Kp_pumpMS_low=8.6e-5,
          Ti_pumpMS_low=571.4,
          Td_pumpMS_low=0,
          Kp_valveTURB_high=-2e-13,
          Ti_valveTURB_high=100,
          Kp_valveTURB_low=-1e-12,
          Ti_valveTURB_low=9.484,
          B=[0.015625; 0; 0; 0; 0],
          C=[-0.0064,-0.00260067328,-0.00025268973305856,-1.21740173322748e-05,
              -2.78018594921513e-08],
          useTS_valveTURB_high=false,
          T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                  -60},{-212,-20}})));

        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed1(
                                                                          w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{-46,130},{-26,150}})));
        Auxiliaries.Components.powerSensor powerSensor(eta_mec=1)
          annotation (Placement(transformation(extent={{-18,130},{2,150}})));
        Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
              transformation(extent={{-288,-46},{-276,-34}})));
        Modelica.Blocks.Sources.RealExpression LOAD1(y=gain.y)
          annotation (Placement(transformation(extent={{340,220},{320,240}})));
        Modelica.Blocks.Sources.RealExpression LOAD2(y=gain.y)
          annotation (Placement(transformation(extent={{340,70},{320,90}})));
        Modelica.Blocks.Sources.RealExpression LOAD3(y=gain.y)
          annotation (Placement(transformation(extent={{340,10},{320,30}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          p0=450000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{260,190},{280,210}})));
        Modelica.Blocks.Tables.CombiTable1D IPTurb_sink(table=[20,0.7006e5;
              30,1.04e5; 40,1.377e5; 50,1.724e5; 60,2.068e5; 70,2.436e5; 80,
              2.753e5; 90,3.09e5; 100,3.448e5])
          annotation (Placement(transformation(extent={{306,220},{286,240}})));
        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=508800,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{246,50},{266,70}})));
        ThermoPower.Water.SinkPressure sinkPressure2(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{246,-10},{266,10}})));
        Modelica.Blocks.Tables.CombiTable1D SP3_sink(table=[20,0.6861e5; 30,
              1.014e5; 40,1.336e5; 50,1.667e5; 60,1.992e5; 70,2.337e5; 80,
              2.633e5; 90,2.946e5; 100,3.276e5])
          annotation (Placement(transformation(extent={{306,70},{286,90}})));
        Modelica.Blocks.Tables.CombiTable1D SP4_sinkP(table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{306,10},{286,30}})));
        ThermoPower.Water.SinkPressure sinkPressure_DR(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=900000,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{186,-90},{206,-70}})));
        ThermoPower.Water.SourcePressure sourcePressure1(redeclare package
            Medium = Modelica.Media.Water.WaterIF97_ph,
          h=768600,
          p0=18380000,
          use_in_h=true)
          annotation (Placement(transformation(extent={{206,-130},{186,-110}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_FW_source(table=[20,565400;
              30,622100; 40,660200; 50,691100; 60,717700; 70,744100; 80,
              764100; 90,783800; 100,803100])
                                   annotation (Placement(transformation(extent={{246,
                  -110},{226,-90}})));
        Modelica.Blocks.Tables.CombiTable1D HPH1_sinkP(
                                                      table=[20,2.234e5; 30,
              3.321e5; 40,4.396e5; 50,5.504e5; 60,6.595e5; 70,7.745e5; 80,
              8.731e5; 90,9.773e5; 100,10.86e5]) annotation (Placement(
              transformation(extent={{246,-70},{226,-50}})));
        Modelica.Blocks.Sources.RealExpression LOAD4(y=gain.y)
          annotation (Placement(transformation(extent={{280,-70},{260,-50}})));
        Modelica.Blocks.Sources.RealExpression LOAD5(y=gain.y)
          annotation (Placement(transformation(extent={{280,-110},{260,-90}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-360,-60},{-320,-20}})));
        Modelica.Blocks.Interfaces.RealOutput y_P_mec = powerSensor.gain.y annotation (Placement(transformation(extent={{380,110},
                  {400,130}})));
        Modelica.Blocks.Interfaces.RealOutput y_p = OTSG.sensP.p annotation (Placement(transformation(extent={{380,30},
                  {400,50}})));
        Modelica.Blocks.Interfaces.RealOutput y_DT_sh = OTSG.DT_sh annotation (Placement(
              transformation(extent={{380,-50},{400,-30}}),
                                                          iconTransformation(extent={{
                  320,-210},{340,-190}})));
        Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{380,
                  -130},{400,-110}})));
      equation
        connect(HPTurb.flange_HP_out, IPTurb.flange_IP_in) annotation (Line(
            points={{103.8,140},{129.9,140}},
            color={0,0,0},
            smooth=Smooth.None));

        connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
            points={{-140,-180},{-128.889,-180},{-128.889,-164}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
            points={{-140,100},{-128.889,100},{-128.889,84}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5));

        connect(OTSG.RH_in, HPTurb.vap_out) annotation (Line(
            points={{-16.1111,48},{20.2,48},{20.2,109.6}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.SH_out, HPTurb.vap_in) annotation (Line(
            points={{-51.1111,84},{-51.1111,162.8},{20.2,162.8}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(OTSG.FW_in, HPHs.FW_out) annotation (Line(
            points={{-16.1111,-132},{-16.1111,-130},{16.6667,-130}},
            color={0,0,255},
            thickness=0.5));
        connect(OTSG.SEP_out, HPHs.SEP_in) annotation (Line(
            points={{-16.1111,-72},{-16.1111,-72},{40,-72},{40,-97}},
            color={0,0,255},
            thickness=0.5));

        connect(OTSG.RH_out, IPTurb.vap_in) annotation (Line(
            points={{-82.2222,84},{-84,84},{-84,168},{-84,200},{129.9,200},{
                129.9,162.8}},
            color={0,0,255},
            thickness=0.5));

        connect(IPTurb.SP5, HPHs.SP2) annotation (Line(
            points={{161.06,98.2},{161.06,48},{106.667,48},{106.667,-97}},
            color={0,127,0},
            thickness=0.5));

        connect(HPTurb.SP6, HPHs.SP1) annotation (Line(
            points={{62,98.2},{62,98.2},{62,-97},{63.3333,-97}},
            color={0,127,0},
            thickness=0.5));
        connect(constantSpeed1.flange, powerSensor.shaft_flange_out1)
          annotation (Line(points={{-26,140},{-19,140}},           color={0,
                0,0}));
        connect(powerSensor.shaft_flange_out, HPTurb.flange_HP_in)
          annotation (Line(points={{3,140},{20.2,140}},            color={0,
                0,0}));
        connect(OTSG.MS_HPH_out, HPHs.MS_HPH_in) annotation (Line(points={{
                -82.2222,-164},{-82.2222,-180},{93.3333,-180},{93.3333,-163}},
                          color={0,0,255},
            thickness=0.5));
        connect(gain.y, controllers.load) annotation (Line(points={{-275.4,-40},
                {-262.182,-40}},      color={0,0,127}));
        connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
            points={{-209.818,-40},{-209.818,-40},{-165.444,-40}},
            color={255,204,51},
            thickness=0.5));
        connect(controllers.signalBus, powerSensor.signalBus) annotation (Line(
            points={{-209.818,-40},{-190,-40},{-190,120},{-8,120},{-8,130}},
            color={255,204,51},
            thickness=0.5));

        connect(HPHs.signalBus, controllers.signalBus) annotation (Line(
            points={{116.667,-161.2},{116.667,-220},{-190,-220},{-190,-40},{
                -209.818,-40}},
            color={255,204,51},
            thickness=0.5));

        connect(sinkPressure.flange, IPTurb.vap_out) annotation (Line(points={{260,200},
                {220.1,200},{220.1,162.8}}, color={0,0,255}));
        connect(IPTurb_sink.y[1],sinkPressure. in_p0) annotation (Line(points={{285,230},
                {266,230},{266,208.8}},          color={0,0,127}));
        connect(SP3_sink.y[1],sinkPressure1. in_p0) annotation (Line(points={{285,80},
                {252,80},{252,68.8}},     color={0,0,127}));
        connect(SP4_sinkP.y[1],sinkPressure2. in_p0) annotation (Line(points={{285,20},
                {252,20},{252,8.8}},           color={0,0,127}));
        connect(HPHs.FW_in,sourcePressure1. flange) annotation (Line(points={{143.333,
                -130},{143.333,-130},{182,-130},{182,-120},{186,-120}}, color={0,0,255},
            thickness=0.5));
        connect(HPHs.DR_out,sinkPressure_DR. flange) annotation (Line(points={{143.333,
                -112},{143.333,-112},{182,-112},{182,-80},{186,-80}},   color={0,127,0},
            thickness=0.5));
        connect(sinkPressure_DR.in_p0,HPH1_sinkP. y[1]) annotation (Line(
              points={{192,-71.2},{192,-60},{225,-60}}, color={0,0,127}));
        connect(sourcePressure1.in_h,HPH1_FW_source. y[1]) annotation (Line(
              points={{192,-111},{192,-100},{225,-100}}, color={0,0,127}));
        connect(sinkPressure1.flange, IPTurb.SP3) annotation (Line(points={{246,60},
                {224,60},{199.6,60},{199.6,98.2}},     color={0,0,255}));
        connect(sinkPressure2.flange, IPTurb.SP4) annotation (Line(points={{246,0},
                {179.92,0},{179.92,98.2}},  color={0,0,255}));
        connect(IPTurb_sink.u[1], LOAD1.y) annotation (Line(points={{308,230},
                {314,230},{319,230}},          color={0,0,127}));
        connect(SP3_sink.u[1], LOAD2.y) annotation (Line(points={{308,80},{
                314,80},{319,80}},      color={0,0,127}));
        connect(SP4_sinkP.u[1], LOAD3.y) annotation (Line(points={{308,20},
                {314,20},{319,20}},     color={0,0,127}));
        connect(HPH1_sinkP.u[1], LOAD4.y) annotation (Line(points={{248,-60},
                {259,-60}},          color={0,0,127}));
        connect(HPH1_FW_source.u[1], LOAD5.y) annotation (Line(points={{248,
                -100},{254,-100},{259,-100}},            color={0,0,127}));
        connect(load, gain.u) annotation (Line(points={{-340,-40},{-314,-40},{-289.2,-40}},
              color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-380,-280},{380,280}},
                preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-380,
                  -280},{380,280}}, preserveAspectRatio=false)),
          experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput(equidistant=false),
          Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
      end Plant_HP_init100_test_FMU;

      model SH_test_FMU
        "Test model for FMI standard test, with the SH as main component"

        ThermoPower.Water.SourceMassFlow sourceMS(
          G=0,
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          use_in_w0=true,
          w0=381.3,
          h=519092,
          p0=1000000)
          annotation (Placement(transformation(extent={{-30,-10},{-10,10}})));
        ThermoPower.Water.SourceMassFlow sourceSteam(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_w0=true,
          use_in_h=true,
          w0=91.28,
          h=2755127)
          annotation (Placement(transformation(extent={{-20,-90},{0,-70}})));
        ThermoPower.Water.SinkPressure sinkSteam(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=17132400)
          annotation (Placement(transformation(extent={{30,50},{50,70}})));
        ThermoPower.Water.SinkPressure sinkMS(
          redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
          p0=855401)
          annotation (Placement(transformation(extent={{60,-10},{80,10}})));
        ThermoPower.Water.PressDrop PDSteamSH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=91.28,
          dpnom=(172 - 171.0324)*10^5,
          rhonom=50.398)                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={10,30})));
        HeatExchangers.Components.HE
                      SH(
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium =
              Modelica.Media.Water.WaterIF97_ph,
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          redeclare package hotMedium =
              PreFlexMS.Media.MoltenSalt60_40_quad,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.847436, gamma_nom=1996.5),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.28867, gamma_nom=2848.1),
          Vhot=12.281,
          Vcold=2.339,
          Shot=1193.5,
          Scold=835.5,
          Mm=19349,
          nominalColdFlow=91.28,
          nominalHotFlow=381.3,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
          Nhex=5,
          generateInitCode=false,
          nominalColdPressure=17200000,
          nominalHotPressure=1050000,
          nominalColdInletTemperature=646.55,
          nominalColdOutletTemperature=823.96,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=733.58,
          hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true))
          annotation (Placement(transformation(extent={{0,-10},{20,10}})));
        Auxiliaries.Components.Spline.SplineFunction
                                            w_MS_SH(table=[20,76.24; 30,114.4;
              40,152.5; 50,190.6; 60,228.7; 70,266.8; 80,304.9; 90,343.1; 100,
              381.2])
          annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
        Auxiliaries.Components.Spline.SplineFunction
                                            h_ST_SH(table=[20,2752e3; 30,
              2751.7e3; 40,2751.2e3; 50,2745.5e3; 60,2834.3e3; 70,2817.3e3; 80,
              2799.2e3; 90,2780.1e3; 100,2756.1e3])
          annotation (Placement(transformation(extent={{-48,-40},{-28,-20}})));
        Auxiliaries.Components.Spline.SplineFunction
                                            w_ST_SH(table=[20,17.67; 30,26.99;
              40,36.63; 50,46.95; 60,57.44; 70,66.02; 80,74.71; 90,83.33; 100,
              91.3])
          annotation (Placement(transformation(extent={{-48,-70},{-28,-50}})));
        Auxiliaries.Components.Spline.SplineFunction
                                            p_ST_SH(table=[20,85.08e5; 30,
              85.18e5; 40,85.33e5; 50,88.82e5; 60,107.6e5; 70,124.1e5; 80,
              139.7e5; 90,155.1e5; 100,171e5])         annotation (Placement(
              transformation(extent={{-50,70},{-30,90}})));
        Modelica.Blocks.Sources.Constant const(k=50)
          annotation (Placement(transformation(extent={{-100,-30},{-80,-10}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
        Modelica.Blocks.Interfaces.RealInput LOAD annotation (Placement(
              transformation(extent={{-120,0},{-80,40}}), iconTransformation(
                extent={{-120,-20},{-80,20}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-70,-2},{-66,2}})));
        Modelica.Blocks.Interfaces.RealOutput T_out_steam = SH.coldFluid.T[5]
          annotation (Placement(transformation(extent={{100,-10},{120,10}})));
      equation
        connect(PDSteamSH.outlet,sinkSteam. flange) annotation (Line(
            points={{10,40},{10,60},{30,60}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(sourceSteam.flange,SH. inletCold) annotation (Line(
            points={{0,-80},{10,-80},{10,-10}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(sourceMS.flange,SH. inletHot) annotation (Line(
            points={{-10,0},{0,0}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(PDSteamSH.inlet,SH. outletCold) annotation (Line(
            points={{10,20},{10,10}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(w_ST_SH.y, sourceSteam.in_w0) annotation (Line(points={{-27,-60},
                {-14,-60},{-14,-74}}, color={0,0,127}));
        connect(h_ST_SH.y, sourceSteam.in_h) annotation (Line(points={{-27,-30},
                {-6,-30},{-6,-74}}, color={0,0,127}));
        connect(w_MS_SH.y, sourceMS.in_w0) annotation (Line(points={{-29,30},{
                -24,30},{-24,6}}, color={0,0,127}));
        connect(p_ST_SH.y, sinkSteam.in_p0) annotation (Line(points={{-29,80},{
                36,80},{36,68.8}}, color={0,0,127}));
        connect(SH.outletHot, sinkMS.flange)
          annotation (Line(points={{20,0},{40,0},{60,0}}, color={0,0,255}));
        connect(LOAD, add.u1) annotation (Line(points={{-100,20},{-74,20},{-74,
                1.2},{-70.4,1.2}}, color={0,0,127}));
        connect(const.y, add.u2) annotation (Line(points={{-79,-20},{-74,-20},{
                -74,-1.2},{-70.4,-1.2}}, color={0,0,127}));
        connect(add.y, p_ST_SH.u) annotation (Line(points={{-65.8,0},{-60,0},{
                -60,80},{-52,80}}, color={0,0,127}));
        connect(add.y, w_ST_SH.u) annotation (Line(points={{-65.8,0},{-60,0},{
                -60,-60},{-50,-60}}, color={0,0,127}));
        connect(add.y, h_ST_SH.u) annotation (Line(points={{-65.8,0},{-66,0},{
                -60,0},{-60,-30},{-50,-30}}, color={0,0,127}));
        connect(add.y, w_MS_SH.u) annotation (Line(points={{-65.8,0},{-66,0},{
                -60,0},{-60,30},{-52,30}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false), graphics={
                                                      Text(
                extent={{10,-20},{50,-40}},
                lineColor={0,0,255},
                textString="SH")}));
      end SH_test_FMU;
    end MachineLearning;

    package Graphics "Package containing models used only for graphic purpose"

      model OTSG_init100_5nodes_scheme
        "Dynamic model of the once through steam generator, for process scheme purpose"
        extends HeatExchangers.BaseClasses.BaseOTSG;

        //Heat exchangers parameter
        parameter Integer Nhex_mono = 5
          "Number of nodes for single phase heat exchangers";
        parameter Integer Nhex_bi = 10
          "Number of nodes for biphase heat exchangers";
        parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

        HeatExchangers.Components.HE HPH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.536143, gamma_nom=3958.9),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447465, gamma_nom=2197.5),
          Nhex=Nhex_mono*2,
          Vhot=3.789,
          Vcold=0.781,
          Shot=314.9,
          Scold=248,
          Mm=3802,
          nominalColdFlow=24.51,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.06284e+006,1.13292e+006,1.18284e+006,1.21872e+006,
                1.24469e+006,1.26359e+006,1.27742e+006,1.28756e+006,
                1.29502e+006,1.30052e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {541.299,549.318,554.93,
              558.906,561.752,563.806,565.297,566.385,567.182}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={110023,109806,109511,109110,108563,107815,106788,105370,
                103396,100624}),
          nominalColdPressure=17400000,
          nominalHotPressure=250000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=564.15,
          nominalHotInletTemperature=569.15,
          nominalHotOutletTemperature=563.15) annotation (Placement(
              transformation(extent={{-76,-244},{-44,-276}})));

        HeatExchangers.Components.HE ECO(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.728761, gamma_nom=4499),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.461561, gamma_nom=2204.3),
          Vhot=44.506,
          Vcold=5.73,
          Shot=2385,
          Scold=1848.4,
          Mm=30279,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                1.64439e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
              620.01}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={196390,188158,176706,156967,110743}),
          nominalColdPressure=17400000,
          nominalHotPressure=450000,
          nominalColdInletTemperature=518.15,
          nominalColdOutletTemperature=621.59,
          nominalHotInletTemperature=626.65,
          nominalHotOutletTemperature=569.15) annotation (Placement(
              transformation(extent={{-44,-176},{-76,-144}})));

        HeatExchangers.Components.HE_2ph EVA1(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              alpha=1.6,
              gamma_nom_liq=3875*0.75,
              gamma_nom_2ph=10000*0.75,
              gamma_nom_vap=3875*0.75),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.447498, gamma_nom=2147.7),
          Vhot=31.955,
          Vcold=9.805,
          Shot=2834.1,
          Scold=2108.5,
          Mm=62846,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,1.94183e+006,
                2.2136e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
              626.498,627.06,627.186,627.848,629.177,631.842}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                194368,192799}),
          nominalColdPressure=17300000,
          nominalHotPressure=650000,
          nominalColdInletTemperature=621.55,
          nominalColdOutletTemperature=626.9,
          nominalHotInletTemperature=689.01,
          nominalHotOutletTemperature=626.65)
          annotation (Placement(transformation(extent={{-76,-96},{-44,-64}})));
        HeatExchangers.Components.HE_2ph EVA2(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_bi,
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.389637, gamma_nom=2650),
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
              (
              wnom_ht=88.59,
              gamma_nom_liq=2000,
              gamma_nom_2ph=5000,
              gamma_nom_vap=2000,
              alpha=1.1),
          Vhot=4.495,
          Vcold=1.028,
          Shot=489,
          Scold=354.5,
          Mm=7374,
          nominalColdFlow=91.28,
          nominalHotFlow=619.8,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            Nt=1,
            hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,2.72547e+006,
                2.78281e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
              653.806,658.116,678.213,683.393,689.164,695.453}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                284059,275898}),
          nominalColdPressure=17250000,
          nominalHotPressure=700000,
          nominalColdInletTemperature=626.69,
          nominalColdOutletTemperature=646.74,
          nominalHotInletTemperature=734.05,
          nominalHotOutletTemperature=689.01)
          annotation (Placement(transformation(extent={{-44,-16},{-76,16}})));

        HeatExchangers.Components.Old.Equilibrium2phVessel separator(
          redeclare package Medium = coldMedium,
          H=8,
          zl_start=0,
          D=0.56,
          noInitialPressure=true,
          h_start=2.75412e6,
          p_start=17200000)
          annotation (Placement(transformation(extent={{-28,28},{28,84}})));
        ThermoPower.Water.ThroughMassFlow waterPump(
          redeclare package Medium = coldMedium,
          allowFlowReversal=false,
          w0=0,
          use_in_w0=true)
                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=-90,
              origin={0,-60})));

        HeatExchangers.Components.HE SH(
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.847436, gamma_nom=1996.5),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.28867, gamma_nom=2848.1),
          Vhot=12.281,
          Vcold=2.339,
          Shot=1193.5,
          Scold=835.5,
          Mm=19349,
          nominalColdFlow=91.28,
          nominalHotFlow=381.3,
          coldFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                3.42217e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
              824.786}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={519092,501167,469703,420819,359564}),
          nominalColdPressure=17200000,
          nominalHotPressure=1050000,
          nominalColdInletTemperature=646.55,
          nominalColdOutletTemperature=823.96,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=733.58) annotation (Placement(
              transformation(
              extent={{-16,-16},{16,16}},
              rotation=0,
              origin={0,140})));
        HeatExchangers.Components.HE RH(
          redeclare model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
          cm=500,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare package coldMedium = coldMedium,
          redeclare package hotMedium = hotMedium,
          Nhex=Nhex_mono,
          redeclare model HeatTransferCold =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.798347, gamma_nom=963.6),
          redeclare model HeatTransferHot =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.320782, gamma_nom=2690.3),
          Vhot=9.255,
          Vcold=4.618,
          Shot=1371.1,
          Scold=1154.6,
          Mm=15054,
          nominalColdFlow=84.94,
          nominalHotFlow=238.6,
          coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                3.55697e+006}),
          tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
              829.056}),
          hotFluid(
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            noInitialPressure=true,
            hstart={519092,502650,475154,429572,356689}),
          nominalColdPressure=4781000,
          nominalHotPressure=1050000,
          nominalColdInletTemperature=633.15,
          nominalColdOutletTemperature=826.06,
          nominalHotInletTemperature=838.65,
          nominalHotOutletTemperature=734.05) annotation (Placement(
              transformation(
              extent={{-16,16},{16,-16}},
              rotation=-90,
              origin={100,180})));
        ThermoPower.Water.ThroughMassFlow valveRH(
          redeclare package Medium = hotMedium,
          use_in_w0=true,
          w0=238.6)
          annotation (Placement(transformation(extent={{-86,210},{-66,230}})));

        ThermoPower.Water.PressDrop PDSteamEVA1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=160.88)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-40})));
        ThermoPower.Water.PressDrop PDSteamECO2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=590.03)          annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-120})));
        ThermoPower.Water.PressDrop PDSteamEVA2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(0.5)*10^5,
          rhonom=92.917)       annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,30})));
        //Overall parameter and variables:
        Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
        Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
        Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
        Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
        Modelica.SIunits.Length sep_lev = separator.zl;
        Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
        Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
        Real x_EVA1_out = EVA1.coldFluid.x[end];
        Real x_EVA2_out = EVA2.coldFluid.x[end];
        Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
        Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
        Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
        Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

        ThermoPower.Water.PressDrop PDSteamRH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=84.86,
          dpnom=(0.5)*10^5,
          rhonom=12.775,
          redeclare package Medium = coldMedium)
                                         annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={60,242})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={188,2}), iconTransformation(
              extent={{-30,-30},{30,30}},
              rotation=-90,
              origin={-194,0})));
        ThermoPower.Water.SensT sensT_FW(
          redeclare package Medium = coldMedium)
          annotation (Placement(transformation(extent={{100,-216},{80,-196}})));
        ThermoPower.Water.ThroughMassFlow throughMassFlow(
          use_in_w0=true,
          redeclare package Medium = hotMedium,
          w0=619.8)
          annotation (Placement(transformation(
              extent={{10,10},{-10,-10}},
              rotation=90,
              origin={-100,256})));
        ThermoPower.Water.SensP sensP_EVA(redeclare package Medium =
              coldMedium) annotation (Placement(transformation(
              extent={{10,10},{-10,-10}},
              rotation=-90,
              origin={-4,180})));
        ThermoPower.Water.PressDrop PDSteamSH2(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=91.28,
          dpnom=(1)*10^5,
          redeclare package Medium = coldMedium,
          rhonom=92.8) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,100})));
        ThermoPower.Water.PressDrop PDSteamECO1(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=91.28,
          dpnom=(1/2)*10^5,
          rhonom=820.48)                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-194})));
        ThermoPower.Water.PressDrop PDSteamHPH(
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          redeclare package Medium = coldMedium,
          wnom=24.51,
          dpnom=(0.5)*10^5,
          rhonom=747.38)       annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=90,
              origin={-60,-226})));
        ThermoPower.Water.ValveVap valveVap(
          thetanom=0.8,
          Fxt_full=0.4542722663,
          Av=0.053642779,
          wnom=91.28,
          redeclare package Medium = coldMedium,
          pnom=17100000,
          dpnom=100000)
          annotation (Placement(transformation(extent={{-10,10},{10,-10}},
              rotation=90,
              origin={0,280})));
        Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
              transformation(
              extent={{-6,-6},{6,6}},
              rotation=270,
              origin={-80,242})));
        Label_input pumpMS_CS
          annotation (Placement(transformation(extent={{-40,266},{-80,254}})));
        Label_output valveBP_PV
          annotation (Placement(transformation(extent={{60,-206},{20,-194}})));
        Label_input valveTURB_CS
          annotation (Placement(transformation(extent={{62,286},{22,274}})));
        Label_output pumpFW_PV_high
          annotation (Placement(transformation(extent={{-66,52},{-112,64}})));
        Label_output pumpFW_PV_low
          annotation (Placement(transformation(extent={{32,36},{78,48}})));
        Label_input pumpSEP_CS
          annotation (Placement(transformation(extent={{70,-50},{30,-62}})));
        Label_output valveTURB_PV
          annotation (Placement(transformation(extent={{-30,184},{-70,196}})));
        Label_output pumpSEP_PV
          annotation (Placement(transformation(extent={{60,-192},{20,-180}})));
        Label_flange_output label_flange(flowName=LIVE_STEAM, from_to=
              TO_TURBINE)
          annotation (Placement(transformation(extent={{0,332},{-40,348}})));
        Label_flange_output label_flange1(from_to=TO_TURBINE, flowName=
              HOT_RH_STEAM)
          annotation (Placement(transformation(extent={{100,332},{48,348}})));
        Label_flange_input label_flange2(flowName=MOLTEN_SALT, from_to=
              FROM_HOT_PUMP) annotation (Placement(transformation(extent={{-168,
                  332},{-112,348}})));
        Label_flange_input label_flange3(flowName=COLD_RH_STEAM, from_to=
              FROM_TURBINE)
          annotation (Placement(transformation(extent={{268,172},{212,188}})));
        Label_flange_input label_flange4(flowName=FEEDWATER, from_to=
              FROM_STEAM_CYCLE) annotation (Placement(transformation(extent={{
                  276,-218},{212,-202}})));
        Label_flange_output label_flange5(flowName=SATURATED_LIQUID, from_to=
              TO_STEAM_CYCLE)
          annotation (Placement(transformation(extent={{200,-88},{258,-72}})));
        Label_flange_output label_flange6(flowName=FEEDWATER, from_to=
              TO_STEAM_CYCLE) annotation (Placement(transformation(extent={{-60,
                  -348},{-118,-332}})));
        Label_flange_output label_flange7(flowName=MOLTEN_SALT, from_to=
              TO_COLD_TANK)
          annotation (Placement(transformation(extent={{20,-348},{72,-332}})));
        Auxiliaries.Components.SensDT_sh sensDT annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-38,52})));
        ThermoPower.Water.ValveLiq valveDrain(
          redeclare package Medium = coldMedium,
          Av=3.702e-5,
          wnom=4.45,
          pnom=17200000,
          dpnom=17000000)
          annotation (Placement(transformation(extent={{40,-44},{60,-24}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              coldMedium, p0=101325)
          annotation (Placement(transformation(extent={{100,-44},{120,-24}})));
        Label_input valveDRAIN_CS
          annotation (Placement(transformation(extent={{110,-8},{70,-20}})));
      equation
        connect(HPH.inletHot, ECO.outletHot) annotation (Line(
            points={{-76,-260},{-100,-260},{-100,-160},{-76,-160}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(HPH.outletCold, MS_HPH_out) annotation (Line(
            points={{-60,-276},{-60,-310}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
            points={{-60,-144},{-60,-130}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(separator.drained_out, waterPump.inlet) annotation (Line(
            points={{0,38},{0,-50},{1.77636e-015,-50}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
            points={{-60,-30},{-60,-16}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
            points={{-60,-64},{-60,-50}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
            points={{-60,16},{-60,20}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
            points={{-76,0},{-100,0},{-100,-80},{-76,-80}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
            points={{-44,-80},{-20,-80},{-20,-160},{-44,-160}},
            color={255,0,0},
            smooth=Smooth.None,
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));

        connect(sensT_FW.inlet, FW_in) annotation (Line(
            points={{96,-210},{96,-210},{130,-210},{190,-210},{190,-210}},
            color={0,0,255},
            thickness=0.5));
        connect(MS_in, throughMassFlow.inlet) annotation (Line(
            points={{-100,310},{-100,266}},
            color={255,0,0},
            thickness=0.5));
        connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
            points={{-100,246},{-100,140},{-16,140}},
            color={255,0,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
            points={{-100,246},{-100,246},{-100,220},{-86,220}},
            color={255,0,0},
            thickness=0.5));
        connect(signalBus.valveTURB_PV, sensP_EVA.p) annotation (Line(
            points={{188,2},{156,2},{156,222},{156,212},{10,212},{10,202},{6,202},{6,188},
                {-10,188}},
            color={256,256,256},
            thickness=0.5));
        connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
            points={{-60,-96},{-60,-110}},
            color={0,0,255},
            thickness=0.5));
        connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
            points={{-60,-176},{-60,-184}},
            color={0,0,255},
            thickness=0.5));
        connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
            points={{-60,-236},{-60,-244}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveTURB_CS, valveVap.theta) annotation (Line(
            points={{188,2},{130,2},{130,264},{8,264},{8,280}},
            color={256,256,256},
            thickness=0.5));
        connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
            points={{188,2},{130,2},{130,-178},{146,-178},{146,-192},{82,-192},
                {82,-200}},
            color={256,256,256},
            thickness=0.5));
        connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
            points={{188,2},{10,2},{10,62},{10,66}},
            color={256,256,256},
            thickness=0.5));
        connect(gain.y, valveRH.in_w0)
          annotation (Line(points={{-80,235.4},{-80,235.4},{-80,226}},
                                                         color={0,0,127}));
        connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
            points={{188,2},{12,2},{12,42},{10,42}},
            color={256,256,256},
            thickness=0.5));
        connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,124},{0,126},
                {0,110}},              color={0,0,255},
            thickness=0.5));
        connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
              points={{-6.66134e-016,90},{0,92},{0,80}}, color={0,0,255},
            thickness=0.5));
        connect(sensP_EVA.flange, SH.outletCold) annotation (Line(
            points={{0,180},{0,180},{0,156}},
            color={0,0,255},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
            points={{188,2},{144,2},{144,296},{122,296},{-94,296},{-94,260}},
            color={256,256,256},
            thickness=0.5));
        connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
            points={{188,2},{138,2},{138,252},{-80,252},{-80,249.2}},
            thickness=0.5,
            color={255,255,255}));
        connect(RH_out, PDSteamRH.outlet) annotation (Line(
            points={{100,310},{100,310},{100,260},{98,260},{60,260},{60,252}},
            color={0,0,255},
            thickness=0.5));
        connect(waterPump.outlet, SEP_out) annotation (Line(
            points={{0,-70},{0,-70},{0,-80},{190,-80}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
            points={{84,-210},{42,-210},{-60,-210},{-60,-216}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
            points={{84,-210},{84,-210},{-60,-210},{-60,-204}},
            color={0,0,255},
            thickness=0.5));
        connect(valveRH.outlet, RH.inletHot) annotation (Line(
            points={{-66,220},{-66,220},{100,220},{100,196}},
            color={255,0,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(SH.outletHot, EVA2.inletHot) annotation (Line(
            points={{16,140},{58,140},{100,140},{100,0},{-44,0}},
            color={255,0,0},
            thickness=0.5));
        connect(RH.outletHot, EVA2.inletHot) annotation (Line(
            points={{100,164},{100,140},{100,0},{-44,0}},
            color={255,0,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(valveVap.inlet, sensP_EVA.flange) annotation (Line(
            points={{0,270},{0,180}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(HPH.outletHot, MS_out) annotation (Line(
            points={{-44,-260},{-12,-260},{20,-260},{20,-310}},
            color={255,0,0},
            thickness=0.5));
        connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
            points={{188,2},{160,2},{160,-76},{6,-76},{6,-56}},
            color={256,256,256},
            thickness=0.5));
        connect(PDSteamRH.inlet, RH.outletCold) annotation (Line(
            points={{60,232},{60,180},{84,180}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(SH_out, valveVap.outlet) annotation (Line(
            points={{0,310},{0,312},{0,290}},
            color={0,0,255},
            thickness=0.5));
        connect(RH.inletCold, RH_in) annotation (Line(
            points={{116,180},{190,180}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(PDSteamEVA2.outlet, sensDT.inlet) annotation (Line(
            points={{-60,40},{-60,48},{-44,48}},
            color={0,0,255},
            thickness=0.5));
        connect(sensDT.outlet, separator.water_in) annotation (Line(
            points={{-32,48},{-21,48},{-10,48}},
            color={0,0,255},
            thickness=0.5));
        connect(separator.drained_out, valveDrain.inlet) annotation (Line(
            points={{0,38},{0,38},{0,-34},{40,-34}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(valveDrain.outlet, sinkPressure.flange) annotation (Line(
            points={{60,-34},{100,-34}},
            color={0,0,255},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                preserveAspectRatio=false), graphics={Line(
                points={{80,-186},{80,-192},{80,-200},{78,-200}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{0,340},{0,320}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{100,340},{100,320}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-100,340},{-100,320}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-60,-320},{-60,-340}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{20,-320},{20,-340}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{50,-14},{50,-24}},
                color={0,0,0},
                thickness=0.5)}),                      Icon(coordinateSystem(
                extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
          Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
      end OTSG_init100_5nodes_scheme;

      model HPH_train_controlledLevel_100
        "Model of the high pressure feedwater train with level controllers"
        extends HeatExchangers.BaseClasses.BaseHPHTrain;
        ThermoPower.Water.ThroughMassFlow pumpFW(
          redeclare package Medium = Medium,
          use_in_w0=true,
          w0=91.28)
          annotation (Placement(transformation(extent={{170,10},{150,-10}})));
        ThermoPower.Water.ThroughMassFlow pumpHPH(
          redeclare package Medium = Medium,
          use_in_w0=true,
          w0=24.91) annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=90,
              origin={20,-56})));
        ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium =
                     Medium)
          annotation (Placement(transformation(extent={{24,-14},{4,6}})));
        ThermoPower.Water.SensT sensT(redeclare package Medium =
                     Medium)
          annotation (Placement(transformation(extent={{-136,-6},{-156,14}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
          redeclare package Medium = Medium,
          h=3218000,
          w0=0)
          annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
        ThermoPower.Water.ValveLiq valveBP(
          redeclare package Medium = Medium,
          Kv=3.820434783e-4/1,
          Av=7.8775e-3,
          wnom=87.87,
          pnom=17630000,
          dpnom=230000) annotation (Placement(transformation(extent={{-40,-38},
                  {-60,-58}})));
        ThermoPower.Water.PressDrop DPSteamHPH1(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          rhonom=867.7,
          wnom=91.28,
          dpnom=240000)
          annotation (Placement(transformation(extent={{52,-10},{32,10}})));
        ThermoPower.Water.PressDrop DPSteamHPH2(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          wnom=27.94,
          rhonom=731.3,
          dpnom=230000)
          annotation (Placement(transformation(extent={{-80,-10},{-100,10}})));
        Modelica.Icons.SignalBus signalBus
          annotation (Placement(transformation(extent={{70,-118},{110,-78}}),
              iconTransformation(extent={{90,-124},{130,-84}})));

        HeatExchangers.FeedwaterTrain.Old.HPH_controlledLevel HPH2(
          A=1,
          zl_set=0.1,
          zl_start=0.1,
          initOpt=ThermoPower.Choices.Init.Options.fixedState,
          cm=500,
          Td=0,
          Ta=0.3,
          Nd=20,
          CSmax=1,
          NusseltCondenser(noInitialPressure=true, initOpt=ThermoPower.Choices.Init.Options.fixedState),
          valveDynamic(initType=Modelica.Blocks.Types.Init.SteadyState),
          Nhex_des=3,
          Nhex_cond=3,
          Nhex_sub=5,
          redeclare model HeatTransferCold_des =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=2400),
          redeclare model HeatTransferHot_des =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=3600),
          Vhot_des=2.99*0.15,
          Vcold_des=0.53*0.15,
          Shot_des=210*0.15,
          Scold_des=210*0.15,
          Mm_des=10000*0.15,
          Vhot_cond=2.99*0.7,
          Shot_cond=210*0.7,
          gamma=4100,
          redeclare model HeatTransferCold_cond =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=2400),
          Vcold_cond=0.53*0.7,
          Scold_cond=210*0.7,
          Mm_cond=10000*0.7,
          nominalColdFlow=27.94,
          nominalHotFlow=4.449,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare model HeatTransferCold_sub =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=2400),
          redeclare model HeatTransferHot_sub =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=3600),
          Vhot_sub=2.99*0.15,
          Vcold_sub=0.53*0.15,
          Shot_sub=210*0.15,
          Scold_sub=210*0.15,
          Mm_sub=10000*0.15,
          PVmin=0,
          PVmax=1,
          Kv=6.9888689915e-7/0.2,
          PVstart=0.1,
          CSstart=0.2,
          nominalDrainFlow=0,
          des_FW(hstart={1.268e6,1.28171e6,1.34722e6}),
          cond_FW(hstart={1.02902e6,1.20014e6,1.268e6}),
          sub_FW(hstart={979187,985072,994215,1.00820e6,1.02902e6}),
          des_SP(hstart={3.231e6,2.83893e6,2.75687e6}),
          sub_SP(hstart={1.32571e6,1.20114e6,1.11741e6,1.06269e6,1.02747e6}),
          CSmin=0.05,
          Ti=10,
          nominalColdPressure=17630000,
          nominalHotPressure=8181000,
          nominalColdInletTemperature_des=557.15,
          nominalColdOutletTemperature_des=572.15,
          nominalHotInletTemperature_des=707.15,
          nominalHotOutletTemperature_des=570.15,
          p_start=8181000,
          nominalColdInletTemperature_cond=547.15,
          nominalColdOutletTemperature_cond=561.15,
          nominalColdInletTemperature_sub=499.45,
          nominalColdOutletTemperature_sub=510.15,
          nominalHotInletTemperature_sub=569.65,
          nominalHotOutletTemperature_sub=504.15,
          Kp=-169)
          annotation (Placement(transformation(extent={{-70,-20},{-30,20}})));

        HeatExchangers.FeedwaterTrain.Old.HPH_controlledLevel HPH1(
          Vcold_des=0.53*0.1,
          A=1,
          zl_set=0.1,
          zl_start=0.1,
          cm=500,
          Td=0,
          Ta=0.3,
          Nd=20,
          CSmax=1,
          Nhex_des=3,
          Nhex_cond=3,
          redeclare model HeatTransferCold_des =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=4000),
          Vhot_des=2.01*0.1,
          Vhot_cond=2.01*0.8,
          gamma=8000,
          redeclare model HeatTransferCold_cond =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=4000),
          Vcold_cond=0.53*0.8,
          Mm_cond=7500*0.8,
          redeclare model HeatTransferCold_sub =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=4000),
          Nhex_sub=5,
          PVmin=0,
          PVmax=1,
          PVstart=0.1,
          CSstart=0.2,
          nominalColdFlow=91.28,
          nominalHotFlow=3.034,
          nominalDrainFlow=4.449,
          nominalColdDeltaP=0,
          nominalHotDeltaP=0,
          redeclare model HeatTransferHot_des =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=2000),
          Shot_des=300*0.08,
          Scold_des=300*0.08,
          Mm_des=7500*0.1,
          Shot_cond=300*0.8,
          Scold_cond=300*0.8,
          redeclare model HeatTransferHot_sub =
              ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
              (alpha=0.8, gamma_nom=5000),
          Vhot_sub=2.01*0.05,
          Vcold_sub=0.53*0.05,
          Shot_sub=300*0.05,
          Scold_sub=300*0.05,
          Mm_sub=7500*0.05,
          Kv=1.026611797e-5/0.2,
          des_FW(hstart={876813,877436,895998}),
          cond_FW(hstart={807696,856039,876813}),
          sub_FW(hstart={803100,803886,804877,806125,807696}),
          des_SP(hstart={3.281e6,2.73749e6,2.71925e6}),
          CSmin=0.05,
          sub_SP(hstart={878793,855666,836808,821450,808952}),
          Ti=10,
          nominalColdPressure=17630000,
          nominalHotPressure=1815000,
          nominalColdInletTemperature_des=477.15,
          nominalColdOutletTemperature_des=480.85,
          nominalHotInletTemperature_des=686.65,
          nominalHotOutletTemperature_des=480.75,
          p_start=1815000,
          nominalColdInletTemperature_cond=461.55,
          nominalColdOutletTemperature_cond=477.15,
          nominalColdInletTemperature_sub=460.35,
          nominalColdOutletTemperature_sub=461.55,
          nominalHotInletTemperature_sub=480.65,
          nominalHotOutletTemperature_sub=466.35,
          Kp=-100)
          annotation (Placement(transformation(extent={{70,-20},{110,20}})));
        Graphics.Label_input valveBP_CS
          annotation (Placement(transformation(extent={{-98,-66},{-66,-54}})));
        Graphics.Label_input pumpFW_CS
          annotation (Placement(transformation(extent={{116,-20},{148,-8}})));
        Graphics.Label_input pumpHPH_CS
          annotation (Placement(transformation(extent={{80,-66},{42,-54}})));
        Label_flange_output label_flange(flowName=FEEDWATER, from_to=TO_OTSG)
          annotation (Placement(transformation(extent={{-200,-8},{-240,8}})));
        Label_flange_input label_flange2(flowName=SATURATED_LIQUID, from_to=
              FROM_SEPARATOR) annotation (Placement(transformation(extent={{
                  -188,132},{-132,148}})));
        Label_flange_input label_flange1(flowName=EXTRACTION, from_to=
              FROM_TURBINE)
          annotation (Placement(transformation(extent={{16,132},{-40,148}})));
        Label_flange_input label_flange3(flowName=EXTRACTION, from_to=
              FROM_TURBINE)
          annotation (Placement(transformation(extent={{156,132},{100,148}})));
        Label_flange_output label_flange4(from_to=TO_DEAERATOR, flowName=
              DRAINED_EXTR)
          annotation (Placement(transformation(extent={{200,-48},{252,-32}})));
        Label_flange_input label_flange5(flowName=FEEDWATER, from_to=
              FROM_DEAERATOR)
          annotation (Placement(transformation(extent={{272,-8},{212,8}})));
        Label_flange_input label_flange6(flowName=FEEDWATER, from_to=FROM_OTSG)
          annotation (Placement(transformation(extent={{86,-148},{30,-132}})));
      equation
        connect(pumpHPH.outlet, flowJoin.in2) annotation (Line(
            points={{20,-46},{20,-16},{20,-8}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(SEP_in, sensT.inlet) annotation (Line(
            points={{-120,110},{-120,0},{-140,0}},
            color={0,0,255},
            thickness=0.5));
        connect(sensT.outlet, FW_out) annotation (Line(
            points={{-152,0},{-190,0}},
            color={0,0,255},
            thickness=0.5));
        connect(valveBP.inlet, flowJoin.out) annotation (Line(
            points={{-40,-48},{0,-48},{0,-4},{8,-4}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(valveBP.outlet, sensT.inlet) annotation (Line(
            points={{-60,-48},{-120,-48},{-120,0},{-140,0}},
            color={0,0,255},
            thickness=0.5));
        connect(flowJoin.in1, DPSteamHPH1.outlet) annotation (Line(
            points={{20,0},{32,0}},
            color={0,0,255},
            thickness=0.5));
        connect(DPSteamHPH2.outlet, sensT.inlet) annotation (Line(
            points={{-100,0},{-140,0}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(signalBus.pumpHPH_CS, pumpHPH.in_w0) annotation (Line(
            points={{90,-98},{90,-76},{28,-76},{28,-60},{26,-60}},
            color={256,256,256},
            thickness=0.5));
        connect(FW_in, pumpFW.inlet) annotation (Line(
            points={{190,0},{170,0}},
            color={0,0,255},
            thickness=0.5));

        connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
            points={{90,-98},{162,-98},{162,-20},{172,-20},{176,-20},{176,-8},{
                164,-8},{164,-6}},
            color={255,255,255},
            thickness=0.5));
        connect(SP1, HPH2.ST_in) annotation (Line(points={{-50,110},{-50,110},
                {-50,20}}, color={0,127,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(sourceMassFlow_DR.flange, HPH2.DR_in) annotation (Line(points=
               {{-80,40},{-72,40},{-64,40},{-64,20}}, color={0,127,0},
            thickness=0.5));
        connect(HPH2.DR_out, HPH1.DR_in) annotation (Line(points={{-50,-20},{
                -50,-30},{-10,-30},{-10,40},{76,40},{76,20}}, color={0,127,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));

        connect(SP2, HPH1.ST_in) annotation (Line(points={{90,110},{90,20}},
                         color={0,127,0},
            thickness=0.5,
            arrow={Arrow.None,Arrow.Filled}));
        connect(HPH1.DR_out, DR_out) annotation (Line(points={{90,-20},{90,
                -40},{190,-40}}, color={0,127,0},
            thickness=0.5));
        connect(HPH1.FW_in, pumpFW.outlet) annotation (Line(
            points={{112,0},{150,0}},
            color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(DPSteamHPH1.inlet, HPH1.FW_out)
          annotation (Line(points={{52,0},{70,0}},        color={0,0,255},
            thickness=0.5));
        connect(HPH2.FW_in, flowJoin.out) annotation (Line(points={{-28,0},{0,
                0},{0,-4},{8,-4}}, color={0,0,255},
            thickness=0.5,
            arrow={Arrow.Filled,Arrow.None}));
        connect(DPSteamHPH2.inlet, HPH2.FW_out) annotation (Line(points={{-80,
                0},{-75,0},{-70,0}}, color={0,0,255},
            thickness=0.5));
        connect(signalBus.valveBP_CS, valveBP.theta) annotation (Line(
            points={{90,-98},{90,-98},{108,-98},{18,-98},{18,-78},{-44,-78},{
                -44,-56},{-50,-56}},
            color={256,256,256},
            thickness=0.5));
        connect(pumpHPH.inlet, MS_HPH_in) annotation (Line(
            points={{20,-66},{20,-86},{20,-110}},
            color={0,0,255},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                  -100},{180,100}}), graphics={Line(
                points={{-50,-58},{-50,-60}},
                color={0,0,0},
                thickness=0.5), Line(
                points={{164,-8},{164,-14}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-120,140},{-120,120}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-50,140},{-50,120}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{90,140},{90,120}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{20,-120},{20,-140}},
                color={0,0,0},
                thickness=0.5)}));
      end HPH_train_controlledLevel_100;

      model turbine_group "Global turbine model (for imaging purposes)"

        SteamTurbine.Corps.HPT HPTurbine(w_seal=0.022)
          annotation (Placement(transformation(extent={{-122,0},{-82,40}})));
        SteamTurbine.Corps.IPT IPTurbine
          annotation (Placement(transformation(extent={{-70,0},{-28,40}})));
        SteamTurbine.Corps.LPT LPTurbine(w_seal_1=0.0182, w_seal_2=0.0076)
          annotation (Placement(transformation(extent={{-12,0},{30,40}})));
        Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
          annotation (Placement(transformation(extent={{120,10},{100,30}})));
        Modelica.Electrical.Machines.Sensors.MechanicalPowerSensor
          mechanicalPowerSensor
          annotation (Placement(transformation(extent={{70,10},{90,30}})));
        Graphics.Label_input pumpMS_PV
          annotation (Placement(transformation(extent={{44,36},{68,28}})));
        Label_flange_output label_flange6(flowName=COLD_RH_STEAM, from_to=
              TO_OTSG)
          annotation (Placement(transformation(extent={{-124,-14},{-146,-8}})));
        Label_flange_output label_flange1(flowName=EXTRACTION, from_to=TO_HPH2)
          annotation (Placement(transformation(extent={{-102,-26},{-124,-20}})));
        Label_flange_output label_flange2(flowName=EXTRACTION, from_to=TO_HPH1)
          annotation (Placement(transformation(extent={{-56,-26},{-78,-20}})));
        Label_flange_output label_flange3(flowName=EXTRACTION, from_to=
              TO_DEAERATOR)
          annotation (Placement(transformation(extent={{-46,-40},{-68,-34}})));
        Label_flange_output label_flange4(flowName=EXTRACTION, from_to=TO_LPH3)
          annotation (Placement(transformation(extent={{-36,-54},{-58,-48}})));
        Label_flange_output label_flange5(flowName=EXTRACTION, from_to=TO_LPH2)
          annotation (Placement(transformation(extent={{-2,-26},{-24,-20}})));
        Label_flange_output label_flange7(flowName=EXTRACTION, from_to=TO_LPH1)
          annotation (Placement(transformation(extent={{12,-40},{-10,-34}})));
        Label_flange_output label_flange8(flowName=STEAM, from_to=TO_CONDENSER)
          annotation (Placement(transformation(extent={{32,60},{54,66}})));
        Label_flange_input label_flange9(flowName=LIVE_STEAM, from_to=FROM_OTSG)
          annotation (Placement(transformation(extent={{-148,60},{-128,66}})));
        Label_flange_input label_flange10(from_to=FROM_OTSG, flowName=
              HOT_RH_STEAM)
          annotation (Placement(transformation(extent={{-96,60},{-76,66}})));
      equation
        connect(HPTurbine.flange_HP_out, IPTurbine.flange_IP_in) annotation (Line(
            points={{-80,20},{-72.1,20}},
            color={0,0,0},
            thickness=0.5));
        connect(IPTurbine.flange_IP_out, LPTurbine.flange_LP_in) annotation (Line(
            points={{-25.9,20},{-14.1,20}},
            color={0,0,0},
            thickness=0.5));
        connect(IPTurbine.vap_out, LPTurbine.vap_in) annotation (Line(
            points={{-25.9,32},{-14.1,32}},
            color={0,0,255},
            thickness=0.5));
        connect(LPTurbine.flange_LP_out, mechanicalPowerSensor.flange_a)
          annotation (Line(
            points={{32.1,20},{70,20}},
            color={0,0,0},
            thickness=0.5));
        connect(mechanicalPowerSensor.flange_b, constantSpeed.flange)
          annotation (Line(
            points={{90,20},{90,20},{100,20}},
            color={0,0,0},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                  -100},{140,100}}), graphics={
              Line(
                points={{-124,2},{-124,-14}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-102,-4},{-102,-26}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-56,-4},{-56,-26}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-46,-4},{-46,-40}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-36,-4},{-36,-54}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-2,-4},{-2,-26}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{12,-4},{12,-40}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{32,32},{32,66}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-124,64},{-124,34}},
                color={0,0,0},
                thickness=0.5),
              Line(
                points={{-72,64},{-72,34}},
                color={0,0,0},
                thickness=0.5)}),                    Icon(coordinateSystem(extent=
                 {{-180,-100},{140,100}})));
      end turbine_group;

      block Label_input "Simple block to tag the input of the model"

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{100,24},{140,0},{100,-24},{100,24}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,40},{100,-40}},
                lineColor={0,0,0},
                fillColor={215,253,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-142,20},{148,-20}},
                lineColor={0,0,0},
                textString="%name"),
              Line(
                points={{140,0},{200,0}},
                color={0,0,0},
                thickness=0.5)}),       Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_input;

      block Label_output "Simple block to tag the output of the model"

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Rectangle(
                extent={{-100,40},{100,-40}},
                lineColor={0,0,0},
                fillColor={215,253,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-146,22},{144,-18}},
                lineColor={0,0,0},
                textString="%name"),
              Polygon(
                points={{-140,24},{-100,0},{-140,-24},{-140,24}},
                lineColor={0,0,0},
                fillColor={0,0,127},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-200,0},{-140,0}},
                color={0,0,0},
                thickness=0.5)}),       Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_output;

      block Label_flange_input "Simple block to tag the flanges of the model"

        parameter string flowName;
        parameter string from_to;

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{-100,40},{100,40},{140,0},{100,-40},{-100,-40},{-100,40}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-94,36},{100,0}},
                lineColor={0,0,0},
                textString="%flowName"),
              Text(
                extent={{-94,-4},{100,-40}},
                lineColor={0,0,0},
                textString="%from_to")}),  Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_flange_input;

      block Label_flange_output "Simple block to tag the flanges of the model"

        parameter string flowName;
        parameter string from_to;

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{-100,40},{100,40},{140,0},{100,-40},{-100,-40},{-100,40}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-94,36},{100,0}},
                lineColor={0,0,0},
                textString="%flowName"),
              Text(
                extent={{-94,-4},{100,-40}},
                lineColor={0,0,0},
                textString="%from_to")}),  Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_flange_output;

      model staticDecoupled_4th
        "Control schemes with a static decoupler between molten salt and water mass flow rate and a 4th order controller on wFW"
        extends Control.Schemes.BaseClasses.BasePowerPressureController;

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));
        parameter Real dec_wMS_wFW
          "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
        parameter Real dec_wFW_wMS
          "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

        //-- pumpMS --
        parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
        parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        //-- pumpMS_low --
        parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_low
          "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_low
          "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Real Nd_pumpMS_low
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Real CSmin_pumpMS_low
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Real CSmax_pumpMS_low
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
        parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

        //-- valveTURB --
        parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
        parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant" annotation (Dialog(tab="valveTURB"));

        //-- valveTURB_high
        parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_valveTURB_high
          "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_valveTURB_high
          "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Real Nd_valveTURB_high
          "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Real CSmin_valveTURB_high
          "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Real CSmax_valveTURB_high
          "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
        parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

        //-- valveTURB_low
        parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Modelica.SIunits.Time Ti_valveTURB_low
          "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Modelica.SIunits.Time Td_valveTURB_low
          "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Real Nd_valveTURB_low
          "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Real CSmin_valveTURB_low
          "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Real CSmax_valveTURB_low
          "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
        parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

        parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
        parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

        //-- pumpFW_high --
        parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
          "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                            annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

        //-- pumpFW_low --
        parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real Kp_pumpFW_low "Controller proportional gain"
                                         annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Modelica.SIunits.Time Ti_pumpFW_low
          "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Modelica.SIunits.Time Td_pumpFW_low
          "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real Nd_pumpFW_low
          "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real CSstart_pumpFW_low "Start value of CS"
                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
        parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

        Control.Schemes.SingleControllers.control_wMS_high control_wMS_high(
          load_switch=load_switch,
          Kp_pumpMS_high=Kp_pumpMS_high,
          Ti_pumpMS_high=Ti_pumpMS_high,
          Td_pumpMS_high=Td_pumpMS_high,
          Nd_pumpMS_high=Nd_pumpMS_high,
          CSmin_pumpMS_high=CSmin_pumpMS_high,
          CSmax_pumpMS_high=CSmax_pumpMS_high,
          CSstart_pumpMS_high=CSstart_pumpMS_high,
          TS_pumpMS_high=TS_pumpMS_high) annotation (Placement(transformation(
                extent={{-160,190},{-100,250}})));
        Control.Schemes.SingleControllers.control_wMS_low control_wMS_low(
          load_switch=load_switch,
          Kp_pumpMS_low=Kp_pumpMS_low,
          Ti_pumpMS_low=Ti_pumpMS_low,
          Td_pumpMS_low=Td_pumpMS_low,
          Nd_pumpMS_low=Nd_pumpMS_low,
          CSmin_pumpMS_low=CSmin_pumpMS_low,
          CSmax_pumpMS_low=CSmax_pumpMS_low,
          CSstart_pumpMS_low=CSstart_pumpMS_low,
          TS_pumpMS_low=TS_pumpMS_low) annotation (Placement(transformation(
                extent={{-160,310},{-100,370}})));
        Control.Schemes.SingleControllers.control_Yt_high control_Yt_high(
          load_switch=load_switch,
          Kp_valveTURB_high=Kp_valveTURB_high,
          Ti_valveTURB_high=Ti_valveTURB_high,
          Td_valveTURB_high=Td_valveTURB_high,
          Nd_valveTURB_high=Nd_valveTURB_high,
          CSmin_valveTURB_high=CSmin_valveTURB_high,
          CSmax_valveTURB_high=CSmax_valveTURB_high,
          CSstart_valveTURB_high=CSstart_valveTURB_high,
          TS_valveTURB_high=TS_valveTURB_high) annotation (Placement(
              transformation(extent={{-160,-250},{-100,-190}})));
        Control.Schemes.SingleControllers.control_Yt_low control_Yt_low(
          load_switch=load_switch,
          Kp_valveTURB_low=Kp_valveTURB_low,
          Ti_valveTURB_low=Ti_valveTURB_low,
          Td_valveTURB_low=Td_valveTURB_low,
          Nd_valveTURB_low=Nd_valveTURB_low,
          CSmin_valveTURB_low=CSmin_valveTURB_low,
          CSmax_valveTURB_low=CSmax_valveTURB_low,
          CSstart_valveTURB_low=CSstart_valveTURB_low,
          TS_valveTURB_low=TS_valveTURB_low) annotation (Placement(
              transformation(extent={{-160,-370},{-100,-310}})));
        Control.Schemes.SingleControllers.control_wFW_high_4th control_wFW_high_4th(
          load_switch=load_switch,
          DT_sh_sp=DT_sh_sp,
          CSmin_pumpFW_high=CSmin_pumpFW_high,
          CSmax_pumpFW_high=CSmax_pumpFW_high,
          TS_pumpFW_high=TS_pumpFW_high,
          A=A,
          B=B,
          C=C,
          D=D)
          annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
        Control.Schemes.SingleControllers.control_wFW_low control_wFW_low(
          load_switch=load_switch,
          l_sp=l_sp,
          Kp_pumpFW_low=Kp_pumpFW_low,
          Ti_pumpFW_low=Ti_pumpFW_low,
          Td_pumpFW_low=Td_pumpFW_low,
          Nd_pumpFW_low=Nd_pumpFW_low,
          CSmin_pumpFW_low=CSmin_pumpFW_low,
          CSmax_pumpFW_low=CSmax_pumpFW_low,
          CSstart_pumpFW_low=CSstart_pumpFW_low,
          TS_pumpFW_low=TS_pumpFW_low) annotation (Placement(transformation(
                extent={{-160,-110},{-100,-50}})));
        Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
             load_switch)
          annotation (Placement(transformation(extent={{-84,-14},{-56,14}})));
        Modelica.Blocks.Logical.Switch switch_MS
          annotation (Placement(transformation(extent={{36,314},{64,286}})));
        Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
          annotation (Placement(transformation(extent={{112,286},{140,314}})));
       Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
          initType=Modelica.Blocks.Types.Init.SteadyState,
          k=actuatorGain_pumpMS,
          T=Ta_pumpMS)
               annotation (Placement(transformation(
              extent={{20,20},{-20,-20}},
              rotation=180,
              origin={220,300})));
        Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-112,140})));
        Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=90,
              origin={-148,162})));
        Modelica.Blocks.Logical.Switch switch_FW
          annotation (Placement(transformation(extent={{36,-14},{64,14}})));
        Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
          annotation (Placement(transformation(extent={{112,-14},{140,14}})));
       Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
          initType=Modelica.Blocks.Types.Init.SteadyState,
          k=actuatorGain_pumpFW,
          T=Ta_pumpFW) annotation (Placement(transformation(
              extent={{20,20},{-20,-20}},
              rotation=180,
              origin={220,0})));
        Modelica.Blocks.Logical.Switch switch_Yt
          annotation (Placement(transformation(extent={{36,-274},{64,-246}})));
        Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[0,0; 1.65313474553841e-06,0.0461462289094925;
              1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
              0.095238097012043; 4.01654733650503e-06,0.142857149243355;
              4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
              0.238095238804817; 4.77075400340254e-06,0.28571429848671;
              4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
              0.380952388048172; 4.93748166263686e-06,0.428571432828903;
              4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
              0.523809552192688; 4.99799261888256e-06,0.571428596973419;
              5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
              0.666666686534882; 5.02638295074576e-06,0.714285731315613;
              5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
              0.809523820877075; 5.04190666106297e-06,0.857142865657806;
              5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
              0.952380955219269; 5.05130128658493e-06,1])
          annotation (Placement(transformation(extent={{96,-274},{124,-246}})));
        Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
          annotation (Placement(transformation(extent={{146,-274},{174,-246}})));
        Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
          initType=Modelica.Blocks.Types.Init.SteadyState,
          k=actuatorGain_valveTURB,
          T=Ta_valveTURB)
          annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
        Label_input pumpMS_PV annotation (Placement(transformation(extent={{
                  -268,348},{-200,332}})));
        Label_input pumpMS_PV1 annotation (Placement(transformation(extent={{
                  -268,228},{-200,212}})));
        Label_input pumpMS_PV_high
          annotation (Placement(transformation(extent={{-268,88},{-200,72}})));
        Label_input pumpMS_PV_low annotation (Placement(transformation(extent={
                  {-268,-72},{-200,-88}})));
        Label_input valveTURB_PV annotation (Placement(transformation(extent={{
                  -268,-212},{-200,-228}})));
        Label_input valveTURB_PV1 annotation (Placement(transformation(extent={
                  {-268,-332},{-200,-348}})));
        Label_output pumpMS_CS
          annotation (Placement(transformation(extent={{274,292},{340,308}})));
        Label_output pumpFW_CS
          annotation (Placement(transformation(extent={{274,-8},{340,8}})));
        Label_output valveTURB_CS annotation (Placement(transformation(extent={
                  {274,-268},{340,-252}})));
      equation
        connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,
                340},{0,340},{0,311.2},{33.2,311.2}},
                                           color={0,127,0},
            thickness=0.5));
        connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,
                220},{-50,220},{0,220},{0,288.8},{33.2,288.8}},
                                                     color={0,127,0},
            thickness=0.5));
        connect(switch_MS.y, pumpMS_lim.u)
          annotation (Line(points={{65.4,300},{65.4,300},{109.2,300}},
                                                                 color={0,127,0},
            thickness=0.5));

        connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141.4,
                300},{160,300},{160,390},{-115,390},{-115,373}},
                                                           color={0,0,127},
            thickness=0.5,
            pattern=LinePattern.Dash));
        connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141.4,
                300},{160,300},{160,270},{-115,270},{-115,253}},
                                                            color={0,0,127},
            thickness=0.5,
            pattern=LinePattern.Dash));
        connect(control_wFW_high_4th.dec_out, gamma_FW_MS.u) annotation (Line(points={
                {-112,111.5},{-112,111.5},{-112,128}}, color={0,0,127}));
        connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
        connect(gamma_MS_FW.y, control_wFW_high_4th.dec_in)
          annotation (Line(points={{-148,151},{-148,113}}, color={0,0,127}));
        connect(gamma_FW_MS.y, control_wMS_high.dec_in)
          annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
        connect(switch_FW.y, pumpFW_lim.u)
          annotation (Line(points={{65.4,1.77636e-015},{90,1.77636e-015},{109.2,
                1.77636e-015}},                     color={0,127,0},
            thickness=0.5));
        connect(pumpFW_lim.y, control_wFW_high_4th.TS) annotation (Line(points={{141.4,
                1.77636e-015},{160,1.77636e-015},{160,30},{-115,30},{-115,47}},
                                                       color={0,0,127},
            thickness=0.5,
            pattern=LinePattern.Dash));
        connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141.4,
                1.77636e-015},{160,1.77636e-015},{160,-30},{-115,-30},{-115,-47}},
                                                     color={0,0,127},
            thickness=0.5,
            pattern=LinePattern.Dash));
        connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-54.6,
                1.77636e-015},{-40,1.77636e-015},{-40,300},{33.2,300}},
                                             color={255,0,255},
            thickness=0.5));
        connect(greaterEqualThreshold.y, switch_FW.u2)
          annotation (Line(points={{-54.6,1.77636e-015},{33.2,1.77636e-015}},
                                                    color={255,0,255},
            thickness=0.5));
        connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{175.4,
                -260},{175.4,-260},{196,-260}},
                                        color={0,127,0},
            thickness=0.5));
        connect(control_wFW_high_4th.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                80},{0,80},{0,11.2},{33.2,11.2}},
                                          color={0,127,0},
            thickness=0.5));
        connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,
                -80},{0,-80},{0,-11.2},{33.2,-11.2}},
                                         color={0,127,0},
            thickness=0.5));
        connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,
                -220},{-50,-220},{0,-220},{0,-248.8},{33.2,-248.8}},
                                                         color={0,127,0},
            thickness=0.5));
        connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,
                -340},{-48,-340},{0,-340},{0,-271.2},{33.2,-271.2}},
                                                         color={0,127,0},
            thickness=0.5));
        connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-54.6,
                1.77636e-015},{-40,1.77636e-015},{-40,-260},{33.2,-260}},
                                               color={255,0,255},
            thickness=0.5));
        connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{125.4,
                -260},{125.4,-260},{143.2,-260}},
                                              color={0,127,0},
            thickness=0.5));
        connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{65.4,
                -260},{80,-260},{80,-170},{-115,-170},{-115,-187}},
                                                          color={0,0,127},
            thickness=0.5,
            pattern=LinePattern.Dash));
        connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{65.4,
                -260},{80,-260},{80,-290},{-115,-290},{-115,-307}},
                                                          color={0,0,127},
            pattern=LinePattern.Dash,
            thickness=0.5));
        connect(load, greaterEqualThreshold.u)
          annotation (Line(points={{-330,0},{-228,0},{-228,1.77636e-015},{-86.8,
                1.77636e-015}},                       color={0,0,127},
            thickness=0.5));
        connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{
                -280,0},{-280,361},{-163,361}},
                                        color={0,0,127},
            thickness=0.5));
        connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},
                {-280,0},{-280,241},{-163,241}},
                                        color={0,0,127},
            thickness=0.5));
        connect(load, control_wFW_high_4th.load) annotation (Line(points={{-330,0},
                {-280,0},{-280,59},{-163,59}},
                                         color={0,0,127},
            thickness=0.5));
        connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{
                -280,0},{-280,-62},{-163,-62}},
                                        color={0,0,127},
            thickness=0.5));
        connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{
                -280,0},{-280,-199},{-163,-199}},
                                          color={0,0,127},
            thickness=0.5));
        connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{
                -280,0},{-280,-319},{-163,-319}},
                                          color={0,0,127},
            thickness=0.5));
        connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
              points={{-200,390},{-145,390},{-145,373}}, color={255,0,255},
            thickness=0.5));
        connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
              points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={255,0,
                255},
            thickness=0.5));
        connect(TS_pumpFWhigh_bool, control_wFW_high_4th.TS_pumpFWhigh_bool)
          annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,
                255},
            thickness=0.5));
        connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
            Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255},
            thickness=0.5));
        connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
          annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                255},
            thickness=0.5));
        connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
          annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                255},
            thickness=0.5));
        connect(pumpMS_lim.y, pumpMS_dynamic.u) annotation (Line(
            points={{141.4,300},{141.4,300},{196,300}},
            color={0,127,0},
            thickness=0.5));
        connect(pumpFW_lim.y, pumpFW_dynamic.u) annotation (Line(
            points={{141.4,1.77636e-015},{168,1.77636e-015},{168,0},{196,0}},
            color={0,127,0},
            thickness=0.5));
        connect(switch_Yt.y, table_Y_tTOtheta.u[1]) annotation (Line(
            points={{65.4,-260},{65.4,-260},{93.2,-260}},
            color={0,127,0},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}}),
              graphics={
              Text(
                extent={{160,44},{132,30}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold}),
              Text(
                extent={{160,-30},{132,-44}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold}),
              Text(
                extent={{80,-154},{52,-168}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold}),
              Text(
                extent={{80,-290},{52,-304}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold}),
              Text(
                extent={{160,404},{132,390}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold}),
              Text(
                extent={{160,270},{132,256}},
                lineColor={0,0,0},
                lineThickness=0.5,
                textString="TS",
                textStyle={TextStyle.Bold})}),                                 Icon(
              coordinateSystem(extent={{-400,-440},{400,440}})));
      end staticDecoupled_4th;

      model control_wMS_high "Model of the mechanical power controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
          AntiWindup=true,
          useTS=true,
          CSmin=CSmin_pumpMS_high,
          CSmax=CSmax_pumpMS_high,
          CS_start=CSstart_pumpMS_high,
          Kp=Kp_pumpMS_high,
          Ti=Ti_pumpMS_high,
          Td=Td_pumpMS_high,
          N=Nd_pumpMS_high) annotation (Placement(transformation(extent={{-80,
                  -120},{-40,-80}})));
        Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
          annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
        Modelica.Blocks.Math.Add add_high
          annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-220,58},{-180,98}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
              transformation(extent={{-120,20},{-80,60}}),iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_P_MEC(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
          annotation (Placement(transformation(extent={{-140,-90},{-120,-70}})));
        Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
              495.8; 90,557.8; 100,619.8]) annotation (Placement(transformation(
                extent={{-60,-160},{-40,-140}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,50},{220,90}}),
              iconTransformation(extent={{200,70},{220,90}})));
        Modelica.Blocks.Math.Add add_dec annotation (Placement(
              transformation(extent={{20,-104},{40,-84}})));
        Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=180,
              origin={32,-30}), iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={120,-220})));
        Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
              transformation(
              extent={{-10,10},{10,-10}},
              rotation=270,
              origin={0,-60})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-32,-40},{-12,-20}})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{-20,-20},{20,20}},
              rotation=0,
              origin={80,110}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,220})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,0})));
        Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,68},
                  {-140,88}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={150,70})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,70})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-22,40})));
        Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
              transformation(extent={{72,-110},{104,-78}}),
              iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-120,-210})));
        Label_input pumpMS_PV annotation (Placement(transformation(extent={{-140,
                  -96},{-100,-108}})));
      equation

        connect(table_P_MEC.y[1], PID_pumpMS_high.SP) annotation (Line(
            points={{-119,-80},{-120,-80},{-102,-80},{-90,-80},{-90,-88},{-76,
                -88}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_P_MEC.u[1]) annotation (Line(
            points={{-200,78},{-200,78},{-188,78},{-172,78},{-172,-80},{-142,
                -80}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_w_MS.u[1]) annotation (Line(
            points={{-200,78},{-172,78},{-172,-150},{-62,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(table_w_MS.y[1], add_high.u2) annotation (Line(
            points={{-39,-150},{78,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(add_dec.y, add_high.u1) annotation (Line(points={{41,-94},{60,
                -94},{60,-138},{78,-138}},
                                     color={0,0,127},
            thickness=0.5));
        connect(PID_pumpMS_high.CS, add_dec.u2) annotation (Line(points={{-42,
                -100},{0,-100},{18,-100}},             color={0,0,127},
            thickness=0.5));
        connect(switch_dec.y, add_dec.u1) annotation (Line(points={{0,-71},{0,
                -88},{18,-88}},     color={0,0,127},
            thickness=0.5));
        connect(const.y, switch_dec.u1) annotation (Line(points={{-11,-30},{-8,
                -30},{-8,-48}},    color={0,0,127},
            thickness=0.5));
        connect(dec_in, switch_dec.u3) annotation (Line(points={{32,-30},{8,-30},
                {8,-48}},          color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, or1.u2) annotation (Line(points={{-139,78},{
                -130,78},{-130,-8},{-82,-8}},
                            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-200,78},{-184,
                78},{-162,78}},                   color={0,0,127},
            thickness=0.5));
        connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-100,40},{-90,
                40},{-90,0},{-82,0}},           color={255,0,255},
            thickness=0.5));
        connect(or1.y, PID_pumpMS_high.TS) annotation (Line(points={{-59,0},{
                -52,0},{-52,-84}},         color={255,0,255},
            thickness=0.5));
        connect(or1.y, switch_dec.u2) annotation (Line(points={{-59,0},{0,0},{0,
                -48}},             color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-11,40},{-11,40},{2,40},{20,40},{20,70},{38,70}},
            color={255,0,255},
            thickness=0.5));
        connect(add_dec.y, dec_out) annotation (Line(points={{41,-94},{60,-94},
                {88,-94}},                 color={0,0,127},
            thickness=0.5));
        connect(pumpMS_TS_high.y, PID_pumpMS_high.TR) annotation (Line(
              points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127},
            thickness=0.5));
        connect(add_high.y, switch_ts.u3) annotation (Line(points={{101,-144},{
                120,-144},{120,62},{138,62}},          color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{161,70},{200,70}},
                                 color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,78},{-139,78},{38,78}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-100,40},{
                -100,40},{-34,40}},           color={255,0,255},
            thickness=0.5));
        connect(TS, switch_ts.u1) annotation (Line(points={{80,110},{120,110},{
                120,78},{138,78}},         color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,70},{80,70},{138,70}},
            color={255,0,255},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                  -200},{200,200}},
                              preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_MS_high

controller")}));
      end control_wMS_high;

      model control_wMS_low "Model of the mechanical power controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
          AntiWindup=true,
          useTS=true,
          CSmin=CSmin_pumpMS_high,
          CSmax=CSmax_pumpMS_high,
          CS_start=CSstart_pumpMS_high,
          Kp=Kp_pumpMS_high,
          Ti=Ti_pumpMS_high,
          Td=Td_pumpMS_high,
          N=Nd_pumpMS_high)
          annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
        Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
          annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
        Modelica.Blocks.Math.Add add_low
          annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-220,58},{-180,98}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
              transformation(extent={{-120,20},{-80,60}}),iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_P_MEC(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
          annotation (Placement(transformation(extent={{-140,-90},{-120,-70}})));
        Modelica.Blocks.Tables.CombiTable1D table_w_MS(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
              495.8; 90,557.8; 100,619.8]) annotation (Placement(transformation(
                extent={{-60,-160},{-40,-140}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,50},{220,90}}),
              iconTransformation(extent={{200,70},{220,90}})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{-20,-20},{20,20}},
              rotation=0,
              origin={80,110}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,220})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,0})));
        Modelica.Blocks.Logical.GreaterEqualThreshold
                                              lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,68},
                  {-140,88}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={150,70})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,70})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-22,40})));
        Label_input pumpMS_PV annotation (Placement(transformation(extent={{-140,
                  -96},{-100,-108}})));
      equation

        connect(table_P_MEC.y[1], PID_pumpMS_low.SP) annotation (Line(
            points={{-119,-80},{-120,-80},{-102,-80},{-90,-80},{-90,-88},{-76,
                -88}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_P_MEC.u[1]) annotation (Line(
            points={{-200,78},{-200,78},{-188,78},{-172,78},{-172,-80},{-142,
                -80}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_w_MS.u[1]) annotation (Line(
            points={{-200,78},{-172,78},{-172,-150},{-62,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(table_w_MS.y[1], add_low.u2) annotation (Line(
            points={{-39,-150},{78,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, or1.u2) annotation (Line(points={{-139,78},{
                -130,78},{-130,-8},{-82,-8}},
                            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-200,78},{-184,
                78},{-162,78}},                   color={0,0,127},
            thickness=0.5));
        connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-100,40},{-90,
                40},{-90,0},{-82,0}},           color={255,0,255},
            thickness=0.5));
        connect(or1.y, PID_pumpMS_low.TS) annotation (Line(
            points={{-59,0},{-52,0},{-52,-84}},
            color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-11,40},{-11,40},{2,40},{20,40},{20,70},{38,70}},
            color={255,0,255},
            thickness=0.5));
        connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(
            points={{-79,-50},{-60,-50},{-60,-84}},
            color={0,0,127},
            thickness=0.5));
        connect(add_low.y, switch_ts.u3) annotation (Line(
            points={{101,-144},{120,-144},{120,62},{138,62}},
            color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{161,70},{200,70}},
                                 color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,78},{-139,78},{38,78}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-100,40},{
                -100,40},{-34,40}},           color={255,0,255},
            thickness=0.5));
        connect(TS, switch_ts.u1) annotation (Line(points={{80,110},{120,110},{
                120,78},{138,78}},         color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,70},{80,70},{138,70}},
            color={255,0,255},
            thickness=0.5));
        connect(PID_pumpMS_low.CS, add_low.u1) annotation (Line(
            points={{-42,-100},{-12,-100},{20,-100},{20,-138},{78,-138}},
            color={0,0,127},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                  -200},{200,200}},
                              preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_MS_high

controller")}));
      end control_wMS_low;

      model control_Yt_high "Model of the mechanical power controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        IndustrialControlSystems.Controllers.PI PI_valveTURB_high(
          AntiWindup=true,
          useTS=true,
          CSmin=CSmin_pumpMS_high,
          CSmax=CSmax_pumpMS_high,
          CS_start=CSstart_pumpMS_high,
          Kp=Kp_pumpMS_high,
          Ti=Ti_pumpMS_high)
          annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
        Modelica.Blocks.Sources.Constant valveTURB_TS_high(k=TS_valveTURB_high)
          annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
        Modelica.Blocks.Math.Add add_high
          annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-220,58},{-180,98}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_valveTURB_high_bool
          annotation (Placement(transformation(extent={{-120,20},{-80,60}}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_P_eva(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
          annotation (Placement(transformation(extent={{-140,-90},{-120,-70}})));
        Modelica.Blocks.Tables.CombiTable1D table_Yt(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
              495.8; 90,557.8; 100,619.8]) annotation (Placement(transformation(
                extent={{-60,-160},{-40,-140}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,50},{220,90}}),
              iconTransformation(extent={{200,70},{220,90}})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{-20,-20},{20,20}},
              rotation=0,
              origin={80,110}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,220})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,0})));
        Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,68},
                  {-140,88}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={150,70})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,70})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-22,40})));
        Label_input valveTURB_PV annotation (Placement(transformation(extent={{
                  -140,-96},{-100,-108}})));
      equation

        connect(table_P_eva.y[1], PI_valveTURB_high.SP) annotation (Line(
            points={{-119,-80},{-120,-80},{-102,-80},{-90,-80},{-90,-88},{-76,
                -88}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_P_eva.u[1]) annotation (Line(
            points={{-200,78},{-200,78},{-188,78},{-172,78},{-172,-80},{-142,
                -80}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_Yt.u[1]) annotation (Line(
            points={{-200,78},{-172,78},{-172,-150},{-62,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(table_Yt.y[1], add_high.u2) annotation (Line(
            points={{-39,-150},{78,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, or1.u2) annotation (Line(points={{-139,78},{
                -130,78},{-130,-8},{-82,-8}},
                            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-200,78},{-184,
                78},{-162,78}},                   color={0,0,127},
            thickness=0.5));
        connect(TS_valveTURB_high_bool, or1.u1) annotation (Line(
            points={{-100,40},{-90,40},{-90,0},{-82,0}},
            color={255,0,255},
            thickness=0.5));
        connect(or1.y, PI_valveTURB_high.TS) annotation (Line(
            points={{-59,0},{-52,0},{-52,-84}},
            color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-11,40},{-11,40},{2,40},{20,40},{20,70},{38,70}},
            color={255,0,255},
            thickness=0.5));
        connect(valveTURB_TS_high.y, PI_valveTURB_high.TR) annotation (Line(
            points={{-79,-50},{-60,-50},{-60,-84}},
            color={0,0,127},
            thickness=0.5));
        connect(add_high.y, switch_ts.u3) annotation (Line(
            points={{101,-144},{120,-144},{120,62},{138,62}},
            color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{161,70},{200,70}},
                                 color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,78},{-139,78},{38,78}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_valveTURB_high_bool, not1.u) annotation (Line(
            points={{-100,40},{-100,40},{-34,40}},
            color={255,0,255},
            thickness=0.5));
        connect(TS, switch_ts.u1) annotation (Line(points={{80,110},{120,110},{
                120,78},{138,78}},         color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,70},{80,70},{138,70}},
            color={255,0,255},
            thickness=0.5));
        connect(PI_valveTURB_high.CS, add_high.u1) annotation (Line(
            points={{-42,-100},{-12,-100},{20,-100},{20,-138},{78,-138}},
            color={0,0,127},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                  -200},{200,200}},
                              preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_MS_high

controller")}));
      end control_Yt_high;

      model control_Yt_low "Model of the mechanical power controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        IndustrialControlSystems.Controllers.PI PI_valveTURB_low(
          AntiWindup=true,
          useTS=true,
          CSmin=CSmin_pumpMS_high,
          CSmax=CSmax_pumpMS_high,
          CS_start=CSstart_pumpMS_high,
          Kp=Kp_pumpMS_high,
          Ti=Ti_pumpMS_high)
          annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
        Modelica.Blocks.Sources.Constant valveTURB_TS_low(k=TS_valveTURB_low)
          annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
        Modelica.Blocks.Math.Add add_low
          annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-220,58},{-180,98}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_valveTURB_low_bool
          annotation (Placement(transformation(extent={{-120,20},{-80,60}}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_P_eva(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
          annotation (Placement(transformation(extent={{-140,-90},{-120,-70}})));
        Modelica.Blocks.Tables.CombiTable1D table_Yt(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,124; 30,185.9; 40,247.9; 50,309.9; 60,371.9; 70,433.9; 80,
              495.8; 90,557.8; 100,619.8]) annotation (Placement(transformation(
                extent={{-60,-160},{-40,-140}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,50},{220,90}}),
              iconTransformation(extent={{200,70},{220,90}})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{-20,-20},{20,20}},
              rotation=0,
              origin={80,110}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,220})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,0})));
        Modelica.Blocks.Logical.GreaterEqualThreshold
                                              lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,68},
                  {-140,88}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={150,70})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,70})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-22,40})));
        Label_input valveTURB_PV annotation (Placement(transformation(extent={{
                  -140,-96},{-100,-108}})));
      equation

        connect(table_P_eva.y[1], PI_valveTURB_low.SP) annotation (Line(
            points={{-119,-80},{-120,-80},{-102,-80},{-90,-80},{-90,-88},{-76,
                -88}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_P_eva.u[1]) annotation (Line(
            points={{-200,78},{-200,78},{-188,78},{-172,78},{-172,-80},{-142,
                -80}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_Yt.u[1]) annotation (Line(
            points={{-200,78},{-172,78},{-172,-150},{-62,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(table_Yt.y[1], add_low.u2) annotation (Line(
            points={{-39,-150},{78,-150}},
            color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, or1.u2) annotation (Line(points={{-139,78},{
                -130,78},{-130,-8},{-82,-8}},
                            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-200,78},{-184,
                78},{-162,78}},                   color={0,0,127},
            thickness=0.5));
        connect(TS_valveTURB_low_bool, or1.u1) annotation (Line(
            points={{-100,40},{-90,40},{-90,0},{-82,0}},
            color={255,0,255},
            thickness=0.5));
        connect(or1.y, PI_valveTURB_low.TS) annotation (Line(
            points={{-59,0},{-52,0},{-52,-84}},
            color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-11,40},{-11,40},{2,40},{20,40},{20,70},{38,70}},
            color={255,0,255},
            thickness=0.5));
        connect(valveTURB_TS_low.y, PI_valveTURB_low.TR) annotation (Line(
            points={{-79,-50},{-60,-50},{-60,-84}},
            color={0,0,127},
            thickness=0.5));
        connect(add_low.y, switch_ts.u3) annotation (Line(
            points={{101,-144},{120,-144},{120,62},{138,62}},
            color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{161,70},{200,70}},
                                 color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,78},{-139,78},{38,78}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_valveTURB_low_bool, not1.u) annotation (Line(
            points={{-100,40},{-100,40},{-34,40}},
            color={255,0,255},
            thickness=0.5));
        connect(TS, switch_ts.u1) annotation (Line(points={{80,110},{120,110},{
                120,78},{138,78}},         color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,70},{80,70},{138,70}},
            color={255,0,255},
            thickness=0.5));
        connect(PI_valveTURB_low.CS, add_low.u1) annotation (Line(
            points={{-42,-100},{-12,-100},{20,-100},{20,-138},{78,-138}},
            color={0,0,127},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                  -200},{200,200}},
                              preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_MS_high

controller")}));
      end control_Yt_low;

      model control_wFW_high_4th
        "Model of the w_FW controller for high load with 4th order controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpFW_high --
        parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
          "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
        parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-240,32},{-200,72}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
          annotation (Placement(transformation(extent={{-20,-30},{0,-10}})));
        Modelica.Blocks.Math.Product product
          annotation (Placement(transformation(extent={{88,-154},{108,-134}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{120,-174},{140,-154}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
            Placement(transformation(extent={{-120,86},{-80,126}}),
                                                                iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,17.67; 30,26.6369; 40,36.3719; 50,46.3832; 60,56.9897;
              70,65.503; 80,74.0789; 90,82.5593; 100,90.8672]) annotation (
            Placement(transformation(extent={{-40,-180},{-20,-160}})));
        Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
              transformation(
              extent={{-10,10},{10,-10}},
              rotation=270,
              origin={40,10})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{8,30},{28,50}})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,60})));
        Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,42},
                  {-140,62}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={162,130})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,130})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-30,106})));
        Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=180,
              origin={72,40}),  iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={-120,-220})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{80,150},{120,190}}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,210})));
        Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
              transformation(extent={{100,-56},{132,-24}}),
              iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={120,-210})));
        Modelica.Blocks.Math.Add add_dec_FW
          annotation (Placement(transformation(extent={{52,-50},{72,-30}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,110},{220,150}}),
              iconTransformation(extent={{200,-10},{220,10}})));
        Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
          annotation (Placement(transformation(extent={{-120,-150},{-100,-130}})));
        Modelica.Blocks.Continuous.StateSpace controller4th_pumpFW_high(
          A=A,
          B=B,
          C=C,
          D=D)
          annotation (Placement(transformation(extent={{-60,-120},{-20,-80}})));
        Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
            uMin=CSmin_pumpFW_high)
          annotation (Placement(transformation(extent={{-10,-110},{10,-90}})));
        Modelica.Blocks.Logical.Switch switch_TS
          annotation (Placement(transformation(extent={{26,-52},{38,-40}})));
        Modelica.Blocks.Logical.Switch switch_err annotation (Placement(
              transformation(
              extent={{-8,-8},{8,8}},
              rotation=0,
              origin={-80,-100})));
        Modelica.Blocks.Sources.Constant const1(
                                               k=0)
          annotation (Placement(transformation(extent={{-120,-80},{-100,-60}})));
        Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
              20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
              DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
          annotation (Placement(transformation(extent={{-160,-130},{-140,-110}})));
        Label_input pumpFW_PV_high annotation (Placement(transformation(extent=
                  {{-192,-140},{-144,-152}})));
      equation
        connect(product.y, add.u1) annotation (Line(points={{109,-144},{109,
                -144},{102,-144},{112,-144},{112,-158},{118,-158}},
                                      color={0,0,127},
            thickness=0.5));

        connect(table_w_FW.y[1], add.u2)
          annotation (Line(points={{-19,-170},{-19,-170},{28,-170},{80,-170},{
                118,-170}},                           color={0,0,127},
            thickness=0.5));
        connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-19,-170},
                {80,-170},{80,-150},{86,-150}},  color={0,0,127},
            thickness=0.5));
        connect(load, table_w_FW.u[1]) annotation (Line(points={{-220,52},{-200,
                52},{-200,-170},{-42,-170}},
                                         color={0,0,127},
            thickness=0.5));
        connect(const.y,switch_dec. u1) annotation (Line(points={{29,40},{32,40},
                {32,22}},          color={0,0,127},
            thickness=0.5));
        connect(dec_in,switch_dec. u3) annotation (Line(points={{72,40},{48,40},
                {48,22}},          color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y,or1. u2) annotation (Line(points={{-139,52},{
                -82,52}},   color={255,0,255},
            thickness=0.5));
        connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,60},{40,60},
                {40,22}},          color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-19,106},{-18,106},{0,106},{20,106},{20,130},{38,130}},
            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-220,52},{-220,
                52},{-172,52},{-162,52}},
                                       color={0,0,127},
            thickness=0.5));
        connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{40,-1},{
                40,-1},{40,-34},{50,-34}},   color={0,0,127},
            thickness=0.5));
        connect(add_dec_FW.y, product.u1)
          annotation (Line(points={{73,-40},{80,-40},{80,-138},{86,-138}},
                                                                color={0,0,127},
            thickness=0.5));

        connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-100,106},
                {-90,106},{-90,60},{-82,60}},
                                      color={255,0,255},
            thickness=0.5));
        connect(controller4th_pumpFW_high.y[1], pumpFW_lim_adim.u)
          annotation (Line(points={{-18,-100},{-18,-100},{-12,-100}},
                                                                  color={0,0,127},
            thickness=0.5));

        connect(add_dec_FW.y, dec_out) annotation (Line(points={{73,-40},{80,
                -40},{116,-40}}, color={0,0,127},
            thickness=0.5));
        connect(switch_TS.y, add_dec_FW.u2)
          annotation (Line(points={{38.6,-46},{50,-46}},          color={0,0,127},
            thickness=0.5));

        connect(pumpFW_lim_adim.y, switch_TS.u3) annotation (Line(points={{11,-100},
                {20,-100},{20,-50.8},{24.8,-50.8}},
                                               color={0,0,127},
            thickness=0.5));
        connect(or1.y, switch_TS.u2) annotation (Line(points={{-59,60},{-40,60},
                {-40,-46},{24.8,-46}},
                             color={255,0,255},
            thickness=0.5));
        connect(pumpFW_TS_high.y, switch_TS.u1) annotation (Line(points={{1,-20},
                {20,-20},{20,-41.2},{24.8,-41.2}},         color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{173,130},{173,130},{
                200,130}},                   color={0,0,127},
            thickness=0.5));
        connect(add.y, switch_ts.u3) annotation (Line(points={{141,-164},{144,
                -164},{144,122},{150,122}},     color={0,0,127},
            thickness=0.5));
        connect(switch_ts.u1, TS) annotation (Line(points={{150,138},{150,138},
                {146,138},{144,138},{144,170},{100,170}},
                       color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,130},{61,130},{150,130}},
            color={255,0,255},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,52},{-128,52},{-128,138},{-118,138},{38,138}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-100,106},
                {-100,106},{-42,106}},             color={255,0,255},
            thickness=0.5));
        connect(DT_sh_error.y, switch_err.u3) annotation (Line(points={{-99,
                -140},{-94,-140},{-94,-106.4},{-89.6,-106.4}},
                                                             color={0,0,127},
            thickness=0.5));
        connect(const1.y, switch_err.u1) annotation (Line(points={{-99,-70},{
                -94,-70},{-94,-93.6},{-89.6,-93.6}},  color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, switch_err.u2) annotation (Line(points={{-139,52},
                {-128,52},{-128,-100},{-89.6,-100}},
              color={255,0,255},
            thickness=0.5));
        connect(switch_err.y, controller4th_pumpFW_high.u[1]) annotation (
            Line(points={{-71.2,-100},{-71.2,-100},{-64,-100}},
              color={0,0,127},
            thickness=0.5));
        connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-220,52},{
                -200,52},{-200,-120},{-162,-120}},                   color={0,0,127},
            thickness=0.5));

        connect(table_DT_sh_sp.y[1], DT_sh_error.u1) annotation (Line(
              points={{-139,-120},{-128,-120},{-128,-134},{-122,-134}},
                                                            color={0,0,127},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                  {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_FW_high

controller")}));
      end control_wFW_high_4th;

      model control_wFW_low "Model of the mechanical power controller"

        //-- General settings --
        parameter Real load_switch
          "Plant load limit for switching from dry to wet separator configuration"
                                                                                   annotation (Dialog(tab="General"));

        //-- pumpMS_high --
        parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Ti_pumpMS_high
          "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Modelica.SIunits.Time Td_pumpMS_high
          "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real Nd_pumpMS_high
          "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmin_pumpMS_high
          "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSmax_pumpMS_high
          "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
        parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

        IndustrialControlSystems.Controllers.PI PI_pumpFW_low(
          AntiWindup=true,
          useTS=true,
          CSmin=CSmin_pumpMS_high,
          CSmax=CSmax_pumpMS_high,
          CS_start=CSstart_pumpMS_high,
          Kp=Kp_pumpMS_high,
          Ti=Ti_pumpMS_high)
          annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
        Modelica.Blocks.Sources.Constant pumpFW_TS_low(k=TS_pumpFW_low)
          annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
        Modelica.Blocks.Interfaces.RealInput load
          annotation (Placement(transformation(extent={{-220,58},{-180,98}}),
              iconTransformation(extent={{-240,120},{-200,160}})));
        Modelica.Blocks.Interfaces.BooleanInput TS_pumpFW_low_bool annotation (
            Placement(transformation(extent={{-120,20},{-80,60}}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={-100,220})));
        Modelica.Blocks.Tables.CombiTable1D table_l_sep(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
            table=[20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
              51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,82.3774e6])
          annotation (Placement(transformation(extent={{-140,-90},{-120,-70}})));
        Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
              transformation(extent={{180,50},{220,90}}),
              iconTransformation(extent={{200,70},{220,90}})));
        Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
              transformation(extent={{-20,-20},{20,20}},
              rotation=0,
              origin={80,110}),
              iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={100,220})));
        Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-70,0})));
        Modelica.Blocks.Logical.GreaterEqualThreshold
                                              lessThreshold(threshold=
              load_switch) annotation (Placement(transformation(extent={{-160,68},
                  {-140,88}})));
        Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={150,70})));
        Modelica.Blocks.Logical.And and1 annotation (Placement(transformation(
              extent={{-10,10},{10,-10}},
              rotation=0,
              origin={50,70})));
        Modelica.Blocks.Logical.Not not1 annotation (Placement(
              transformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-22,40})));
        Label_input pumpFW_PV_low annotation (Placement(transformation(extent={
                  {-146,-96},{-100,-108}})));
      equation

        connect(table_l_sep.y[1], PI_pumpFW_low.SP) annotation (Line(
            points={{-119,-80},{-120,-80},{-102,-80},{-90,-80},{-90,-88},{-76,
                -88}},
            color={0,0,127},
            thickness=0.5));
        connect(load, table_l_sep.u[1]) annotation (Line(
            points={{-200,78},{-200,78},{-188,78},{-172,78},{-172,-80},{-142,
                -80}},
            color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, or1.u2) annotation (Line(points={{-139,78},{
                -130,78},{-130,-8},{-82,-8}},
                            color={255,0,255},
            thickness=0.5));
        connect(load, lessThreshold.u) annotation (Line(points={{-200,78},{-184,
                78},{-162,78}},                   color={0,0,127},
            thickness=0.5));
        connect(TS_pumpFW_low_bool, or1.u1) annotation (Line(
            points={{-100,40},{-90,40},{-90,0},{-82,0}},
            color={255,0,255},
            thickness=0.5));
        connect(or1.y, PI_pumpFW_low.TS) annotation (Line(
            points={{-59,0},{-52,0},{-52,-84}},
            color={255,0,255},
            thickness=0.5));
        connect(not1.y, and1.u1) annotation (Line(
            points={{-11,40},{-11,40},{2,40},{20,40},{20,70},{38,70}},
            color={255,0,255},
            thickness=0.5));
        connect(pumpFW_TS_low.y, PI_pumpFW_low.TR) annotation (Line(
            points={{-79,-50},{-60,-50},{-60,-84}},
            color={0,0,127},
            thickness=0.5));
        connect(switch_ts.y, CS) annotation (Line(points={{161,70},{200,70}},
                                 color={0,0,127},
            thickness=0.5));
        connect(lessThreshold.y, and1.u2) annotation (Line(
            points={{-139,78},{-139,78},{38,78}},
            color={255,0,255},
            thickness=0.5));
        connect(TS_pumpFW_low_bool, not1.u) annotation (Line(
            points={{-100,40},{-100,40},{-34,40}},
            color={255,0,255},
            thickness=0.5));
        connect(TS, switch_ts.u1) annotation (Line(points={{80,110},{120,110},{
                120,78},{138,78}},         color={0,0,127},
            thickness=0.5));
        connect(and1.y, switch_ts.u2) annotation (Line(
            points={{61,70},{80,70},{138,70}},
            color={255,0,255},
            thickness=0.5));
        connect(PI_pumpFW_low.CS, switch_ts.u3) annotation (Line(
            points={{-42,-100},{120,-100},{120,62},{138,62}},
            color={0,0,127},
            thickness=0.5));
        annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                  -200},{200,200}},
                              preserveAspectRatio=false), graphics={Rectangle(
                extent={{-200,200},{200,-200}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                lineThickness=0.5), Text(
                extent={{-180,180},{180,-180}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="w_MS_high

controller")}));
      end control_wFW_low;
    end Graphics;
    annotation (Documentation(info="<html>
<p>The package structure is the following:</p>
<ol>
<li><i>HeatExchangers</i>: it contains the models of the full scale MS OTSG and preheaters, with the related test cases. There are also some custom plant component model, involved somehow in the heat exchange;</li>
<li><i>SteamTurbine: </i>it contains the models of the high, intermediate and low pressure turbine corps, with the related test cases;</li>
<li><i>Plants:</i> it contains the models of the complete or partial power plant, with specific test cases that evaluate the system performances in particular operating points and/or conditions;</li>
<li><i>Control</i>: it contains all the models related to the control systems;</li>
<li><i>Optimization: ...</i></li>
<li><i>Graphics: </i>it contains models used only for graphic purposes, such as the creation of model structure schemes via screenshots.</li>
</ol>
</html>"));
  end FullScale_245degC;

  package Pilot_245degC
    "Package containing the models regarding the pilot design with 245 degC as FW OTSG nominal inlet temperature"

    package HeatExchangers
      "Package including all the heat exchangers model (OTSG and preheating train)"
      package BaseClasses "Partial models of the heat exchangers"
        partial model BaseWaterMSHeatExchanger
          "Base model for water/steam-MS fluid heat exchanger"
          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA inletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,-110},{
                    10,-90}}, rotation=0)));
          ThermoPower.Water.FlangeB outletCold(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(extent={{-10,90},{10,
                    110}}, rotation=0)));
          ThermoPower.Water.FlangeA inletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{-110,-10},{
                    -90,10}}, rotation=0)));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(extent={{90,-10},{110,
                    10}}, rotation=0)));
          annotation (Icon(graphics={
                Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
                Line(points={{40,-82},{40,-24}}, color={135,135,135}),
                Line(points={{60,-60},{40,-24}}, color={135,135,135}),
                Line(points={{20,-60},{40,-24}}, color={135,135,135}),
                Line(points={{-48,0},{-74,-16}}, color={0,0,255}),
                Line(points={{-74,16},{-48,0}}, color={0,0,255}),
                Line(
                  points={{-92,0},{-40,0},{0,-60},{0,60},{40,0},{108,0}},
                  color={0,0,255},
                  thickness=0.5)}),
                                  Diagram(coordinateSystem(preserveAspectRatio=false,
                          extent={{-110,-110},{110,110}}),
                                          graphics));

        end BaseWaterMSHeatExchanger;

        partial model BaseOTSG "Base model of the OTSG "

          replaceable package coldMedium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              PreFlexMS.Media.MoltenSalt60_40_quad "MS fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA RH_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,170},{200,190}}),
                                              iconTransformation(extent={{180,210},
                    {200,230}})));
          ThermoPower.Water.FlangeA FW_in(redeclare package Medium = coldMedium)
                                                                                 annotation (Placement(transformation(
                  extent={{180,-220},{200,-200}}),
                                                iconTransformation(extent={{180,
                    -240},{200,-220}})));
          ThermoPower.Water.FlangeB RH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{90,300},{110,320}}), iconTransformation(extent={{10,300},
                    {30,320}})));
          ThermoPower.Water.FlangeB SH_out(redeclare package Medium = coldMedium)
                                                                                  annotation (Placement(transformation(
                  extent={{-10,300},{10,320}}),
                                              iconTransformation(extent={{90,300},
                    {110,320}})));
          ThermoPower.Water.FlangeA MS_in(redeclare package Medium = hotMedium)
                                                                                annotation (Placement(transformation(extent={{-110,
                    300},{-90,320}}),      iconTransformation(extent={{-110,300},
                    {-90,320}})));
          ThermoPower.Water.FlangeB MS_out(redeclare package Medium = hotMedium)
                                                                                 annotation (Placement(transformation(extent={{10,-320},
                    {30,-300}}),           iconTransformation(extent={{-110,-320},
                    {-90,-300}})));
          ThermoPower.Water.FlangeB SEP_out(redeclare package Medium = coldMedium)
                                                                                   annotation (Placement(transformation(extent={{180,-90},{200,-70}})));
        equation
          connect(FW_in, FW_in) annotation (Line(points={{190,-210},{185,-210},
                  {185,-210},{190,-210}}, color={0,0,255}));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-180,
                    -300},{180,300}}),      graphics={
                Rectangle(extent={{-180,300},{180,-300}}, lineColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  fillColor={255,255,255}),
                Line(
                  points={{192,-230},{20,-230},{20,-246},{0,-250},{40,-260},{20,
                      -270},{20,-286}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{20,-230},{20,-150},{0,-140},{40,-130},{20,-120},{20,
                      -100},{0,-90},{40,-80},{20,-72},{20,20},{80,20}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Rectangle(
                  extent={{80,54},{120,-26}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid,
                  radius=10),
                Rectangle(
                  extent={{86,18},{114,-20}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Rectangle(
                  extent={{86,48},{114,10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Line(
                  points={{100,54},{100,116},{80,128},{120,138},{100,148},{100,
                      228},{100,238},{100,298}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Ellipse(
                  extent={{90,-46},{110,-66}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{92,-50},{108,-50},{100,-66},{92,-50}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{100,-66},{100,-80},{180,-80}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{100,-26},{100,-38},{100,-46}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Line(
                  points={{94,220},{94,222},{96,224},{100,226},{104,224},{106,222},
                      {106,220},{178,220}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Text(
                  extent={{-44,248},{28,212}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="RH"),
                Line(
                  points={{94,220},{70,220},{60,240},{50,200},{40,220},{20,220},{
                      20,300}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{120,150},{174,114}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="SH"),
                Text(
                  extent={{-68,-68},{-8,-110}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="EVA"),
                Text(
                  extent={{-64,-120},{-6,-164}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="ECO"),
                Text(
                  extent={{-80,-218},{-8,-284}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="MS_HPH"),
                Line(
                  points={{-100,236},{-100,220},{-80,208},{-120,200},{-80,190},
                      {-120,180},{-80,170},{-100,160},{-100,-60},{-120,-70},{
                      -80,-80},{-120,-90},{-80,-100},{-120,-110},{-80,-120},{
                      -120,-130},{-80,-140},{-120,-150},{-80,-160},{-120,-172},
                      {-100,-180},{-100,-298}},
                  color={255,0,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-78,134},{66,20}},
                  lineColor={0,0,0},
                  textString="OTSG"),
                Polygon(
                  points={{-108,252},{-92,252},{-100,236},{-108,252}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Ellipse(
                  extent={{-110,256},{-90,236}},
                  lineColor={255,0,0},
                  lineThickness=0.5),
                Line(
                  points={{-100,256},{-100,300}},
                  color={255,0,0},
                  thickness=0.5),
                Rectangle(
                  extent={{106,-220},{122,-236}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{20,-286},{114,-286},{114,-286},{114,-236}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled})}),
                                         Diagram(coordinateSystem(extent={{-180,
                    -300},{180,300}},
                           preserveAspectRatio=false)));
        end BaseOTSG;

        model BaseWSC "Base model for water/steam cycle"

          replaceable package Medium =
              Modelica.Media.Water.WaterIF97_ph
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);

          ThermoPower.Water.FlangeA RH_in(
            redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-260,
                    230},{-240,250}}),    iconTransformation(extent={{-260,230},
                    {-240,250}})));
          ThermoPower.Water.FlangeA SH_in(
            redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-260,
                    130},{-240,150}}),      iconTransformation(extent={{-260,
                    130},{-240,150}})));
          ThermoPower.Water.FlangeB SH_out(
            redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-260,50},
                    {-240,70}}),           iconTransformation(extent={{-260,30},
                    {-240,50}})));
          ThermoPower.Water.FlangeB FW_out(
            redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-20,
                    -320},{0,-300}}),    iconTransformation(extent={{-20,-320},
                    {0,-300}})));
          ThermoPower.Water.FlangeA SEP_in(
            redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-260,
                    -140},{-240,-120}}),    iconTransformation(extent={{-260,
                    -226},{-240,-206}})));
        equation
          connect(SH_out, SH_out)
            annotation (Line(points={{-250,60},{-250,60}}, color={0,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-240,-300},{240,300}},
                  preserveAspectRatio=false,
                initialScale=0.1)),            Icon(coordinateSystem(extent={{-240,
                    -300},{240,300}}, preserveAspectRatio=false,
                initialScale=0.1),                                graphics={
                Rectangle(extent={{-240,300},{240,-300}}, lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-200,144},{-200,136},{-190,140},{-180,136},{-180,144},
                      {-190,140},{-200,144}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-190,140},{-190,150}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Polygon(
                  points={{-194,146},{-186,146},{-186,148},{-188,150},{-192,150},
                      {-194,148},{-194,146}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-130,244},{-130,236},{-120,240},{-110,236},{-110,244},
                      {-120,240},{-130,244}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-120,240},{-120,250}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Polygon(
                  points={{-124,246},{-116,246},{-116,248},{-118,250},{-122,250},
                      {-124,248},{-124,246}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-18,-208},{-2,-224}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-240,240},{-162,240},{-80,240}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-260,140},{-146,140},{-146,48}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{154,260},{220,220}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="to
condenser"),    Line(
                  points={{-64,240},{68,240},{150,240}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{27,56},{27,34},{27,-26}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled},
                  origin={-214,67},
                  rotation=270),
                Line(
                  points={{108,120},{50,120},{50,80}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{-64,-47},{26,-47},{26,13}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled},
                  origin={7,6},
                  rotation=-90),
                Rectangle(
                  extent={{20,80},{80,-60}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid,
                  radius=10),
                Rectangle(
                  extent={{28,22},{72,-52}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Rectangle(
                  extent={{28,72},{72,14}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid,
                  radius=5),
                Ellipse(
                  extent={{40,-80},{60,-100}},
                  lineColor={0,0,255},
                  lineThickness=0.5),
                Polygon(
                  points={{42,-84},{58,-84},{50,-100},{42,-84}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{50,-60},{50,-72},{50,-80}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None),
                Rectangle(
                  extent={{-158,48},{-134,32}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-134,40},{-140,40}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-140,40},{-144,44}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-140,40},{-144,40}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-140,40},{-144,36}},
                  color={0,0,255},
                  thickness=0.5),
                Rectangle(
                  extent={{-12,8},{12,-8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  origin={-72,234},
                  rotation=90),
                Line(
                  points={{2,-2},{-2,2}},
                  color={0,0,255},
                  thickness=0.5,
                  origin={-70,230},
                  rotation=270),
                Line(
                  points={{2,0},{-2,0}},
                  color={0,0,255},
                  thickness=0.5,
                  origin={-72,230},
                  rotation=270),
                Line(
                  points={{2,2},{-2,-2}},
                  color={0,0,255},
                  thickness=0.5,
                  origin={-74,230},
                  rotation=270),
                Line(
                  points={{-72,228},{-72,222}},
                  color={0,0,255},
                  thickness=0.5),
                Text(
                  extent={{154,140},{220,100}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  textString="from
condenser"),    Ellipse(
                  extent={{-10,11},{10,-11}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  origin={119,120},
                  rotation=-90),
                Polygon(
                  points={{-8,8},{8,8},{0,-8},{-8,8}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillPattern=FillPattern.Solid,
                  origin={118,120},
                  rotation=-90),
                Line(
                  points={{0,10},{0,-2},{0,-10}},
                  color={0,0,255},
                  thickness=0.5,
                  smooth=Smooth.None,
                  origin={140,120},
                  rotation=-90),
                Polygon(
                  points={{-10,4},{-10,-4},{0,0},{10,-4},{10,4},{0,0},{-10,4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  origin={-40,80},
                  rotation=-90),
                Line(
                  points={{5,3.03067e-017},{5,8}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  origin={-40,85},
                  rotation=-90),
                Polygon(
                  points={{-4,-2},{4,-2},{4,0},{2,2},{-2,2},{-4,0},{-4,-2}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  origin={-30,80},
                  rotation=-90),
                Line(
                  points={{-72,-60},{-72,-140},{50,-140}},
                  color={0,0,255},
                  thickness=0.5),
                Line(
                  points={{-160,240},{-160,190},{-80,190},{-78,194},{-74,196},{
                      -70,196},{-66,194},{-64,190},{-40,190},{-40,90}},
                  color={0,0,255},
                  thickness=0.5),
                Polygon(
                  points={{-116,44},{-116,36},{-106,40},{-96,36},{-96,44},{-106,
                      40},{-116,44}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-106,40},{-106,50}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None),
                Polygon(
                  points={{-110,46},{-102,46},{-102,48},{-104,50},{-108,50},{
                      -110,48},{-110,46}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid),
                Line(
                  points={{-72,-60},{-72,40},{-134,40}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Polygon(
                  points={{-10,4},{-10,-4},{0,0},{10,-4},{10,4},{0,0},{-10,4}},
                  lineColor={0,0,255},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid,
                  origin={-72,130},
                  rotation=-90),
                Line(
                  points={{5,3.03067e-017},{5,8}},
                  color={0,0,0},
                  thickness=0.5,
                  smooth=Smooth.None,
                  origin={-72,135},
                  rotation=-90),
                Polygon(
                  points={{-4,-2},{4,-2},{4,0},{2,2},{-2,2},{-4,0},{-4,-2}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  smooth=Smooth.None,
                  fillColor={0,0,0},
                  fillPattern=FillPattern.Solid,
                  origin={-62,130},
                  rotation=-90),
                Line(
                  points={{-70,45},{46,45},{46,-7}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled},
                  origin={5,-170},
                  rotation=-90),
                Line(
                  points={{-76,3},{46,3},{106,3}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled},
                  origin={-69,116},
                  rotation=90),
                Line(
                  points={{-244,-216},{-100,-216},{-18,-216}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Line(
                  points={{32,-41},{58,-41},{114,-41}},
                  color={0,0,255},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled},
                  origin={31,-186},
                  rotation=-90),
                Text(
                  extent={{96,-90},{206,-204}},
                  lineColor={0,0,0},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  textString="WSC")}));
        end BaseWSC;
      end BaseClasses;

      package Components "Package of heat transfer-related components"
        model HE "Model of MS/steam heat exchanger"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";

          ThermoPower.Water.Flow1DFV coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}),
                              graphics),
                               Icon(graphics));
        end HE;

        model HE_shell
          "Model of MS/steam heat exchanger with shell and insulation models"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, internal hot fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_shell =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, external hot fluid side (shell)"
            annotation(choicesAllMatching = true);
          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Integer Nr = 2
            "Number of radial nodes for the tubesheets/manifolds";
          parameter Modelica.SIunits.Volume Vhot_bundle
            "Volume of the fluid in the hot side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_bundle
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Area Shot_bundle
            "Heat transfer surface in the hot side (bundle)";
          parameter Modelica.SIunits.Area Scold_bundle
            "Heat transfer surface in the cold side (bundle)";
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length";
          parameter Modelica.SIunits.Length omega_shell
            "Perimeter of heat transfer surface (shell side)";
          parameter Modelica.SIunits.Length D_ext_shell
            "Shell external diameter";
          parameter Modelica.SIunits.Length D_int_shell
            "Shell internal diameter";
          parameter Modelica.SIunits.Length s_ins "Insulation thickness";
          parameter Modelica.SIunits.Mass Mm_bundle
            "Mass of the metal tubes between the two fluids";
          parameter Modelica.SIunits.Mass Mm_shell "Mass of the shell";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.ThermalConductivity km
            "Metal thermal conductivity";
          parameter Modelica.SIunits.Density rhom "Density of metal";
          parameter Modelica.SIunits.Mass Mi
            "Mass of the insulation between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity ci
            "Specific heat capacity of insulation";
          parameter Modelica.SIunits.ThermalConductivity ki
            "Nominal insulation thermal conductivity";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature T_amb
            "Nominal value of ambiebt temperature";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          constant Real pi=Modelica.Constants.pi;
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          ThermoPower.Water.Flow1DFV coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold_bundle/L,
            final omega=Scold_bundle/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold_bundle)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_bundle)                     annotation (Placement(transformation(
                  extent={{-20,-6},{20,-46}},rotation=0)));
          Flow1DFV_2walls            hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot_bundle/L,
            omega=Shot_bundle/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer_int = HeatTransferHot_bundle,
            redeclare model HeatTransfer_ext = HeatTransferHot_shell,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            L_shell=L_shell,
            omega_shell=omega_shell)                           annotation (Placement(transformation(extent={{20,50},
                    {-20,10}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-16},{20,24}},rotation=0)));

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology1(
                                                                            Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},rotation=90,
                origin={-14,76})));
          ThermoPower.Thermal.MetalWallFV
                                   shellWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                                   annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},rotation=90,
                origin={-28,76})));
          MetalTubeFV_kvar                insulation(
            final Nw=Nhex - 1,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            WallRes=true,
            final M=Mi,
            final cm=ci,
            L_shell=L_shell,
            knom=ki,
            D_ext=D_ext_shell + 2*s_ins,
            D_int=D_ext_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={-46,76})));
          ThermoPower.Thermal.TempSource1DFV tempSource1DFV(Nw=Nhex - 1)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-66,76})));
          Modelica.Blocks.Sources.Constant ambient(k=T_amb)
            annotation (Placement(transformation(extent={{-100,66},{-80,86}})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Power Q_diss = Q_Hot - Q_Cold
            "Power to the environment";
          Real csi_th = Q_diss/Q_Hot;
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer_int.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,-2.2},{0,-19.8}},color={255,127,0}));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-32},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;

        equation
          connect(shellWalls.int, heatExchangerTopology1.side1)
            annotation (Line(points={{-25,76},{-25,76},{-17,76}}, color={255,127,0}));
          connect(insulation.int, shellWalls.ext)
            annotation (Line(points={{-43,76},{-31.1,76}}, color={255,127,0}));
          connect(tempSource1DFV.wall, insulation.ext) annotation (Line(points={{-63,76},
                  {-63,76},{-49.1,76}}, color={255,127,0}));
          connect(ambient.y, tempSource1DFV.temperature)
            annotation (Line(points={{-79,76},{-70,76}},          color={0,0,127}));
          connect(hotFluid.wall_int, heatExchangerTopology.side1)
            annotation (Line(points={{0,20},{0,20},{0,10}}, color={255,127,0}));
          connect(heatExchangerTopology1.side2, hotFluid.wall_ext)
            annotation (Line(points={{-10.9,76},{0,76},{0,40}}, color={255,127,0}));
          connect(inletHot, hotFluid.infl) annotation (Line(points={{-100,0},{-100,0},{-100,
                  -80},{76,-80},{76,30},{20,30}}, color={0,0,255},
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(points={{-20,30},{-30,30},
                  {-40,30},{-40,60},{100,60},{100,0}}, color={0,0,255},
              thickness=0.5));
          connect(inletCold, coldFluid.infl) annotation (Line(
              points={{0,-100},{-22,-100},{-40,-100},{-40,-52},{-20,-52}},
              color={0,0,255},
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{60,-52},{60,100},{0,100}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),
                               Icon(graphics));
        end HE_shell;

        model HE_shell_ts
          "Model of MS/steam heat exchanger with shell, tubesheets and insulation models"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold_man =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (manifold)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, internal hot fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_shell =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, external hot fluid side (shell)"
            annotation(choicesAllMatching = true);
          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Integer Nr = 2
            "Number of radial nodes for the tubesheets/manifolds";
          parameter Modelica.SIunits.Volume Vhot_bundle
            "Volume of the fluid in the hot side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_bundle
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_tubesheet
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_man
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Area Shot_bundle
            "Heat transfer surface in the hot side (bundle)";
          parameter Modelica.SIunits.Area Scold_bundle
            "Heat transfer surface in the cold side (bundle)";
          parameter Modelica.SIunits.Length L_tubesheet "Tubesheet thickness";
          parameter Modelica.SIunits.Length L_man "Manifold equivalent length";
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length";
          parameter Modelica.SIunits.Length omega_shell
            "Perimeter of heat transfer surface (shell side)";
          parameter Modelica.SIunits.Length D_ext_shell
            "Shell external diameter";
          parameter Modelica.SIunits.Length D_int_shell
            "Shell internal diameter";
          parameter Modelica.SIunits.Length D_ext_ts
            "Tubesheet external diameter";
          parameter Modelica.SIunits.Length D_int_ts = D_int_shell
            "Tubesheet internal diameter";
          parameter Modelica.SIunits.Length D_ext_man = D_ext_ts
            "Manifold external diameter";
          parameter Modelica.SIunits.Length D_int_man = sqrt(4*Vcold_man/pi/L_man)
            "Manifold internal diameter";
          parameter Modelica.SIunits.Length s_ins "Insulation thickness";
          parameter Modelica.SIunits.Mass Mm_bundle
            "Mass of the metal tubes between the two fluids";
          parameter Modelica.SIunits.Mass Mm_shell "Mass of the shell";
          parameter Modelica.SIunits.Mass Mm_ts "Mass of the tubesheets";
          parameter Modelica.SIunits.Mass Mm_man "Mass of the manifold";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.ThermalConductivity km
            "Metal thermal conductivity";
          parameter Modelica.SIunits.Density rhom "Density of metal";
          parameter Modelica.SIunits.Mass Mi
            "Mass of the insulation between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity ci
            "Specific heat capacity of insulation";
          parameter Modelica.SIunits.ThermalConductivity ki
            "Nominal insulation thermal conductivity";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature T_amb
            "Nominal value of ambiebt temperature";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          constant Real pi=Modelica.Constants.pi;
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          ThermoPower.Water.Flow1DFV coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold_bundle/L,
            final omega=Scold_bundle/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold_bundle)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_bundle)                     annotation (Placement(transformation(
                  extent={{-20,-6},{20,-46}},rotation=0)));
          Flow1DFV_2walls            hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot_bundle/L,
            omega=Shot_bundle/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer_int = HeatTransferHot_bundle,
            redeclare model HeatTransfer_ext = HeatTransferHot_shell,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            L_shell=L_shell,
            omega_shell=omega_shell)                           annotation (Placement(transformation(extent={{20,50},
                    {-20,10}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-16},{20,24}},rotation=0)));

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology1(
                                                                            Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},rotation=90,
                origin={-14,76})));
          ThermoPower.Thermal.MetalWallFV
                                   shellWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                                   annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},rotation=90,
                origin={-28,76})));
          MetalTubeFV_kvar                insulation(
            final Nw=Nhex - 1,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            WallRes=true,
            final M=Mi,
            final cm=ci,
            L_shell=L_shell,
            knom=ki,
            D_ext=D_ext_shell + 2*s_ins,
            D_int=D_ext_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={-46,76})));
          ThermoPower.Thermal.TempSource1DFV tempSource1DFV(Nw=Nhex - 1)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-66,76})));
          Modelica.Blocks.Sources.Constant ambient(k=T_amb)
            annotation (Placement(transformation(extent={{-100,66},{-80,86}})));
          ThermoPower.Water.Flow1DFV coldFluid_ts_in(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_tubesheet,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_bundle,
            N=2,
            final A=Vcold_tubesheet/L_tubesheet,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_shell,
            noInitialPressure=true)                 annotation (Placement(transformation(extent={{-46,-58},{
                    -34,-46}}, rotation=0)));
          CylinderFourier tubeSheet_int_cold_in(final cm=cm,
            rint=D_int_ts/2,
            rext=D_ext_ts/2,
            rhom=rhom,
            km=km,
            Nr=Nr,
            Tstartint=nominalColdInletTemperature,
            Tstartext=nominalColdInletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_tubesheet,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                             annotation (Placement(
                transformation(extent={{-46,-22},{-34,-34}}, rotation=0)));

          ThermoPower.Water.Flow1DFV coldFluid_man_in(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_man,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_man,
            N=2,
            final A=Vcold_man/L_man,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_man,
            noInitialPressure=true)         annotation (Placement(transformation(extent={{-66,-58},{
                    -54,-46}}, rotation=0)));
          CylinderFourier tubeSheet_ext_cold_in(
            rhom=rhom,
            cm=cm,
            km=km,
            rint=D_int_man/2,
            rext=D_ext_man/2,
            Nr=Nr,
            Tstartint=nominalColdInletTemperature,
            Tstartext=nominalColdInletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_man,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                annotation (Placement(transformation(
                  extent={{-66,-22},{-54,-34}}, rotation=0)));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in
            annotation (Placement(transformation(extent={{-70,-8},{-50,12}})));
          Modelica.Blocks.Sources.Constant ext_flux1(k=0)
            annotation (Placement(transformation(extent={{-66,18},{-62,22}})));
          ThermoPower.Water.Flow1DFV coldFluid_man_out(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_man,
            N=2,
            final A=Vcold_man/L_man,
            L=L_man,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_man,
            noInitialPressure=true)         annotation (Placement(transformation(extent={{54,-58},{66,
                    -46}}, rotation=0)));
          CylinderFourier tubeSheet_ext_cold_out(
            rhom=rhom,
            cm=cm,
            km=km,
            rint=D_int_man/2,
            rext=D_ext_man/2,
            Nr=Nr,
            Tstartint=nominalColdOutletTemperature,
            Tstartext=nominalColdOutletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_man,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                              annotation (Placement(
                transformation(extent={{54,-22},{66,-34}}, rotation=0)));
          ThermoPower.Water.Flow1DFV coldFluid_ts_out(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_tubesheet,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_bundle,
            N=2,
            final A=Vcold_tubesheet/L_tubesheet,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_shell,
            noInitialPressure=true)                 annotation (Placement(transformation(extent={{34,-58},{46,
                    -46}}, rotation=0)));
          CylinderFourier tubeSheet_int_cold_out(final cm=cm,
            rint=D_int_ts/2,
            rext=D_ext_ts/2,
            rhom=rhom,
            km=km,
            Nr=Nr,
            Tstartint=nominalColdOutletTemperature,
            Tstartext=nominalColdOutletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_tubesheet,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                              annotation (Placement(
                transformation(extent={{34,-22},{46,-34}}, rotation=0)));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_out
            annotation (Placement(transformation(extent={{30,-8},{50,12}})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Power Q_diss = Q_Hot - Q_Cold
            "Power to the environment";
          Real csi_th = Q_diss/Q_Hot;
          Modelica.SIunits.Energy E_ts_in
            "Integral internal energy increase/decrease of inlet tubesheet";
          Modelica.SIunits.Energy E_ts_out
            "Integral internal energy increase/decrease of outlet tubesheet";
          Modelica.SIunits.Energy E_man_in
            "Integral internal energy increase/decrease of inlet manifold";
          Modelica.SIunits.Energy E_man_out
            "Integral internal energy increase/decrease of outlet manifold";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer_int.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in1
            annotation (Placement(transformation(extent={{-50,-8},{-30,12}})));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_out1
            annotation (Placement(transformation(extent={{50,-8},{70,12}})));
          Modelica.Blocks.Sources.Constant ext_flux2(k=0)
            annotation (Placement(transformation(extent={{-46,18},{-42,22}})));
          Modelica.Blocks.Sources.Constant ext_flux3(k=0)
            annotation (Placement(transformation(extent={{32,18},{36,22}})));
          Modelica.Blocks.Sources.Constant ext_flux4(k=0)
            annotation (Placement(transformation(extent={{54,18},{58,22}})));
        equation
          if time >= t_in and time <= t_fin then
            der(E_ts_in) = tubeSheet_int_cold_in.internalBoundary.Q[1];
            der(E_ts_out) = tubeSheet_int_cold_out.internalBoundary.Q[1];
            der(E_man_in) = tubeSheet_ext_cold_in.internalBoundary.Q[1];
            der(E_man_out) = tubeSheet_ext_cold_out.internalBoundary.Q[1];
          else
            der(E_ts_in) = 0;
            der(E_ts_out) = 0;
            der(E_man_in) = 0;
            der(E_man_out) = 0;
          end if;
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q + coldFluid_man_in.Q + coldFluid_ts_in.Q + coldFluid_man_out.Q + coldFluid_ts_out.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,-2.2},{0,-19.8}},color={255,127,0}));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-32},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;

        equation
          connect(shellWalls.int, heatExchangerTopology1.side1)
            annotation (Line(points={{-25,76},{-25,76},{-17,76}}, color={255,127,0}));
          connect(insulation.int, shellWalls.ext)
            annotation (Line(points={{-43,76},{-31.1,76}}, color={255,127,0}));
          connect(tempSource1DFV.wall, insulation.ext) annotation (Line(points={{-63,76},
                  {-63,76},{-49.1,76}}, color={255,127,0}));
          connect(ambient.y, tempSource1DFV.temperature)
            annotation (Line(points={{-79,76},{-70,76}},          color={0,0,127}));
          connect(hotFluid.wall_int, heatExchangerTopology.side1)
            annotation (Line(points={{0,20},{0,20},{0,10}}, color={255,127,0}));
          connect(heatExchangerTopology1.side2, hotFluid.wall_ext)
            annotation (Line(points={{-10.9,76},{0,76},{0,40}}, color={255,127,0}));
          connect(coldFluid_ts_in.outfl, coldFluid.infl)
            annotation (Line(points={{-34,-52},{-32,-52},{-20,-52}}, color={0,0,255}));
          connect(inletHot, hotFluid.infl) annotation (Line(points={{-100,0},{-100,0},{-100,
                  -80},{76,-80},{76,30},{20,30}}, color={0,0,255},
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(points={{-20,30},{-30,30},
                  {-40,30},{-40,60},{100,60},{100,0}}, color={0,0,255},
              thickness=0.5));
          connect(inletCold, coldFluid_man_in.infl) annotation (Line(points={{0,-100},{-80,
                  -100},{-80,-52},{-66,-52}}, color={0,0,255},
              thickness=0.5));
          connect(coldFluid_man_in.outfl, coldFluid_ts_in.infl)
            annotation (Line(points={{-54,-52},{-50,-52},{-46,-52}}, color={0,0,255}));
          connect(coldFluid.outfl, coldFluid_ts_out.infl)
            annotation (Line(points={{20,-52},{27,-52},{34,-52}}, color={0,0,255}));
          connect(coldFluid_ts_out.outfl, coldFluid_man_out.infl)
            annotation (Line(points={{46,-52},{54,-52}}, color={0,0,255}));
          connect(coldFluid_man_out.outfl, outletCold) annotation (Line(points={{66,-52},
                  {84,-52},{84,100},{0,100}}, color={0,0,255},
              thickness=0.5));
          connect(tubeSheet_ext_cold_in.internalBoundary, coldFluid_man_in.wall)
            annotation (Line(points={{-60,-29.8},{-60,-49}},           color={255,127,0}));
          connect(tubeSheet_int_cold_in.internalBoundary, coldFluid_ts_in.wall)
            annotation (Line(points={{-40,-29.8},{-40,-49}},           color={255,127,0}));
          connect(tubeSheet_int_cold_out.internalBoundary, coldFluid_ts_out.wall)
            annotation (Line(points={{40,-29.8},{40,-49}},          color={255,127,0}));
          connect(tubeSheet_ext_cold_out.internalBoundary, coldFluid_man_out.wall)
            annotation (Line(points={{60,-29.8},{60,-49}},          color={255,127,0}));
          connect(ext_flux1.y, heatSource1DFV_in.power) annotation (Line(points=
                 {{-61.8,20},{-60,20},{-60,6}}, color={0,0,127}));
          connect(ext_flux2.y, heatSource1DFV_in1.power) annotation (Line(
                points={{-41.8,20},{-40,20},{-40,6}}, color={0,0,127}));
          connect(ext_flux3.y, heatSource1DFV_out.power) annotation (Line(
                points={{36.2,20},{40,20},{40,6}}, color={0,0,127}));
          connect(ext_flux4.y, heatSource1DFV_out1.power) annotation (Line(
                points={{58.2,20},{60,20},{60,6}}, color={0,0,127}));
          connect(heatSource1DFV_in.wall, tubeSheet_ext_cold_in.externalBoundary)
            annotation (Line(points={{-60,-1},{-60,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_in1.wall, tubeSheet_int_cold_in.externalBoundary)
            annotation (Line(points={{-40,-1},{-40,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_out.wall, tubeSheet_int_cold_out.externalBoundary)
            annotation (Line(points={{40,-1},{40,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_out1.wall, tubeSheet_ext_cold_out.externalBoundary)
            annotation (Line(points={{60,-1},{60,-26.2}}, color={255,127,0}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),
                               Icon(graphics));
        end HE_shell_ts;

        model HE_2ph "Model of MS/steam heat exchanger with phase change"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          ThermoPower.Water.Flow1DFV2ph coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold/L,
            final omega=Scold/L,
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                                annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final M=Mm,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2)
                                                   annotation (Placement(transformation(
                  extent={{-20,4},{20,-36}}, rotation=0)));
          ThermoPower.Water.Flow1DFV hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot/L,
            omega=Shot/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer = HeatTransferHot,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction)
                                                               annotation (Placement(transformation(extent={{20,72},
                    {-20,32}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-2},{20,38}}, rotation=0)));
          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,11.8},{0,-9.8}}, color={255,127,0}));
          connect(hotFluid.wall, heatExchangerTopology.side1) annotation (Line(
              points={{0,42},{0,24}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-22},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));
          connect(coldFluid.infl, inletCold) annotation (Line(
              points={{-20,-52},{-40,-52},{-40,-100},{0,-100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{70,-52},{70,100},{0,100}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.infl, inletHot) annotation (Line(
              points={{20,52},{52,52},{52,-80},{-100,-80},{-100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(
              points={{-20,52},{-40,52},{-40,80},{100,80},{100,0}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}),
                              graphics),
                               Icon(graphics));
        end HE_2ph;

        model HE_shell_2ph
          "Model of MS/steam heat exchanger with shell and insulation models"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, internal hot fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_shell =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, external hot fluid side (shell)"
            annotation(choicesAllMatching = true);
          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Integer Nr = 2
            "Number of radial nodes for the tubesheets/manifolds";
          parameter Modelica.SIunits.Volume Vhot_bundle
            "Volume of the fluid in the hot side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_bundle
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Area Shot_bundle
            "Heat transfer surface in the hot side (bundle)";
          parameter Modelica.SIunits.Area Scold_bundle
            "Heat transfer surface in the cold side (bundle)";
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length";
          parameter Modelica.SIunits.Length omega_shell
            "Perimeter of heat transfer surface (shell side)";
          parameter Modelica.SIunits.Length D_ext_shell
            "Shell external diameter";
          parameter Modelica.SIunits.Length D_int_shell
            "Shell internal diameter";
          parameter Modelica.SIunits.Length s_ins "Insulation thickness";
          parameter Modelica.SIunits.Mass Mm_bundle
            "Mass of the metal tubes between the two fluids";
          parameter Modelica.SIunits.Mass Mm_shell "Mass of the shell";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.ThermalConductivity km
            "Metal thermal conductivity";
          parameter Modelica.SIunits.Density rhom "Density of metal";
          parameter Modelica.SIunits.Mass Mi
            "Mass of the insulation between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity ci
            "Specific heat capacity of insulation";
          parameter Modelica.SIunits.ThermalConductivity ki
            "Nominal insulation thermal conductivity";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature T_amb
            "Nominal value of ambiebt temperature";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          constant Real pi=Modelica.Constants.pi;
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold_bundle/L,
            final omega=Scold_bundle/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold_bundle)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_bundle)                     annotation (Placement(transformation(
                  extent={{-20,-6},{20,-46}},rotation=0)));
          Flow1DFV_2walls            hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot_bundle/L,
            omega=Shot_bundle/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer_int = HeatTransferHot_bundle,
            redeclare model HeatTransfer_ext = HeatTransferHot_shell,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            L_shell=L_shell,
            omega_shell=omega_shell)                           annotation (Placement(transformation(extent={{20,50},
                    {-20,10}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-16},{20,24}},rotation=0)));

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology1(
                                                                            Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},rotation=90,
                origin={-14,76})));
          ThermoPower.Thermal.MetalWallFV
                                   shellWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                                   annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},rotation=90,
                origin={-28,76})));
          MetalTubeFV_kvar                insulation(
            final Nw=Nhex - 1,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            WallRes=true,
            final M=Mi,
            final cm=ci,
            L_shell=L_shell,
            knom=ki,
            D_ext=D_ext_shell + 2*s_ins,
            D_int=D_ext_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={-46,76})));
          ThermoPower.Thermal.TempSource1DFV tempSource1DFV(Nw=Nhex - 1)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-66,76})));
          Modelica.Blocks.Sources.Constant ambient(k=T_amb)
            annotation (Placement(transformation(extent={{-100,66},{-80,86}})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Power Q_diss = Q_Hot - Q_Cold
            "Power to the environment";
          Real csi_th = Q_diss/Q_Hot;
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer_int.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

        equation
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,-2.2},{0,-19.8}},color={255,127,0}));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-32},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;

        equation
          connect(shellWalls.int, heatExchangerTopology1.side1)
            annotation (Line(points={{-25,76},{-25,76},{-17,76}}, color={255,127,0}));
          connect(insulation.int, shellWalls.ext)
            annotation (Line(points={{-43,76},{-31.1,76}}, color={255,127,0}));
          connect(tempSource1DFV.wall, insulation.ext) annotation (Line(points={{-63,76},
                  {-63,76},{-49.1,76}}, color={255,127,0}));
          connect(ambient.y, tempSource1DFV.temperature)
            annotation (Line(points={{-79,76},{-70,76}},          color={0,0,127}));
          connect(hotFluid.wall_int, heatExchangerTopology.side1)
            annotation (Line(points={{0,20},{0,20},{0,10}}, color={255,127,0}));
          connect(heatExchangerTopology1.side2, hotFluid.wall_ext)
            annotation (Line(points={{-10.9,76},{0,76},{0,40}}, color={255,127,0}));
          connect(inletHot, hotFluid.infl) annotation (Line(points={{-100,0},{-100,0},{-100,
                  -80},{76,-80},{76,30},{20,30}}, color={0,0,255},
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(points={{-20,30},{-30,30},
                  {-40,30},{-40,60},{100,60},{100,0}}, color={0,0,255},
              thickness=0.5));
          connect(inletCold, coldFluid.infl) annotation (Line(
              points={{0,-100},{-22,-100},{-40,-100},{-40,-52},{-20,-52}},
              color={0,0,255},
              thickness=0.5));
          connect(coldFluid.outfl, outletCold) annotation (Line(
              points={{20,-52},{60,-52},{60,100},{0,100}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),
                               Icon(graphics));
        end HE_shell_2ph;

        model HE_shell_ts_2ph
          "Model of MS/steam heat exchanger with shell, tubesheets and insulation models"

          extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          // Heat exchange parameters-variables
          replaceable model HeatTransferCold_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold_man =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side (manifold)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_bundle =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, internal hot fluid side (bundle)"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot_shell =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, external hot fluid side (shell)"
            annotation(choicesAllMatching = true);
          replaceable model HeatExchangerTopology =
              ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow
            constrainedby
            ThermoPower.Thermal.BaseClasses.HeatExchangerTopologyData
            "Heat exchanger topology"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Integer Nr = 2
            "Number of radial nodes for the tubesheets/manifolds";
          parameter Modelica.SIunits.Volume Vhot_bundle
            "Volume of the fluid in the hot side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_bundle
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_tubesheet
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Volume Vcold_man
            "Volume of the fluid in the cold side (bundle)";
          parameter Modelica.SIunits.Area Shot_bundle
            "Heat transfer surface in the hot side (bundle)";
          parameter Modelica.SIunits.Area Scold_bundle
            "Heat transfer surface in the cold side (bundle)";
          parameter Modelica.SIunits.Length L_tubesheet "Tubesheet thickness";
          parameter Modelica.SIunits.Length L_man "Manifold equivalent length";
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length";
          parameter Modelica.SIunits.Length omega_shell
            "Perimeter of heat transfer surface (shell side)";
          parameter Modelica.SIunits.Length D_ext_shell
            "Shell external diameter";
          parameter Modelica.SIunits.Length D_int_shell
            "Shell internal diameter";
          parameter Modelica.SIunits.Length D_ext_ts
            "Tubesheet external diameter";
          parameter Modelica.SIunits.Length D_int_ts = D_int_shell
            "Tubesheet internal diameter";
          parameter Modelica.SIunits.Length D_ext_man = D_ext_ts
            "Manifold external diameter";
          parameter Modelica.SIunits.Length D_int_man = sqrt(4*Vcold_man/pi/L_man)
            "Manifold internal diameter";
          parameter Modelica.SIunits.Length s_ins "Insulation thickness";
          parameter Modelica.SIunits.Mass Mm_bundle
            "Mass of the metal tubes between the two fluids";
          parameter Modelica.SIunits.Mass Mm_shell "Mass of the shell";
          parameter Modelica.SIunits.Mass Mm_ts "Mass of the tubesheets";
          parameter Modelica.SIunits.Mass Mm_man "Mass of the manifold";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.ThermalConductivity km
            "Metal thermal conductivity";
          parameter Modelica.SIunits.Density rhom "Density of metal";
          parameter Modelica.SIunits.Mass Mi
            "Mass of the insulation between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity ci
            "Specific heat capacity of insulation";
          parameter Modelica.SIunits.ThermalConductivity ki
            "Nominal insulation thermal conductivity";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature T_amb
            "Nominal value of ambiebt temperature";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          constant Real pi=Modelica.Constants.pi;
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid(
            final N=Nhex,
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L,
            dpnom=nominalColdDeltaP,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            final A=Vcold_bundle/L,
            final omega=Scold_bundle/L,
            Dhyd=1,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.OpPoint,
            redeclare model HeatTransfer = HeatTransferCold_bundle)    annotation (Placement(transformation(extent={{-20,-72},
                    {20,-32}},      rotation=0)));
          ThermoPower.Thermal.MetalWallFV
                                   tubeWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_bundle)                     annotation (Placement(transformation(
                  extent={{-20,-6},{20,-46}},rotation=0)));
          Flow1DFV_2walls            hotFluid(
            N=Nhex,
            H=0,
            Dhyd=1,
            pstart=nominalHotPressure,
            redeclare package Medium = hotMedium,
            L=L,
            A=Vhot_bundle/L,
            omega=Shot_bundle/L,
            wnom=nominalHotFlow,
            dpnom=nominalHotDeltaP,
            rhonom=hotMedium.density_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartin=hotMedium.specificEnthalpy_pT(nominalHotPressure,
                nominalHotInletTemperature),
            hstartout=hotMedium.specificEnthalpy_pT(nominalHotPressure -
                nominalHotDeltaP, nominalHotOutletTemperature),
            redeclare model HeatTransfer_int = HeatTransferHot_bundle,
            redeclare model HeatTransfer_ext = HeatTransferHot_shell,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            L_shell=L_shell,
            omega_shell=omega_shell)                           annotation (Placement(transformation(extent={{20,50},
                    {-20,10}},     rotation=0)));
          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology(Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-20,-16},{20,24}},rotation=0)));

          // Initialisation script parameters-variables
          parameter Boolean generateInitCode = false
            "Generate initialization code at the end of the simulation";
          function print = Modelica.Utilities.Streams.print;
          String s;

          ThermoPower.Thermal.HeatExchangerTopologyFV heatExchangerTopology1(
                                                                            Nw=Nhex
                 - 1, redeclare model HeatExchangerTopology =
                HeatExchangerTopology) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},rotation=90,
                origin={-14,76})));
          ThermoPower.Thermal.MetalWallFV
                                   shellWalls(
            final Nw=Nhex-1,
            final cm=cm,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            final M=Mm_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                                                   annotation (Placement(transformation(
                  extent={{-10,10},{10,-10}},rotation=90,
                origin={-28,76})));
          MetalTubeFV_kvar                insulation(
            final Nw=Nhex - 1,
            Tstart1=(nominalColdInletTemperature + nominalHotOutletTemperature)/2,
            TstartN=(nominalColdOutletTemperature + nominalHotInletTemperature)/2,
            WallRes=true,
            final M=Mi,
            final cm=ci,
            L_shell=L_shell,
            knom=ki,
            D_ext=D_ext_shell + 2*s_ins,
            D_int=D_ext_shell,
            initOpt=ThermoPower.Choices.Init.Options.steadyState)
                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=90,
                origin={-46,76})));
          ThermoPower.Thermal.TempSource1DFV tempSource1DFV(Nw=Nhex - 1)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-66,76})));
          Modelica.Blocks.Sources.Constant ambient(k=T_amb)
            annotation (Placement(transformation(extent={{-100,66},{-80,86}})));
          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid_ts_in(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_tubesheet,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_bundle,
            N=2,
            final A=Vcold_tubesheet/L_tubesheet,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_shell)             annotation (Placement(transformation(extent={{-46,-58},{
                    -34,-46}}, rotation=0)));
          CylinderFourier tubeSheet_int_cold_in(final cm=cm,
            rint=D_int_ts/2,
            rext=D_ext_ts/2,
            rhom=rhom,
            km=km,
            Nr=Nr,
            Tstartint=nominalColdInletTemperature,
            Tstartext=nominalColdInletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_tubesheet,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                             annotation (Placement(
                transformation(extent={{-46,-22},{-34,-34}}, rotation=0)));

          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid_man_in(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_man,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_man,
            N=2,
            final A=Vcold_man/L_man,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_man)       annotation (Placement(transformation(extent={{-66,-58},{
                    -54,-46}}, rotation=0)));
          CylinderFourier tubeSheet_ext_cold_in(
            rhom=rhom,
            cm=cm,
            km=km,
            rint=D_int_man/2,
            rext=D_ext_man/2,
            Nr=Nr,
            Tstartint=nominalColdInletTemperature,
            Tstartext=nominalColdInletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_man,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                annotation (Placement(transformation(
                  extent={{-66,-22},{-54,-34}}, rotation=0)));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in
            annotation (Placement(transformation(extent={{-70,-8},{-50,12}})));
          Modelica.Blocks.Sources.Constant ext_flux1(k=0)
            annotation (Placement(transformation(extent={{-66,18},{-62,22}})));
          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid_man_out(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_man,
            N=2,
            final A=Vcold_man/L_man,
            L=L_man,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_man)       annotation (Placement(transformation(extent={{54,-58},{66,
                    -46}}, rotation=0)));
          CylinderFourier tubeSheet_ext_cold_out(
            rhom=rhom,
            cm=cm,
            km=km,
            rint=D_int_man/2,
            rext=D_ext_man/2,
            Nr=Nr,
            Tstartint=nominalColdOutletTemperature,
            Tstartext=nominalColdOutletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_man,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                              annotation (Placement(
                transformation(extent={{54,-22},{66,-34}}, rotation=0)));
          ThermoPower.Water.Flow1DFV2ph
                                     coldFluid_ts_out(
            H=0,
            wnom=nominalColdFlow,
            pstart=nominalColdPressure,
            redeclare package Medium = coldMedium,
            L=L_tubesheet,
            rhonom=coldMedium.density_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartin=coldMedium.specificEnthalpy_pT(nominalColdPressure,
                nominalColdInletTemperature),
            hstartout=coldMedium.specificEnthalpy_pT(nominalColdPressure -
                nominalColdDeltaP, nominalColdOutletTemperature),
            Dhyd=1,
            redeclare model HeatTransfer = HeatTransferCold_bundle,
            N=2,
            final A=Vcold_tubesheet/L_tubesheet,
            FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
            dpnom=0,
            final omega=pi*D_int_shell)             annotation (Placement(transformation(extent={{34,-58},{46,
                    -46}}, rotation=0)));
          CylinderFourier tubeSheet_int_cold_out(final cm=cm,
            rint=D_int_ts/2,
            rext=D_ext_ts/2,
            rhom=rhom,
            km=km,
            Nr=Nr,
            Tstartint=nominalColdOutletTemperature,
            Tstartext=nominalColdOutletTemperature,
            initOpt=ThermoPower.Choices.Init.Options.steadyState,
            L=L_tubesheet,
            nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.thickInternal)
                                                              annotation (Placement(
                transformation(extent={{34,-22},{46,-34}}, rotation=0)));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_out
            annotation (Placement(transformation(extent={{30,-8},{50,12}})));

          Modelica.SIunits.Power Q_Hot "Power from the hot side";
          Modelica.SIunits.Power Q_Cold "Power to the cold side";
          Modelica.SIunits.Power Q_diss = Q_Hot - Q_Cold
            "Power to the environment";
          Real csi_th = Q_diss/Q_Hot;
          Modelica.SIunits.Energy E_ts_in
            "Integral internal energy increase/decrease of inlet tubesheet";
          Modelica.SIunits.Energy E_ts_out
            "Integral internal energy increase/decrease of outlet tubesheet";
          Modelica.SIunits.Energy E_man_in
            "Integral internal energy increase/decrease of inlet manifold";
          Modelica.SIunits.Energy E_man_out
            "Integral internal energy increase/decrease of outlet manifold";
          Modelica.SIunits.Temperature T_hot_prof[Nhex+1] = vector([hotFluid.T[1];hotFluid.heatTransfer_int.Tvol;hotFluid.T[end]])
            "Hot temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_wall_prof[Nhex+1] = vector([(hotFluid.T[1]+coldFluid.T[end])/2;tubeWalls.Tvol[end:-1:1];(hotFluid.T[end]+coldFluid.T[1])/2])
            "Wall temperature vector (hot in the left side)";
          Modelica.SIunits.Temperature T_cold_prof[Nhex+1] = vector([coldFluid.T[end];coldFluid.heatTransfer.Tvol[end:-1:1];coldFluid.T[1]])
            "Cold temperature vector (hot in the left side)";

          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_in1
            annotation (Placement(transformation(extent={{-50,-8},{-30,12}})));
          ThermoPower.Thermal.HeatSource1DFV heatSource1DFV_out1
            annotation (Placement(transformation(extent={{50,-8},{70,12}})));
          Modelica.Blocks.Sources.Constant ext_flux2(k=0)
            annotation (Placement(transformation(extent={{-46,18},{-42,22}})));
          Modelica.Blocks.Sources.Constant ext_flux3(k=0)
            annotation (Placement(transformation(extent={{32,18},{36,22}})));
          Modelica.Blocks.Sources.Constant ext_flux4(k=0)
            annotation (Placement(transformation(extent={{54,18},{58,22}})));
        equation
          if time >= t_in and time <= t_fin then
            der(E_ts_in) = tubeSheet_int_cold_in.internalBoundary.Q[1];
            der(E_ts_out) = tubeSheet_int_cold_out.internalBoundary.Q[1];
            der(E_man_in) = tubeSheet_ext_cold_in.internalBoundary.Q[1];
            der(E_man_out) = tubeSheet_ext_cold_out.internalBoundary.Q[1];
          else
            der(E_ts_in) = 0;
            der(E_ts_out) = 0;
            der(E_man_in) = 0;
            der(E_man_out) = 0;
          end if;
          Q_Hot = -hotFluid.Q;
          Q_Cold = coldFluid.Q + coldFluid_man_in.Q + coldFluid_ts_in.Q + coldFluid_man_out.Q + coldFluid_ts_out.Q;
          connect(heatExchangerTopology.side2, tubeWalls.ext)
            annotation (Line(points={{0,-2.2},{0,-19.8}},color={255,127,0}));
          connect(tubeWalls.int, coldFluid.wall) annotation (Line(
              points={{0,-32},{0,-42}},
              color={255,127,0},
              smooth=Smooth.None));

        algorithm
          when terminal() and generateInitCode then
            print("HEAT EXCHANGER(");
            print("  hotFluid(");
            s := "    hstart={";
            for i in 1:hotFluid.N loop
              s := s + String(hotFluid.h[i]);
              if i < hotFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(hotFluid.p)+"),";
            print(s);

            print("  coldFluid(");
            s := "    hstart={";
            for i in 1:coldFluid.N loop
              s := s + String(coldFluid.h[i]);
              if i < coldFluid.N then
                s := s + ",";
              end if;
            end for;
            s :=s + "},";
            print(s);

            s :="    pstart="+String(coldFluid.p)+"),";
            print(s);

            s := "  tubeWalls(Tvolstart={";
            for i in 1:tubeWalls.Nw loop
              s := s + String(tubeWalls.Tvol[i]);
              if i < tubeWalls.Nw then
                s := s + ",";
              end if;
            end for;
            s := s + "})));";
            print(s);
          end when;

        equation
          connect(shellWalls.int, heatExchangerTopology1.side1)
            annotation (Line(points={{-25,76},{-25,76},{-17,76}}, color={255,127,0}));
          connect(insulation.int, shellWalls.ext)
            annotation (Line(points={{-43,76},{-31.1,76}}, color={255,127,0}));
          connect(tempSource1DFV.wall, insulation.ext) annotation (Line(points={{-63,76},
                  {-63,76},{-49.1,76}}, color={255,127,0}));
          connect(ambient.y, tempSource1DFV.temperature)
            annotation (Line(points={{-79,76},{-70,76}},          color={0,0,127}));
          connect(hotFluid.wall_int, heatExchangerTopology.side1)
            annotation (Line(points={{0,20},{0,20},{0,10}}, color={255,127,0}));
          connect(heatExchangerTopology1.side2, hotFluid.wall_ext)
            annotation (Line(points={{-10.9,76},{0,76},{0,40}}, color={255,127,0}));
          connect(coldFluid_ts_in.outfl, coldFluid.infl)
            annotation (Line(points={{-34,-52},{-32,-52},{-20,-52}}, color={0,0,255}));
          connect(inletHot, hotFluid.infl) annotation (Line(points={{-100,0},{-100,0},{-100,
                  -80},{76,-80},{76,30},{20,30}}, color={0,0,255},
              thickness=0.5));
          connect(hotFluid.outfl, outletHot) annotation (Line(points={{-20,30},{-30,30},
                  {-40,30},{-40,60},{100,60},{100,0}}, color={0,0,255},
              thickness=0.5));
          connect(inletCold, coldFluid_man_in.infl) annotation (Line(points={{0,-100},{-80,
                  -100},{-80,-52},{-66,-52}}, color={0,0,255},
              thickness=0.5));
          connect(coldFluid_man_in.outfl, coldFluid_ts_in.infl)
            annotation (Line(points={{-54,-52},{-50,-52},{-46,-52}}, color={0,0,255}));
          connect(coldFluid.outfl, coldFluid_ts_out.infl)
            annotation (Line(points={{20,-52},{27,-52},{34,-52}}, color={0,0,255}));
          connect(coldFluid_ts_out.outfl, coldFluid_man_out.infl)
            annotation (Line(points={{46,-52},{54,-52}}, color={0,0,255}));
          connect(coldFluid_man_out.outfl, outletCold) annotation (Line(points={{66,-52},
                  {84,-52},{84,100},{0,100}}, color={0,0,255},
              thickness=0.5));
          connect(tubeSheet_ext_cold_in.internalBoundary, coldFluid_man_in.wall)
            annotation (Line(points={{-60,-29.8},{-60,-49}},           color={255,127,0}));
          connect(tubeSheet_int_cold_in.internalBoundary, coldFluid_ts_in.wall)
            annotation (Line(points={{-40,-29.8},{-40,-49}},           color={255,127,0}));
          connect(tubeSheet_int_cold_out.internalBoundary, coldFluid_ts_out.wall)
            annotation (Line(points={{40,-29.8},{40,-49}},          color={255,127,0}));
          connect(tubeSheet_ext_cold_out.internalBoundary, coldFluid_man_out.wall)
            annotation (Line(points={{60,-29.8},{60,-49}},          color={255,127,0}));
          connect(ext_flux1.y, heatSource1DFV_in.power) annotation (Line(points=
                 {{-61.8,20},{-60,20},{-60,6}}, color={0,0,127}));
          connect(ext_flux2.y, heatSource1DFV_in1.power) annotation (Line(
                points={{-41.8,20},{-40,20},{-40,6}}, color={0,0,127}));
          connect(ext_flux3.y, heatSource1DFV_out.power) annotation (Line(
                points={{36.2,20},{40,20},{40,6}}, color={0,0,127}));
          connect(ext_flux4.y, heatSource1DFV_out1.power) annotation (Line(
                points={{58.2,20},{60,20},{60,6}}, color={0,0,127}));
          connect(heatSource1DFV_in.wall, tubeSheet_ext_cold_in.externalBoundary)
            annotation (Line(points={{-60,-1},{-60,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_in1.wall, tubeSheet_int_cold_in.externalBoundary)
            annotation (Line(points={{-40,-1},{-40,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_out.wall, tubeSheet_int_cold_out.externalBoundary)
            annotation (Line(points={{40,-1},{40,-26.2}}, color={255,127,0}));
          connect(heatSource1DFV_out1.wall, tubeSheet_ext_cold_out.externalBoundary)
            annotation (Line(points={{60,-1},{60,-26.2}}, color={255,127,0}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}})),
                               Icon(graphics));
        end HE_shell_ts_2ph;

        model FlowDependentHeatTransferCoefficient_switch
          "Flow-dependent h.t.c. gamma = gamma_nom*(w/wnom)^alpha"
          extends ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV;

           parameter Modelica.SIunits.Time t_switch;
           parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma_nom_pre
            "Nominal heat transfer coefficient for t < t_switch";
           parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma_nom_post
            "Nominal heat transfer coefficient for t >= t_switch";
           parameter Modelica.SIunits.PerUnit alpha
            "Exponent in the flow-dependency law";
           parameter Modelica.SIunits.PerUnit beta=0.1
            "Fraction of nominal flow rate below which the heat transfer is not reduced";
           parameter Modelica.SIunits.MassFlowRate wnom_ht=wnom
            "Nominal flow rate for heat transfer correlation (single tube)";
           Medium.Temperature Tvol[Nw] "Fluid temperature in the volumes";
           Modelica.SIunits.CoefficientOfHeatTransfer gamma(start=gamma_nom_pre)
            "Actual heat transfer coefficient";
           Modelica.SIunits.PerUnit w_wnom(start=1, final unit="1")
            "Ratio between actual and nominal flow rate";
           Modelica.SIunits.PerUnit w_wnom_reg
            "Regularized ratio between actual and nominal flow rate";
        equation
          assert(Nw ==  Nf - 1, "Number of volumes Nw on wall side should be equal to number of volumes fluid side Nf - 1");

          // Computation of actual heat transfer coefficient with smooth lower saturation to avoid numerical singularities at low flows
          w_wnom = abs(w[1])/wnom_ht
            "Inlet flow rate used for the computation of the h.t.c.";
          w_wnom_reg = ThermoPower.Functions.smoothSat(
            w_wnom,
            beta,
            1e9,
            beta/2);
          if time < t_switch then
            gamma = homotopy(gamma_nom_pre*w_wnom_reg^alpha,
                             gamma_nom_pre);
          else
            gamma = homotopy(gamma_nom_post*w_wnom_reg^alpha,
                             gamma_nom_post);
          end if;

          for j in 1:Nw loop
             Tvol[j] = if useAverageTemperature then (T[j] + T[j + 1])/2 else T[j+1];
             Qw[j] = (Tw[j] - Tvol[j])*gamma*omega*l*Nt;
          end for;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
                    100,100}}),
                    graphics),
            Icon(graphics={Text(extent={{-100,-52},{100,-80}}, textString="%name")}));
        end FlowDependentHeatTransferCoefficient_switch;

        model Flow1DFV_2walls
          "1-dimensional fluid flow model for water/steam (finite volumes) with internal and external wall connection"
          extends ThermoPower.Water.BaseClasses.Flow1DBase;
          import ThermoPower.Choices.Flow1D.FFtypes;
          import ThermoPower.Choices.Flow1D.HCtypes;
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length" annotation (Evaluate=true);
          parameter Modelica.SIunits.Length omega_shell
            "Perimeter of heat transfer surface (shell side)";
          Medium.ThermodynamicState fluidState[N]
            "Thermodynamic state of the fluid at the nodes";
          Modelica.SIunits.Length omega_hyd "Wet perimeter (single tube)";
          Modelica.SIunits.Pressure Dpfric
            "Pressure drop due to friction (total)";
          Modelica.SIunits.Pressure Dpfric1
            "Pressure drop due to friction (from inlet to capacitance)";
          Modelica.SIunits.Pressure Dpfric2
            "Pressure drop due to friction (from capacitance to outlet)";
          Modelica.SIunits.Pressure Dpstat "Pressure drop due to static head";
          Medium.MassFlowRate win "Flow rate at the inlet (single tube)";
          Medium.MassFlowRate wout "Flow rate at the outlet (single tube)";
          Real Kf "Hydraulic friction coefficient";
          Real dwdt "Dynamic momentum term";
          Modelica.SIunits.PerUnit Cf "Fanning friction factor";
          Medium.AbsolutePressure p(start=pstart,stateSelect=StateSelect.prefer)
            "Fluid pressure for property calculations";
          Medium.MassFlowRate w(start=wnom/Nt) "Mass flow rate (single tube)";
          Medium.MassFlowRate wbar[N - 1](each start=wnom/Nt)
            "Average flow rate through volumes (single tube)";
          Modelica.SIunits.Power Q_single_int[N - 1]=heatTransfer_int.Qvol/Nt
            "Heat flows entering the volumes from the internal lateral boundary (single tube)";
          Modelica.SIunits.Power Q_single_ext[N - 1]=heatTransfer_ext.Qvol/Nt
            "Heat flows entering the volumes from the external lateral boundary (single tube)";
        //   MassFlowRate wstar[N];
          Modelica.SIunits.Velocity u[N] "Fluid velocity";
          Medium.Temperature T[N] "Fluid temperature";
          Medium.SpecificEnthalpy h[N](start=hstart)
            "Fluid specific enthalpy at the nodes";
          Medium.SpecificEnthalpy htilde[N - 1](start=hstart[2:N],each stateSelect=StateSelect.prefer)
            "Enthalpy state variables";
          Medium.Density rho[N] "Fluid nodal density";
          Modelica.SIunits.Mass M "Fluid mass (single tube)";
          Modelica.SIunits.Mass Mtot "Fluid mass (total)";
          Modelica.SIunits.MassFlowRate dMdt[N - 1]
            "Time derivative of mass in each cell between two nodes";
          replaceable model HeatTransfer_int =
              ThermoPower.Thermal.HeatTransferFV.IdealHeatTransfer constrainedby
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            annotation (choicesAllMatching=true);
          replaceable model HeatTransfer_ext =
              ThermoPower.Thermal.HeatTransferFV.IdealHeatTransfer constrainedby
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            annotation (choicesAllMatching=true);
          HeatTransfer_int heatTransfer_int(
            redeclare package Medium = Medium,
            final Nf=N,
            final Nw=Nw,
            final Nt=Nt,
            final L=L,
            final A=A,
            final Dhyd=Dhyd,
            final omega=omega,
            final wnom=wnom/Nt,
            final w=w*ones(N),
            final fluidState=fluidState)
            "Instantiated internal heat transfer model";

          HeatTransfer_ext heatTransfer_ext(
            redeclare package Medium = Medium,
            final Nf=N,
            final Nw=Nw,
            final Nt=1,
            final L=L_shell,
            final A=A,
            final Dhyd=Dhyd,
            final omega=omega_shell,
            final wnom=wnom/Nt,
            final w=w*ones(N),
            final fluidState=fluidState)
            "Instantiated internal heat transfer model";

        protected
          Medium.Density rhobar[N - 1] "Fluid average density";
          Modelica.SIunits.SpecificVolume vbar[N - 1]
            "Fluid average specific volume";
          //HeatFlux phibar[N - 1] "Average heat flux";
          Modelica.SIunits.DerDensityByEnthalpy drdh[N]
            "Derivative of density by enthalpy";
          Modelica.SIunits.DerDensityByEnthalpy drbdh[N - 1]
            "Derivative of average density by enthalpy";
          Modelica.SIunits.DerDensityByPressure drdp[N]
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByPressure drbdp[N - 1]
            "Derivative of average density by pressure";
        public
          ThermoPower.Thermal.DHTVolumes wall_ext(final N=Nw) annotation (Placement(
                transformation(extent={{-40,-60},{40,-40}}, rotation=0),
                iconTransformation(extent={{-40,-60},{40,-40}})));
          ThermoPower.Thermal.DHTVolumes wall_int(final N=Nw) annotation (Placement(
                transformation(extent={{-40,40},{40,60}}, rotation=0)));
        equation
          //All equations are referred to a single tube
          // Friction factor selection
          omega_hyd = 4*A/Dhyd;
          if FFtype == FFtypes.Kfnom then
            Kf = Kfnom*Kfc;
          elseif FFtype == FFtypes.OpPoint then
            Kf = dpnom*rhonom/(wnom/Nt)^2*Kfc;
          elseif FFtype == FFtypes.Cfnom then
            Cf = Cfnom*Kfc;
          elseif FFtype == FFtypes.Colebrook then
            Cf = ThermoPower.Water.f_colebrook(
              w,
              Dhyd/A,
              e,
              Medium.dynamicViscosity(fluidState[integer(N/2)]))*Kfc;
          else  // if FFtype == FFtypes.NoFriction then
            Cf = 0;
          end if;
          Kf = Cf*omega_hyd*L/(2*A^3)
            "Relationship between friction coefficient and Fanning friction factor";
          assert(Kf >= 0, "Negative friction coefficient");

          // Dynamic momentum term
          if DynamicMomentum then
            dwdt = der(w);
          else
            dwdt = 0;
          end if;

          sum(dMdt) = (infl.m_flow + outfl.m_flow)/Nt "Mass balance";
          L/A*dwdt + (outfl.p - infl.p) + Dpstat + Dpfric = 0
            "Momentum balance";
          Dpfric = Dpfric1 + Dpfric2 "Total pressure drop due to friction";
          if FFtype == FFtypes.NoFriction then
            Dpfric1 = 0;
            Dpfric2 = 0;
          elseif HydraulicCapacitance == HCtypes.Middle then
            //assert((N-1)-integer((N-1)/2)*2 == 0, "N must be odd");
            Dpfric1 = homotopy(Kf*squareReg(win, wnom/Nt*wnf)*sum(vbar[1:integer((N
               - 1)/2)])/(N - 1), dpnom/2/(wnom/Nt)*win)
              "Pressure drop from inlet to capacitance";
            Dpfric2 = homotopy(Kf*squareReg(wout, wnom/Nt*wnf)*sum(vbar[1 + integer((
              N - 1)/2):N - 1])/(N - 1), dpnom/2/(wnom/Nt)*wout)
              "Pressure drop from capacitance to outlet";
          elseif HydraulicCapacitance == HCtypes.Upstream then
            Dpfric1 = 0 "Pressure drop from inlet to capacitance";
            Dpfric2 = homotopy(Kf*squareReg(wout, wnom/Nt*wnf)*sum(vbar)/(N - 1),
                               dpnom/(wnom/Nt)*wout)
              "Pressure drop from capacitance to outlet";
          else // if HydraulicCapacitance == HCtypes.Downstream then
            Dpfric1 = homotopy(Kf*squareReg(win, wnom/Nt*wnf)*sum(vbar)/(N - 1),
                               dpnom/(wnom/Nt)*win)
              "Pressure drop from inlet to capacitance";
            Dpfric2 = 0 "Pressure drop from capacitance to outlet";
          end if "Pressure drop due to friction";
          Dpstat = if abs(dzdx) < 1e-6 then 0 else g*l*dzdx*sum(rhobar)
            "Pressure drop due to static head";
          for j in 1:N-1 loop
            if Medium.singleState then
              A*l*rhobar[j]*der(htilde[j]) + wbar[j]*(h[j + 1] - h[j]) = Q_single_int[j] + Q_single_ext[j]
                "Energy balance (pressure effects neglected)";
                //Qvol = l*omega*phibar[j]
            else
              A*l*rhobar[j]*der(htilde[j]) + wbar[j]*(h[j + 1] - h[j]) - A*l*der(p) =
                Q_single_int[j] + Q_single_ext[j] "Energy balance";  //Qvol = l*omega*phibar[j]
            end if;
            dMdt[j] = A*l*(drbdh[j]*der(htilde[j]) + drbdp[j]*der(p))
              "Mass derivative for each volume";
            // Average volume quantities
            rhobar[j] = (rho[j] + rho[j + 1])/2;
            drbdp[j] = (drdp[j] + drdp[j + 1])/2;
            drbdh[j] = (drdh[j] + drdh[j + 1])/2;
            vbar[j] = 1/rhobar[j];
            wbar[j] = homotopy(infl.m_flow/Nt - sum(dMdt[1:j - 1]) - dMdt[j]/2, wnom/Nt);
          end for;

          // for j in 1:N loop
          //   wstar[j] = homotopy(infl.m_flow/Nt - sum(dMdt[1:j - 1]) - dMdt[j]/2, wnom/Nt);
          // end for;

          // Fluid property calculations
          for j in 1:N loop
            fluidState[j] = Medium.setState_ph(p, h[j]);
            T[j] = Medium.temperature(fluidState[j]);
            rho[j] = Medium.density(fluidState[j]);
            drdp[j] = if Medium.singleState then 0 else Medium.density_derp_h(
              fluidState[j]);
            drdh[j] = Medium.density_derh_p(fluidState[j]);
            u[j] = w/(rho[j]*A);
          end for;

          // Boundary conditions
          win = infl.m_flow/Nt;
          wout = -outfl.m_flow/Nt;
          assert(HydraulicCapacitance == HCtypes.Upstream or
                   HydraulicCapacitance == HCtypes.Middle or
                   HydraulicCapacitance == HCtypes.Downstream,
                   "Unsupported HydraulicCapacitance option");
          if HydraulicCapacitance == HCtypes.Middle then
            p = infl.p - Dpfric1 - Dpstat/2;
            w = win;
          elseif HydraulicCapacitance == HCtypes.Upstream then
            p = infl.p;
            w = -outfl.m_flow/Nt;
          else  // if HydraulicCapacitance == HCtypes.Downstream then
            p = outfl.p;
            w = win;
          end if;
          infl.h_outflow = htilde[1];
          outfl.h_outflow = htilde[N - 1];

          h[1] = inStream(infl.h_outflow);
          h[2:N] = htilde;

          connect(wall_int, heatTransfer_int.wall);
          connect(wall_ext, heatTransfer_ext.wall);

          Q = heatTransfer_int.Q + heatTransfer_ext.Q
            "Total heat flow through lateral boundary";
          M = sum(rhobar)*A*l "Fluid mass (single tube)";
          Mtot = M*Nt "Fluid mass (total)";
          Tr = noEvent(M/max(win, Modelica.Constants.eps)) "Residence time";
        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = pstart;
            end if;
            htilde = hstart[2:N];
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            der(htilde) = zeros(N - 1);
            if (not Medium.singleState) and not noInitialPressure then
              der(p) = 0;
            end if;
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyStateNoP then
            der(htilde) = zeros(N - 1);
            assert(false, "initOpt = steadyStateNoP deprecated, use steadyState and noInitialPressure",AssertionLevel.warning);
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyStateNoT and not
              Medium.singleState then
            der(p) = 0;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Icon(graphics={Text(extent={{-100,-60},{100,-100}},textString="%name")}),
            Documentation(info="<HTML>
<p>This model describes the flow of water or steam in a rigid tube. The basic modelling assumptions are:
<ul><li>The fluid state is always one-phase (i.e. subcooled liquid or superheated steam).
<li>Uniform velocity is assumed on the cross section, leading to a 1-D distributed parameter model.
<li>Turbulent friction is always assumed; a small linear term is added to avoid numerical singularities at zero flowrate. The friction effects are not accurately computed in the laminar and transitional flow regimes, which however should not be an issue in most applications using water or steam as a working fluid.
<li>The model is based on dynamic mass, momentum, and energy balances. The dynamic momentum term can be switched off, to avoid the fast oscillations that can arise from its coupling with the mass balance (sound wave dynamics).
<li>The longitudinal heat diffusion term is neglected.
<li>The energy balance equation is written by assuming a uniform pressure distribution; the compressibility effects are lumped at the inlet, at the outlet, or at the middle of the pipe.
<li>The fluid flow can exchange thermal power through the lateral surface, which is represented by the <tt>wall</tt> connector. The actual heat flux must be computed by a connected component (heat transfer computation module).
</ul>
<p>The mass, momentum and energy balance equation are discretised with the finite volume method. The state variables are one pressure, one flowrate (optional) and N-1 specific enthalpies.
<p>The turbulent friction factor can be either assumed as a constant, or computed by Colebrook's equation. In the former case, the friction factor can be supplied directly, or given implicitly by a specified operating point. In any case, the multiplicative correction coefficient <tt>Kfc</tt> can be used to modify the friction coefficient, e.g. to fit experimental data.
<p>A small linear pressure drop is added to avoid numerical singularities at low or zero flowrate. The <tt>wnom</tt> parameter must be always specified: the additional linear pressure drop is such that it is equal to the turbulent pressure drop when the flowrate is equal to <tt>wnf*wnom</tt> (the default value is 1% of the nominal flowrate). Increase <tt>wnf</tt> if numerical instabilities occur in tubes with very low pressure drops.
<p>Flow reversal is fully supported.
<p><b>Modelling options</b></p>
<p>Thermal variables (enthalpy, temperature, density) are computed in <tt>N</tt> equally spaced nodes, including the inlet (node 1) and the outlet (node N); <tt>N</tt> must be greater than or equal to 2.
<p>The following options are available to specify the friction coefficient:
<ul><li><tt>FFtype = FFtypes.Kfnom</tt>: the hydraulic friction coefficient <tt>Kf</tt> is set directly to <tt>Kfnom</tt>.
<li><tt>FFtype = FFtypes.OpPoint</tt>: the hydraulic friction coefficient is specified by a nominal operating point (<tt>wnom</tt>,<tt>dpnom</tt>, <tt>rhonom</tt>).
<li><tt>FFtype = FFtypes.Cfnom</tt>: the friction coefficient is computed by giving the (constant) value of the Fanning friction factor <tt>Cfnom</tt>.
<li><tt>FFtype = FFtypes.Colebrook</tt>: the Fanning friction factor is computed by Colebrook's equation (assuming Re > 2100, e.g. turbulent flow).
<li><tt>FFtype = FFtypes.NoFriction</tt>: no friction is assumed across the pipe.</ul>
<p>The dynamic momentum term is included or neglected depending on the <tt>DynamicMomentum</tt> parameter.
<p>If <tt>HydraulicCapacitance = HCtypes.Downstream</tt> (default option) then the compressibility effect depending on the pressure derivative is lumped at the outlet, while the optional dynamic momentum term depending on the flowrate is lumped at the inlet; therefore, the state variables are the outlet pressure and the inlet flowrate. If <tt>HydraulicCapacitance = HCtypes.Upstream</tt> the reverse takes place.
 If <tt>HydraulicCapacitance = HCtypes.Middle</tt>, the compressibility effect is lumped at the middle of the pipe; to use this option, an odd number of nodes N is required.
<p>Start values for the pressure and flowrate state variables are specified by <tt>pstart</tt>, <tt>wstart</tt>. The start values for the node enthalpies are linearly distributed from <tt>hstartin</tt> at the inlet to <tt>hstartout</tt> at the outlet.
<p>A bank of <tt>Nt</tt> identical tubes working in parallel can be modelled by setting <tt>Nt > 1</tt>. The geometric parameters always refer to a <i>single</i> tube.
<p>This models makes the temperature and external heat flow distributions available to connected components through the <tt>wall</tt> connector. If other variables (e.g. the heat transfer coefficient) are needed by external components to compute the actual heat flow, the <tt>wall</tt> connector can be replaced by an extended version of the <tt>DHT</tt> connector.
</HTML>",       revisions="<html>
<ul>
<li><i>16 Sep 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Option to lump compressibility at the middle added.</li>
<li><i>30 May 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Initialisation support added.</li>
<li><i>24 Mar 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       <tt>FFtypes</tt> package and <tt>NoFriction</tt> option added.</li>
<li><i>16 Dec 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Standard medium definition added.</li>
<li><i>8 Oct 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Model now based on <tt>Flow1DBase</tt>.
<li><i>24 Sep 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Removed <tt>wstart</tt>, <tt>pstart</tt>. Added <tt>pstartin</tt>, <tt>pstartout</tt>.
<li><i>22 Jun 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted to Modelica.Media.
<li><i>15 Jan 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Computation of fluid velocity <i>u</i> added. Improved treatment of geometric parameters</li>.
<li><i>1 Oct 2003</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       First release.</li>
</ul>
</html>
"));
        end Flow1DFV_2walls;

        model MetalTubeFV_kvar
          "Generic metal tube model with Nw finite volumes and variable thermal conductivity"
          extends ThermoPower.Icons.MetalWall;
          parameter Integer Nw = 1 "Number of volumes on the wall ports";
          parameter Modelica.SIunits.Mass M "Mass";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.HeatCapacity Cm=M*cm
            "Heat capacity of the wall";
          parameter Boolean WallRes=false
            "Wall thermal resistance accounted for";
          parameter Modelica.SIunits.Length D_ext
            "Insulation external diameter";
          parameter Modelica.SIunits.Length D_int
            "Insulation internal diameter";
          parameter Modelica.SIunits.Length L_shell "Shell equivalent length" annotation (Evaluate=true);
          //parameter Modelica.SIunits.ThermalConductance UA_ext=0
          //  "Equivalent thermal conductance of outer half-wall"
          //  annotation (Dialog(enable=WallRes));
          //parameter Modelica.SIunits.ThermalConductance UA_int=UA_ext
          //  "Equivalent thermal conductance of inner half-wall"
          //  annotation (Dialog(enable=WallRes));
          parameter Modelica.SIunits.ThermalConductivity knom
            "Nominal thermal conductivity";
          parameter Modelica.SIunits.Temperature Tstartbar=300
            "Average temperature"
            annotation (Dialog(tab="Initialisation"));
          parameter Modelica.SIunits.Temperature Tstart1=Tstartbar
            "Temperature start value - first volume"
            annotation (Dialog(tab="Initialisation"));
          parameter Modelica.SIunits.Temperature TstartN=Tstartbar
            "Temperature start value - last volume"
            annotation (Dialog(tab="Initialisation"));
          parameter Modelica.SIunits.Temperature Tvolstart[Nw]=
              ThermoPower.Functions.linspaceExt(
              Tstart1,
              TstartN,
              Nw);
          parameter ThermoPower.Choices.Init.Options initOpt = system.initOpt
            "Initialisation option" annotation (Dialog(tab="Initialisation"));
          constant Real pi=Modelica.Constants.pi;
          outer ThermoPower.System system "System wide properties";
          ThermoPower.Units.AbsoluteTemperature Tvol[Nw](start=Tvolstart)
            "Volume temperatures";
          Modelica.SIunits.ThermalConductivity k[Nw]
            "Local thermal conductivity";
          Modelica.SIunits.ThermalConductance UA_ext[Nw]
            "Equivalent thermal conductance of outer half-wall";
          Modelica.SIunits.ThermalConductance UA_int[Nw]
            "Equivalent thermal conductance of outer half-wall";

          ThermoPower.Thermal.DHTVolumes int(final N=Nw, T(start=Tvolstart))
            "Internal surface"
             annotation (Placement(transformation(extent={{-40,20},{40,40}}, rotation=0)));
          ThermoPower.Thermal.DHTVolumes ext(final N=Nw, T(start=Tvolstart))
            "External surface"
             annotation (Placement(transformation(extent={{-40,-42},{40,-20}}, rotation=0)));
        equation
          (Cm/Nw)*der(Tvol) = int.Q + ext.Q "Energy balance";
          if WallRes then
            assert(UA_int[1]> 0, "Assign postive values to UA");
            for j in 1:Nw loop
              k[j] = homotopy(3e-7*Tvol[j]^2 - 5e-5*Tvol[j] + 0.0265,knom);
              UA_int[j] = k[j]/log((D_int + (D_ext - D_int)/2)/D_int)*L_shell/Nw*pi;
              UA_ext[j] = k[j]/log(D_ext/(D_int + (D_ext - D_int)/2))*L_shell/Nw*pi;
            end for;
            ext.Q = (ext.T-Tvol).*UA_ext/Nw;
            int.Q = (int.T-Tvol).*UA_int/Nw;
          else
            // No temperature gradients across the thickness
            for j in 1:Nw loop
              k[j] = knom;
              UA_int[j] = 0;
              UA_ext[j] = 0;
            end for;
            ext.T = Tvol;
            int.T = Tvol;
          end if;
        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            Tvol = Tvolstart;
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            der(Tvol) = zeros(Nw);
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyStateNoT then
            // do nothing
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Icon(graphics={
                Text(
                  extent={{-100,60},{-40,20}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Int"),
                Text(
                  extent={{-100,-20},{-40,-60}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Ext"),
                Text(
                  extent={{-138,-60},{142,-100}},
                  lineColor={191,95,0},
                  textString="%name")}),
            Documentation(info="<html>
<p>Finite volumes 1D model of a generic wall for 1D heat exchangers.</p>
<p>The heat capacity of the wall is accounted for, and lumped half-way between the inner and outer surfaces.</p>
<p>The thermal resistance of the wall is optionally accounted for by setting WallRes = true; in that case, the total heat conductance of the outer and inner half-layers of the wall must then be set. For a flat (or approximately flat) wall with surface S, thickness d and conductivity lambda, both parameters are equal to 2*S*lambda/d.</p>
<h4>Modelling options</h4>
<p>The following options are available: </p>
<ul>
<li><code>WallRes = false</code>: the thermal resistance of the wall is neglected. </li>
<li><code>WallRes = true</code>: the thermal resistance of the wall is accounted for. </li>
</ul>
</html>",       revisions="<html>
<ul>
<li>11 Jul 2014 by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>Added support for wall resistance.</li>
<li><i>30 May 2005</i> by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>Initialisation support added.</li>
<li><i>1 Oct 2003</i> by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>First release. </li>
</ul>
</html>"),  Diagram(graphics));
        end MetalTubeFV_kvar;

        model CylinderFourier
          "Thermal model of a hollow cylinder by Fourier's equation - 1 axial node and Nr radial nodes"
          import Modelica.SIunits.*;
          import ThermoPower.Choices.CylinderFourier.NodeDistribution;
          extends ThermoPower.Icons.MetalWall;

          parameter Integer Nr=2 "Number of radial nodes";
          parameter NodeDistribution nodeDistribution=ThermoPower.Choices.CylinderFourier.NodeDistribution.uniform
            "Node distribution";
          parameter Modelica.SIunits.Length rint "Internal radius";
          parameter Modelica.SIunits.Length rext "External radius";
          parameter Modelica.SIunits.Length L "Cylinder length";
          parameter Modelica.SIunits.Density rhom "Material density";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Material specific heat capacity";
          parameter Modelica.SIunits.ThermalConductivity km
            "Material thermal conductivity";
          parameter Modelica.SIunits.Temperature Tstartint=300
            "Temperature start value at rint (first node)"
            annotation (Dialog(tab="Initialisation"));
          parameter Modelica.SIunits.Temperature Tstartext=300
            "Temperature start value at rext (last node)"
            annotation (Dialog(tab="Initialisation"));
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option" annotation (Dialog(tab="Initialisation"));
          constant Real pi=Modelica.Constants.pi;

          Modelica.SIunits.Length r[Nr](fixed=false) "Node radii";
        protected
          Modelica.SIunits.Length r1_2[Nr - 1](fixed=false) "Slice mean radii";
          Modelica.SIunits.Length r_lin[Nr](fixed=false)
            "Linearly distributed radii";
          Real A[Nr](fixed=false);
          Real B[Nr](fixed=false);
          Real C[Nr](fixed=false);

        public
          Modelica.SIunits.Temperature T[Nr](start=linspace(
                Tstartint,
                Tstartext,
                Nr)) "Nodal temperatures";
          Modelica.SIunits.Temperature Tm "Mean temperature";

          ThermoPower.Thermal.DHTVolumes
                                  internalBoundary(final N=1) annotation (Placement(
                transformation(extent={{-20,20},{20,40}}, rotation=0)));
          ThermoPower.Thermal.DHTVolumes
                                  externalBoundary(final N=1) annotation (Placement(
                transformation(extent={{-20,-40},{20,-20}}, rotation=0)));

        equation
          // Generation of the temperature node distribution
          r_lin = linspace(
              rint,
              rext,
              Nr) "Linearly distributed node radii";
          for i in 1:Nr loop
            if nodeDistribution == NodeDistribution.uniform then
              r[i] = r_lin[i] "Uniform distribution of node radii";
            elseif nodeDistribution == NodeDistribution.thickInternal then
              r[i] = rint + 1/(rext - rint)*(r_lin[i] - rint)^2
                "Quadratically distributed node radii - thickest at rint";
            elseif nodeDistribution == NodeDistribution.thickExternal then
              r[i] = rext - 1/(rext - rint)*(rext - r_lin[i])^2
                "Quadratically distributed node radii - thickest at rext";
            elseif nodeDistribution == NodeDistribution.thickBoth then
              if r_lin[i] <= (rint + rext)/2 then
                r[i] = 2/(rext - rint)*(r_lin[i] - rint)^2 + rint
                  "Quadratically distributed node radii - thickest at rint";
              else
                r[i] = -2/(rext - rint)*(r_lin[i] - rext)^2 + rext
                  "Quadratically distributed node radii - thickest at rext";
              end if;
            else
              r[i] = 0;
              assert(true, "Unsupported NodeDistribution type");
            end if;
          end for;
          for i in 1:Nr - 1 loop
            r1_2[i] = (r[i + 1] + r[i])/2;
          end for;

          // Spatially discretized coefficients of Fourier's equation
          for i in 2:Nr - 1 loop
            A[i] = r1_2[i - 1]/(r[i]*(r[i] - r[i - 1])*(r1_2[i] - r1_2[i - 1]));
            C[i] = r1_2[i]/(r[i]*(r[i + 1] - r[i])*(r1_2[i] - r1_2[i - 1]));
            B[i] = -A[i] - C[i];
          end for;
          // Not used by Fourier equations
          A[1] = 0;
          B[1] = 0;
          C[1] = 0;
          A[Nr] = 0;
          B[Nr] = 0;
          C[Nr] = 0;

          // Thermal field
          for i in 2:Nr - 1 loop
            rhom*cm/km*der(T[i]) = A[i]*T[i - 1] + B[i]*T[i] + C[i]*T[i + 1]
              "Fourier's equation";
          end for;

          // Thermal boundary conditions
          internalBoundary.T[1] = T[1];
          externalBoundary.T[1] = T[Nr];
          internalBoundary.Q[1] = -km*(T[2] - T[1])/(r[2] - r[1])*2*pi*rint*L;
          externalBoundary.Q[1] = km*(T[Nr] - T[Nr - 1])/(r[Nr] - r[Nr - 1])*2*pi*rext*L;

          // Mean temperature
          Tm = 1/(rext^2 - rint^2)*sum((T[i]*r[i] + T[i + 1]*r[i + 1])*(r[i + 1] - r[
            i]) for i in 1:Nr - 1);
          //  Tm = sum(T)/Nr;
        initial equation
          // Initial conditions
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            der(T[2:Nr - 1]) = zeros(Nr - 2);
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Icon(graphics={
                Text(
                  extent={{-94,52},{-42,24}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Int"),
                Text(
                  extent={{-90,-24},{-42,-50}},
                  lineColor={0,0,0},
                  fillColor={128,128,128},
                  fillPattern=FillPattern.Forward,
                  textString="Ext"),
                Text(
                  extent={{-98,-44},{102,-72}},
                  lineColor={191,95,0},
                  textString="%name")}),
            Documentation(info="<html>
This is the 1D thermal model of a solid hollow cylinder by Fourier's equations.
<p>The model is axis-symmetric, has one node in the longitudinal direction, and <tt>Nr</tt> nodes in the radial direction. The two connectors correspond to the internal and external surfaces; if one of the surface is thermally insulated, just leave the connector unconnected (no connection on a <tt>DHT</tt> connector means zero heat flux). The temperature-dependent properties of the material are described by the replaceable <tt>MaterialModel</tt> model.
<p><b>Modelling options</b></p>
The radial distribution of the nodes can be chosen by selecting the value of <tt>nodeDistribution</tt>:
<ul>
<li> <tt>Choices.CylinderFourier.NodeDistribution.uniform</tt> uniform distribution, nodes are equally spaced;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickInternal</tt> quadratic distribution, nodes are thickest near the internal surface;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickExternal</tt> quadratic distribution, nodes are thickest near the external surface;
<li> <tt>Choices.CylinderFourier.NodeDistribution.thickBoth</tt> quadratic distribution, nodes are thickest near both surfaces.
</ul>
</html>",       revisions="<html>
<ul>
<li><i>30 Dec 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Bugs fixed in boundary condition and node distribution.</li>
<li><i>1 May 2005</i>
    by <a href=\"mailto:luca.bascetta@polimi.it\">Luca Bascetta</a>:<br>
       First release.</li>
</ul>
</html>"));
        end CylinderFourier;

        model Equilibrium2phVessel
          "Base model of an adiabatic steam/liquid separator at thermodynamic equilibrium"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Length D "tank diameter";
          parameter Modelica.SIunits.Height H "Height of the tank";
          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
            "Cross Sectional Area";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.AbsolutePressure p_start "Start pressure";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));
          parameter Boolean noInitialLevel=true
            "Remove initial equation on level"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,-50},{-40,-30}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeB steam_out(
                                           redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}},  rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));

          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{40,-80},{60,-60}})));
          Modelica.Blocks.Interfaces.RealOutput DT_sh annotation (Placement(transformation(
                  extent={{-228,68},{-208,88}}), iconTransformation(extent={{40,40},{60,
                    60}})));

          Medium.ThermodynamicState state
            "Thermodynamic state of the separator";
          Medium.SaturationProperties sat
            "Saturation properties of the separator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate w_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_in
            "Medium inflow mass flow rate (liquid fraction)";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate wv_out "Medium steam outflow mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hv_out
            "Medium steam outlet specific enthalpy";
          Medium.SpecificEnthalpy hl "Bubble point specific enthalpy";
          Medium.SpecificEnthalpy hv "Dew-point specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Saturation temperature";
          Medium.AbsolutePressure p(start = p_start, stateSelect=StateSelect.prefer)
            "Medium pressure";
          Modelica.SIunits.SpecificEnthalpy h(start = h_start, stateSelect=StateSelect.prefer)
            "Specific mixture enthalpy";
          Modelica.SIunits.Density rho "Mixture density";
          ThermoPower.Units.LiquidDensity rho_l "Density of the liquid medium";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.MassFraction  x_in = Medium.vapourQuality(Medium.setState_ph(p,hl_in))
            "Inlet steam quality";
          Modelica.SIunits.MassFraction  x "Mixture steam quality";

          Real vf "Void fraction";
          Integer phase(start = 1)
            "Definition of thermodynamic state in the separator";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          phase = if h >= hv then 1 else 2;
          state = Medium.setState_ph(p,h,phase);
          T = Medium.temperature(state);
          T_sat = Medium.saturationTemperature(p);
          hv = Medium.dewEnthalpy(sat);
          hl = Medium.bubbleEnthalpy(sat);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(state);
          drdh = Medium.density_derh_p(state);
          wl_in = w_in*(1-x_in);

          //Mass and energy balances
          V*(drdp*der(p) + drdh*der(h)) = w_in - wl_out - wv_out;
          V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = w_in*hl_in - wl_out*hl_out - wv_out*hv_out;
          rho = Medium.density(state);
          x = Medium.vapourQuality(state);
          M = V*rho;
          Ml = M*(1-x);
          Ml = A*zl*rho_l;
          vf =(H-zl)/H;

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hv_out = if phase == 1 then h else hv;
          hl_out = if phase == 1 then h else hl;

          steam_out.h_outflow = hv_out;
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(steam_out.h_outflow)
            "Dummy equation for flow reversal";

          w_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          wv_out = -steam_out.m_flow;
          assert(w_in > -w_small, "Flow reversal not supported at phase separator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at phase separator liquid outlet");
          assert(wv_out > -w_small, "Flow reversal not supported at phase separator steam outlet");
          water_in.p = p;
          steam_out.p = p;
          drained_out.p = p;
          assert(vf>0,"Separator full");

          // Level sensor output
          level = zl;
          // Degree of superheating sensor
          DT_sh = max(0,T - T_sat) + 273.15;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            if not noInitialLevel then
              zl = zl_start;
            end if;
            h = h_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<html>
<p>Modelling assumptions:</p>
<ul>
<li>The state can be either saturated liquid and saturated steam at thermodynamic equilibrium, or superheated steam.</li>
<li>Full liquid state not supported</li>
<li>No flow reversal at the ports</li>
<li>Reference zero level @ empty tank</li>
</ul>
</html>"));
        end Equilibrium2phVessel;

        model NusseltCondenser_noLevel
          "Base model of condensing section based on Nusselt theory, with enthalpy and pressure as states in vapour energy balance"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));
          Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                    {-60,0}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{-118,-74},{-98,-54}}),
                                              iconTransformation(extent={{-40,-80},{-60,
                    -60}})));

          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour";
          Medium.ThermodynamicState steamIn_state
            "Thermodynamic state of the inlet vapour";
          Medium.ThermodynamicState drainedIn_state
            "Thermodynamic state of the inlet drain";
          Medium.SaturationProperties sat "Saturation properties of the vapour";

          parameter Integer Nw "Number of volumes, tube side";
          parameter Modelica.SIunits.Volume V "Total volume";
          parameter Modelica.SIunits.Area A "Cross Sectional Area";
          parameter Modelica.SIunits.Height H=V/A
            "Height of the condensing volume";
          parameter Modelica.SIunits.Area S "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC";
          parameter Modelica.SIunits.Height zl_set "Liquid level set point";
          parameter Modelica.SIunits.Height zl_start "Liquid level start";
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        public
          Medium.MassFlowRate ws_in "Steam mass flow rate";
          Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
          Medium.MassFlowRate wd_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
          Modelica.SIunits.Height zl(start = zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = hv)
            "Specific internal enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv
            "Specific saturated steam enthalpy";
          Modelica.SIunits.Density rho_v "Steam density";
          Modelica.SIunits.Density rho_l "Liquid density";
          Real x_s "Vapour quality at steam inlet";
          Real x_d "Vapour quality at drained inlet";
          Modelica.SIunits.Power Q_cond "Condensation thermal load";
          Modelica.SIunits.Power Q_des_st
            "De-superheating power of steam inlet";
          Modelica.SIunits.Power Q_des_dr
            "De-superheating power of drained inlet";
          Modelica.SIunits.Power Qw[Nw]
            "Condensation thermal load on a single volume";
          Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

          ThermoPower.Thermal.DHTVolumes DHT(
            N = Nw) annotation (Placement(
                transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                    {50,20}})));
        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          vapour_state = Medium.setState_ph(p,h);
          steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
          drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
          T = Medium.temperature(vapour_state);
          rho_v = Medium.density(vapour_state);
          hv = Medium.dewEnthalpy(sat);
          hd_out = Medium.bubbleEnthalpy(sat);
          T_sat = Medium.saturationTemperature(p);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(vapour_state);
          drdh = Medium.density_derh_p(vapour_state);
          x_s = Medium.vapourQuality(steamIn_state);
          x_d = Medium.vapourQuality(drainedIn_state);

          //Mass and energy balances
          //Liquid mass balance
          rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out;
          //Vapour mass balance
          Vv*(drdp*der(p) + drdh*der(h)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d - w_cond;
          //ws_in*x_s + wd_in*x_d - w_cond = 0;
          Vl = A*zl;
          Vv = V - Vl;
          //Vapour energy balance
          //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          //A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          //ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
          Q_des_st = max(0,ws_in*(hs_in - hv));
          Q_des_dr = max(0,wd_in*(hd_in - hv));
          for j in 1:Nw loop
            Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
          end for;
          Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
          w_cond = Q_cond/(h - hd_out);

          // Boundary conditions
          hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
             else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
            steam_in.h_outflow));
          hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
             else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
            drained_in.h_outflow));
          drained_out.h_outflow = hd_out;
          steam_in.h_outflow = inStream(drained_out.h_outflow);
          drained_in.h_outflow = inStream(drained_out.h_outflow);

          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          wd_out = -drained_out.m_flow;
          steam_in.p = p;
          drained_in.p = p;
          drained_out.p = p;

          Tw = DHT.T;
          Qw = -DHT.Q;

          // Level set-point definition
          zl_SP = zl_set;
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(zl) = 0;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = hv;
            zl = zl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end NusseltCondenser_noLevel;

        model NusseltCondenser_onlyLevel
          "Base model of condensing section based on Nusselt theory, with level as states in vapour energy balance"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-60,30},{-40,50}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,82},{10,102}}, rotation=0),
                iconTransformation(extent={{-10,110},{10,130}})));
          Modelica.Blocks.Interfaces.RealOutput zl_SP annotation (Placement(
                transformation(extent={{-96,-14},{-76,6}}), iconTransformation(extent={{-40,-20},
                    {-60,0}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{-118,-74},{-98,-54}}),
                                              iconTransformation(extent={{-40,-80},{-60,
                    -60}})));

          Medium.ThermodynamicState vapour_state
            "Thermodynamic state of the vapour";
          Medium.ThermodynamicState steamIn_state
            "Thermodynamic state of the inlet vapour";
          Medium.ThermodynamicState drainedIn_state
            "Thermodynamic state of the inlet drain";
          Medium.SaturationProperties sat "Saturation properties of the vapour";

          parameter Integer Nw "Number of volumes, tube side";
          parameter Modelica.SIunits.Volume V "Total volume";
          parameter Modelica.SIunits.Area A "Cross Sectional Area";
          parameter Modelica.SIunits.Height H=V/A
            "Height of the condensing volume";
          parameter Modelica.SIunits.Area S "Heat transfer surface";
          parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma
            "Nusselt theory HTC";
          parameter Modelica.SIunits.Height zl_set "Liquid level set point";
          parameter Modelica.SIunits.Height zl_start "Liquid level start";
          parameter Modelica.SIunits.Pressure p_start "Medium start pressure";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        public
          Medium.MassFlowRate ws_in "Steam mass flow rate";
          Medium.MassFlowRate wd_in "Drained inlet mass flow rate";
          Medium.MassFlowRate wd_out "Drained outet mass flow rate";
          Medium.MassFlowRate w_cond "Condensed vapour mass flow rate";
          Modelica.SIunits.Height zl(start = zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hs_in "Steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in "Drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_out "Drained outlet specific enthalpy";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Medium.AbsolutePressure p "Medium pressure";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = hv)
            "Specific internal enthalpy";
          Modelica.SIunits.SpecificEnthalpy hv
            "Specific saturated steam enthalpy";
          Modelica.SIunits.Density rho_v "Steam density";
          Modelica.SIunits.Density rho_l "Liquid density";
          Real x_s "Vapour quality at steam inlet";
          Real x_d "Vapour quality at drained inlet";
          Modelica.SIunits.Power Q_cond "Condensation thermal load";
          Modelica.SIunits.Power Q_des_st
            "De-superheating power of steam inlet";
          Modelica.SIunits.Power Q_des_dr
            "De-superheating power of drained inlet";
          Modelica.SIunits.Power Qw[Nw]
            "Condensation thermal load on a single volume";
          Modelica.SIunits.Temperature Tw[Nw] "Wall temperatures";

          ThermoPower.Thermal.DHTVolumes DHT(
            N = Nw) annotation (Placement(
                transformation(extent={{40,-10},{60,10}}), iconTransformation(extent={{40,-20},
                    {50,20}})));
        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          vapour_state = Medium.setState_ph(p,h);
          steamIn_state = Medium.setState_ph(p,inStream(steam_in.h_outflow));
          drainedIn_state = Medium.setState_ph(p,inStream(drained_in.h_outflow));
          T = Medium.temperature(vapour_state);
          rho_v = Medium.density(vapour_state);
          hv = Medium.dewEnthalpy(sat);
          hd_out = Medium.bubbleEnthalpy(sat);
          T_sat = Medium.saturationTemperature(p);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(vapour_state);
          drdh = Medium.density_derh_p(vapour_state);
          x_s = Medium.vapourQuality(steamIn_state);
          x_d = Medium.vapourQuality(drainedIn_state);

          //Mass and energy balances
          //Liquid mass balance
          rho_l*A*der(zl) = ws_in*(1-x_s) + wd_in*(1-x_d) + w_cond - wd_out;
          //Vapour mass balance
          Vv*(drdp*der(p) + drdh*der(h)) - rho_v*A*der(zl)= ws_in*x_s + wd_in*x_d - w_cond;
          //ws_in*x_s + wd_in*x_d - w_cond = 0;
          Vl = A*zl;
          Vv = V - Vl;
          //Vapour energy balance
          //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) + A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          A*(p-rho_v*h)*der(zl)= ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          //Vv*(rho_v + h*drdh)*der(h) + Vv*(h*drdp - 1)*der(p) = ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond;
          //ws_in*(hs_in-hd_out) + wd_in*(hd_in-hd_out) - Q_cond = 0;
          Q_des_st = max(0,ws_in*(hs_in - hv));
          Q_des_dr = max(0,wd_in*(hd_in - hv));
          for j in 1:Nw loop
            Qw[j] = gamma*S/Nw*(T_sat - Tw[j]);
          end for;
          Q_cond = sum(Qw) + Q_des_st + Q_des_dr;
          w_cond = Q_cond/(h - hd_out);

          // Boundary conditions
          hs_in = homotopy(if not allowFlowReversal then inStream(steam_in.h_outflow)
             else if ws_in >= 0 then inStream(steam_in.h_outflow) else h, inStream(
            steam_in.h_outflow));
          hd_in = homotopy(if not allowFlowReversal then inStream(drained_in.h_outflow)
             else if wd_in >= 0 then inStream(drained_in.h_outflow) else h, inStream(
            drained_in.h_outflow));
          drained_out.h_outflow = hd_out;
          steam_in.h_outflow = inStream(drained_out.h_outflow);
          drained_in.h_outflow = inStream(drained_out.h_outflow);

          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          wd_out = -drained_out.m_flow;
          steam_in.p = p;
          drained_in.p = p;
          drained_out.p = p;

          Tw = DHT.T;
          Qw = -DHT.Q;

          // Level set-point definition
          zl_SP = zl_set;
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(zl) = 0;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = hv;
            zl = zl_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}})),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end NusseltCondenser_onlyLevel;

        model Separator_controlledLevel
          "Model of a water/steam separator with control level "

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph annotation (choicesAllMatching=true);

          parameter Modelica.SIunits.Length D "tank diameter";
          final parameter Modelica.SIunits.Area A=D^2/4*Modelica.Constants.pi
            "Cross Sectional Area";
          parameter Modelica.SIunits.Height H "Height of the tank";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Real Kp "Controller proportional gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ti "Controller integral time" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Td "Controller derivative time" annotation (Dialog(tab="Level controller"));
          parameter Real Nd "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="Level controller"));
          parameter Real PVmin "Minimum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVmax "Maximum value of process variable for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmin "Minimum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real CSmax "Maximum value of control signal for scaling" annotation (Dialog(tab="Level controller"));
          parameter Real PVstart=0.5 "Start value of PV (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real CSstart=0.5 "Start value of CS (scaled)" annotation (Dialog(tab="Level controller"));
          parameter Real actuatorGain=0.5 "Actuator gain" annotation (Dialog(tab="Level controller"));
          parameter Modelica.SIunits.Time Ta "Actuator time constant" annotation (Dialog(tab="Level controller"));

          ThermoPower.PowerPlants.Control.PID PID_level(
          Kp=Kp,
          Ti=Ti,
          Td=Td,
          Nd=Nd,
          PVmin=PVmin,
          PVmax=PVmax,
          CSmin=CSmin,
          CSmax=CSmax,
          CSstart=CSstart,
          PVstart=PVstart) annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={50,-10})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = Medium,
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-64})));
          Equilibrium2phVessel             vessel(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            D=D,
            H=H,
            zl_start=zl_start,
            h_start=h_start,
            p_start=p_start)
            annotation (Placement(transformation(extent={{-58,-18},{58,88}})));
          ThermoPower.Water.FlangeA inlet(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-120,-10},{-100,10}}),
                iconTransformation(extent={{-60,-50},{-40,-30}})));
          ThermoPower.Water.FlangeB outlet_vap(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-10,100},{10,120}})));
          ThermoPower.Water.FlangeB outlet_liq(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-10,-120},{10,-100}}),
                iconTransformation(extent={{-10,-100},{10,-80}})));
          Modelica.Blocks.Continuous.FirstOrder pumpDynamic(
            k=actuatorGain,
            T=Ta) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={50,-40})));
          Modelica.Blocks.Sources.Constant zl_SP(k=4)
            annotation (Placement(transformation(extent={{80,20},{60,40}})));
        equation
          connect(vessel.drained_out, waterPump.inlet) annotation (Line(
              points={{7.10543e-015,0.928571},{7.10543e-015,-40},{1.77636e-015,
                  -40},{1.77636e-015,-54}},
              color={0,0,255},
              smooth=Smooth.None));

          connect(inlet, inlet) annotation (Line(
              points={{-110,0},{-110,0}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(inlet, vessel.water_in) annotation (Line(
              points={{-110,0},{-60,0},{-60,19.8571},{-20.7143,19.8571}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(waterPump.outlet, outlet_liq) annotation (Line(
              points={{-1.77636e-015,-74},{-1.77636e-015,-92},{0,-92},{0,-110}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(vessel.steam_out, outlet_vap) annotation (Line(
              points={{7.10543e-015,80.4286},{7.10543e-015,82},{0,82},{0,110}},
              color={0,0,255},
              smooth=Smooth.None));
          connect(vessel.level, PID_level.PV) annotation (Line(
              points={{20.7143,8.5},{46,8.5},{46,0}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(PID_level.CS, pumpDynamic.u) annotation (Line(
              points={{50,-20},{50,-28}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(pumpDynamic.y, waterPump.in_w0) annotation (Line(
              points={{50,-51},{50,-60},{6,-60}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(zl_SP.y, PID_level.SP) annotation (Line(
              points={{59,30},{54,30},{54,0}},
              color={0,0,127},
              smooth=Smooth.None));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                    -100},{100,100}}), graphics),
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-40,70},{40,-72}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,70},{-36,76},{-26,80},{-10,80},{-4,80},{2,80},{10,80},{28,
                      80},{36,76},{40,70},{18,70},{-40,70}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-40,-72},{-38,-78},{-34,-80},{-30,-80},{-26,-80},{-20,-80},{-12,
                      -80},{-6,-80},{32,-80},{38,-76},{40,-72},{-40,-72}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,0},{28,-60}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,60},{28,0}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,60},{-26,66},{-18,68},{18,68},{26,66},{28,60},{-22,58},{-28,
                      60}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,-60},{-26,-64},{-22,-68},{14,-68},{20,-68},{26,-64},{28,-60},
                      {-28,-60}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-6,110},{6,80}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end Separator_controlledLevel;

        model Deaerator "Base model of an adiabatic deaerator"

          replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
            Modelica.Media.Interfaces.PartialMedium "Medium"
            annotation (choicesAllMatching=true);

          final parameter Modelica.SIunits.Volume V=A*H "Total volume";
          final parameter Modelica.SIunits.Area A=L*H "Cross Sectional Area";
          parameter Modelica.SIunits.Length L "tank length";
          parameter Modelica.SIunits.Height H "Height of the tank (squared)";
          parameter Modelica.SIunits.Height zl_start "Medium start level";
          parameter Modelica.SIunits.Pressure p_start "Pressure start level";
          parameter Medium.SpecificEnthalpy h_start "Start specific enthalpy";
          parameter Medium.MassFlowRate w_small = 1e-3
            "Small flow rate for reverse flow check";
          outer ThermoPower.System system "System wide properties";
          parameter Boolean allowFlowReversal=system.allowFlowReversal
            "= true to allow flow reversal, false restricts to design direction";
          parameter ThermoPower.Choices.Init.Options initOpt=ThermoPower.Choices.Init.Options.noInit
            "Initialisation option";
          parameter Boolean noInitialPressure=false
            "Remove initial equation on pressure"
            annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

          ThermoPower.Water.FlangeA water_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{26,70},{46,90}})));
          ThermoPower.Water.FlangeB drained_out(redeclare package Medium = Medium,
              m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-10,-90},{10,-70}}, rotation=0),
                iconTransformation(extent={{-10,-120},{10,-100}})));
          ThermoPower.Water.FlangeA drained_in(redeclare package Medium = Medium,
              m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-140,-80},{-120,-60}})));
          ThermoPower.Water.FlangeA steam_in(redeclare package Medium = Medium, m_flow(
                min=if allowFlowReversal then -Modelica.Constants.inf else 0))
            annotation (Placement(transformation(extent={{-104,-38},{-84,-18}},
                  rotation=0), iconTransformation(extent={{-48,10},{-28,30}})));
          Modelica.Blocks.Interfaces.RealOutput level annotation (Placement(transformation(
                  extent={{40,-80},{60,-60}}),iconTransformation(extent={{120,-90},{140,
                    -70}})));

          Medium.ThermodynamicState state
            "Thermodynamic state of the deaerator";
          Medium.SaturationProperties sat
            "Saturation properties of the deaerator";

        protected
          constant Modelica.SIunits.Acceleration g=Modelica.Constants.g_n;
        public
          Medium.MassFlowRate wl_in "Medium inflow mass flow rate";
          Medium.MassFlowRate wl_out "Medium drained outflow mass flow rate";
          Medium.MassFlowRate ws_in "Medium steam inlet mass flow rate";
          Medium.MassFlowRate wd_in "Medium drained inlet mass flow rate";
          Modelica.SIunits.Height zl(start=zl_start)
            "Medium level (relative to reference)";
          Medium.SpecificEnthalpy hl_in "Medium inlet specific enthalpy";
          Medium.SpecificEnthalpy hl_out
            "Medium drained outlet specific enthalpy";
          Medium.SpecificEnthalpy hs_in "Medium steam inlet specific enthalpy";
          Medium.SpecificEnthalpy hd_in
            "Medium drained inlet specific enthalpy";
          Medium.SpecificEnthalpy hl "Medium internal specific enthalpy";
          Medium.SpecificEnthalpy hv "Medium internal specific enthalpy";
          Modelica.SIunits.Mass M "Total mass";
          Modelica.SIunits.Mass Ml "Mass of liquid";
          Medium.Temperature T "Medium temperature";
          Medium.Temperature T_sat "Medium saturation temperature";
          Modelica.SIunits.Volume Vv "Volume occupied by vapour";
          Modelica.SIunits.Volume Vl "Volume occupied by liquid medium";
          ThermoPower.Units.LiquidDensity rho_l "Density of the liquid medium";
          Modelica.SIunits.DerDensityByPressure drdp
            "Derivative of density by pressure";
          Modelica.SIunits.DerDensityByEnthalpy drdh
            "Derivative of density by enthalpy";
          Modelica.SIunits.SpecificEnthalpy h(start = h_start, stateSelect=StateSelect.prefer)
            "Specific internal enthalpy";
          Medium.AbsolutePressure p( start = p_start, stateSelect=StateSelect.prefer)
            "Medium pressure";
          Modelica.SIunits.Density rho "Density";
          Modelica.SIunits.MassFraction  x "Mixture steam quality";
          Real vf "Void fraction";
          Integer phase(start = 2)
            "Definition of thermodynamic state in the separator";

        equation
          // Fluid property calculations
          sat = Medium.setSat_p(p);
          phase = if h >= hv then 1 else 2;
          state = Medium.setState_ph(p,h,phase);
          T = Medium.temperature(state);
          T_sat = Medium.saturationTemperature(p);
          hv = Medium.dewEnthalpy(sat);
          hl = Medium.bubbleEnthalpy(sat);
          rho_l = Medium.bubbleDensity(sat);
          drdp = Medium.density_derp_h(state);
          drdh = Medium.density_derh_p(state);

          //Mass and energy balances
          V*(drdp*der(p) + drdh*der(h)) = wl_in - wl_out + ws_in + wd_in;
          V*((rho + h*drdh)*der(h) + (h*drdp - 1)*der(p)) = wl_in*hl_in - wl_out*hl_out + ws_in*hs_in + wd_in*hd_in;
          rho = Medium.density(state);
          x = Medium.vapourQuality(state);
          M = V*rho;
          Ml = M*(1-x);
          Ml = A*zl*rho_l;
          Vl = A*zl;
          Vv = V - Vl;
          vf = (H-zl)/H;

          // Boundary conditions
          hl_in = inStream(water_in.h_outflow);
          hs_in = inStream(steam_in.h_outflow);
          hd_in = inStream(drained_in.h_outflow);
          hl_out = if phase == 1 then h else hl;

          steam_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";
          drained_out.h_outflow = hl_out;
          water_in.h_outflow = inStream(drained_out.h_outflow)
            "Dummy equation for flow reversal";

          wl_in = water_in.m_flow;
          wl_out = -drained_out.m_flow;
          ws_in = steam_in.m_flow;
          wd_in = drained_in.m_flow;
          assert(wl_in > -w_small, "Flow reversal not supported at deaerator inlet");
          assert(wl_out > -w_small, "Flow reversal not supported at deaerator liquid outlet");
          assert(ws_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          assert(wd_in > -w_small, "Flow reversal not supported at deaerator steam outlet");
          water_in.p = p;
          steam_in.p = p;
          drained_out.p = p;
          drained_in.p = p;
          assert(vf>0,"Separator full");

          // Level set-point definition
          level = zl;

        initial equation
          if initOpt == ThermoPower.Choices.Init.Options.noInit then
            // do nothing
          elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
            if not noInitialPressure then
              der(p) = 0;
            end if;
            der(h) = 0;
          elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
            if not noInitialPressure then
              p = p_start;
            end if;
            h = h_start;
          else
            assert(false, "Unsupported initialisation option");
          end if;
          annotation (
            Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,
                    140}}),
                    graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                    {140,140}}),
                 graphics={
                Rectangle(
                  extent={{-120,-10},{120,-92}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-10},{-116,-4},{-106,0},{-90,0},{-84,0},{-78,0},{-70,0},
                      {110,0},{116,-4},{120,-10},{-62,-10},{-120,-10}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-120,-92},{-118,-98},{-114,-100},{-110,-100},{-106,-100},{-100,
                      -100},{-92,-100},{-86,-100},{114,-100},{118,-96},{120,-92},{-120,-92}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-34},{112,-88}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-112,-16},{112,-34}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-16},{-110,-10},{-102,-8},{104,-8},{110,-10},{112,-16},{
                      -106,-16},{-112,-16}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-112,-88},{-110,-92},{-104,-94},{0,-94},{106,-94},{110,-92},{
                      112,-88},{-112,-88}},
                  lineColor={0,0,255},
                  smooth=Smooth.None,
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-28,90},{26,0}},
                  lineColor={135,135,135},
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-28,90},{-26,96},{-20,100},{2,100},{8,100},{14,100},{16,100},
                      {22,98},{24,96},{26,90},{26,90},{-28,90}},
                  lineColor={135,135,135},
                  smooth=Smooth.None,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{-20,84},{-20,90},{-16,92},{14,92},{18,90},{18,84},{-14,84},{-20,
                      84}},
                  lineColor={85,170,255},
                  smooth=Smooth.None,
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,84},{18,-10}},
                  lineColor={85,170,255},
                  fillColor={85,170,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,76},{18,74}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,64},{10,62}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,40},{10,38}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,52},{18,50}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,28},{18,26}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-20,16},{10,14}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-12,4},{18,2}},
                  lineColor={0,0,255},
                  fillColor={0,0,255},
                  fillPattern=FillPattern.Solid)}),
            Documentation(info="<HTML></html>"));
        end Deaerator;

        model ECO_base_high
          "Base component for the model of the economizer, with 1 passes on shell side and 4 passes on water side"

          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";

          Modelica.SIunits.Power Q_Hot = a1.Q_Hot + a8.Q_Hot + b4.Q_Hot + b5.Q_Hot + c3.Q_Hot + c6.Q_Hot + d2.Q_Hot + d7.Q_Hot;
          Modelica.SIunits.Power Q_Cold = a1.Q_Cold + a8.Q_Cold + b4.Q_Cold + b5.Q_Cold + c3.Q_Cold + c6.Q_Cold + d2.Q_Cold + d7.Q_Cold;

          ThermoPower.Water.FlangeA inletHot(redeclare package Medium = hotMedium)
                                             annotation (Placement(
                transformation(extent={{-170,60},{-150,80}}),
                iconTransformation(extent={{100,-220},{120,-200}})));
          HE a8(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-70,160},{-50,140}})));
          ThermoPower.Water.SensW sensW(redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-140,74})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-110,160},{-90,140}})));
          Modelica.Blocks.Math.Gain gain(k=0.5) annotation (Placement(
                transformation(extent={{-120,76},{-112,84}})));
          HE a1(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{-70,40},{-50,20}})));
          ThermoPower.Water.Mixer mixer(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP/4)
            annotation (Placement(transformation(extent={{-12,50},{8,70}})));
          HE b5(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{70,140},{90,160}})));
          HE b4(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{70,20},{90,40}})));
          ThermoPower.Water.Mixer mixer1(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP/2)
            annotation (Placement(transformation(extent={{128,50},{148,70}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow1(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{40,160},{60,140}})));
          HE c3(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{90,-40},{70,-20}})));
          HE c6(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{90,-160},{70,-140}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow2(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{130,-40},{110,-20}})));
          ThermoPower.Water.Mixer mixer2(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP*3/4)
            annotation (Placement(transformation(extent={{42,-80},{22,-60}})));
          HE d2(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-50,-20},{-70,-40}})));
          HE d7(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-50,-140},{-70,-160}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow3(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-20},{-40,-40}})));
          ThermoPower.Water.Mixer mixer3(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP)
                                         annotation (Placement(transformation(
                  extent={{-120,-80},{-140,-60}})));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium = hotMedium)
                                              annotation (Placement(
                transformation(extent={{-170,-80},{-150,-60}}),
                iconTransformation(extent={{-120,-220},{-100,-200}})));
          ThermoPower.Water.FlangeA inletCold7(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-120},{-50,-100}}),
                iconTransformation(extent={{220,-60},{240,-40}})));
          ThermoPower.Water.FlangeA inletCold1(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,50},{-50,70}}),
                iconTransformation(extent={{-240,-160},{-220,-140}})));
          ThermoPower.Water.FlangeA inletCold3(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,-80},{90,-60}}), iconTransformation(
                  extent={{220,40},{240,60}})));
          ThermoPower.Water.FlangeB outletCold4(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,50},{90,70}}), iconTransformation(
                  extent={{-240,40},{-220,60}})));
          ThermoPower.Water.FlangeA inletCold5(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,100},{90,120}}),iconTransformation(
                  extent={{-240,140},{-220,160}})));
          ThermoPower.Water.FlangeB outletCold6(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,-120},{90,-100}}),
                iconTransformation(extent={{220,140},{240,160}})));
          ThermoPower.Water.FlangeB outletCold8(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,100},{-50,120}}),
                iconTransformation(extent={{-240,-60},{-220,-40}})));
          ThermoPower.Water.FlangeB coldOutlet2(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-80},{-50,-60}}),
                iconTransformation(extent={{220,-160},{240,-140}})));
          ThermoPower.Water.PressDropLin pressDropLin(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2))
            annotation (Placement(transformation(extent={{-110,20},{-90,40}})));
          ThermoPower.Water.PressDropLin pressDropLin1(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2))
            annotation (Placement(transformation(extent={{40,20},{60,40}})));
          ThermoPower.Water.PressDropLin pressDropLin2(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2)) annotation (
             Placement(transformation(extent={{60,-160},{40,-140}})));
          ThermoPower.Water.PressDropLin pressDropLin3(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2)) annotation (
             Placement(transformation(extent={{-80,-160},{-100,-140}})));
          ThermoPower.Water.SensW sensW1(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={20,64})));
          Modelica.Blocks.Math.Gain gain1(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=90,
                origin={46,96})));
          ThermoPower.Water.SensW sensW2(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={156,14})));
          Modelica.Blocks.Math.Gain gain2(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=270,
                origin={150,-6})));
          ThermoPower.Water.SensW sensW3(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={6,-66})));
          Modelica.Blocks.Math.Gain gain3(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=90,
                origin={-26,-46})));
        equation
          connect(sensW.inlet, inletHot) annotation (Line(points={{-146,70},{-146,70},{-160,
                  70}},                color={0,0,255}));
          connect(gain.y, throughMassFlow.in_w0) annotation (Line(points={{-111.6,80},{-104,
                  80},{-104,144}},                  color={0,0,127}));
          connect(sensW.w, gain.u)
            annotation (Line(points={{-132,80},{-120.8,80}}, color={0,0,127}));
          connect(sensW.outlet, throughMassFlow.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,150},{-110,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet,a8. inletHot) annotation (Line(
              points={{-90,150},{-70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(a1.outletHot, mixer.in2) annotation (Line(
              points={{-50,30},{-10,30},{-10,54}},
              color={255,0,0},
              thickness=0.5));
          connect(a8.outletHot, mixer.in1) annotation (Line(
              points={{-50,150},{-10,150},{-10,66}},
              color={255,0,0},
              thickness=0.5));
          connect(b4.outletHot, mixer1.in2) annotation (Line(
              points={{90,30},{130,30},{130,54}},
              color={255,0,0},
              thickness=0.5));
          connect(b5.outletHot, mixer1.in1) annotation (Line(
              points={{90,150},{130,150},{130,66}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow1.outlet,b5. inletHot) annotation (Line(
              points={{60,150},{60,150},{70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow2.outlet,c3. inletHot) annotation (Line(
              points={{110,-30},{110,-30},{90,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(c3.outletHot, mixer2.in1) annotation (Line(
              points={{70,-30},{50,-30},{40,-30},{40,-64}},
              color={255,0,0},
              thickness=0.5));
          connect(d2.inletHot, throughMassFlow3.outlet)
            annotation (Line(points={{-50,-30},{-40,-30}}, color={0,0,255}));
          connect(mixer3.in1,d2. outletHot) annotation (Line(
              points={{-122,-64},{-122,-64},{-122,-30},{-70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(outletHot, mixer3.out) annotation (Line(
              points={{-160,-70},{-150,-70},{-140,-70}},
              color={255,0,0},
              thickness=0.5));

          connect(inletCold3, inletCold3)
            annotation (Line(points={{80,-70},{80,-70}},       color={0,0,255}));
          connect(inletCold1, a1.inletCold) annotation (Line(
              points={{-60,60},{-60,40}},
              color={0,0,255},
              thickness=0.5));
          connect(a1.outletCold, d2.inletCold) annotation (Line(
              points={{-60,20},{-60,0},{-60,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(d2.outletCold, coldOutlet2) annotation (Line(
              points={{-60,-40},{-60,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(outletCold4, b4.outletCold) annotation (Line(
              points={{80,60},{80,50},{80,40}},
              color={0,0,255},
              thickness=0.5));
          connect(b4.inletCold, c3.outletCold) annotation (Line(
              points={{80,20},{80,20},{80,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(c3.inletCold, inletCold3) annotation (Line(
              points={{80,-40},{80,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(b5.inletCold, inletCold5) annotation (Line(
              points={{80,140},{80,140},{80,110}},
              color={0,0,255},
              thickness=0.5));
          connect(outletCold6, c6.outletCold) annotation (Line(
              points={{80,-110},{80,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(b5.outletCold, c6.inletCold) annotation (Line(
              points={{80,160},{80,180},{190,180},{190,-180},{80,-180},{80,-160}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold7, d7.inletCold) annotation (Line(
              points={{-60,-110},{-60,-125},{-60,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(a8.outletCold, outletCold8) annotation (Line(
              points={{-60,140},{-60,110}},
              color={0,0,255},
              thickness=0.5));
          connect(d7.outletCold, a8.inletCold) annotation (Line(
              points={{-60,-160},{-60,-180},{-190,-180},{-190,180},{-60,180},{-60,160}},
              color={0,0,255},
              thickness=0.5));

          connect(sensW.outlet, pressDropLin.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,30},{-110,30}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin.outlet, a1.inletHot) annotation (Line(
              points={{-90,30},{-70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin3.outlet, mixer3.in2) annotation (Line(
              points={{-100,-150},{-122,-150},{-122,-76}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin3.inlet, d7.outletHot) annotation (Line(
              points={{-80,-150},{-70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer2.in2, pressDropLin2.outlet) annotation (Line(
              points={{40,-76},{40,-76},{40,-146},{40,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin2.inlet, c6.outletHot) annotation (Line(
              points={{60,-150},{60,-150},{70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin1.outlet, b4.inletHot) annotation (Line(
              points={{60,30},{60,30},{70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow1.in_w0, gain1.y)
            annotation (Line(points={{46,144},{46,100.4}}, color={0,0,127}));
          connect(sensW1.w, gain1.u) annotation (Line(points={{28,70},{46,70},{
                  46,91.2}}, color={0,0,127}));
          connect(mixer.out, sensW1.inlet) annotation (Line(points={{8,60},{11,
                  60},{14,60}}, color={0,0,255}));
          connect(sensW1.outlet, throughMassFlow1.inlet) annotation (Line(
              points={{26,60},{34,60},{34,150},{40,150}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW1.outlet, pressDropLin1.inlet) annotation (Line(
              points={{26,60},{34,60},{34,30},{40,30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.w, gain2.u)
            annotation (Line(points={{150,6},{150,-1.2}}, color={0,0,127}));
          connect(gain2.y, throughMassFlow2.in_w0) annotation (Line(points={{
                  150,-10.4},{150,-18},{124,-18},{124,-24}}, color={0,0,127}));
          connect(mixer1.out, sensW2.inlet) annotation (Line(
              points={{148,60},{160,60},{160,20}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, throughMassFlow2.inlet) annotation (Line(
              points={{160,8},{160,8},{160,-30},{130,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, c6.inletHot) annotation (Line(
              points={{160,8},{160,8},{160,-150},{90,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow3.in_w0, gain3.y)
            annotation (Line(points={{-26,-36},{-26,-41.6}}, color={0,0,127}));
          connect(sensW3.inlet, mixer2.out) annotation (Line(points={{12,-70},{
                  16,-70},{22,-70}}, color={0,0,255}));
          connect(sensW3.outlet, throughMassFlow3.inlet) annotation (Line(
              points={{0,-70},{-12,-70},{-12,-30},{-20,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW3.outlet, d7.inletHot) annotation (Line(
              points={{0,-70},{-12,-70},{-12,-150},{-50,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW3.w, gain3.u) annotation (Line(points={{-2,-60},{-26,-60},
                  {-26,-50.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-220,-200},{220,200}}),
                graphics={Text(
                  extent={{-180,58},{-140,50}},
                  lineColor={28,108,200},
                  textString="HOT INLET"), Text(
                  extent={{-180,-82},{-140,-90}},
                  lineColor={28,108,200},
                  textString="HOT OUTLET")}),
              Icon(coordinateSystem(extent={{-220,-200},{220,200}}), graphics={
                Rectangle(
                  extent={{-220,156},{220,144}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,56},{220,44}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-44},{220,-56}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-144},{220,-156}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,200},{220,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Line(
                  points={{-110,-200},{-110,160},{-108,166},{-102,172},{-96,174},
                      {-86,176},{-80,176},{88,176},{100,174},{104,170},{108,166},
                      {110,162},{110,160},{110,-200}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Rectangle(
                  extent={{-2,164},{2,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillPattern=FillPattern.HorizontalCylinder)}));
        end ECO_base_high;

        model ECO_base_low
          "Base component for the model of the economizer, with 1 passes on shell side and 4 passes on water side"

          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";

          Modelica.SIunits.Power Q_Hot = d1.Q_Hot + d8.Q_Hot + c4.Q_Hot + c5.Q_Hot + b3.Q_Hot + b6.Q_Hot + a2.Q_Hot + a7.Q_Hot;
          Modelica.SIunits.Power Q_Cold = d1.Q_Cold + d8.Q_Cold + c4.Q_Cold + c5.Q_Cold + b3.Q_Cold + b6.Q_Cold + a2.Q_Cold + a7.Q_Cold;

          ThermoPower.Water.FlangeA inletHot(redeclare package Medium = hotMedium)
                                             annotation (Placement(
                transformation(extent={{-170,60},{-150,80}}),
                iconTransformation(extent={{100,-220},{120,-200}})));
          HE a7(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-70,140},{-50,160}})));
          ThermoPower.Water.SensW sensW(redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-140,74})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-110,160},{-90,140}})));
          Modelica.Blocks.Math.Gain gain(k=0.5) annotation (Placement(
                transformation(extent={{-120,76},{-112,84}})));
          HE a2(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{-70,20},{-50,40}})));
          ThermoPower.Water.Mixer mixer(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP/4)
            annotation (Placement(transformation(extent={{-12,50},{8,70}})));
          HE b6(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{70,160},{90,140}})));
          HE b3(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{70,40},{90,20}})));
          ThermoPower.Water.Mixer mixer1(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP/2)
            annotation (Placement(transformation(extent={{128,50},{148,70}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow1(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{40,160},{60,140}})));
          HE c4(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
            annotation (Placement(transformation(extent={{90,-20},{70,-40}})));
          HE c5(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{90,-140},{70,-160}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow2(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{120,-40},{100,-20}})));
          ThermoPower.Water.Mixer mixer2(redeclare package Medium = hotMedium,
            pstart=nominalHotPressure - nominalColdDeltaP*3/4,
            V=0.002)
            annotation (Placement(transformation(extent={{38,-80},{18,-60}})));
          HE d1(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-50,-40},{-70,-20}})));
          HE d8(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=false))
                annotation (Placement(transformation(extent={{-50,-160},{-70,-140}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow3(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-20},{-40,-40}})));
          ThermoPower.Water.Mixer mixer3(redeclare package Medium = hotMedium,
            V=0.002,
            pstart=nominalHotPressure - nominalColdDeltaP/4)
                                         annotation (Placement(transformation(
                  extent={{-108,-80},{-128,-60}})));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium = hotMedium)
                                              annotation (Placement(
                transformation(extent={{-170,-80},{-150,-60}}),
                iconTransformation(extent={{-120,-220},{-100,-200}})));
          ThermoPower.Water.FlangeA inletCold7(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,100},{-50,120}}),
                iconTransformation(extent={{220,-60},{240,-40}})));
          ThermoPower.Water.FlangeA inletCold1(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-80},{-50,-60}}),
                iconTransformation(extent={{-240,-160},{-220,-140}})));
          ThermoPower.Water.FlangeA inletCold3(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,50},{90,70}}),   iconTransformation(
                  extent={{220,40},{240,60}})));
          ThermoPower.Water.FlangeB outletCold4(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,-80},{90,-60}}),
                                                          iconTransformation(
                  extent={{-240,40},{-220,60}})));
          ThermoPower.Water.FlangeA inletCold5(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,-120},{90,-100}}),
                                                           iconTransformation(
                  extent={{-240,140},{-220,160}})));
          ThermoPower.Water.FlangeB outletCold6(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,100},{90,120}}),
                iconTransformation(extent={{220,140},{240,160}})));
          ThermoPower.Water.FlangeB outletCold8(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-120},{-50,-100}}),
                iconTransformation(extent={{-240,-60},{-220,-40}})));
          ThermoPower.Water.FlangeB coldOutlet2(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,50},{-50,70}}),
                iconTransformation(extent={{220,-160},{240,-140}})));
          ThermoPower.Water.PressDropLin pressDropLin(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2))
            annotation (Placement(transformation(extent={{-110,20},{-90,40}})));
          ThermoPower.Water.PressDropLin pressDropLin1(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2))
            annotation (Placement(transformation(extent={{40,20},{60,40}})));
          ThermoPower.Water.PressDropLin pressDropLin3(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2)) annotation (
             Placement(transformation(extent={{-80,-160},{-100,-140}})));
          ThermoPower.Water.PressDropLin pressDropLin2(redeclare package Medium
              = hotMedium, R=nominalHotDeltaP/4/(nominalHotFlow/2)) annotation (
             Placement(transformation(extent={{60,-160},{40,-140}})));
          ThermoPower.Water.SensW sensW1(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={20,64})));
          Modelica.Blocks.Math.Gain gain1(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=90,
                origin={46,96})));
          Modelica.Blocks.Math.Gain gain2(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=270,
                origin={150,-6})));
          ThermoPower.Water.SensW sensW2(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={156,14})));
          ThermoPower.Water.SensW sensW3(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={6,-66})));
          Modelica.Blocks.Math.Gain gain3(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=90,
                origin={-26,-46})));
        equation
          connect(sensW.inlet, inletHot) annotation (Line(points={{-146,70},{-146,70},{-160,
                  70}},                color={0,0,255}));
          connect(gain.y, throughMassFlow.in_w0) annotation (Line(points={{-111.6,80},{-104,
                  80},{-104,144}},                  color={0,0,127}));
          connect(sensW.w, gain.u)
            annotation (Line(points={{-132,80},{-120.8,80}}, color={0,0,127}));
          connect(sensW.outlet, throughMassFlow.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,150},{-110,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet,a7. inletHot) annotation (Line(
              points={{-90,150},{-70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(a2.outletHot, mixer.in2) annotation (Line(
              points={{-50,30},{-10,30},{-10,54}},
              color={255,0,0},
              thickness=0.5));
          connect(a7.outletHot, mixer.in1) annotation (Line(
              points={{-50,150},{-10,150},{-10,66}},
              color={255,0,0},
              thickness=0.5));
          connect(b3.outletHot, mixer1.in2) annotation (Line(
              points={{90,30},{130,30},{130,54}},
              color={255,0,0},
              thickness=0.5));
          connect(b6.outletHot, mixer1.in1) annotation (Line(
              points={{90,150},{130,150},{130,66}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow1.outlet,b6. inletHot) annotation (Line(
              points={{60,150},{60,150},{70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow2.outlet,c4. inletHot) annotation (Line(
              points={{100,-30},{100,-30},{90,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(c4.outletHot, mixer2.in1) annotation (Line(
              points={{70,-30},{36,-30},{36,-64}},
              color={255,0,0},
              thickness=0.5));
          connect(d1.inletHot, throughMassFlow3.outlet)
            annotation (Line(points={{-50,-30},{-40,-30}}, color={0,0,255}));
          connect(mixer3.in1,d1. outletHot) annotation (Line(
              points={{-110,-64},{-110,-64},{-110,-30},{-70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(outletHot, mixer3.out) annotation (Line(
              points={{-160,-70},{-128,-70}},
              color={255,0,0},
              thickness=0.5));

          connect(a2.inletCold, d1.outletCold) annotation (Line(
              points={{-60,20},{-60,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold1, d1.inletCold) annotation (Line(
              points={{-60,-70},{-60,-55},{-60,-40}},
              color={0,0,255},
              thickness=0.5));
          connect(a7.inletCold, inletCold7) annotation (Line(
              points={{-60,140},{-60,125},{-60,110}},
              color={0,0,255},
              thickness=0.5));
          connect(d8.outletCold, outletCold8) annotation (Line(
              points={{-60,-140},{-60,-110}},
              color={0,0,255},
              thickness=0.5));
          connect(a7.outletCold, d8.inletCold) annotation (Line(
              points={{-60,160},{-60,180},{-192,180},{-192,-180},{-60,-180},{-60,-160}},
              color={0,0,255},
              thickness=0.5));

          connect(inletCold5, c5.inletCold) annotation (Line(
              points={{80,-110},{80,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(c5.outletCold, b6.inletCold) annotation (Line(
              points={{80,-160},{80,-180},{188,-180},{188,180},{80,180},{80,160}},
              color={0,0,255},
              thickness=0.5));
          connect(b6.outletCold, outletCold6) annotation (Line(
              points={{80,140},{80,110}},
              color={0,0,255},
              thickness=0.5));
          connect(c4.outletCold, outletCold4) annotation (Line(
              points={{80,-40},{80,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(b3.outletCold, c4.inletCold) annotation (Line(
              points={{80,20},{80,20},{80,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold3, inletCold3)
            annotation (Line(points={{80,60},{80,60},{80,60}}, color={0,0,255}));
          connect(inletCold3, b3.inletCold) annotation (Line(
              points={{80,60},{80,40}},
              color={0,0,255},
              thickness=0.5));
          connect(coldOutlet2, a2.outletCold) annotation (Line(
              points={{-60,60},{-60,50},{-60,40}},
              color={0,0,255},
              thickness=0.5));
          connect(sensW.outlet, pressDropLin.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,30},{-110,30}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin.outlet, a2.inletHot) annotation (Line(
              points={{-90,30},{-80,30},{-70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin1.outlet, b3.inletHot) annotation (Line(
              points={{60,30},{70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer3.in2, pressDropLin3.outlet) annotation (Line(
              points={{-110,-76},{-110,-76},{-110,-144},{-110,-150},{-100,-150}},
              color={255,0,0},
              thickness=0.5));

          connect(pressDropLin3.inlet, d8.outletHot) annotation (Line(
              points={{-80,-150},{-76,-150},{-70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer2.in2, pressDropLin2.outlet) annotation (Line(
              points={{36,-76},{36,-150},{40,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(pressDropLin2.inlet, c5.outletHot) annotation (Line(
              points={{60,-150},{70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW1.w, gain1.u) annotation (Line(points={{28,70},{36,70},{
                  46,70},{46,91.2}}, color={0,0,127}));
          connect(throughMassFlow1.in_w0, gain1.y) annotation (Line(points={{46,
                  144},{46,100.4},{46,100.4}}, color={0,0,127}));
          connect(mixer.out, sensW1.inlet) annotation (Line(
              points={{8,60},{14,60}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW1.outlet, throughMassFlow1.inlet) annotation (Line(
              points={{26,60},{32,60},{32,150},{40,150}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW1.outlet, pressDropLin1.inlet) annotation (Line(
              points={{26,60},{32,60},{32,30},{40,30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer1.out, sensW2.inlet) annotation (Line(
              points={{148,60},{160,60},{160,20}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, throughMassFlow2.inlet) annotation (Line(
              points={{160,8},{160,-30},{120,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.w, gain2.u) annotation (Line(points={{150,6},{150,-1.2},
                  {150,-1.2}}, color={0,0,127}));
          connect(gain2.y, throughMassFlow2.in_w0) annotation (Line(points={{
                  150,-10.4},{150,-18},{114,-18},{114,-24}}, color={0,0,127}));
          connect(sensW2.outlet, c5.inletHot) annotation (Line(
              points={{160,8},{160,8},{160,-150},{90,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow3.in_w0, gain3.y) annotation (Line(points={{
                  -26,-36},{-26,-41.6},{-26,-41.6}}, color={0,0,127}));
          connect(gain3.u, sensW3.w) annotation (Line(points={{-26,-50.8},{-26,
                  -60},{-2,-60}}, color={0,0,127}));
          connect(sensW3.inlet, mixer2.out) annotation (Line(
              points={{12,-70},{18,-70}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW3.outlet, throughMassFlow3.inlet) annotation (Line(
              points={{0,-70},{-14,-70},{-14,-30},{-20,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW3.outlet, d8.inletHot) annotation (Line(
              points={{0,-70},{-14,-70},{-14,-150},{-50,-150}},
              color={255,0,0},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-220,-200},{220,200}}),
                graphics={Text(
                  extent={{-180,58},{-140,50}},
                  lineColor={28,108,200},
                  textString="HOT INLET"), Text(
                  extent={{-180,-82},{-140,-90}},
                  lineColor={28,108,200},
                  textString="HOT OUTLET")}),
              Icon(coordinateSystem(extent={{-220,-200},{220,200}}), graphics={
                Rectangle(
                  extent={{-220,156},{220,144}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,56},{220,44}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-44},{220,-56}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-144},{220,-156}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,200},{220,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Line(
                  points={{-110,-200},{-110,160},{-108,166},{-102,172},{-96,174},
                      {-86,176},{-80,176},{88,176},{100,174},{104,170},{108,166},
                      {110,162},{110,160},{110,-200}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Rectangle(
                  extent={{-2,164},{2,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillPattern=FillPattern.HorizontalCylinder)}));
        end ECO_base_low;

        model ECO_base_high_2
          "Base component for the model of the economizer, with 1 passes on shell side and 4 passes on water side"

          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";

          Modelica.SIunits.Power Q_Hot = a1.Q_Hot + a8.Q_Hot + b4.Q_Hot + b5.Q_Hot + c3.Q_Hot + c6.Q_Hot + d2.Q_Hot + d7.Q_Hot;
          Modelica.SIunits.Power Q_Cold = a1.Q_Cold + a8.Q_Cold + b4.Q_Cold + b5.Q_Cold + c3.Q_Cold + c6.Q_Cold + d2.Q_Cold + d7.Q_Cold;

          ThermoPower.Water.FlangeA inletHot(redeclare package Medium = hotMedium)
                                             annotation (Placement(
                transformation(extent={{-170,60},{-150,80}}),
                iconTransformation(extent={{100,-220},{120,-200}})));
          HE a8(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-70,160},{-50,140}})));
          ThermoPower.Water.SensW sensW(redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-140,74})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-110,160},{-90,140}})));
          Modelica.Blocks.Math.Gain gain(k=0.5) annotation (Placement(
                transformation(extent={{-120,76},{-112,84}})));
          HE a1(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{-70,40},{-50,20}})));
          HE b5(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{70,140},{90,160}})));
          HE b4(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{70,20},{90,40}})));
          ThermoPower.Water.FlowJoin
                                  mixer1(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{128,50},{148,70}})));
          HE c3(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{90,-40},{70,-20}})));
          HE c6(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{90,-160},{70,-140}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow2(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{130,-40},{110,-20}})));
          HE d2(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-50,-20},{-70,-40}})));
          HE d7(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-50,-140},{-70,-160}})));
          ThermoPower.Water.FlowJoin
                                  mixer3(redeclare package Medium = hotMedium)
                                         annotation (Placement(transformation(
                  extent={{-120,-80},{-140,-60}})));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium = hotMedium)
                                              annotation (Placement(
                transformation(extent={{-170,-80},{-150,-60}}),
                iconTransformation(extent={{-120,-220},{-100,-200}})));
          ThermoPower.Water.FlangeA inletCold7(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-120},{-50,-100}}),
                iconTransformation(extent={{220,-60},{240,-40}})));
          ThermoPower.Water.FlangeA inletCold1(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,50},{-50,70}}),
                iconTransformation(extent={{-240,-160},{-220,-140}})));
          ThermoPower.Water.FlangeA inletCold3(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,-80},{90,-60}}), iconTransformation(
                  extent={{220,40},{240,60}})));
          ThermoPower.Water.FlangeB outletCold4(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,50},{90,70}}), iconTransformation(
                  extent={{-240,40},{-220,60}})));
          ThermoPower.Water.FlangeA inletCold5(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,100},{90,120}}),iconTransformation(
                  extent={{-240,140},{-220,160}})));
          ThermoPower.Water.FlangeB outletCold6(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,-120},{90,-100}}),
                iconTransformation(extent={{220,140},{240,160}})));
          ThermoPower.Water.FlangeB outletCold8(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,100},{-50,120}}),
                iconTransformation(extent={{-240,-60},{-220,-40}})));
          ThermoPower.Water.FlangeB coldOutlet2(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-80},{-50,-60}}),
                iconTransformation(extent={{220,-160},{240,-140}})));
          ThermoPower.Water.SensW sensW2(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={156,14})));
          Modelica.Blocks.Math.Gain gain2(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=270,
                origin={150,-6})));
        equation
          connect(sensW.inlet, inletHot) annotation (Line(points={{-146,70},{-146,70},{-160,
                  70}},                color={0,0,255}));
          connect(gain.y, throughMassFlow.in_w0) annotation (Line(points={{-111.6,80},{-104,
                  80},{-104,144}},                  color={0,0,127}));
          connect(sensW.w, gain.u)
            annotation (Line(points={{-132,80},{-120.8,80}}, color={0,0,127}));
          connect(sensW.outlet, throughMassFlow.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,150},{-110,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet,a8. inletHot) annotation (Line(
              points={{-90,150},{-70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(b4.outletHot, mixer1.in2) annotation (Line(
              points={{90,30},{132,30},{132,56}},
              color={255,0,0},
              thickness=0.5));
          connect(b5.outletHot, mixer1.in1) annotation (Line(
              points={{90,150},{132,150},{132,64}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow2.outlet,c3. inletHot) annotation (Line(
              points={{110,-30},{110,-30},{90,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer3.in1,d2. outletHot) annotation (Line(
              points={{-124,-66},{-124,-66},{-124,-30},{-70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(outletHot, mixer3.out) annotation (Line(
              points={{-160,-70},{-136,-70},{-136,-70}},
              color={255,0,0},
              thickness=0.5));

          connect(inletCold3, inletCold3)
            annotation (Line(points={{80,-70},{80,-70}},       color={0,0,255}));
          connect(inletCold1, a1.inletCold) annotation (Line(
              points={{-60,60},{-60,40}},
              color={0,0,255},
              thickness=0.5));
          connect(a1.outletCold, d2.inletCold) annotation (Line(
              points={{-60,20},{-60,0},{-60,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(d2.outletCold, coldOutlet2) annotation (Line(
              points={{-60,-40},{-60,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(outletCold4, b4.outletCold) annotation (Line(
              points={{80,60},{80,50},{80,40}},
              color={0,0,255},
              thickness=0.5));
          connect(b4.inletCold, c3.outletCold) annotation (Line(
              points={{80,20},{80,20},{80,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(c3.inletCold, inletCold3) annotation (Line(
              points={{80,-40},{80,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(b5.inletCold, inletCold5) annotation (Line(
              points={{80,140},{80,140},{80,110}},
              color={0,0,255},
              thickness=0.5));
          connect(outletCold6, c6.outletCold) annotation (Line(
              points={{80,-110},{80,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(b5.outletCold, c6.inletCold) annotation (Line(
              points={{80,160},{80,180},{190,180},{190,-180},{80,-180},{80,-160}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold7, d7.inletCold) annotation (Line(
              points={{-60,-110},{-60,-125},{-60,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(a8.outletCold, outletCold8) annotation (Line(
              points={{-60,140},{-60,110}},
              color={0,0,255},
              thickness=0.5));
          connect(d7.outletCold, a8.inletCold) annotation (Line(
              points={{-60,-160},{-60,-180},{-190,-180},{-190,180},{-60,180},{-60,160}},
              color={0,0,255},
              thickness=0.5));

          connect(sensW2.w, gain2.u)
            annotation (Line(points={{150,6},{150,-1.2}}, color={0,0,127}));
          connect(gain2.y, throughMassFlow2.in_w0) annotation (Line(points={{
                  150,-10.4},{150,-18},{124,-18},{124,-24}}, color={0,0,127}));
          connect(mixer1.out, sensW2.inlet) annotation (Line(
              points={{144,60},{160,60},{160,20}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, throughMassFlow2.inlet) annotation (Line(
              points={{160,8},{160,8},{160,-30},{130,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, c6.inletHot) annotation (Line(
              points={{160,8},{160,8},{160,-150},{90,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(a8.outletHot, b5.inletHot) annotation (Line(
              points={{-50,150},{10,150},{70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(d2.inletHot, c3.outletHot) annotation (Line(
              points={{-50,-30},{10,-30},{70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer3.in2, d7.outletHot) annotation (Line(
              points={{-124,-74},{-124,-74},{-124,-112},{-124,-150},{-70,-150}},
              color={255,0,0},
              thickness=0.5));

          connect(d7.inletHot, c6.outletHot) annotation (Line(
              points={{-50,-150},{70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW.outlet, a1.inletHot) annotation (Line(
              points={{-134,70},{-126,70},{-126,30},{-70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(a1.outletHot, b4.inletHot) annotation (Line(
              points={{-50,30},{10,30},{70,30}},
              color={255,0,0},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-220,-200},{220,200}}),
                graphics={Text(
                  extent={{-180,58},{-140,50}},
                  lineColor={28,108,200},
                  textString="HOT INLET"), Text(
                  extent={{-180,-82},{-140,-90}},
                  lineColor={28,108,200},
                  textString="HOT OUTLET")}),
              Icon(coordinateSystem(extent={{-220,-200},{220,200}}), graphics={
                Rectangle(
                  extent={{-220,156},{220,144}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,56},{220,44}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-44},{220,-56}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-144},{220,-156}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,200},{220,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Line(
                  points={{-110,-200},{-110,160},{-108,166},{-102,172},{-96,174},
                      {-86,176},{-80,176},{88,176},{100,174},{104,170},{108,166},
                      {110,162},{110,160},{110,-200}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Rectangle(
                  extent={{-2,164},{2,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillPattern=FillPattern.HorizontalCylinder)}));
        end ECO_base_high_2;

        model ECO_base_low_2
          "Base component for the model of the economizer, with 1 passes on shell side and 4 passes on water side"

          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          parameter Integer Nhex = 2 "Number of nodes for the heat exchanger";
          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";

          Modelica.SIunits.Power Q_Hot = d1.Q_Hot + d8.Q_Hot + c4.Q_Hot + c5.Q_Hot + b3.Q_Hot + b6.Q_Hot + a2.Q_Hot + a7.Q_Hot;
          Modelica.SIunits.Power Q_Cold = d1.Q_Cold + d8.Q_Cold + c4.Q_Cold + c5.Q_Cold + b3.Q_Cold + b6.Q_Cold + a2.Q_Cold + a7.Q_Cold;

          ThermoPower.Water.FlangeA inletHot(redeclare package Medium = hotMedium)
                                             annotation (Placement(
                transformation(extent={{-170,60},{-150,80}}),
                iconTransformation(extent={{100,-220},{120,-200}})));
          HE a7(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-70,140},{-50,160}})));
          ThermoPower.Water.SensW sensW(redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-140,74})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-110,160},{-90,140}})));
          Modelica.Blocks.Math.Gain gain(k=0.5) annotation (Placement(
                transformation(extent={{-120,76},{-112,84}})));
          HE a2(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{-70,20},{-50,40}})));
          HE b6(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{70,160},{90,140}})));
          HE b3(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{70,40},{90,20}})));
          ThermoPower.Water.FlowJoin
                                  mixer1(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{128,50},{148,70}})));
          HE c4(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
            annotation (Placement(transformation(extent={{90,-20},{70,-40}})));
          HE c5(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{90,-140},{70,-160}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow2(use_in_w0=true, redeclare
              package Medium = hotMedium)
            annotation (Placement(transformation(extent={{120,-40},{100,-20}})));
          HE d1(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-50,-40},{-70,-20}})));
          HE d8(redeclare package coldMedium = coldMedium, redeclare package
              hotMedium =
                hotMedium,
            Vhot=Vhot/8,
            Vcold=Vcold/8,
            Shot=Shot/8,
            Scold=Scold/8,
            Mm=Mm/8,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow/2,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            nominalHotDeltaP=nominalHotDeltaP,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Nhex=Nhex,
            nominalColdInletTemperature=274.15,
            nominalColdOutletTemperature=274.15,
            nominalHotInletTemperature=274.15,
            nominalHotOutletTemperature=274.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true))
                annotation (Placement(transformation(extent={{-50,-160},{-70,-140}})));
          ThermoPower.Water.FlowJoin
                                  mixer3(redeclare package Medium = hotMedium)
                                         annotation (Placement(transformation(
                  extent={{-108,-80},{-128,-60}})));
          ThermoPower.Water.FlangeB outletHot(redeclare package Medium = hotMedium)
                                              annotation (Placement(
                transformation(extent={{-170,-80},{-150,-60}}),
                iconTransformation(extent={{-120,-220},{-100,-200}})));
          ThermoPower.Water.FlangeA inletCold7(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,100},{-50,120}}),
                iconTransformation(extent={{220,-60},{240,-40}})));
          ThermoPower.Water.FlangeA inletCold1(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-80},{-50,-60}}),
                iconTransformation(extent={{-240,-160},{-220,-140}})));
          ThermoPower.Water.FlangeA inletCold3(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,50},{90,70}}),   iconTransformation(
                  extent={{220,40},{240,60}})));
          ThermoPower.Water.FlangeB outletCold4(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,-80},{90,-60}}),
                                                          iconTransformation(
                  extent={{-240,40},{-220,60}})));
          ThermoPower.Water.FlangeA inletCold5(redeclare package Medium = coldMedium)
                                               annotation (Placement(
                transformation(extent={{70,-120},{90,-100}}),
                                                           iconTransformation(
                  extent={{-240,140},{-220,160}})));
          ThermoPower.Water.FlangeB outletCold6(redeclare package Medium = coldMedium)
                                                annotation (Placement(
                transformation(extent={{70,100},{90,120}}),
                iconTransformation(extent={{220,140},{240,160}})));
          ThermoPower.Water.FlangeB outletCold8(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,-120},{-50,-100}}),
                iconTransformation(extent={{-240,-60},{-220,-40}})));
          ThermoPower.Water.FlangeB coldOutlet2(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{-70,50},{-50,70}}),
                iconTransformation(extent={{220,-160},{240,-140}})));
          Modelica.Blocks.Math.Gain gain2(
                                         k=0.5) annotation (Placement(
                transformation(extent={{-4,-4},{4,4}},
                rotation=270,
                origin={150,-6})));
          ThermoPower.Water.SensW sensW2(
                                        redeclare package Medium = hotMedium)
                                        annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={156,14})));
        equation
          connect(sensW.inlet, inletHot) annotation (Line(points={{-146,70},{-146,70},{-160,
                  70}},                color={0,0,255}));
          connect(gain.y, throughMassFlow.in_w0) annotation (Line(points={{-111.6,80},{-104,
                  80},{-104,144}},                  color={0,0,127}));
          connect(sensW.w, gain.u)
            annotation (Line(points={{-132,80},{-120.8,80}}, color={0,0,127}));
          connect(sensW.outlet, throughMassFlow.inlet) annotation (Line(
              points={{-134,70},{-126,70},{-126,150},{-110,150}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet,a7. inletHot) annotation (Line(
              points={{-90,150},{-70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(b3.outletHot, mixer1.in2) annotation (Line(
              points={{90,30},{132,30},{132,56}},
              color={255,0,0},
              thickness=0.5));
          connect(b6.outletHot, mixer1.in1) annotation (Line(
              points={{90,150},{132,150},{132,64}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow2.outlet,c4. inletHot) annotation (Line(
              points={{100,-30},{100,-30},{90,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer3.in1,d1. outletHot) annotation (Line(
              points={{-112,-66},{-112,-66},{-112,-30},{-70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(outletHot, mixer3.out) annotation (Line(
              points={{-160,-70},{-124,-70}},
              color={255,0,0},
              thickness=0.5));

          connect(a2.inletCold, d1.outletCold) annotation (Line(
              points={{-60,20},{-60,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold1, d1.inletCold) annotation (Line(
              points={{-60,-70},{-60,-55},{-60,-40}},
              color={0,0,255},
              thickness=0.5));
          connect(a7.inletCold, inletCold7) annotation (Line(
              points={{-60,140},{-60,125},{-60,110}},
              color={0,0,255},
              thickness=0.5));
          connect(d8.outletCold, outletCold8) annotation (Line(
              points={{-60,-140},{-60,-110}},
              color={0,0,255},
              thickness=0.5));
          connect(a7.outletCold, d8.inletCold) annotation (Line(
              points={{-60,160},{-60,180},{-192,180},{-192,-180},{-60,-180},{-60,-160}},
              color={0,0,255},
              thickness=0.5));

          connect(inletCold5, c5.inletCold) annotation (Line(
              points={{80,-110},{80,-140}},
              color={0,0,255},
              thickness=0.5));
          connect(c5.outletCold, b6.inletCold) annotation (Line(
              points={{80,-160},{80,-180},{188,-180},{188,180},{80,180},{80,160}},
              color={0,0,255},
              thickness=0.5));
          connect(b6.outletCold, outletCold6) annotation (Line(
              points={{80,140},{80,110}},
              color={0,0,255},
              thickness=0.5));
          connect(c4.outletCold, outletCold4) annotation (Line(
              points={{80,-40},{80,-70}},
              color={0,0,255},
              thickness=0.5));
          connect(b3.outletCold, c4.inletCold) annotation (Line(
              points={{80,20},{80,20},{80,-20}},
              color={0,0,255},
              thickness=0.5));
          connect(inletCold3, inletCold3)
            annotation (Line(points={{80,60},{80,60},{80,60}}, color={0,0,255}));
          connect(inletCold3, b3.inletCold) annotation (Line(
              points={{80,60},{80,40}},
              color={0,0,255},
              thickness=0.5));
          connect(coldOutlet2, a2.outletCold) annotation (Line(
              points={{-60,60},{-60,50},{-60,40}},
              color={0,0,255},
              thickness=0.5));

          connect(mixer1.out, sensW2.inlet) annotation (Line(
              points={{144,60},{160,60},{160,20}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.outlet, throughMassFlow2.inlet) annotation (Line(
              points={{160,8},{160,-30},{120,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW2.w, gain2.u) annotation (Line(points={{150,6},{150,-1.2},
                  {150,-1.2}}, color={0,0,127}));
          connect(gain2.y, throughMassFlow2.in_w0) annotation (Line(points={{
                  150,-10.4},{150,-18},{114,-18},{114,-24}}, color={0,0,127}));
          connect(sensW2.outlet, c5.inletHot) annotation (Line(
              points={{160,8},{160,8},{160,-150},{90,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(a7.outletHot, b6.inletHot) annotation (Line(
              points={{-50,150},{10,150},{70,150}},
              color={255,0,0},
              thickness=0.5));
          connect(d1.inletHot, c4.outletHot) annotation (Line(
              points={{-50,-30},{10,-30},{70,-30}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW.outlet, a2.inletHot) annotation (Line(
              points={{-134,70},{-126,70},{-126,30},{-70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(a2.outletHot, b3.inletHot) annotation (Line(
              points={{-50,30},{10,30},{70,30}},
              color={255,0,0},
              thickness=0.5));
          connect(mixer3.in2, d8.outletHot) annotation (Line(
              points={{-112,-74},{-112,-74},{-112,-114},{-112,-146},{-112,-150},
                  {-70,-150}},
              color={255,0,0},
              thickness=0.5));
          connect(d8.inletHot, c5.outletHot) annotation (Line(
              points={{-50,-150},{10,-150},{70,-150}},
              color={255,0,0},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-220,-200},{220,200}}),
                graphics={Text(
                  extent={{-180,58},{-140,50}},
                  lineColor={28,108,200},
                  textString="HOT INLET"), Text(
                  extent={{-180,-82},{-140,-90}},
                  lineColor={28,108,200},
                  textString="HOT OUTLET")}),
              Icon(coordinateSystem(extent={{-220,-200},{220,200}}), graphics={
                Rectangle(
                  extent={{-220,156},{220,144}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,56},{220,44}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-44},{220,-56}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,-144},{220,-156}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillColor={135,135,135},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-220,200},{220,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Line(
                  points={{-110,-200},{-110,160},{-108,166},{-102,172},{-96,174},
                      {-86,176},{-80,176},{88,176},{100,174},{104,170},{108,166},
                      {110,162},{110,160},{110,-200}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.Filled,Arrow.None}),
                Rectangle(
                  extent={{-2,164},{2,-200}},
                  lineColor={0,0,0},
                  lineThickness=0.5,
                  fillPattern=FillPattern.HorizontalCylinder)}));
        end ECO_base_low_2;

        model ECO_complete "Complete model of the economizer"

        extends
            PreFlexMS.Pilot_245degC.HeatExchangers.BaseClasses.BaseWaterMSHeatExchanger;

          replaceable package coldMedium =
              Modelica.Media.Interfaces.PartialTwoPhaseMedium
            "Water/steam fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable package hotMedium =
              Modelica.Media.Interfaces.PartialPureSubstance
            "MS fluid medium model"
              annotation(choicesAllMatching = true);
          replaceable model HeatTransferCold =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, cold fluid side"
            annotation(choicesAllMatching = true);
          replaceable model HeatTransferHot =
            ThermoPower.Thermal.BaseClasses.DistributedHeatTransferFV
            "Heat transfer model, hot fluid side"
            annotation(choicesAllMatching = true);

          parameter Modelica.SIunits.Volume Vhot
            "Volume of the fluid in the hot side";
          parameter Modelica.SIunits.Volume Vcold
            "Volume of the fluid in the cold side";
          parameter Modelica.SIunits.Area Shot
            "Heat transfer surface in the hot side";
          parameter Modelica.SIunits.Area Scold
            "Heat transfer surface in the cold side";
          final parameter Modelica.SIunits.Length L=1
            "Lenght of the fluid path (unused)";
          parameter Modelica.SIunits.Mass Mm
            "Mass of the metal between the two fluids";
          parameter Modelica.SIunits.SpecificHeatCapacity cm
            "Specific heat capacity of metal";
          parameter Modelica.SIunits.MassFlowRate nominalColdFlow
            "Nominal flow rate of cold fluid";
          parameter Modelica.SIunits.MassFlowRate nominalHotFlow
            "Nominal flow rate of hot fluid";
          parameter Modelica.SIunits.Pressure nominalColdPressure
            "Nominal inlet pressure of cold fluid";
          parameter Modelica.SIunits.Pressure nominalColdDeltaP
            "Nominal cold fluid pressure loss";
          parameter Modelica.SIunits.Pressure nominalHotPressure
            "Nominal inlet pressure of hot fluid";
          parameter Modelica.SIunits.Pressure nominalHotDeltaP
            "Nominal hot fluid pressure loss";
          parameter Modelica.SIunits.Temperature nominalColdInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalColdOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";
          parameter Modelica.SIunits.Temperature nominalHotInletTemperature
            "Nominal value of cold fluid temperature at the inlet";
          parameter Modelica.SIunits.Temperature nominalHotOutletTemperature
            "Nominal value of cold fluid temperature at the outlet";

          Modelica.SIunits.Power Q_Hot = ECO1.Q_Hot + ECO2.Q_Hot + ECO3.Q_Hot + ECO4.Q_Hot;
          Modelica.SIunits.Power Q_Cold = ECO1.Q_Cold + ECO2.Q_Cold + ECO3.Q_Cold + ECO4.Q_Cold;

          ECO_base_high_2
                        ECO1(
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Vhot=Vhot/4,
            Vcold=Vcold/4,
            Shot=Shot/4,
            Scold=Scold/4,
            Mm=Mm/4,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            nominalHotPressure=nominalHotPressure,
            Nhex=1,
            a1(
              nominalColdInletTemperature=566.15,
              nominalColdOutletTemperature=569.15,
              nominalHotInletTemperature=628.15,
              nominalHotOutletTemperature=624.15),
            d2(
              nominalColdInletTemperature=569.15,
              nominalColdOutletTemperature=572.15,
              nominalHotInletTemperature=616.15,
              nominalHotOutletTemperature=612.15),
            c3(
              nominalColdInletTemperature=584.15,
              nominalColdOutletTemperature=587.15,
              nominalHotInletTemperature=620.15,
              nominalHotOutletTemperature=616.15),
            b4(
              nominalColdInletTemperature=587.15,
              nominalColdOutletTemperature=590.15,
              nominalHotInletTemperature=624.15,
              nominalHotOutletTemperature=620.15),
            b5(
              nominalColdInletTemperature=590.15,
              nominalColdOutletTemperature=593.15,
              nominalHotInletTemperature=624.15,
              nominalHotOutletTemperature=620.15),
            c6(
              nominalColdInletTemperature=593.15,
              nominalColdOutletTemperature=596.15,
              nominalHotInletTemperature=620.15,
              nominalHotOutletTemperature=616.15),
            d7(
              nominalColdInletTemperature=608.15,
              nominalColdOutletTemperature=611.15,
              nominalHotInletTemperature=616.15,
              nominalHotOutletTemperature=612.15),
            a8(
              nominalColdInletTemperature=611.15,
              nominalColdOutletTemperature=614.15,
              nominalHotInletTemperature=628.15,
              nominalHotOutletTemperature=624.15),
            nominalHotDeltaP=nominalHotDeltaP/4)
            annotation (Placement(transformation(extent={{-18,20},{-62,60}})));
          ECO_base_low_2
                       ECO4(
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Vhot=Vhot/4,
            Vcold=Vcold/4,
            Shot=Shot/4,
            Scold=Scold/4,
            Mm=Mm/4,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            Nhex=1,
            d1(
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=521.15,
              nominalHotInletTemperature=568.15,
              nominalHotOutletTemperature=564.15),
            a2(
              nominalColdInletTemperature=521.15,
              nominalColdOutletTemperature=524.15,
              nominalHotInletTemperature=580.15,
              nominalHotOutletTemperature=576.15),
            b3(
              nominalColdInletTemperature=536.15,
              nominalColdOutletTemperature=539.15,
              nominalHotInletTemperature=576.15,
              nominalHotOutletTemperature=572.15),
            c4(
              nominalColdInletTemperature=539.15,
              nominalColdOutletTemperature=542.15,
              nominalHotInletTemperature=572.15,
              nominalHotOutletTemperature=568.15),
            c5(
              nominalColdInletTemperature=542.15,
              nominalColdOutletTemperature=545.15,
              nominalHotInletTemperature=572.15,
              nominalHotOutletTemperature=568.15),
            b6(
              nominalColdInletTemperature=545.15,
              nominalColdOutletTemperature=548.15,
              nominalHotInletTemperature=576.15,
              nominalHotOutletTemperature=572.15),
            a7(
              nominalColdInletTemperature=560.15,
              nominalColdOutletTemperature=563.15,
              nominalHotInletTemperature=580.15,
              nominalHotOutletTemperature=576.15),
            d8(
              nominalColdInletTemperature=563.15,
              nominalColdOutletTemperature=566.15,
              nominalHotInletTemperature=568.15,
              nominalHotOutletTemperature=564.15),
            nominalHotPressure=nominalHotPressure - nominalHotDeltaP*3/4,
            nominalHotDeltaP=nominalHotDeltaP/4)
            annotation (Placement(transformation(extent={{-62,-20},{-18,-60}})));
          ECO_base_high_2
                        ECO2(
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Vhot=Vhot/4,
            Vcold=Vcold/4,
            Shot=Shot/4,
            Scold=Scold/4,
            Mm=Mm/4,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            Nhex=1,
            a1(
              nominalColdInletTemperature=572.15,
              nominalColdOutletTemperature=575.15,
              nominalHotInletTemperature=612.15,
              nominalHotOutletTemperature=608.15),
            d2(
              nominalColdInletTemperature=575.15,
              nominalColdOutletTemperature=578.15,
              nominalHotInletTemperature=600.15,
              nominalHotOutletTemperature=596.15),
            c3(
              nominalColdInletTemperature=578.15,
              nominalColdOutletTemperature=581.15,
              nominalHotInletTemperature=604.15,
              nominalHotOutletTemperature=600.15),
            b4(
              nominalColdInletTemperature=581.15,
              nominalColdOutletTemperature=584.15,
              nominalHotInletTemperature=608.15,
              nominalHotOutletTemperature=604.15),
            b5(
              nominalColdInletTemperature=596.15,
              nominalColdOutletTemperature=599.15,
              nominalHotInletTemperature=608.15,
              nominalHotOutletTemperature=604.15),
            c6(
              nominalColdInletTemperature=599.15,
              nominalColdOutletTemperature=602.15,
              nominalHotInletTemperature=604.15,
              nominalHotOutletTemperature=600.15),
            d7(
              nominalColdInletTemperature=602.15,
              nominalColdOutletTemperature=605.15,
              nominalHotInletTemperature=600.15,
              nominalHotOutletTemperature=596.15),
            a8(
              nominalColdInletTemperature=605.15,
              nominalColdOutletTemperature=608.15,
              nominalHotInletTemperature=612.15,
              nominalHotOutletTemperature=608.15),
            nominalHotPressure=nominalHotPressure - nominalHotDeltaP/4,
            nominalHotDeltaP=nominalHotDeltaP/4)
            annotation (Placement(transformation(extent={{62,20},{18,60}})));
          ECO_base_low_2
                       ECO3(
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold = HeatTransferCold,
            redeclare model HeatTransferHot = HeatTransferHot,
            Vhot=Vhot/4,
            Vcold=Vcold/4,
            Shot=Shot/4,
            Scold=Scold/4,
            Mm=Mm/4,
            cm=cm,
            nominalColdFlow=nominalColdFlow,
            nominalHotFlow=nominalHotFlow,
            nominalColdPressure=nominalColdPressure,
            nominalColdDeltaP=nominalColdDeltaP,
            Nhex=1,
            d1(
              nominalColdInletTemperature=524.15,
              nominalColdOutletTemperature=527.15,
              nominalHotInletTemperature=584.15,
              nominalHotOutletTemperature=580.15),
            a2(
              nominalColdInletTemperature=527.15,
              nominalColdOutletTemperature=530.15,
              nominalHotInletTemperature=596.15,
              nominalHotOutletTemperature=592.15),
            b3(
              nominalColdInletTemperature=530.15,
              nominalColdOutletTemperature=533.15,
              nominalHotInletTemperature=592.15,
              nominalHotOutletTemperature=588.15),
            c4(
              nominalColdInletTemperature=533.15,
              nominalColdOutletTemperature=536.15,
              nominalHotInletTemperature=588.15,
              nominalHotOutletTemperature=584.15),
            c5(
              nominalColdInletTemperature=548.15,
              nominalColdOutletTemperature=551.15,
              nominalHotInletTemperature=588.15,
              nominalHotOutletTemperature=584.15),
            b6(
              nominalColdInletTemperature=551.15,
              nominalColdOutletTemperature=554.15,
              nominalHotInletTemperature=592.15,
              nominalHotOutletTemperature=588.15),
            a7(
              nominalColdInletTemperature=554.15,
              nominalColdOutletTemperature=557.15,
              nominalHotInletTemperature=596.15,
              nominalHotOutletTemperature=592.15),
            d8(
              nominalColdInletTemperature=557.15,
              nominalColdOutletTemperature=560.15,
              nominalHotInletTemperature=584.15,
              nominalHotOutletTemperature=580.15),
            nominalHotPressure=nominalHotPressure - nominalHotDeltaP/2,
            nominalHotDeltaP=nominalHotDeltaP/4)
            annotation (Placement(transformation(extent={{18,-20},{62,-60}})));
        equation
          connect(ECO1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-29,19},{-29,10},{29,10},{29,19}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO2.outletHot, ECO3.inletHot) annotation (Line(
              points={{51,19},{51,-0.5},{51,-19}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO3.outletHot, ECO4.inletHot) annotation (Line(
              points={{29,-19},{29,-10},{-29,-10},{-29,-19}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(inletHot, ECO1.inletHot) annotation (Line(
              points={{-100,0},{-90,0},{-80,0},{-80,10},{-51,10},{-51,19}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO4.outletHot, outletHot) annotation (Line(
              points={{-51,-19},{-51,0},{100,0}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(inletCold, ECO4.inletCold1) annotation (Line(
              points={{0,-100},{-100,-100},{-100,-25},{-63,-25}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO4.coldOutlet2, ECO3.inletCold1) annotation (Line(
              points={{-17,-25},{0.5,-25},{17,-25}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO3.coldOutlet2, ECO3.inletCold3) annotation (Line(
              points={{63,-25},{68,-25},{68,-45},{63,-45}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO3.outletCold4, ECO4.inletCold3) annotation (Line(
              points={{17,-45},{0.5,-45},{-17,-45}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO4.outletCold4, ECO4.inletCold5) annotation (Line(
              points={{-63,-45},{-70,-45},{-70,-55},{-63,-55}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO4.outletCold6, ECO3.inletCold5) annotation (Line(
              points={{-17,-55},{-0.5,-55},{17,-55}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO3.outletCold6, ECO3.inletCold7) annotation (Line(
              points={{63,-55},{74,-55},{74,-35},{63,-35}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO3.outletCold8, ECO4.inletCold7) annotation (Line(
              points={{17,-35},{0.5,-35},{-17,-35}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO4.outletCold8, ECO2.inletCold1) annotation (Line(
              points={{-63,-35},{-80,-35},{-80,-80},{80,-80},{80,25},{63,25}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.coldOutlet2, ECO1.inletCold1) annotation (Line(
              points={{17,25},{-17,25}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.coldOutlet2, ECO1.inletCold3) annotation (Line(
              points={{-63,25},{-68,25},{-68,45},{-63,45}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold4, ECO2.inletCold3) annotation (Line(
              points={{-17,45},{-17,45},{17,45}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.outletCold4, ECO2.inletCold5) annotation (Line(
              points={{63,45},{70,45},{70,55},{63,55}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.outletCold6, ECO1.inletCold5) annotation (Line(
              points={{17,55},{-17,55}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold6, ECO1.inletCold7) annotation (Line(
              points={{-63,55},{-74,55},{-74,35},{-63,35}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold8, ECO2.inletCold7) annotation (Line(
              points={{-17,35},{-17,35},{17,35}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.outletCold8, outletCold) annotation (Line(
              points={{63,35},{80,35},{80,80},{0,80},{0,100}},
              color={0,0,255},
              thickness=0.5));
          annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                coordinateSystem(preserveAspectRatio=false)));
        end ECO_complete;

        package Test

          model test_Separator
            "Controlled separator test, with filling and dryout procedure"

            ThermoPower.Water.SinkPressure sinkPressure(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17200000)
              annotation (Placement(transformation(extent={{20,50},{40,70}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow(
              h=2872800,
              use_in_h=true,
              use_in_w0=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=1.757)
              annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{100,100},{120,120}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=500,
              startTime=10,
              offset=2772800,
              height=-9e5)
              annotation (Placement(transformation(extent={{-100,30},{-80,50}})));
            Separator_controlledLevel base_2ph_vessel(
              Kp=-250,
              Ti=20,
              Td=0,
              Nd=1,
              PVmin=0,
              PVmax=20,
              CSmin=0,
              CSmax=150,
              actuatorGain=1,
              Ta=5,
              h_start=2740000,
              vessel(initOpt=ThermoPower.Choices.Init.Options.fixedState,
                  noInitialPressure=true),
              D=0.28,
              H=6.2,
              zl_start=3.1,
              p_start=17710000,
              zl_SP(k=3.1))
              annotation (Placement(transformation(extent={{-18,-20},{38,36}})));
            ThermoPower.Water.SinkPressure sinkPressure1(redeclare package
                Medium =
                  Modelica.Media.Water.WaterIF97_ph, p0=17200000)
              annotation (Placement(transformation(extent={{20,-50},{40,-30}})));
            Modelica.Blocks.Sources.Ramp ramp1(
              duration=500,
              offset=0,
              startTime=1500,
              height=9e5)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
          equation
            connect(sourceMassFlow.flange, base_2ph_vessel.inlet) annotation (Line(
                points={{-20,0},{0,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(base_2ph_vessel.outlet_vap, sinkPressure.flange) annotation (
                Line(
                points={{10,30},{10,60},{20,60}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(base_2ph_vessel.outlet_liq, sinkPressure1.flange) annotation (
                Line(
                points={{10,-10},{10,-40},{20,-40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(add.y, sourceMassFlow.in_h) annotation (Line(
                points={{-39,60},{-26,60},{-26,6}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(ramp.y, add.u2) annotation (Line(
                points={{-79,40},{-70,40},{-70,54},{-62,54}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(ramp1.y, add.u1) annotation (Line(
                points={{-79,80},{-70,80},{-70,66},{-62,66}},
                color={0,0,127},
                smooth=Smooth.None));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                      -120},{120,120}}),        graphics), Icon(coordinateSystem(extent={{
                      -120,-120},{120,120}})),
              experiment(StopTime=2500),
              __Dymola_experimentSetupOutput);
          end test_Separator;

          model test_deaerator "Test model of the deaerator"

            Deaerator deaerator(
              initOpt=ThermoPower.Choices.Init.Options.fixedState,
              h_start=1.2e6,
              L=1.6,
              H=0.866025,
              zl_start=0.5,
              p_start=2717000)
              annotation (Placement(transformation(extent={{-30,-26},{30,36}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=821.9e3,
              w0=0)
              annotation (Placement(transformation(extent={{-80,-30},{-60,-10}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_ST(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              h=3467.5e3,
              w0=0.13)
              annotation (Placement(transformation(extent={{-62,30},{-42,50}})));
            ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=2.58,
              h=875.5e3,
              use_in_w0=true)
              annotation (Placement(transformation(extent={{66,90},{46,70}})));
            IndustrialControlSystems.Controllers.PI
                                                PID_level(
              CSmin=0,
              CSmax=10,
              Ti=100,
              Kp=10,
              CS_start=2.6)  annotation (
                Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=-90,
                  origin={60,4})));
            Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=2)
                    annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=-90,
                  origin={60,38})));
            Modelica.Blocks.Sources.Constant zl_SP(k=0.5)
              annotation (Placement(transformation(extent={{100,-40},{80,-20}})));
            ThermoPower.Water.SinkMassFlow    waterPump(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              w0=2.69,
              use_in_w0=false)
                     annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=-90,
                  origin={0,-84})));
            inner ThermoPower.System system
              annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
          equation
            connect(deaerator.drained_in, sourceMassFlow_DR.flange) annotation (
                Line(
                points={{-27.8571,-10.5},{-40,-10.5},{-40,-20},{-60,-20}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.steam_in, sourceMassFlow_ST.flange) annotation (Line(
                points={{-8.14286,9.42857},{-20,9.42857},{-20,40},{-42,40}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(deaerator.water_in, sourceMassFlow_FW.flange) annotation (Line(
                points={{7.71429,22.7143},{8,22.7143},{8,80},{46,80}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(zl_SP.y,PID_level. SP) annotation (Line(
                points={{79,-30},{66,-30},{66,-4}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.level, PID_level.PV) annotation (Line(
                points={{27.8571,-12.7143},{59,-12.7143},{59,-4}},
                color={0,0,127},
                smooth=Smooth.None));
            connect(deaerator.drained_out, waterPump.flange) annotation (Line(
                points={{0,-19.3571},{0,-74}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMassFlow_FW.in_w0, pumpDynamic.y) annotation (Line(
                  points={{60,74},{60,49},{60,49}}, color={0,0,127}));
            connect(pumpDynamic.u, PID_level.CS)
              annotation (Line(points={{60,26},{60,13}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent=
                      {{-100,-100},{100,100}})),
              experiment(StopTime=5000),
              __Dymola_experimentSetupOutput);
          end test_deaerator;

          model test_ECO_complete "Test model for the complete ECO"
            import PreFlexMS;
            ThermoPower.Water.SourceMassFlow sourceMS2(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              use_in_w0=true,
              use_in_h=true,
              h=196421,
              w0=11.95)
              annotation (Placement(transformation(extent={{-170,-10},{-150,10}})));
            ThermoPower.Water.SourceMassFlow sourceSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              use_in_h=true,
              w0=91.28,
              h=1062835)
              annotation (Placement(transformation(extent={{-168,-110},{-148,
                      -90}})));
            ThermoPower.Water.SinkPressure sinkSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=17345880)
              annotation (Placement(transformation(extent={{-110,48},{-90,68}})));
            ThermoPower.Water.SinkPressure sinkMS2(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=279240)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            ThermoPower.Water.PressDrop PDMSECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              dpnom=(1.7076)*10^5,
              rhonom=1901.7,
              wnom=11.95)
              annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
            ThermoPower.Water.PressDrop PDSteamECO(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              dpnom=(0.54118)*10^5,
              rhonom=590.03,
              wnom=1.757)                    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-130,30})));
            HE ECO_simple(
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
              redeclare package hotMedium =
                  PreFlexMS.Media.MoltenSalt60_40_quad,
              generateInitCode=true,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              Vhot=1.41501,
              Vcold=0.21088,
              Shot=77.459,
              Scold=63.904,
              Mm=786.38,
              nominalColdFlow=1.757,
              nominalHotFlow=11.96,
              Nhex=20,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4850),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2310),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.75,
              nominalHotOutletTemperature=569.15) annotation (Placement(
                  transformation(extent={{-140,-10},{-120,10}})));

            Modelica.Blocks.Tables.CombiTable1D p_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                  80,141.3e5; 90,157e5; 100,173e5])
              annotation (Placement(transformation(extent={{-150,80},{-130,100}})));
            Modelica.Blocks.Tables.CombiTable1D h_MS_ECO(
                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                  90,186692; 100,196390])
              annotation (Placement(transformation(extent={{-190,50},{-170,70}})));
            Modelica.Blocks.Tables.CombiTable1D w_MS_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{-190,20},{-170,40}})));
            Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1262e3; 30,1261.9e3; 40,1262.4e3; 50,1257.9e3; 60,1121.9e3; 70,1062.2e3;
                  80,1062.4e3; 90,1062.4e3; 100,1063e3])
              annotation (Placement(transformation(extent={{-190,-50},{-170,-30}})));
            Modelica.Blocks.Tables.CombiTable1D w_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                  1.605; 100,1.757])
              annotation (Placement(transformation(extent={{-190,-80},{-170,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD_ECO(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-230,0})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-280,100},{-260,120}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_ramp=0,
              load_end=100,
              t_start=0) annotation (Placement(transformation(extent={{-40,-100},
                      {0,-60}})));
            ThermoPower.Water.SourceMassFlow sourceMS1(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              use_in_w0=true,
              use_in_h=true,
              h=196421,
              w0=11.95)
              annotation (Placement(transformation(extent={{90,-10},{110,10}})));
            ThermoPower.Water.SourceMassFlow sourceSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              use_in_h=true,
              w0=91.28,
              h=1062835)
              annotation (Placement(transformation(extent={{92,-110},{112,-90}})));
            ThermoPower.Water.SinkPressure sinkSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=17345880)
              annotation (Placement(transformation(extent={{150,60},{170,80}})));
            ThermoPower.Water.SinkPressure sinkMS1(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=279240)
              annotation (Placement(transformation(extent={{210,-10},{230,10}})));
            ThermoPower.Water.PressDrop PDMSECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              dpnom=(1.7076)*10^5,
              rhonom=1901.7,
              wnom=11.95)
              annotation (Placement(transformation(extent={{180,-10},{200,10}})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              dpnom=(0.54118)*10^5,
              rhonom=590.03,
              wnom=1.757)                    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={130,50})));
            PreFlexMS.Pilot_245degC.HeatExchangers.Components.ECO_complete ECO_complete(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
              redeclare package hotMedium =
                  PreFlexMS.Media.MoltenSalt60_40_quad,
              Vhot=1.41501,
              Vcold=0.21088,
              Shot=77.459,
              Scold=63.904,
              Mm=786.38,
              nominalColdFlow=1.757,
              nominalHotFlow=11.96,
              ECO1(Nhex=2),
              ECO2(Nhex=2),
              ECO4(Nhex=2),
              ECO3(Nhex=2),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4850),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2310),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.75,
              nominalHotOutletTemperature=569.15) annotation (Placement(
                  transformation(extent={{120,-10},{140,10}})));

            Modelica.Blocks.Tables.CombiTable1D p_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                  80,141.3e5; 90,157e5; 100,173e5])
              annotation (Placement(transformation(extent={{110,80},{130,100}})));
            Modelica.Blocks.Tables.CombiTable1D h_MS_ECO1(
                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                  90,186692; 100,196390])
              annotation (Placement(transformation(extent={{70,50},{90,70}})));
            Modelica.Blocks.Tables.CombiTable1D w_MS_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{70,20},{90,40}})));
            Modelica.Blocks.Tables.CombiTable1D h_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1262e3; 30,1261.9e3; 40,1262.4e3; 50,1257.9e3; 60,1121.9e3; 70,1062.2e3;
                  80,1062.4e3; 90,1062.4e3; 100,1063e3])
              annotation (Placement(transformation(extent={{70,-50},{90,-30}})));
            Modelica.Blocks.Tables.CombiTable1D w_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                  1.605; 100,1.757])
              annotation (Placement(transformation(extent={{70,-80},{90,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD_ECO1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,0})));
            ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                  PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                  transformation(extent={{150,-6},{170,14}})));
            ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph) annotation (Placement(
                  transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=270,
                  origin={134,26})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=10)
              annotation (Placement(transformation(extent={{20,-10},{40,10}})));
          equation
            connect(sinkMS2.flange,PDMSECO. outlet) annotation (Line(
                points={{-80,0},{-90,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PDSteamECO.outlet,sinkSteam2. flange) annotation (Line(
                points={{-130,40},{-130,58},{-110,58}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceSteam2.flange, ECO_simple.inletCold) annotation (Line(
                points={{-148,-100},{-130,-100},{-130,-10}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS2.flange, ECO_simple.inletHot) annotation (Line(
                points={{-150,0},{-140,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(ECO_simple.outletHot, PDMSECO.inlet) annotation (Line(
                points={{-120,0},{-110,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PDSteamECO.inlet, ECO_simple.outletCold) annotation (Line(
                points={{-130,20},{-130,10}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(h_MS_ECO.y[1],sourceMS2. in_h)
              annotation (Line(points={{-169,60},{-156,60},{-156,6}},  color={0,0,127}));
            connect(p_ST_ECO.y[1],sinkSteam2. in_p0) annotation (Line(points={{-129,90},
                    {-118,90},{-104,90},{-104,66.8}},
                                                 color={0,0,127}));
            connect(w_MS_ECO.y[1],sourceMS2. in_w0) annotation (Line(points={{-169,30},
                    {-166,30},{-164,30},{-164,6}},
                                               color={0,0,127}));
            connect(h_ST_ECO.y[1],sourceSteam2. in_h) annotation (Line(points={{-169,
                    -40},{-164,-40},{-154,-40},{-154,-94}},
                                            color={0,0,127}));
            connect(w_ST_ECO.y[1],sourceSteam2. in_w0)
              annotation (Line(points={{-169,-70},{-162,-70},{-162,-94}},
                                                                    color={0,0,127}));
            connect(LOAD_ECO.y,p_ST_ECO. u[1]) annotation (Line(points={{-219,0},
                    {-210,0},{-210,90},{-152,90}},
                                          color={0,0,127}));
            connect(LOAD_ECO.y,h_MS_ECO. u[1]) annotation (Line(points={{-219,0},
                    {-210,0},{-210,60},{-192,60}},
                                          color={0,0,127}));
            connect(LOAD_ECO.y,w_MS_ECO. u[1]) annotation (Line(points={{-219,0},
                    {-210,0},{-210,30},{-192,30}},
                                          color={0,0,127}));
            connect(LOAD_ECO.y,h_ST_ECO. u[1]) annotation (Line(points={{-219,0},
                    {-214,0},{-210,0},{-210,-40},{-192,-40}},
                                                  color={0,0,127}));
            connect(LOAD_ECO.y,w_ST_ECO. u[1]) annotation (Line(points={{-219,0},
                    {-210,0},{-210,-70},{-192,-70}},
                                        color={0,0,127}));
            connect(sinkMS1.flange, PDMSECO1.outlet) annotation (Line(
                points={{210,0},{200,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(PDSteamECO1.outlet, sinkSteam1.flange) annotation (Line(
                points={{130,60},{130,70},{150,70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceSteam1.flange, ECO_complete.inletCold) annotation (
                Line(
                points={{112,-100},{130,-100},{130,-10}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS1.flange, ECO_complete.inletHot) annotation (Line(
                points={{110,0},{120,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(h_MS_ECO1.y[1], sourceMS1.in_h) annotation (Line(points={{
                    91,60},{104,60},{104,6}}, color={0,0,127}));
            connect(p_ST_ECO1.y[1], sinkSteam1.in_p0) annotation (Line(points={
                    {131,90},{142,90},{156,90},{156,78.8}}, color={0,0,127}));
            connect(w_MS_ECO1.y[1], sourceMS1.in_w0) annotation (Line(points={{
                    91,30},{94,30},{96,30},{96,6}}, color={0,0,127}));
            connect(h_ST_ECO1.y[1], sourceSteam1.in_h) annotation (Line(points=
                    {{91,-40},{96,-40},{106,-40},{106,-94}}, color={0,0,127}));
            connect(w_ST_ECO1.y[1], sourceSteam1.in_w0) annotation (Line(points=
                   {{91,-70},{98,-70},{98,-94}}, color={0,0,127}));
            connect(PDSteamECO1.inlet, sensT_FW.outlet) annotation (Line(points=
                   {{130,40},{130,40},{130,32}}, color={0,0,255}));
            connect(sensT_FW.inlet, ECO_complete.outletCold)
              annotation (Line(points={{130,20},{130,10}}, color={0,0,255}));
            connect(ECO_complete.outletHot, sensT_MS.inlet)
              annotation (Line(points={{140,0},{154,0}}, color={0,0,255}));
            connect(sensT_MS.outlet, PDMSECO1.inlet) annotation (Line(points={{
                    166,0},{173,0},{180,0}}, color={0,0,255}));
            connect(LOAD_ECO1.y, firstOrder.u)
              annotation (Line(points={{1,0},{18,0}}, color={0,0,127}));
            connect(firstOrder.y, p_ST_ECO1.u[1]) annotation (Line(points={{41,
                    0},{50,0},{50,90},{108,90}}, color={0,0,127}));
            connect(firstOrder.y, h_MS_ECO1.u[1]) annotation (Line(points={{41,
                    0},{50,0},{50,60},{68,60}}, color={0,0,127}));
            connect(firstOrder.y, w_MS_ECO1.u[1]) annotation (Line(points={{41,
                    0},{46,0},{50,0},{50,30},{68,30}}, color={0,0,127}));
            connect(firstOrder.y, h_ST_ECO1.u[1]) annotation (Line(points={{41,
                    0},{50,0},{50,-40},{68,-40}}, color={0,0,127}));
            connect(firstOrder.y, w_ST_ECO1.u[1]) annotation (Line(points={{41,
                    0},{50,0},{50,-70},{68,-70}}, color={0,0,127}));
            annotation (
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -120},{280,120}})),
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -120},{280,120}}), graphics={
                                      Text(
                    extent={{-120,-20},{-40,-40}},
                    lineColor={0,0,255},
                    textString="ECO_simple"),
                                      Text(
                    extent={{140,-20},{234,-42}},
                    lineColor={0,0,255},
                    textString="ECO_complete")}),
              experiment(StopTime=500),
              __Dymola_experimentSetupOutput);
          end test_ECO_complete;

          model lin_ECO_complete "Linearization model for the complete ECO"
            import PreFlexMS;
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-280,120},{-260,140}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_start=0,
              load_end=60,
              t_ramp=40000) annotation (Placement(transformation(extent={{-240,
                      -100},{-200,-60}})));
            ThermoPower.Water.SourceMassFlow sourceMS1(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              use_in_w0=true,
              use_in_h=true,
              h=196421,
              w0=11.95)
              annotation (Placement(transformation(extent={{50,-10},{70,10}})));
            ThermoPower.Water.SourceMassFlow sourceSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              use_in_h=true,
              w0=91.28,
              h=1062835)
              annotation (Placement(transformation(extent={{52,-110},{72,-90}})));
            ThermoPower.Water.SinkPressure sinkSteam1(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=17345880)
              annotation (Placement(transformation(extent={{110,60},{130,80}})));
            ThermoPower.Water.SinkPressure sinkMS1(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=279240)
              annotation (Placement(transformation(extent={{170,-10},{190,10}})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              dpnom=(0.54118)*10^5,
              rhonom=590.03,
              wnom=1.757)                    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={90,50})));
            PreFlexMS.Pilot_245degC.HeatExchangers.Components.ECO_complete ECO_complete(
              cm=500,
              nominalColdDeltaP=0,
              redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
              redeclare package hotMedium =
                  PreFlexMS.Media.MoltenSalt60_40_quad,
              Vhot=1.41501,
              Vcold=0.21088,
              Shot=77.459,
              Scold=63.904,
              Mm=786.38,
              nominalColdFlow=1.757,
              nominalHotFlow=11.96,
              ECO1(Nhex=2),
              ECO2(Nhex=2),
              ECO3(Nhex=2),
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4850),
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2310),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalHotDeltaP=171720,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.75,
              nominalHotOutletTemperature=569.15,
              ECO4(Nhex=2))
              annotation (Placement(transformation(extent={{80,-10},{100,10}})));
            Modelica.Blocks.Tables.CombiTable1D p_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                  80,141.3e5; 90,157e5; 100,173e5])
              annotation (Placement(transformation(extent={{70,80},{90,100}})));
            Modelica.Blocks.Tables.CombiTable1D h_MS_ECO1(
                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                  90,186692; 100,196390])
              annotation (Placement(transformation(extent={{-100,50},{-80,70}})));
            Modelica.Blocks.Tables.CombiTable1D w_MS_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{-100,20},{-80,40}})));
            Modelica.Blocks.Tables.CombiTable1D h_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1262e3; 30,1261.9e3; 40,1262.4e3; 50,1257.9e3; 60,1121.9e3; 70,1062.2e3;
                  80,1062.4e3; 90,1062.4e3; 100,1063e3])
              annotation (Placement(transformation(extent={{-100,-50},{-80,-30}})));
            Modelica.Blocks.Tables.CombiTable1D w_ST_ECO1(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                  1.605; 100,1.757])
              annotation (Placement(transformation(extent={{-100,-80},{-80,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD_ECO1(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-190,0})));
            ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                  PreFlexMS.Media.MoltenSalt60_40_quad)
              annotation (Placement(transformation(extent={{110,-6},{130,14}})));
            ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=270,
                  origin={94,26})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder(
              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=10) annotation (Placement(transformation(extent={{-160,-10},{
                      -140,10}})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{0,-66},
                      {20,-86}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-40,-110},{-20,-90}})));

            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{28,34},
                      {48,14}})));
            Modelica.Blocks.Math.Product product1
                                                 annotation (Placement(transformation(
                    extent={{-12,-10},{8,10}})));
            Modelica.Blocks.Math.Add add3 annotation (Placement(transformation(extent={{-100,
                      -96},{-80,-116}})));
            Modelica.Blocks.Sources.Step step(
              offset=0,
              startTime=0,
              height=0) annotation (Placement(transformation(extent={{-160,-130},{-140,-110}})));
            Modelica.Blocks.Math.Add add4 annotation (Placement(transformation(extent={{-40,4},
                      {-20,-16}})));
            Modelica.Blocks.Sources.Step step1(
              offset=0,
              startTime=0,
              height=0) annotation (Placement(transformation(extent={{-252,-30},
                      {-232,-10}})));

            Modelica.Blocks.Continuous.FirstOrder firstOrder1(
              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=5)  annotation (Placement(transformation(extent={{-180,-40},{
                      -160,-20}})));

            Modelica.Blocks.Interfaces.RealInput du_wMS annotation (Placement(
                  transformation(extent={{-120,-20},{-80,20}}), iconTransformation(extent=
                     {{-304,16},{-264,56}})));
            Modelica.Blocks.Interfaces.RealInput du_wFW annotation (Placement(
                  transformation(extent={{-180,-100},{-140,-60}}),iconTransformation(
                    extent={{-304,16},{-264,56}})));
            Modelica.Blocks.Interfaces.RealOutput y_T_MS annotation (Placement(
                  transformation(extent={{220,70},{240,90}}), iconTransformation(extent={{
                      -284,48},{-264,68}})));
            Modelica.Blocks.Interfaces.RealOutput y_T_FW annotation (Placement(
                  transformation(extent={{220,30},{240,50}}), iconTransformation(extent={{
                      -278,48},{-258,68}})));
          equation
            connect(PDSteamECO1.outlet, sinkSteam1.flange) annotation (Line(
                points={{90,60},{90,70},{110,70}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceSteam1.flange, ECO_complete.inletCold) annotation (Line(
                points={{72,-100},{90,-100},{90,-10}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS1.flange, ECO_complete.inletHot) annotation (Line(
                points={{70,0},{80,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(h_MS_ECO1.y[1], sourceMS1.in_h)
              annotation (Line(points={{-79,60},{64,60},{64,6}}, color={0,0,127}));
            connect(p_ST_ECO1.y[1], sinkSteam1.in_p0) annotation (Line(points={{91,90},{102,
                    90},{116,90},{116,78.8}}, color={0,0,127}));
            connect(h_ST_ECO1.y[1], sourceSteam1.in_h) annotation (Line(points={{-79,-40},
                    {-79,-40},{66,-40},{66,-94}}, color={0,0,127}));
            connect(PDSteamECO1.inlet, sensT_FW.outlet)
              annotation (Line(points={{90,40},{90,40},{90,32}}, color={0,0,255}));
            connect(sensT_FW.inlet, ECO_complete.outletCold)
              annotation (Line(points={{90,20},{90,10}}, color={0,0,255}));
            connect(ECO_complete.outletHot, sensT_MS.inlet)
              annotation (Line(points={{100,0},{114,0}}, color={0,0,255}));
            connect(LOAD_ECO1.y, firstOrder.u)
              annotation (Line(points={{-179,0},{-162,0}}, color={0,0,127}));
            connect(firstOrder.y, p_ST_ECO1.u[1]) annotation (Line(points={{-139,0},
                    {-120,0},{-120,90},{68,90}},
                                           color={0,0,127}));
            connect(firstOrder.y, h_MS_ECO1.u[1]) annotation (Line(points={{-139,0},
                    {-120,0},{-120,60},{-102,60}},
                                             color={0,0,127}));
            connect(firstOrder.y, w_MS_ECO1.u[1]) annotation (Line(points={{-139,0},
                    {-139,0},{-120,0},{-120,30},{-102,30}},
                                                      color={0,0,127}));
            connect(firstOrder.y, h_ST_ECO1.u[1]) annotation (Line(points={{-139,0},
                    {-120,0},{-120,-40},{-102,-40}},
                                               color={0,0,127}));
            connect(firstOrder.y, w_ST_ECO1.u[1]) annotation (Line(points={{-139,0},
                    {-120,0},{-120,-70},{-102,-70}},
                                               color={0,0,127}));
            connect(product.y,add1. u1)
              annotation (Line(points={{-19,-100},{-10,-100},{-10,-82},{-8,-82},
                    {-2,-82}},                                   color={0,0,127}));
            connect(w_ST_ECO1.y[1], add1.u2)
              annotation (Line(points={{-79,-70},{-40,-70},{-2,-70}}, color={0,0,127}));
            connect(add1.y, sourceSteam1.in_w0) annotation (Line(points={{21,-76},{38,-76},
                    {58,-76},{58,-94}}, color={0,0,127}));
            connect(w_ST_ECO1.y[1], product.u1) annotation (Line(points={{-79,-70},{-68,-70},
                    {-60,-70},{-60,-94},{-42,-94}}, color={0,0,127}));
            connect(product1.y, add2.u1) annotation (Line(points={{9,0},{18,0},{18,18},{26,
                    18}},     color={0,0,127}));
            connect(w_MS_ECO1.y[1], add2.u2)
              annotation (Line(points={{-79,30},{-28,30},{26,30}},color={0,0,127}));
            connect(add2.y, sourceMS1.in_w0)
              annotation (Line(points={{49,24},{56,24},{56,6}}, color={0,0,127}));
            connect(w_MS_ECO1.y[1], product1.u1) annotation (Line(points={{-79,30},{-32,30},
                    {-32,6},{-14,6}}, color={0,0,127}));
            connect(sensT_MS.T, y_T_MS) annotation (Line(points={{128,10},{160,10},{160,80},
                    {230,80}}, color={0,0,127}));
            connect(sensT_FW.T, y_T_FW)
              annotation (Line(points={{100,34},{100,40},{230,40}}, color={0,0,127}));
            connect(add3.y, product.u2) annotation (Line(points={{-79,-106},{
                    -60.5,-106},{-42,-106}}, color={0,0,127}));
            connect(du_wFW, add3.u2) annotation (Line(points={{-160,-80},{-140,
                    -80},{-120,-80},{-120,-100},{-102,-100}}, color={0,0,127}));
            connect(step.y, add3.u1) annotation (Line(points={{-139,-120},{-120,-120},{-120,
                    -112},{-102,-112}},             color={0,0,127}));
            connect(du_wMS, add4.u2)
              annotation (Line(points={{-100,0},{-42,0},{-42,0}}, color={0,0,127}));
            connect(add4.y, product1.u2)
              annotation (Line(points={{-19,-6},{-16.5,-6},{-14,-6}}, color={0,0,127}));
            connect(sensT_MS.outlet, sinkMS1.flange) annotation (Line(points={{
                    126,0},{148,0},{170,0}}, color={0,0,255}));
            connect(step1.y, firstOrder1.u) annotation (Line(points={{-231,-20},
                    {-212,-20},{-212,-30},{-182,-30}}, color={0,0,127}));
            connect(firstOrder1.y, add4.u1) annotation (Line(points={{-159,-30},
                    {-132,-30},{-132,-20},{-50,-20},{-50,-12},{-42,-12}}, color=
                   {0,0,127}));
            annotation (
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-280,-140},{280,140}})),
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,-140},{280,
                      140}}), graphics={
                                      Text(
                    extent={{100,-20},{194,-42}},
                    lineColor={0,0,255},
                    textString="ECO_complete")}),
              experiment(
                StartTime=-10,
                StopTime=1500,
                __Dymola_NumberOfIntervals=1500,
                __Dymola_Algorithm="Dassl"),
              __Dymola_experimentSetupOutput);
          end lin_ECO_complete;

          model lin_ECO_simple "Linearization model for the simple ECO"
            import PreFlexMS;
            ThermoPower.Water.SourceMassFlow sourceMS2(
              allowFlowReversal=false,
              G=0,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              use_in_w0=true,
              use_in_h=true,
              h=196421,
              w0=11.95)
              annotation (Placement(transformation(extent={{50,-10},{70,10}})));
            ThermoPower.Water.SourceMassFlow sourceSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_w0=true,
              use_in_h=true,
              w0=91.28,
              h=1062835)
              annotation (Placement(transformation(extent={{52,-110},{72,-90}})));
            ThermoPower.Water.SinkPressure sinkSteam2(
              allowFlowReversal=false,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              use_in_p0=true,
              p0=17345880)
              annotation (Placement(transformation(extent={{110,60},{130,80}})));
            ThermoPower.Water.SinkPressure sinkMS2(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=279240)
              annotation (Placement(transformation(extent={{170,-10},{190,10}})));
            PreFlexMS.Pilot_245degC.HeatExchangers.Components.HE
               ECO_simple(
              cm=500,
              nominalColdDeltaP=0,
              nominalHotDeltaP=0,
              hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                  noInitialPressure=true),
              redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
              redeclare package hotMedium =
                  PreFlexMS.Media.MoltenSalt60_40_quad,
              generateInitCode=true,
              coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
              Vhot=1.41501,
              Vcold=0.21088,
              Mm=786.38,
              nominalColdFlow=1.757,
              nominalHotFlow=11.96,
              redeclare model HeatTransferCold =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.728761, gamma_nom=4850),
              Shot=77.459,
              Scold=63.904,
              Nhex=21,
              redeclare model HeatExchangerTopology =
                  ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
              redeclare model HeatTransferHot =
                  ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                  (alpha=0.461561, gamma_nom=2310),
              nominalColdPressure=17400000,
              nominalHotPressure=450000,
              nominalColdInletTemperature=518.15,
              nominalColdOutletTemperature=621.59,
              nominalHotInletTemperature=626.75,
              nominalHotOutletTemperature=569.15) annotation (Placement(
                  transformation(extent={{80,-10},{100,10}})));

            Modelica.Blocks.Tables.CombiTable1D p_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                  80,141.3e5; 90,157e5; 100,173e5])
              annotation (Placement(transformation(extent={{70,80},{90,100}})));
            Modelica.Blocks.Tables.CombiTable1D h_MS_ECO(
                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                  90,186692; 100,196390])
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            Modelica.Blocks.Tables.CombiTable1D w_MS_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{-140,20},{-120,40}})));
            Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1262e3; 30,1261.9e3; 40,1262.4e3; 50,1257.9e3; 60,1121.9e3; 70,1062.2e3;
                  80,1062.4e3; 90,1062.4e3; 100,1063e3])
              annotation (Placement(transformation(extent={{-140,-50},{-120,-30}})));
            Modelica.Blocks.Tables.CombiTable1D w_ST_ECO(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                  1.605; 100,1.757])
              annotation (Placement(transformation(extent={{-140,-80},{-120,-60}})));
            Modelica.Blocks.Sources.Ramp LOAD_ECO(
              height=loadCalc.load_end - loadCalc.load_start,
              duration=loadCalc.t_ramp,
              offset=loadCalc.load_start,
              startTime=loadCalc.t_start) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-180,0})));
            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
              annotation (Placement(transformation(extent={{-280,120},{-260,140}})));
            PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
              load_start=100,
              t_ramp=0,
              load_end=100,
              t_start=0) annotation (Placement(transformation(extent={{-240,-100},
                      {-200,-60}})));

            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{22,34},
                      {42,14}})));
            Modelica.Blocks.Math.Product product1
                                                 annotation (Placement(transformation(
                    extent={{-18,-10},{2,10}})));

            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-80,-110},{-60,-90}})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-40,-66},
                      {-20,-86}})));
            ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                  Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=270,
                  origin={94,26})));
            ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                  PreFlexMS.Media.MoltenSalt60_40_quad)
              annotation (Placement(transformation(extent={{110,-6},{130,14}})));
            Modelica.Blocks.Math.Add add3 annotation (Placement(transformation(extent={{-120,
                      -106},{-100,-126}})));
            Modelica.Blocks.Sources.Step step(
              offset=0,
              startTime=0,
              height=0.01)
                        annotation (Placement(transformation(extent={{-180,-140},{-160,-120}})));

            Modelica.Blocks.Math.Add add4 annotation (Placement(transformation(extent={{-48,4},
                      {-28,-16}})));
            Modelica.Blocks.Sources.Step step1(
              offset=0,
              startTime=0,
              height=0) annotation (Placement(transformation(extent={{-260,-40},
                      {-240,-20}})));
            ThermoPower.Water.PressDrop PDSteamECO1(
              FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
              redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
              dpnom=(0.54118)*10^5,
              rhonom=590.03,
              wnom=1.757)                    annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={90,50})));
            Modelica.Blocks.Continuous.FirstOrder firstOrder1(
              k=1,
              initType=Modelica.Blocks.Types.Init.SteadyState,
              T=5)  annotation (Placement(transformation(extent={{-220,-40},{
                      -200,-20}})));

            Modelica.Blocks.Interfaces.RealInput du_wMS annotation (Placement(
                  transformation(extent={{-160,-20},{-120,20}}),iconTransformation(extent=
                     {{-304,16},{-264,56}})));
            Modelica.Blocks.Interfaces.RealInput du_wFW annotation (Placement(
                  transformation(extent={{-200,-120},{-160,-80}}),iconTransformation(
                    extent={{-304,16},{-264,56}})));
            Modelica.Blocks.Interfaces.RealOutput y_T_MS annotation (Placement(
                  transformation(extent={{220,70},{240,90}}), iconTransformation(extent={{
                      -284,48},{-264,68}})));
            Modelica.Blocks.Interfaces.RealOutput y_T_FW annotation (Placement(
                  transformation(extent={{220,30},{240,50}}), iconTransformation(extent={{
                      -278,48},{-258,68}})));
          equation
            connect(sourceSteam2.flange, ECO_simple.inletCold) annotation (Line(
                points={{72,-100},{90,-100},{90,-10}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(sourceMS2.flange, ECO_simple.inletHot) annotation (Line(
                points={{70,0},{80,0}},
                color={0,0,255},
                smooth=Smooth.None));
            connect(h_MS_ECO.y[1],sourceMS2. in_h)
              annotation (Line(points={{-119,60},{64,60},{64,6}},      color={0,0,127}));
            connect(p_ST_ECO.y[1],sinkSteam2. in_p0) annotation (Line(points={{91,90},{102,
                    90},{116,90},{116,78.8}},    color={0,0,127}));
            connect(h_ST_ECO.y[1],sourceSteam2. in_h) annotation (Line(points={{-119,-40},
                    {-119,-40},{66,-40},{66,-94}},
                                            color={0,0,127}));
            connect(LOAD_ECO.y,p_ST_ECO. u[1]) annotation (Line(points={{-169,0},{-160,0},
                    {-160,90},{68,90}},   color={0,0,127}));
            connect(LOAD_ECO.y,h_MS_ECO. u[1]) annotation (Line(points={{-169,0},{-160,0},
                    {-160,60},{-142,60}}, color={0,0,127}));
            connect(LOAD_ECO.y,w_MS_ECO. u[1]) annotation (Line(points={{-169,0},{-160,0},
                    {-160,30},{-142,30}}, color={0,0,127}));
            connect(LOAD_ECO.y,h_ST_ECO. u[1]) annotation (Line(points={{-169,0},{-164,0},
                    {-160,0},{-160,-40},{-142,-40}},
                                                  color={0,0,127}));
            connect(LOAD_ECO.y,w_ST_ECO. u[1]) annotation (Line(points={{-169,0},{-160,0},
                    {-160,-70},{-142,-70}},
                                        color={0,0,127}));
            connect(w_MS_ECO.y[1], add2.u2)
              annotation (Line(points={{-119,30},{20,30}},           color={0,0,127}));
            connect(add2.y, sourceMS2.in_w0)
              annotation (Line(points={{43,24},{56,24},{56,6}},  color={0,0,127}));
            connect(w_MS_ECO.y[1], product1.u1) annotation (Line(points={{-119,30},
                    {-108,30},{-100,30},{-100,6},{-20,6}},
                                                 color={0,0,127}));
            connect(product1.y, add2.u1) annotation (Line(points={{3,0},{12,0},
                    {12,18},{20,18}},
                               color={0,0,127}));
            connect(w_ST_ECO.y[1], add1.u2) annotation (Line(points={{-119,-70},{-80.5,-70},
                    {-42,-70}}, color={0,0,127}));
            connect(add1.y, sourceSteam2.in_w0) annotation (Line(points={{-19,-76},{18,-76},
                    {58,-76},{58,-94}}, color={0,0,127}));
            connect(product.y, add1.u1) annotation (Line(points={{-59,-100},{-50,-100},{-50,
                    -82},{-42,-82}}, color={0,0,127}));
            connect(w_ST_ECO.y[1], product.u1) annotation (Line(points={{-119,-70},{-100,-70},
                    {-100,-94},{-82,-94}}, color={0,0,127}));
            connect(sensT_FW.inlet, ECO_simple.outletCold)
              annotation (Line(points={{90,20},{90,10}},         color={0,0,255}));
            connect(ECO_simple.outletHot, sensT_MS.inlet)
              annotation (Line(points={{100,0},{107,0},{114,0}}, color={0,0,255}));
            connect(sensT_FW.T, y_T_FW)
              annotation (Line(points={{100,34},{100,40},{230,40}}, color={0,0,127}));
            connect(sensT_MS.T, y_T_MS) annotation (Line(points={{128,10},{136,10},{140,10},
                    {140,80},{230,80}}, color={0,0,127}));
            connect(step.y,add3. u1) annotation (Line(points={{-159,-130},{-140,-130},{-140,
                    -122},{-122,-122}},             color={0,0,127}));
            connect(du_wFW, add3.u2) annotation (Line(points={{-180,-100},{-140,
                    -100},{-140,-110},{-122,-110}},
                                        color={0,0,127}));
            connect(add3.y, product.u2) annotation (Line(points={{-99,-116},{-90,-116},{-90,
                    -106},{-82,-106}}, color={0,0,127}));
            connect(add4.y, product1.u2) annotation (Line(points={{-27,-6},{-20,
                    -6},{-20,-6}}, color={0,0,127}));
            connect(du_wMS, add4.u2) annotation (Line(points={{-140,0},{-95,0},
                    {-50,0}}, color={0,0,127}));
            connect(PDSteamECO1.outlet, sinkSteam2.flange) annotation (Line(
                  points={{90,60},{90,70},{110,70}}, color={0,0,255}));
            connect(PDSteamECO1.inlet, sensT_FW.outlet) annotation (Line(points=
                   {{90,40},{90,40},{90,32}}, color={0,0,255}));
            connect(sensT_MS.outlet, sinkMS2.flange) annotation (Line(points={{
                    126,0},{170,0},{170,0}}, color={0,0,255}));
            connect(step1.y, firstOrder1.u) annotation (Line(points={{-239,-30},
                    {-230,-30},{-222,-30}},
                                 color={0,0,127}));
            connect(firstOrder1.y, add4.u1) annotation (Line(points={{-199,-30},
                    {-178,-30},{-178,-20},{-68,-20},{-68,-12},{-50,-12}}, color=
                   {0,0,127}));
            annotation (
              Icon(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -140},{280,140}})),
              Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,
                      -140},{280,140}}), graphics={
                                      Text(
                    extent={{100,-20},{180,-40}},
                    lineColor={0,0,255},
                    textString="ECO_simple")}),
              experiment(
                StartTime=-10,
                StopTime=1500,
                __Dymola_NumberOfIntervals=1500),
              __Dymola_experimentSetupOutput);
          end lin_ECO_simple;
        end Test;

      end Components;

      package OTSG
        "Package containing all the Once Through Steam Generator models"

        model OTSG_init100_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=21,
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            tubeWalls(Tvolstart(displayUnit="K")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-244},{-44,-276}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                  1.64439e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                620.01}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={196390,188158,176706,156967,110743}),
            Vhot=1.41501,
            Vcold=0.21088,
            Shot=77.459,
            Scold=63.904,
            Mm=786.38,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-176},{-76,-144}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                  1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                  1.94183e+006,2.2136e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                626.498,627.06,627.186,627.848,629.177,631.842}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                  194368,192799}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-96},{-44,-64}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                  2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                  2.72547e+006,2.78281e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                653.806,658.116,678.213,683.393,689.164,695.453}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                  284059,275898}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-16},{-76,16}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            noInitialPressure=true,
            h_start=2.75412e6,
            D=0.28,
            H=6.2,
            p_start=17200000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-40})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                  3.42217e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                824.786}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,501167,469703,420819,359564}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                  3.55697e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                829.056}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,502650,475154,429572,356689}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            nominalColdPressure=4781000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={100,180})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-86,210},{-66,230}})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-40})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=590.03,
            wnom=1.757)             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-120})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-32,48})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = RH.coldFluid.T[end];
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={60,242})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={188,2}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-216},{80,-196}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.SensP sensP_EVA(redeclare package Medium =
                coldMedium) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=-90,
                origin={-4,180})));
          ThermoPower.Water.PressDrop PDSteamSH2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757)  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=820.48,
            wnom=1.757)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-194})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-226})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-80,242})));
          Graphics.Label_input pumpMS_CS annotation (Placement(transformation(
                  extent={{-40,266},{-80,254}})));
          Graphics.Label_output valveBP_PV annotation (Placement(transformation(
                  extent={{60,-206},{20,-194}})));
          Graphics.Label_output pumpFW_PV_high
            annotation (Placement(transformation(extent={{32,60},{78,72}})));
          Graphics.Label_output pumpFW_PV_low
            annotation (Placement(transformation(extent={{32,36},{78,48}})));
          Graphics.Label_input pumpSEP_CS
            annotation (Placement(transformation(extent={{70,-30},{30,-42}})));
          Graphics.Label_output valveTURB_PV annotation (Placement(
                transformation(extent={{-30,184},{-70,196}})));
          Graphics.Label_output pumpSEP_PV annotation (Placement(transformation(
                  extent={{60,-192},{20,-180}})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{60,-290},{80,-270}})));
          Graphics.Label_input pumpHPH_CS annotation (Placement(transformation(
                  extent={{126,-262},{86,-274}})));
        equation
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-260},{-100,-260},{-100,-160},{-76,-160}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-144},{-60,-130}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-30},{1.77636e-015,-30}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-22,48},{-10,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-30},{-60,-16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-64},{-60,-50}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-60,16},{-60,48},{-42,48}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,0},{-100,0},{-100,-80},{-76,-80}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-80},{-20,-80},{-20,-160},{-44,-160}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-210},{96,-210},{130,-210},{190,-210}},
              color={0,0,255},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,220},{-86,220}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, sensP_EVA.p) annotation (Line(
              points={{188,2},{156,2},{156,222},{156,212},{10,212},{10,202},{6,
                  202},{6,188},{-10,188}},
              color={256,256,256},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-96},{-60,-110}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-176},{-60,-180},{-60,-184}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-236},{-60,-244}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveBP_PV, sensT_FW.T) annotation (Line(
              points={{188,2},{80,2},{80,-178},{96,-178},{96,-192},{86,-192},{
                  86,-196},{82,-196},{82,-200}},
              color={256,256,256},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
              points={{188,2},{10,2},{10,62},{10,66}},
              color={256,256,256},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0)
            annotation (Line(points={{-80,235.4},{-80,235.4},{-80,226}},
                                                           color={0,0,127}));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{188,2},{12,2},{12,42},{10,42}},
              color={256,256,256},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,124},{0,126},
                  {0,110}},              color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                points={{-6.66134e-016,90},{0,92},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(sensP_EVA.flange, SH.outletCold) annotation (Line(
              points={{0,180},{0,180},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{188,2},{144,2},{144,296},{122,296},{-94,296},{-94,260}},
              color={256,256,256},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{188,2},{138,2},{138,252},{-80,252},{-80,249.2}},
              thickness=0.5,
              color={255,255,255}));
          connect(RH_out, PDSteamRH.outlet) annotation (Line(
              points={{100,310},{100,310},{100,260},{98,260},{60,260},{60,252}},
              color={0,0,255},
              thickness=0.5));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{0,-50},{0,-50},{0,-80},{190,-80}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-210},{42,-210},{-60,-210},{-60,-216}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-210},{84,-210},{-60,-210},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-66,220},{-66,220},{100,220},{100,196}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{58,140},{100,140},{100,0},{-44,0}},
              color={255,0,0},
              thickness=0.5));
          connect(RH.outletHot, EVA2.inletHot) annotation (Line(
              points={{100,164},{100,140},{100,0},{-44,0}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.outletHot, MS_out) annotation (Line(
              points={{-44,-260},{-12,-260},{20,-260},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{188,2},{160,2},{160,-72},{6,-72},{6,-36}},
              color={256,256,256},
              thickness=0.5));
          connect(PDSteamRH.inlet, RH.outletCold) annotation (Line(
              points={{60,232},{60,180},{84,180}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{116,180},{190,180}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(SH_out, sensP_EVA.flange) annotation (Line(
              points={{0,310},{0,310},{0,258},{0,180}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-276},{-60,-280},{60,-280}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{188,2},{188,36},{72,36},{72,-144},{212,-144},{212,-258},
                  {46,-258},{46,-272},{64,-272},{66,-272},{66,-274}},
              color={256,256,256},
              thickness=0.5));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{80,-280},{140,-280},{140,-210},{96,-210}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false), graphics={Line(
                  points={{80,-186},{80,-192},{80,-200},{78,-200}},
                  color={0,0,0},
                  thickness=0.5), Line(
                  points={{66,-268},{66,-272}},
                  thickness=0.5,
                  color={0,0,0})}),                      Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init100_5nodes;

        model OTSG_init50_5nodes
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE           ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
            annotation (Placement(transformation(extent={{-74,-196},{-106,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-54})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          //Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          //Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          //Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));
          Components.HE ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            nominalColdPressure=17350000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=596.15,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
            annotation (Placement(transformation(extent={{-14,-164},{-46,-196}})));

          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=0.05*3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=0.08785)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-44}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-64},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{52,-50},{52,46},{52,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{52,-50},{52,260},{-40,260},{-40,253.2}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,-50},{28,-50},{6,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{0,-300},{0,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,-50},{52,-50},{52,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{52,-50},{52,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));
          connect(ECO2.outletCold,PDSteamECO2. outlet) annotation (Line(
              points={{-30,-196},{-30,-210},{-1.77636e-015,-210},{-1.77636e-015,-170}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{20,-100},{20,-180},{-14,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-60,-180},{-46,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,-50},{52,-50},{52,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{-34,-220},{-34,-248},{-60,
                  -248},{-60,-238}},
              color={255,204,51},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255}));
          connect(valveLiq.outlet, sinkPressure.flange)
            annotation (Line(points={{80,20},{100,20}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,24},{52,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{54,-220},{54,-220},{82,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes;

        model OTSG_init50_5nodes_no_pumpMS
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, no pumpMS"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE           ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-74,-196},{-106,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-54})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO2.T_hot_prof[2:end];ECO1.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO2.T_cold_prof[2:end];ECO1.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO2.T_wall_prof[2:end];ECO1.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.SensW sensW_MS(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-96,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));
          Components.HE ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            nominalColdPressure=17350000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=596.15,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-14,-164},{-46,-196}})));

          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=0.05*3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=0.08785)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-44}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-64},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, sensW_MS.inlet) annotation (Line(
              points={{-100,310},{-100,286}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, SH.inletHot) annotation (Line(
              points={{-100,274},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,274},{-100,274},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{52,-50},{52,46},{52,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,-50},{28,-50},{6,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{0,-300},{0,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,-50},{52,-50},{52,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{52,-50},{52,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));
          connect(ECO2.outletCold,PDSteamECO2. outlet) annotation (Line(
              points={{-30,-196},{-30,-210},{-1.77636e-015,-210},{-1.77636e-015,-170}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{20,-100},{20,-180},{-14,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-60,-180},{-46,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,-50},{52,-50},{52,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{-34,-220},{-34,-248},{-60,
                  -248},{-60,-238}},
              color={255,204,51},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255}));
          connect(valveLiq.outlet, sinkPressure.flange)
            annotation (Line(points={{80,20},{100,20}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,24},{52,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{54,-220},{54,-220},{82,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(sensW_MS.w, gain.u) annotation (Line(points={{-90,272},{-90,
                  260},{-40,260},{-40,253.2}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_no_pumpMS;

        model OTSG_init50_5nodes_no_pumpMS_shell
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, no pumpMS and HE models with shell and insulation"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Integer Nr = 10
            "Number of nodes for tubesheets discretization";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
          parameter Modelica.SIunits.Temperature T_amb = 298.15
            "Nominal value of ambiebt temperature";
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          Components.HE_shell    ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.728761),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2204.6, alpha=0.461561),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.7113,
            Vcold_bundle=0.10544,
            Shot_bundle=38.73,
            Scold_bundle=31.952,
            L_shell=11.5,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            s_ins=0.09,
            km=36,
            rhom=7950,
            Mi=106.7,
            ci=1030,
            ki=0.06,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            Mm_bundle=393.2,
            Mm_shell=611.5,
            nominalColdPressure=17400000,
            nominalHotPressure=450000)
            annotation (Placement(transformation(extent={{-74,-196},{-106,-164}})));

          Components.HE_shell_2ph    EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,1.30704e+006,1.31579e+006,
                  1.32733e+006,1.34263e+006,1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75,
                alpha=1.6),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2147.7, alpha=0.447498),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.882,
            Vcold_bundle=0.26,
            Shot_bundle=67.8,
            Scold_bundle=53.15,
            L_shell=16.6,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            s_ins=0.11,
            Mm_bundle=1297.6,
            Mm_shell=882.7,
            km=20,
            rhom=7950,
            Mi=195.2,
            ci=1030,
            ki=0.06,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb)
            annotation (Placement(transformation(extent={{-76,-116},{-44,-84}})));

          Components.HE_shell_2ph    EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2650, alpha=0.389637),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.094,
            Vcold_bundle=0.024,
            Shot_bundle=9.671,
            Scold_bundle=7.616,
            L_shell=3.7,
            omega_shell=0.6369,
            D_ext_shell=0.2191,
            D_int_shell=0.20274,
            s_ins=0.12,
            Mm_bundle=116.8,
            Mm_shell=159.4,
            km=20,
            rhom=7950,
            Mi=56.8,
            ci=1030,
            ki=0.07,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb)
            annotation (Placement(transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-54})));

          Components.HE_shell    SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            t_in=t_in,
            t_fin=t_fin,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.847436),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2848.1, alpha=0.28867),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.222,
            Vcold_bundle=0.053,
            Shot_bundle=22.8,
            Scold_bundle=17.385,
            L_shell=16.8,
            omega_shell=0.484057,
            D_ext_shell=0.1683,
            D_int_shell=0.15408,
            s_ins=0.14,
            Mm_bundle=303.39,
            Mm_shell=480.7,
            km=21.5,
            rhom=7950,
            Mi=273.4,
            ci=1030,
            ki=0.07,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58,
            T_amb=T_amb) annotation (Placement(transformation(
                extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE_shell    RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=963.9, alpha=0.798347),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2690.3, alpha=0.320782),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.371,
            Vcold_bundle=0.106,
            Shot_bundle=27.935,
            Scold_bundle=24.995,
            L_shell=15.6,
            omega_shell=0.636926,
            D_ext_shell=0.2191,
            D_int_shell=0.20274,
            s_ins=0.14,
            Mm_bundle=210.31,
            Mm_shell=672,
            km=21.5,
            rhom=7950,
            Mi=295.7,
            ci=1030,
            ki=0.07,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05) annotation (Placement(transformation(
                extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO2.T_hot_prof[2:end];ECO1.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO2.T_cold_prof[2:end];ECO1.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO2.T_wall_prof[2:end];ECO1.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.SensW sensW_MS(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-96,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717,
            allowFlowReversal=false)
                                 annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));

          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=0.05*3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=0.08785)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Components.HE_shell    ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.728761),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2204.6, alpha=0.461561),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.7113,
            Vcold_bundle=0.10544,
            Shot_bundle=38.73,
            Scold_bundle=31.952,
            L_shell=11.5,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            s_ins=0.09,
            km=36,
            rhom=7950,
            Mi=106.7,
            ci=1030,
            ki=0.06,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=618.15,
            nominalHotInletTemperature=631.15,
            nominalHotOutletTemperature=596.15,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            Mm_bundle=393.2,
            Mm_shell=611.5,
            nominalColdPressure=17400000,
            nominalHotPressure=450000) annotation (Placement(transformation(
                extent={{-16,-16},{16,16}},
                rotation=180,
                origin={-40,-180})));

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            Vhot=0.13653,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=573.15,
            nominalHotOutletTemperature=558.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-44}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-64},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, sensW_MS.inlet) annotation (Line(
              points={{-100,310},{-100,286}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, SH.inletHot) annotation (Line(
              points={{-100,274},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,274},{-100,274},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{52,-50},{52,46},{52,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,-50},{28,-50},{6,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,-50},{52,-50},{52,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{52,-50},{52,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,-50},{52,-50},{52,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{-34,-220},{-34,-248},{-60,
                  -248},{-60,-238}},
              color={255,204,51},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255}));
          connect(valveLiq.outlet, sinkPressure.flange)
            annotation (Line(points={{80,20},{100,20}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,24},{52,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{54,-220},{54,-220},{82,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(sensW_MS.w, gain.u) annotation (Line(points={{-90,272},{-90,
                  260},{-40,260},{-40,253.2}}, color={0,0,127}));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-40,-150},{-40,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.outletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-40,-196},{-40,-196},{-40,-206},{0,-206},{0,-170},{-1.77636e-015,
                  -170}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{-44,-100},{20,-100},{20,-180},{-24,-180}},
              color={255,0,0},
              thickness=0.5));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-70,-180},{-66,-180},{-56,-180}},
              color={255,0,0},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-220},{-60,-156},{-60,-150},{-40,-150},{-40,-164}},
              color={0,0,255},
              thickness=0.5));

          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{-20,-300},{-20,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_no_pumpMS_shell;

        model OTSG_init50_5nodes_no_pumpMS_shell_ts
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes, no pumpMS and HE models with shell, insulation and tubesheets parts"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Integer Nr = 10
            "Number of nodes for tubesheets discretization";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";
          parameter Modelica.SIunits.Temperature T_amb = 298.15
            "Nominal value of ambiebt temperature";
          parameter Modelica.SIunits.Time t_in = 0 "Integration initial time";
          parameter Modelica.SIunits.Time t_fin = 50000
            "Integration final time";

          Components.HE_shell_ts HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            Vhot_bundle=0.13653,
            Vcold_bundle=0.02017,
            Vcold_tubesheet=0.0004405,
            Vcold_man=0.001272,
            Shot_bundle=7.188,
            Scold_bundle=6.02,
            L_tubesheet=0.142,
            L_man=0.17,
            L_shell=3.25,
            omega_shell=0.3997,
            D_ext_shell=0.273,
            D_int_shell=0.25446,
            D_ext_ts=0.5525,
            s_ins=0.06,
            Mm_bundle=68.23,
            Mm_shell=198.4,
            Mm_ts=135.27,
            Mm_man=162,
            km=36,
            rhom=7950,
            Mi=11.1,
            ci=1030,
            ki=0.06,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=3958.9, alpha=0.536143),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=1000),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2197.5, alpha=0.447465),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb) annotation (Placement(transformation(extent={{-76,-264},
                    {-44,-296}})));

          Components.HE_shell_ts ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.728761),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2204.6, alpha=0.461561),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=1000),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.7113,
            Vcold_bundle=0.10544,
            Vcold_tubesheet=0.002109,
            Vcold_man=0.004519,
            Shot_bundle=38.73,
            Scold_bundle=31.952,
            L_tubesheet=0.23,
            L_man=0.23,
            L_shell=11.5,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            D_ext_ts=0.889,
            s_ins=0.09,
            Mm_ts=567.25,
            Mm_man=567.25,
            km=36,
            rhom=7950,
            Mi=106.7,
            ci=1030,
            ki=0.06,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            Mm_bundle=393.2,
            Mm_shell=611.5,
            nominalColdPressure=17400000,
            nominalHotPressure=450000) annotation (Placement(transformation(
                  extent={{-74,-196},{-106,-164}})));

          Components.HE_shell_ts_2ph EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,
                566.625,568.238,570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,
                  103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75,
                alpha=1.6),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=500),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2147.7, alpha=0.447498),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.882,
            Vcold_bundle=0.26,
            Vcold_tubesheet=0.00361192,
            Vcold_man=0.005273,
            Shot_bundle=67.8,
            Scold_bundle=53.15,
            L_tubesheet=0.23,
            L_man=0.23,
            L_shell=16.6,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            D_ext_ts=0.889,
            s_ins=0.11,
            Mm_bundle=1297.6,
            Mm_shell=882.7,
            Mm_ts=567.27,
            Mm_man=567.27,
            km=20,
            rhom=7950,
            Mi=195.2,
            ci=1030,
            ki=0.06,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb) annotation (Placement(transformation(extent={{-76,-116},
                    {-44,-84}})));

          Components.HE_shell_ts_2ph EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,
                  1.54799e+006,1.59242e+006,1.64599e+006,1.71054e+006,
                  1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,
                587.372,589.664,592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,
                  170909,162318}),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=500),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2650, alpha=0.389637),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.094,
            Vcold_bundle=0.024,
            Vcold_tubesheet=0.001187,
            Vcold_man=0.004926,
            Shot_bundle=9.671,
            Scold_bundle=7.616,
            L_tubesheet=0.183,
            L_man=0.233,
            L_shell=3.7,
            omega_shell=0.6369,
            D_ext_shell=0.2191,
            D_int_shell=0.20274,
            D_ext_ts=0.675,
            s_ins=0.12,
            Mm_bundle=116.8,
            Mm_shell=159.4,
            Mm_ts=520.41,
            Mm_man=662.6,
            km=20,
            rhom=7950,
            Mi=56.8,
            ci=1030,
            ki=0.07,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb)
            annotation (Placement(transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-54})));

          Components.HE_shell_ts SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,
                  3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,
                833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            t_in=t_in,
            t_fin=t_fin,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2000, alpha=0.847436),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=500),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2848.1, alpha=0.28867),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.222,
            Vcold_bundle=0.053,
            Vcold_tubesheet=0.0004502,
            Vcold_man=0.001119,
            Shot_bundle=22.8,
            Scold_bundle=17.385,
            L_tubesheet=0.141,
            L_man=0.15,
            L_shell=16.8,
            omega_shell=0.484057,
            D_ext_shell=0.1683,
            D_int_shell=0.15408,
            D_ext_ts=0.3935,
            s_ins=0.14,
            Mm_bundle=303.39,
            Mm_shell=480.7,
            Mm_ts=136,
            Mm_man=144,
            km=21.5,
            rhom=7950,
            Mi=273.4,
            ci=1030,
            ki=0.07,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58,
            T_amb=T_amb) annotation (Placement(transformation(
                extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE_shell_ts RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.15366e+006,3.40526e+006,3.52164e+006,3.57547e+006,
                  3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,
                834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=963.9, alpha=0.798347),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=500),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2690.3, alpha=0.320782),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.371,
            Vcold_bundle=0.106,
            Vcold_tubesheet=0.0019433,
            Vcold_man=0.001937,
            Shot_bundle=27.935,
            Scold_bundle=24.995,
            L_tubesheet=0.143,
            L_man=0.15,
            L_shell=15.6,
            omega_shell=0.636926,
            D_ext_shell=0.2191,
            D_int_shell=0.20274,
            D_ext_ts=0.585,
            s_ins=0.14,
            Mm_bundle=210.31,
            Mm_shell=672,
            Mm_ts=305.45,
            Mm_man=320.4,
            km=21.5,
            rhom=7950,
            Mi=295.7,
            ci=1030,
            ki=0.07,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05) annotation (Placement(
                transformation(
                extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));

          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO2.T_hot_prof[2:end];ECO1.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO2.T_cold_prof[2:end];ECO1.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[3*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO2.T_wall_prof[2:end];ECO1.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.SensW sensW_MS(redeclare package Medium = hotMedium)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-96,280})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));

          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
          ThermoPower.Water.ValveLiq valveLiq(
            redeclare package Medium = coldMedium,
            Av=0.05*3.702e-5,
            pnom=17200000,
            dpnom=17000000,
            wnom=0.08785)
            annotation (Placement(transformation(extent={{60,10},{80,30}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = coldMedium, p0=101325)
            annotation (Placement(transformation(extent={{100,10},{120,30}})));
          Components.HE_shell_ts ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=4500, alpha=0.728761),
            redeclare model HeatTransferHot_bundle =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2204.6, alpha=0.461561),
            redeclare model HeatTransferCold_man =
                ThermoPower.Thermal.HeatTransferFV.ConstantHeatTransferCoefficient
                (gamma=1000),
            redeclare model HeatTransferHot_shell =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=200, alpha=0.8),
            Nr=Nr,
            Vhot_bundle=0.7113,
            Vcold_bundle=0.10544,
            Vcold_tubesheet=0.002109,
            Vcold_man=0.004519,
            Shot_bundle=38.73,
            Scold_bundle=31.952,
            L_tubesheet=0.23,
            L_man=0.23,
            L_shell=11.5,
            omega_shell=0.687946,
            D_ext_shell=0.457,
            D_int_shell=0.43796,
            D_ext_ts=0.889,
            s_ins=0.09,
            Mm_ts=567.25,
            Mm_man=567.25,
            km=36,
            rhom=7950,
            Mi=106.7,
            ci=1030,
            ki=0.06,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=618.15,
            nominalHotInletTemperature=631.15,
            nominalHotOutletTemperature=596.15,
            t_in=t_in,
            t_fin=t_fin,
            T_amb=T_amb,
            Mm_bundle=393.2,
            Mm_shell=611.5,
            nominalColdPressure=17400000,
            nominalHotPressure=450000) annotation (Placement(transformation(
                extent={{-16,-16},{16,16}},
                rotation=180,
                origin={-40,-180})));

        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-44}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-64},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, sensW_MS.inlet) annotation (Line(
              points={{-100,310},{-100,286}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, SH.inletHot) annotation (Line(
              points={{-100,274},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(sensW_MS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,274},{-100,274},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{52,-50},{52,46},{52,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,-50},{28,-50},{6,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{0,-300},{0,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,-50},{52,-50},{52,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{52,-50},{52,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));

          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,-50},{52,-50},{52,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{-34,-220},{-34,-248},{-60,
                  -248},{-60,-238}},
              color={255,204,51},
              thickness=0.5));
          connect(separator.drained_out, valveLiq.inlet)
            annotation (Line(points={{0,38},{0,20},{60,20}}, color={0,0,255}));
          connect(valveLiq.outlet, sinkPressure.flange)
            annotation (Line(points={{80,20},{100,20}}, color={0,0,255}));
          connect(signalBus.valveSEP_CS, valveLiq.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,24},{52,42},{70,42},{70,28}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{54,-220},{54,-220},{82,-220},
                  {82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(sensW_MS.w, gain.u) annotation (Line(points={{-90,272},{-90,
                  260},{-40,260},{-40,253.2}}, color={0,0,127}));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-40,-150},{-40,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO2.outletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-40,-196},{-40,-196},{-40,-206},{0,-206},{0,-170},{-1.77636e-015,
                  -170}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{-44,-100},{20,-100},{20,-180},{-24,-180}},
              color={255,0,0},
              thickness=0.5));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-70,-180},{-66,-180},{-56,-180}},
              color={255,0,0},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-220},{-60,-156},{-60,-150},{-40,-150},{-40,-164}},
              color={0,0,255},
              thickness=0.5));

          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_no_pumpMS_shell_ts;

        model OTSG_init100_5nodes_lin
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Nhex=21,
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            tubeWalls(Tvolstart(displayUnit="K")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                inletTubeAtTop=false,
                inletShellAtTop=false,
                Ntp=6),
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.06284e+006,1.3767e+006,1.51073e+006,1.58849e+006,
                  1.64439e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {563.133,597.644,611.941,
                620.01}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={196390,188158,176706,156967,110743}),
            Vhot=1.41501,
            Vcold=0.21088,
            Shot=77.459,
            Scold=63.904,
            Mm=786.38,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499*0.8),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3*0.8),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-44,-196},{-76,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                  1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                  1.94183e+006,2.2136e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                626.498,627.06,627.186,627.848,629.177,631.842}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                  194368,192799}),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.6,
                gamma_nom_2ph=10000*0.6,
                gamma_nom_vap=3875*0.6),
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                  2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                  2.72547e+006,2.78281e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                653.806,658.116,678.213,683.393,689.164,695.453}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                  284059,275898}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            noInitialPressure=true,
            h_start=2.75412e6,
            D=0.28,
            H=6.2,
            w_small=1e4,
            p_start=17200000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=false)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                  3.42217e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                824.786}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,501167,469703,420819,359564}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                  3.55697e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                829.056}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,502650,475154,429572,356689}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6*0.85),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3*0.85),
            nominalColdPressure=4781000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,200})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,220},{-26,240}})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=590.03,
            wnom=1.757)             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,276})));
          ThermoPower.Water.PressDrop PDSteamSH2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757)  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=820.48,
            wnom=1.757)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,258})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,164})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,278})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,200},{174,200},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,216}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(HPH.inletHot, ECO.outletHot) annotation (Line(
              points={{-76,-280},{-100,-280},{-100,-180},{-76,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-60,-164},{-60,-150}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,200},{100,200},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{140,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,286}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,266},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,266},{-100,266},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,280},{-94,280}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0)
            annotation (Line(points={{-40,247},{-40,236}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,10},{50,10},{50,280},{-40,280},{-40,270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                  124},{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{-20,-300},{-20,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{64,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.outletCold, SH_out) annotation (Line(
              points={{0,156},{0,310}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,184},{140,170}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,158},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,272},{100,266},{100,260}},
              color={0,0,255},
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,310},{100,284}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,10},{50,10},{50,156},{130,156}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-60,10},{-60,3},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
              points={{-34,48},{-10,48}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.inlet, PDSteamEVA2.outlet) annotation (Line(
              points={{-46,48},{-60,48},{-60,30}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,10},{50,10},{50,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init100_5nodes_lin;

        model OTSG_init100_5nodes_lin_ECO_complete
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 100% load and 5 nodes and real ECO configuration"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            tubeWalls(Tvolstart(displayUnit="K")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                inletTubeAtTop=false,
                inletShellAtTop=false,
                Ntp=6),
            Nhex=11,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=564.15,
            nominalHotInletTemperature=569.15,
            nominalHotOutletTemperature=563.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={1.64935e+006,1.66e+006,1.67025e+006,1.68028e+006,
                  1.6903e+006,1.70575e+006,1.73919e+006,1.80649e+006,
                  1.94183e+006,2.2136e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {623.42,624.495,625.515,
                626.498,627.06,627.186,627.848,629.177,631.842}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={275898,235873,215942,206030,201105,198829,197354,195876,
                  194368,192799}),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.6,
                gamma_nom_2ph=10000*0.6,
                gamma_nom_vap=3875*0.6),
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2136e+006,2.26901e+006,2.33008e+006,2.39737e+006,
                  2.47152e+006,2.5506e+006,2.60846e+006,2.66705e+006,
                  2.72547e+006,2.78281e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {646.908,648.99,651.282,
                653.806,658.116,678.213,683.393,689.164,695.453}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={359728,351283,342679,334050,325530,313883,302963,293052,
                  284059,275898}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          Components.Equilibrium2phVessel separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            noInitialPressure=true,
            h_start=2.75412e6,
            D=0.28,
            H=6.2,
            w_small=1e4,
            p_start=17200000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=false)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7561e+006,3.01185e+006,3.21596e+006,3.34733e+006,
                  3.42217e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {727.066,768.643,802.651,
                824.786}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,501167,469703,420819,359564}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));
          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                hstart={3.10088e+006,3.30556e+006,3.43357e+006,3.51079e+006,
                  3.55697e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {737.607,783.417,811.91,
                829.056}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,502650,475154,429572,356689}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6*0.85),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3*0.85),
            nominalColdPressure=4781000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,200})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,220},{-26,240}})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=590.03,
            wnom=1.757)             annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-140})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T;
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          //Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          //Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          //Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow pumpMS(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8) annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,276})));
          ThermoPower.Water.PressDrop PDSteamSH2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757)  annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(1/2)*10^5,
            rhonom=820.48,
            wnom=1.757)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-214})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-60,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-40,258})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,164})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,278})));
          Components.ECO_complete ECO(
            cm=500,
            nominalColdDeltaP=0,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Vhot=1.41501,
            Vcold=0.21088,
            Shot=77.459,
            Scold=63.904,
            Mm=786.38,
            nominalColdFlow=1.757,
            nominalHotFlow=11.96,
            ECO2(Nhex=2),
            ECO3(Nhex=2),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4850),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2310),
            ECO4(Nhex=2),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalHotDeltaP=171720,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=621.59,
            nominalHotInletTemperature=626.75,
            nominalHotOutletTemperature=569.15,
            ECO1(Nhex=2)) annotation (Placement(transformation(extent={{-44,-196},
                    {-76,-164}})));

          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-44,42},{-24,62}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,200},{174,200},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,230},{140,230},{140,216}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,200},{100,200},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{140,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, pumpMS.inlet) annotation (Line(
              points={{-100,310},{-100,286}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, SH.inletHot) annotation (Line(
              points={{-100,266},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(pumpMS.outlet, valveRH.inlet) annotation (Line(
              points={{-100,266},{-100,266},{-100,230},{-46,230}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, pumpMS.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,280},{-94,280}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-60,-116},{-60,-130}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{84,-230},{40,-230},{-6,-230},{-60,-230},{-60,-224}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-60,-256},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-60,-230},{-60,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0)
            annotation (Line(points={{-40,247},{-40,236}}, color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,10},{50,10},{50,280},{-40,280},{-40,270}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,44},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH2.outlet) annotation (Line(points={{0,
                  124},{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH2.inlet, separator.steam_out) annotation (Line(
                points={{-6.66134e-016,90},{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{-20,-300},{-20,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{64,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.outletCold, SH_out) annotation (Line(
              points={{0,156},{0,310}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,184},{140,170}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,158},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,272},{100,266},{100,260}},
              color={0,0,255},
              thickness=0.5));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,310},{100,284}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,10},{50,10},{50,156},{130,156}},
              color={255,204,51},
              thickness=0.5));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-44,-100},{-20,-100},{-20,-180},{-44,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO.outletHot, HPH.inletHot) annotation (Line(
              points={{-76,-180},{-88,-180},{-100,-180},{-100,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(PDSteamECO2.inlet, ECO.outletCold) annotation (Line(
              points={{-60,-150},{-60,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-60,-196},{-60,-196},{-60,-204}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.inlet, EVA2.outletCold) annotation (Line(
              points={{-60,10},{-60,3},{-60,-4}},
              color={0,0,255},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in) annotation (Line(
              points={{-28,48},{-10,48}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet) annotation (Line(
              points={{-60,30},{-60,48},{-40,48}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,10},{50,10},{50,84},{-26,84},{-26,58}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,10},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init100_5nodes_lin_ECO_complete;

        model OTSG_init50_5nodes_lin
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.HE           ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15,
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
            annotation (Placement(transformation(extent={{-74,-196},{-106,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,-54})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          //Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          //Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          //Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,-50}),iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));
          Components.HE ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            nominalColdPressure=17350000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=596.15,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15,
            hotFluid(noInitialPressure=true, FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction))
            annotation (Placement(transformation(extent={{-14,-164},{-46,-196}})));

          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,-44}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-64},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,-50},{52,-50},{52,46},{52,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,-50},{52,-50},{52,260},{-40,260},{-40,253.2}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,-50},{28,-50},{6,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{0,-300},{0,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,-50},{52,-50},{52,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,-50},{52,-50},{52,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,-50},{52,-50},{52,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));
          connect(ECO2.outletCold,PDSteamECO2. outlet) annotation (Line(
              points={{-30,-196},{-30,-210},{-1.77636e-015,-210},{-1.77636e-015,-170}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{20,-100},{20,-180},{-14,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-60,-180},{-46,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,-50},{52,-50},{52,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,-50},{52,-50},{52,-220},{-34,-220},{-34,-248},{-60,
                  -248},{-60,-238}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_high, sensT_FW.T) annotation (Line(
              points={{50,-50},{50,-56},{52,-56},{52,-94},{52,-94},{52,-136},{
                  52,-136},{52,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_lin;

        model OTSG_init50_5nodes_lin_ECO_complete
          "Dynamic model of the once through steam generator, enthalpy profile initialisation at 50% load and 5 nodes"
          extends BaseClasses.BaseOTSG;

          //Heat exchangers parameter
          parameter Integer Nhex_mono = 5
            "Number of nodes for single phase heat exchangers";
          parameter Integer Nhex_bi = 10
            "Number of nodes for biphase heat exchangers";
          parameter Real wRH_wMS = 0.385 "Fraction of total MS flow to RH";

          Components.HE HPH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.536143, gamma_nom=3958.9),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447465, gamma_nom=2197.5),
            tubeWalls(Tvolstart(displayUnit="degC")),
            hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
                noInitialPressure=true),
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                Nw=10,
                Ntp=2,
                inletTubeAtTop=false,
                inletShellAtTop=false),
            Vhot=0.05554,
            Vcold=0.02017,
            Shot=7.188,
            Scold=6.02,
            Mm=68.23,
            nominalColdFlow=0.4717,
            nominalHotFlow=11.95,
            Nhex=5,
            nominalColdPressure=17400000,
            nominalHotPressure=250000,
            nominalColdInletTemperature=557.15,
            nominalColdOutletTemperature=558.15,
            nominalHotInletTemperature=559.15,
            nominalHotOutletTemperature=558.15) annotation (Placement(
                transformation(extent={{-76,-264},{-44,-296}})));

          Components.ECO_complete ECO1(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            ECO1(Nhex=2),
            ECO2(Nhex=2),
            ECO4(Nhex=2),
            ECO3(Nhex=2),
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            nominalColdPressure=17400000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=518.15,
            nominalColdOutletTemperature=568.15,
            nominalHotInletTemperature=596.15,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-74,-196},{-106,-164}})));

          Components.HE_2ph
                        EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.447498, gamma_nom=2147.7),
            tubeWalls(Tvolstart(displayUnit="K") = {563.715,564.442,565.39,566.625,568.238,
                570.351,573.127,576.732,577.41}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={162318,133391,124779,118512,113788,110206,107479,105395,103799,102574}),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={1.2884e+006,1.29139e+006,1.29529e+006,1.30038e+006,
                  1.30704e+006,1.31579e+006,1.32733e+006,1.34263e+006,
                  1.36366e+006,1.43431e+006},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                alpha=1.6,
                gamma_nom_liq=3875*0.75,
                gamma_nom_2ph=10000*0.75,
                gamma_nom_vap=3875*0.75),
            Vhot=0.821,
            Vcold=0.26,
            Shot=67.796,
            Scold=53.152,
            Mm=1297.56,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17300000,
            nominalHotPressure=650000,
            nominalColdInletTemperature=621.55,
            nominalColdOutletTemperature=626.9,
            nominalHotInletTemperature=689.01,
            nominalHotOutletTemperature=626.65) annotation (Placement(
                transformation(extent={{-76,-116},{-44,-84}})));
          Components.HE_2ph
                        EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_bi,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.43431e+006,1.45529e+006,1.48061e+006,1.51115e+006,1.54799e+006,1.59242e+006,
                  1.64599e+006,1.71054e+006,1.78832e+006,1.88199e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.58,583.89,585.469,587.372,589.664,
                592.425,595.747,599.741,604.541}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={345637,307282,275432,248996,227062,208869,193783,181276,170909,162318}),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Vhot=0.094,
            Vcold=0.024,
            Shot=9.671,
            Scold=7.616,
            Mm=116.772,
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            nominalColdPressure=17250000,
            nominalHotPressure=700000,
            nominalColdInletTemperature=626.69,
            nominalColdOutletTemperature=646.74,
            nominalHotInletTemperature=734.05,
            nominalHotOutletTemperature=689.01) annotation (Placement(
                transformation(extent={{-44,-36},{-76,-4}})));

          FullScale_245degC.HeatExchangers.Components.nonEquilibriumVessel
                                          separator(
            redeclare package Medium = coldMedium,
            zl_start=0,
            w_small=1e4,
            D=0.28,
            H=6.2,
            gamma=0,
            hv_start=2.7e6,
            hl_start=1.3e6,
            noInitialPressure=false,
            p_start=8935000)
            annotation (Placement(transformation(extent={{-28,28},{28,84}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            redeclare package Medium = coldMedium,
            allowFlowReversal=false,
            w0=0,
            use_in_w0=true)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={0,6})));

          Components.HE SH(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.847436, gamma_nom=1996.5),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.28867, gamma_nom=2848.1),
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={2.7455e+006,3.16804e+006,3.40651e+006,3.50256e+006,3.53821e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {716.591,782.314,818.772,833.393}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510311,486650,427909,323825}),
            Vhot=0.234,
            Vcold=0.053,
            Shot=22.8,
            Scold=17.385,
            Mm=303.385,
            nominalColdFlow=1.757,
            nominalHotFlow=7.35,
            nominalColdPressure=17200000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=646.55,
            nominalColdOutletTemperature=823.96,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=733.58)
            annotation (Placement(transformation(extent={{-16,-16},{16,16}},
                rotation=0,
                origin={0,140})));

          Components.HE RH(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            Nhex=Nhex_mono,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.798347, gamma_nom=963.6),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.320782, gamma_nom=2690.3),
            coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction, hstart={3.15366e+006,
                  3.40526e+006,3.52164e+006,3.57547e+006,3.60052e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {754.836,802.458,824.417,834.567}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              noInitialPressure=true,
              hstart={519092,510695,492652,453640,369304}),
            Vhot=0.425,
            Vcold=0.106,
            Shot=27.935,
            Scold=24.995,
            Mm=210.313,
            nominalColdFlow=1.635,
            nominalHotFlow=4.607,
            nominalColdPressure=2260000,
            nominalHotPressure=1050000,
            nominalColdInletTemperature=633.15,
            nominalColdOutletTemperature=826.06,
            nominalHotInletTemperature=838.65,
            nominalHotOutletTemperature=734.05)
            annotation (Placement(transformation(extent={{-16,16},{16,-16}},
                rotation=-90,
                origin={140,192})));
          ThermoPower.Water.ThroughMassFlow valveRH(
            redeclare package Medium = hotMedium,
            use_in_w0=true,
            w0=238.6)
            annotation (Placement(transformation(extent={{-46,218},{-26,238}})));
          ThermoPower.Water.SensT sensT_RH(redeclare package Medium = coldMedium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={96,276})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=160.88,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,-60})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=92.917,
            wnom=1.757)          annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-60,20})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = HPH.Q_Hot + ECO1.Q_Hot + ECO2.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot + SH.Q_Hot + RH.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = sensT_FW.T[1];
          Modelica.SIunits.Temperature T_outMS = HPH.hotFluid.T[end];
          Modelica.SIunits.Temperature T_RH = sensT_RH.T;
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,separator.DT_sh);
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          //Modelica.SIunits.Temperature T_hot_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_hot_prof;EVA2.T_hot_prof[2:end];EVA1.T_hot_prof[2:end];ECO.T_hot_prof[2:end]]);
          //Modelica.SIunits.Temperature T_cold_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_cold_prof;EVA2.T_cold_prof[2:end];EVA1.T_cold_prof[2:end];ECO.T_cold_prof[2:end]]);
          //Modelica.SIunits.Temperature T_wall_prof[2*Nhex_mono + 2*Nhex_bi + 1] = vector([SH.T_wall_prof;EVA2.T_wall_prof[2:end];EVA1.T_wall_prof[2:end];ECO.T_wall_prof[2:end]]);
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.PressDrop PDSteamRH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.5)*10^5,
            rhonom=12.775,
            redeclare package Medium = coldMedium,
            wnom=1.635)                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={100,250})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={50,10}), iconTransformation(
                extent={{-30,-30},{30,30}},
                rotation=-90,
                origin={-194,0})));
          ThermoPower.Water.SensT sensT_FW(
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{100,-236},{80,-216}})));
          ThermoPower.Water.SensT sensT_MS(
            redeclare package Medium = hotMedium)
            annotation (Placement(transformation(extent={{-20,-286},{0,-266}})));
          ThermoPower.Water.ThroughMassFlow throughMassFlow(
            use_in_w0=true,
            redeclare package Medium = hotMedium,
            w0=619.8)
            annotation (Placement(transformation(
                extent={{10,10},{-10,-10}},
                rotation=90,
                origin={-100,256})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=820.48,
            wnom=1.757,
            dpnom=(1/2)*10^5)              annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=180,
                origin={-76,-150})));
          ThermoPower.Water.PressDrop PDSteamHPH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            dpnom=(0.5)*10^5,
            rhonom=747.38,
            wnom=0.4717)         annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=90,
                origin={-20,-246})));
          Modelica.Blocks.Math.Gain gain(k=wRH_wMS) annotation (Placement(
                transformation(
                extent={{-6,-6},{6,6}},
                rotation=270,
                origin={-40,246})));
          ThermoPower.Water.PressDrop PDSteamSH(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(1)*10^5,
            redeclare package Medium = coldMedium,
            rhonom=92.8,
            wnom=1.757,
            pout(start=91.6e5, fixed=true))
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,100})));
          ThermoPower.Water.ThroughMassFlow pump_HPH(
            use_in_w0=true,
            w0=24.51,
            redeclare package Medium = coldMedium)
            annotation (Placement(transformation(extent={{44,-300},{64,-280}})));
          ThermoPower.Water.SensT sensT_MS_RHout(redeclare package Medium =
                hotMedium) annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={136,160})));
          Auxiliaries.Components.SensDT_sh sensDT_sh
            annotation (Placement(transformation(extent={{-50,42},{-30,62}})));
          Components.ECO_complete
                        ECO2(
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            redeclare package coldMedium = coldMedium,
            redeclare package hotMedium = hotMedium,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4499),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2204.3),
            nominalHotFlow=11.95,
            nominalColdFlow=1.757,
            ECO1(Nhex=2),
            ECO2(Nhex=2),
            ECO4(Nhex=2),
            ECO3(Nhex=2),
            Vhot=1.41501/2,
            Vcold=0.21088/2,
            Shot=77.459/2,
            Scold=63.904/2,
            Mm=786.38/2,
            nominalColdPressure=17350000,
            nominalHotPressure=450000,
            nominalColdInletTemperature=568.15,
            nominalColdOutletTemperature=596.15,
            nominalHotInletTemperature=626.65,
            nominalHotOutletTemperature=569.15)
            annotation (Placement(transformation(extent={{-14,-164},{-46,-196}})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            redeclare package Medium = coldMedium,
            rhonom=590.03,
            wnom=1.757,
            dpnom=(1/2)*10^5)       annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={0,-160})));
          Auxiliaries.Components.ThreeWayValve_2out threeWayValve annotation (
              Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=180,
                origin={-60,-230})));
          Auxiliaries.Components.SensDT_sc sensDT_sc
            annotation (Placement(transformation(extent={{-30,-134},{-10,-114}})));
        equation
          connect(RH.inletCold, RH_in) annotation (Line(
              points={{156,192},{174,192},{174,180},{190,180}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(valveRH.outlet, RH.inletHot) annotation (Line(
              points={{-26,228},{140,228},{140,208}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(RH_out, sensT_RH.outlet) annotation (Line(
              points={{100,310},{100,282}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{0,38},{0,16},{1.77636e-015,16}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-60,-50},{-60,-36}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-60,-84},{-60,-70}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(SH.outletHot, EVA2.inletHot) annotation (Line(
              points={{16,140},{140,140},{140,-20},{-44,-20}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-76,-20},{-100,-20},{-100,-100},{-76,-100}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(waterPump.outlet, SEP_out) annotation (Line(
              points={{-1.77636e-015,-4},{-1.77636e-015,-80},{190,-80}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_RH.inlet, PDSteamRH.outlet) annotation (Line(
              points={{100,270},{100,260}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(RH.outletCold, PDSteamRH.inlet) annotation (Line(
              points={{124,192},{100,192},{100,240}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(sensT_FW.inlet, FW_in) annotation (Line(
              points={{96,-230},{96,-230},{110,-230},{140,-230},{140,-210},{190,
                  -210}},
              color={0,0,255},
              thickness=0.5));
          connect(HPH.outletHot, sensT_MS.inlet) annotation (Line(
              points={{-44,-280},{-16,-280}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.outlet, MS_out) annotation (Line(
              points={{-4,-280},{20,-280},{20,-310}},
              color={255,0,0},
              thickness=0.5));
          connect(MS_in, throughMassFlow.inlet) annotation (Line(
              points={{-100,310},{-100,266}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, SH.inletHot) annotation (Line(
              points={{-100,246},{-100,140},{-16,140}},
              color={255,0,0},
              thickness=0.5));
          connect(throughMassFlow.outlet, valveRH.inlet) annotation (Line(
              points={{-100,246},{-100,246},{-100,228},{-46,228}},
              color={255,0,0},
              thickness=0.5));
          connect(signalBus.pumpMS_CS, throughMassFlow.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,260},{-94,260}},
              color={255,204,51},
              thickness=0.5));
          connect(PDSteamHPH.outlet, HPH.inletCold) annotation (Line(
              points={{-20,-256},{-20,-260},{-60,-260},{-60,-264}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamHPH.inlet) annotation (Line(
              points={{84,-230},{12,-230},{-20,-230},{-20,-236}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{50,10},{50,10},{50,46},{50,42},{10,42}},
              color={255,204,51},
              thickness=0.5));
          connect(gain.y, valveRH.in_w0) annotation (Line(points={{-40,239.4},{
                  -40,239.4},{-40,234}},
                                       color={0,0,127}));
          connect(signalBus.pumpMS_CS, gain.u) annotation (Line(
              points={{50,10},{50,10},{50,260},{-40,260},{-40,253.2}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{50,10},{28,10},{6,10}},
              color={255,204,51},
              thickness=0.5));
          connect(SH.inletCold, PDSteamSH.outlet)
            annotation (Line(points={{0,124},{0,110}}, color={0,0,255},
              thickness=0.5));
          connect(PDSteamSH.inlet, separator.steam_out)
            annotation (Line(points={{0,90},{0,80}}, color={0,0,255},
              thickness=0.5));
          connect(HPH.outletCold, pump_HPH.inlet) annotation (Line(
              points={{-60,-296},{-60,-300},{0,-300},{0,-290},{44,-290}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(pump_HPH.outlet, sensT_FW.inlet) annotation (Line(
              points={{64,-290},{104,-290},{140,-290},{140,-230},{96,-230}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.pumpHPH_CS, pump_HPH.in_w0) annotation (Line(
              points={{50,10},{50,10},{50,-284},{50,-284}},
              color={255,204,51},
              thickness=0.5));
          connect(SH_out, SH.outletCold) annotation (Line(
              points={{0,310},{0,156}},
              color={0,0,255},
              thickness=0.5));
          connect(RH.outletHot, sensT_MS_RHout.inlet) annotation (Line(
              points={{140,176},{140,176},{140,166}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensT_MS_RHout.outlet, EVA2.inletHot) annotation (Line(
              points={{140,154},{140,154},{140,130},{140,-20},{-44,-20}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveDEA_SH_PV, sensT_MS_RHout.T) annotation (Line(
              points={{50,10},{50,10},{50,152},{130,152}},
              color={255,204,51},
              thickness=0.5));
          connect(sensDT_sh.outlet, separator.water_in)
            annotation (Line(points={{-34,48},{-10,48}},          color={0,0,255}));
          connect(PDSteamEVA2.outlet, sensDT_sh.inlet)
            annotation (Line(points={{-60,30},{-60,48},{-46,48}}, color={0,0,255}));
          connect(PDSteamEVA2.inlet, EVA2.outletCold)
            annotation (Line(points={{-60,10},{-60,-4}},          color={0,0,255}));
          connect(signalBus.pumpSEP_PV, sensT_FW.T) annotation (Line(
              points={{50,10},{50,10},{50,-220},{82,-220}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, sensDT_sh.DT_sh) annotation (Line(
              points={{50,10},{50,10},{50,84},{-32,84},{-32,58}},
              color={255,204,51},
              thickness=0.5));
          connect(ECO2.outletCold,PDSteamECO2. outlet) annotation (Line(
              points={{-30,-196},{-30,-210},{-1.77636e-015,-210},{-1.77636e-015,-170}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.outletHot, ECO2.inletHot) annotation (Line(
              points={{-44,-100},{20,-100},{20,-180},{-14,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.outletHot, HPH.inletHot) annotation (Line(
              points={{-106,-180},{-120,-180},{-120,-280},{-76,-280}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(ECO1.inletHot, ECO2.outletHot) annotation (Line(
              points={{-74,-180},{-60,-180},{-46,-180}},
              color={255,0,0},
              thickness=0.5,
              arrow={Arrow.Filled,Arrow.None}));

          connect(PDSteamECO2.inlet, sensDT_sc.outlet) annotation (Line(
              points={{1.77636e-015,-150},{1.77636e-015,-128},{-14,-128}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(sensDT_sc.inlet, EVA1.inletCold) annotation (Line(
              points={{-26,-128},{-44,-128},{-60,-128},{-60,-116}},
              color={0,0,255},
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(signalBus.valveSUB_PV, sensDT_sc.DT_sc) annotation (Line(
              points={{50,10},{50,10},{50,-118},{-12,-118}},
              color={255,204,51},
              thickness=0.5));
          connect(sensT_FW.outlet, threeWayValve.inlet) annotation (Line(
              points={{84,-230},{84,-230},{-50,-230}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet1, ECO1.inletCold) annotation (Line(
              points={{-70,-230},{-70,-230},{-90,-230},{-90,-196}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO1.outletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-90,-164},{-90,-150},{-86,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(PDSteamECO1.inlet, ECO2.inletCold) annotation (Line(
              points={{-66,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(threeWayValve.outlet2, ECO2.inletCold) annotation (Line(
              points={{-60,-220},{-60,-150},{-30,-150},{-30,-164}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveSUB_CS, threeWayValve.theta) annotation (Line(
              points={{50,10},{50,10},{50,-220},{-34,-220},{-34,-248},{-60,-248},
                  {-60,-238}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-180,-300},{180,300}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-180,-300},{180,300}}, preserveAspectRatio=false)),
            Documentation(info="<html>
<p>This model is meant for linearization, since not all the sensors are connected to the signal bus and can be moved if needed.</p>
</html>"));
        end OTSG_init50_5nodes_lin_ECO_complete;

        package Test

          package HE "Package of single heat exchanger test model"

            model test_heatExchangers_offDesign
              "Test model of all the heat exchangers, from nominal load to 20% load, steady-state initialisation"

              //Heat exchangers parameter
              parameter Integer Nhex_mono = 5
                "Number of nodes for single phase heat exchangers";
              parameter Integer Nhex_bi = 10
                "Number of nodes for biphase heat exchangers";

              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                w0=381.3,
                p0=1000000,
                h=519092)
                annotation (Placement(transformation(extent={{-250,120},{-230,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=2755127)
                annotation (Placement(transformation(extent={{-250,20},{-230,40}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17132400)
                annotation (Placement(transformation(extent={{-190,180},{-170,200}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=855401)
                annotation (Placement(transformation(extent={{-160,120},{-140,140}})));
              ThermoPower.Water.PressDrop PDMSSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(10.5 - 8.55401)*10^5,
                rhonom=1797.2,
                wnom=7.349)
                annotation (Placement(transformation(extent={{-190,120},{-170,140}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(172 - 171.0324)*10^5,
                rhonom=50.398,
                wnom=1.757)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={-210,160})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-340,240},{-320,260}})));
              Components.HE SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.847436, gamma_nom=1996.5),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.28867, gamma_nom=2848.1),
                Nhex=Nhex_mono,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=0.234,
                Vcold=0.053,
                Shot=22.8,
                Scold=17.385,
                Mm=303.385,
                nominalColdFlow=1.757,
                nominalHotFlow=7.35,
                nominalColdPressure=17200000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=646.55,
                nominalColdOutletTemperature=823.96,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=733.58)
                annotation (Placement(transformation(extent={{-220,120},{-200,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS1(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=false,
                w0=238.6,
                p0=1050000,
                h=519092)
                annotation (Placement(transformation(extent={{-40,120},{-20,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=84.94,
                h=3081212)
                annotation (Placement(transformation(extent={{-40,20},{-20,40}})));
              ThermoPower.Water.SinkPressure sinkSteam1(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=4733745)
                annotation (Placement(transformation(extent={{20,178},{40,198}})));
              ThermoPower.Water.SinkPressure sinkMS1(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=915515)
                annotation (Placement(transformation(extent={{50,120},{70,140}})));
              ThermoPower.Water.PressDrop PDMSRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_lin,
                dpnom=(1.34485)*10^5,
                rhonom=1796.9,
                wnom=4.601)
                annotation (Placement(transformation(extent={{20,120},{40,140}})));
              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.47256)*10^5,
                rhonom=12.775,
                wnom=2.029)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={0,160})));
              Components.HE RH(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=963.6),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.320782, gamma_nom=2690.3),
                Nhex=Nhex_mono,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=0.425,
                Vcold=0.106,
                Shot=27.935,
                Scold=24.995,
                Mm=210.313,
                nominalColdFlow=1.635,
                nominalHotFlow=4.607,
                nominalColdPressure=4781000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=633.25,
                nominalColdOutletTemperature=824.15,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=734.05)
                annotation (Placement(transformation(extent={{-10,120},{10,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS2(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                h=196421,
                w0=11.95)
                annotation (Placement(transformation(extent={{170,120},{190,140}})));
              ThermoPower.Water.SourceMassFlow sourceSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=1062835)
                annotation (Placement(transformation(extent={{172,20},{192,40}})));
              ThermoPower.Water.SinkPressure sinkSteam2(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17345880)
                annotation (Placement(transformation(extent={{230,178},{250,198}})));
              ThermoPower.Water.SinkPressure sinkMS2(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=279240)
                annotation (Placement(transformation(extent={{260,120},{280,140}})));
              ThermoPower.Water.PressDrop PDMSECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.7076)*10^5,
                rhonom=1901.7,
                wnom=11.95)
                annotation (Placement(transformation(extent={{230,120},{250,140}})));
              ThermoPower.Water.PressDrop PDSteamECO(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.54118)*10^5,
                rhonom=590.03,
                wnom=1.757)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={210,160})));
              Components.HE ECO(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.728761, gamma_nom=4499),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.461561, gamma_nom=2204.3),
                Nhex=Nhex_mono,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=1.41501,
                Vcold=0.21088,
                Shot=77.459,
                Scold=63.904,
                Mm=786.38,
                nominalColdFlow=1.757,
                nominalHotFlow=11.96,
                nominalColdPressure=17400000,
                nominalHotPressure=450000,
                nominalColdInletTemperature=518.15,
                nominalColdOutletTemperature=621.59,
                nominalHotInletTemperature=626.75,
                nominalHotOutletTemperature=569.15)
                annotation (Placement(transformation(extent={{200,120},{220,140}})));

              ThermoPower.Water.SourceMassFlow sourceSteam4(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=1649400)
                annotation (Placement(transformation(extent={{-100,-220},{-80,-200}})));
              ThermoPower.Water.SinkPressure sinkMS4(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=543863)
                annotation (Placement(transformation(extent={{-120,-120},{-140,-100}})));
              ThermoPower.Water.PressDrop PDMSEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(1.06137)*10^5,
                rhonom=1865.18,
                wnom=11.95)
                annotation (Placement(transformation(extent={{-80,-120},{-100,-100}})));
              ThermoPower.Water.PressDrop PDSteamEVA1(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.0622)*10^5,
                rhonom=160.882,
                wnom=1.757)          annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={0,-60})));
              Components.HE_2ph
                            EVA1(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2300, alpha=0.447498),
                generateInitCode=true,
                Nhex=Nhex_bi,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=0.821,
                Vcold=0.26,
                Shot=67.796,
                Scold=53.152,
                Mm=1297.56,
                nominalColdFlow=1.757,
                nominalHotFlow=11.96,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    alpha=1.6,
                    gamma_nom_liq=3875*0.75,
                    gamma_nom_2ph=25350*0.75,
                    gamma_nom_vap=3875*0.75),
                nominalColdPressure=17300000,
                nominalHotPressure=650000,
                nominalColdInletTemperature=621.55,
                nominalColdOutletTemperature=626.9,
                nominalHotInletTemperature=689.01,
                nominalHotOutletTemperature=626.65) annotation (Placement(
                    transformation(extent={{-50,-120},{-70,-100}})));
              ThermoPower.Water.SourceMassFlow sourceMS5(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                w0=619.8,
                h=359728.2)
                annotation (Placement(transformation(extent={{120,-120},{100,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam5(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17228810)
                annotation (Placement(transformation(extent={{90,-220},{110,-200}})));
              ThermoPower.Water.PressDrop PDMSEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(0.2863)*10^5,
                rhonom=1825.49,
                wnom=11.95)
                annotation (Placement(transformation(extent={{10,-120},{-10,-100}})));
              ThermoPower.Water.PressDrop PDSteamEVA2(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.2119)*10^5,
                rhonom=93.08,
                wnom=1.757)          annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=90,
                    origin={70,-150})));
              Components.HE_2ph
                            EVA2(
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                Nhex=Nhex_bi,
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=0.094,
                Vcold=0.024,
                Shot=9.671,
                Scold=7.616,
                Mm=116.772,
                nominalColdFlow=1.757,
                nominalHotFlow=11.95,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                    (
                    alpha=1.6,
                    gamma_nom_2ph=6000,
                    gamma_nom_liq=2600,
                    gamma_nom_vap=2600),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.389637, gamma_nom=2650),
                nominalColdPressure=17250000,
                nominalHotPressure=700000,
                nominalColdInletTemperature=626.69,
                nominalColdOutletTemperature=646.74,
                nominalHotInletTemperature=734.05,
                nominalHotOutletTemperature=689.01) annotation (Placement(
                    transformation(extent={{80,-100},{60,-120}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_SH(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1.471; 30,2.207; 40,2.942; 50,3.678; 60,4.41; 70,5.144; 80,5.879; 90,
                    6.617; 100,7.349])
                annotation (Placement(transformation(extent={{-270,150},{-250,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,2752e3; 30,2751.7e3; 40,2751.2e3; 50,2745.5e3; 60,2834.3e3; 70,2817.3e3;
                    80,2799.2e3; 90,2780.1e3; 100,2756.1e3])
                annotation (Placement(transformation(extent={{-270,80},{-250,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,1.436;
                    90,1.605; 100,1.757])
                annotation (Placement(transformation(extent={{-270,50},{-250,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.6e5; 70,124.1e5;
                    80,139.7e5; 90,155.1e5; 100,171e5])      annotation (Placement(
                    transformation(extent={{-230,210},{-210,230}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,8.839e5; 30,13.32e5; 40,17.87e5; 50,21.61e5; 60,27.45e5; 70,32.69e5;
                    80,37.23e5; 90,42.09e5; 100,47.32e5])
                annotation (Placement(transformation(extent={{-20,210},{0,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(            smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,3242e3;
                    30,3230e3; 40,3218e3; 50,3204e3; 60,3186e3; 70,3159e3; 80,3137e3; 90,3113e3;
                    100,3103e3])
                annotation (Placement(transformation(extent={{-60,80},{-40,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.3738; 30,0.5824; 40,0.8001; 50,1.026; 60,1.262; 70,1.456; 80,1.649;
                    90,1.845; 100,2.029])
                annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_RH(
                                   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.9209; 30,1.381; 40,1.842; 50,2.302; 60,2.75; 70,3.221; 80,3.681; 90,
                    4.143; 100,4.601])
                annotation (Placement(transformation(extent={{-60,150},{-40,170}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.44e5; 30,86.11e5; 40,86.98e5; 50,90.74e5; 60,109.1e5; 70,125.6e5;
                    80,141.3e5; 90,157e5; 100,173e5])
                annotation (Placement(transformation(extent={{190,210},{210,230}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_ECO(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85022; 30,92144; 40,96841; 50,105478; 60,143812; 70,160025; 80,174268;
                    90,186692; 100,196390])
                annotation (Placement(transformation(extent={{150,180},{170,200}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                    100,11.95])
                annotation (Placement(transformation(extent={{150,150},{170,170}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1262e3; 30,1261.9e3; 40,1262.4e3; 50,1257.9e3; 60,1121.9e3; 70,1062.2e3;
                    80,1062.4e3; 90,1062.4e3; 100,1063e3])
                annotation (Placement(transformation(extent={{150,80},{170,100}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_ECO(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                    1.605; 100,1.757])
                annotation (Placement(transformation(extent={{150,50},{170,70}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.16e5; 30,85.37e5; 40,85.67e5; 50,89.35e5; 60,108.5e5; 70,124.9e5;
                    80,140.5e5; 90,156.1e5; 100,172e5])
                annotation (Placement(transformation(extent={{140,-190},{120,-170}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,352001; 30,350485; 40,348819; 50,345637; 60,358364; 70,359274; 80,360183;
                    90,360789; 100,359728])
                annotation (Placement(transformation(extent={{140,-60},{120,-40}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                    100,11.95])
                annotation (Placement(transformation(extent={{140,-90},{120,-70}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1262e3; 30,1264.9e3; 40,1271.5e3; 50,1289.5e3; 60,1451.5e3; 70,1515.6e3;
                    80,1572.2e3; 90,1615.5e3; 100,1650.3e3])
                annotation (Placement(transformation(extent={{-120,-160},{-100,-140}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_EVA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,1.436; 90,
                    1.605; 100,1.757])
                annotation (Placement(transformation(extent={{-120,-190},{-100,-170}})));

              Real load = sourceMS2.w/sourceMS2.w0;
              Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                t_ramp=8e6,
                load_end=100) annotation (Placement(transformation(extent={{-300,
                        -220},{-260,-180}})));
              Modelica.Blocks.Sources.Ramp LOAD_SH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-310,130})));
              Modelica.Blocks.Sources.Ramp LOAD_RH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-100,130})));
              Modelica.Blocks.Sources.Ramp LOAD_ECO(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={110,130})));
              Modelica.Blocks.Sources.Ramp LOAD_EVA1(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-170,-160})));
              Modelica.Blocks.Sources.Ramp LOAD_EVA2(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{10,-10},{-10,10}},
                    rotation=0,
                    origin={190,-110})));
            equation
              connect(sinkMS.flange, PDMSSH.outlet) annotation (Line(
                  points={{-160,130},{-170,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.outlet, sinkSteam.flange) annotation (Line(
                  points={{-210,170},{-210,190},{-190,190}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange, SH.inletCold) annotation (Line(
                  points={{-230,30},{-210,30},{-210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, SH.inletHot) annotation (Line(
                  points={{-230,130},{-220,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SH.outletHot, PDMSSH.inlet) annotation (Line(
                  points={{-200,130},{-190,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.inlet, SH.outletCold) annotation (Line(
                  points={{-210,150},{-210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS1.flange, PDMSRH.outlet) annotation (Line(
                  points={{50,130},{40,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.outlet, sinkSteam1.flange) annotation (Line(
                  points={{4.44089e-016,170},{0,170},{0,188},{20,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam1.flange, RH.inletCold) annotation (Line(
                  points={{-20,30},{0,30},{0,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS1.flange, RH.inletHot) annotation (Line(
                  points={{-20,130},{-10,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.outletHot,PDMSRH. inlet) annotation (Line(
                  points={{10,130},{20,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.inlet,RH. outletCold) annotation (Line(
                  points={{0,150},{0,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS2.flange, PDMSECO.outlet) annotation (Line(
                  points={{260,130},{250,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.outlet, sinkSteam2.flange) annotation (Line(
                  points={{210,170},{210,188},{230,188}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam2.flange, ECO.inletCold) annotation (Line(
                  points={{192,30},{210,30},{210,120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS2.flange, ECO.inletHot) annotation (Line(
                  points={{190,130},{200,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(ECO.outletHot, PDMSECO.inlet) annotation (Line(
                  points={{220,130},{230,130}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamECO.inlet, ECO.outletCold) annotation (Line(
                  points={{210,150},{210,140}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS4.flange,PDMSEVA1. outlet) annotation (Line(
                  points={{-120,-110},{-100,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam4.flange,EVA1. inletCold) annotation (Line(
                  points={{-80,-210},{-60,-210},{-60,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA1.outletHot,PDMSEVA1. inlet) annotation (Line(
                  points={{-70,-110},{-80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA1.inlet,EVA1. outletCold) annotation (Line(
                  points={{-10,-60},{-60,-60},{-60,-100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.outlet,sinkSteam5. flange) annotation (Line(
                  points={{70,-160},{70,-210},{90,-210}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS5.flange,EVA2. inletHot) annotation (Line(
                  points={{100,-110},{80,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(EVA2.outletHot,PDMSEVA2. inlet) annotation (Line(
                  points={{60,-110},{10,-110}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamEVA2.inlet,EVA2. outletCold) annotation (Line(
                  points={{70,-140},{70,-120}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(w_MS_SH.y[1], sourceMS.in_w0) annotation (Line(
                  points={{-249,160},{-244,160},{-244,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_SH.y[1], sourceSteam.in_w0) annotation (Line(
                  points={{-249,60},{-244,60},{-244,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_SH.y[1], sourceSteam.in_h) annotation (Line(
                  points={{-249,90},{-236,90},{-236,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_SH.y[1], sinkSteam.in_p0) annotation (Line(
                  points={{-209,220},{-184,220},{-184,198.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_RH.y[1], sourceSteam1.in_w0) annotation (Line(
                  points={{-39,60},{-34,60},{-34,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_RH.y[1], sourceSteam1.in_h) annotation (Line(
                  points={{-39,90},{-26,90},{-26,36}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_RH.y[1], sourceMS1.in_w0) annotation (Line(
                  points={{-39,160},{-34,160},{-34,136}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_RH.y[1], sinkSteam1.in_p0) annotation (Line(
                  points={{1,220},{26,220},{26,196.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_MS_ECO.y[1], sourceMS2.in_h)
                annotation (Line(points={{171,190},{184,190},{184,136}}, color={0,0,127}));
              connect(p_ST_ECO.y[1], sinkSteam2.in_p0) annotation (Line(points={{211,220},{222,
                      220},{236,220},{236,196.8}}, color={0,0,127}));
              connect(w_MS_ECO.y[1], sourceMS2.in_w0) annotation (Line(points={{171,160},{174,
                      160},{176,160},{176,136}}, color={0,0,127}));
              connect(h_ST_ECO.y[1], sourceSteam2.in_h) annotation (Line(points={{171,90},{176,
                      90},{186,90},{186,36}}, color={0,0,127}));
              connect(w_ST_ECO.y[1], sourceSteam2.in_w0)
                annotation (Line(points={{171,60},{178,60},{178,36}}, color={0,0,127}));
              connect(h_ST_EVA.y[1], sourceSteam4.in_h) annotation (Line(points={{-99,-150},
                      {-92,-150},{-86,-150},{-86,-204}}, color={0,0,127}));
              connect(w_ST_EVA.y[1], sourceSteam4.in_w0) annotation (Line(points={{-99,-180},
                      {-94,-180},{-94,-204}}, color={0,0,127}));
              connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(points={{10,-60},
                      {42,-60},{70,-60},{70,-100}},    color={0,0,255}));
              connect(EVA1.inletHot, PDMSEVA2.outlet)
                annotation (Line(points={{-50,-110},{-10,-110}},         color={0,0,255}));
              connect(h_MS_EVA.y[1], sourceMS5.in_h) annotation (Line(points={{119,-50},{106,
                      -50},{106,-104}}, color={0,0,127}));
              connect(w_MS_EVA.y[1], sourceMS5.in_w0) annotation (Line(points={{119,-80},{116,
                      -80},{114,-80},{114,-104}},   color={0,0,127}));
              connect(p_ST_EVA.y[1], sinkSteam5.in_p0) annotation (Line(points={{119,-180},{
                      106,-180},{96,-180},{96,-201.2}},   color={0,0,127}));
              connect(LOAD_SH.y, p_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,220},{-232,220}}, color={0,0,127}));
              connect(LOAD_SH.y, w_MS_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,160},{-272,160}}, color={0,0,127}));
              connect(LOAD_SH.y, h_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,90},{-272,90}}, color={0,0,127}));
              connect(LOAD_SH.y, w_ST_SH.u[1]) annotation (Line(points={{-299,130},{-290,130},
                      {-290,60},{-272,60}}, color={0,0,127}));
              connect(LOAD_RH.y, p_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,220},{-22,220}}, color={0,0,127}));
              connect(LOAD_RH.y, w_MS_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,160},{-62,160}}, color={0,0,127}));
              connect(LOAD_RH.y, h_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,90},{-62,90}}, color={0,0,127}));
              connect(LOAD_RH.y, w_ST_RH.u[1]) annotation (Line(points={{-89,130},{-80,130},
                      {-80,60},{-62,60}}, color={0,0,127}));
              connect(LOAD_ECO.y, p_ST_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,220},{188,220}}, color={0,0,127}));
              connect(LOAD_ECO.y, h_MS_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,190},{148,190}}, color={0,0,127}));
              connect(LOAD_ECO.y, w_MS_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,160},{148,160}}, color={0,0,127}));
              connect(LOAD_ECO.y, h_ST_ECO.u[1]) annotation (Line(points={{121,130},{126,130},
                      {130,130},{130,90},{148,90}}, color={0,0,127}));
              connect(LOAD_ECO.y, w_ST_ECO.u[1]) annotation (Line(points={{121,130},{130,130},
                      {130,60},{148,60}}, color={0,0,127}));
              connect(LOAD_EVA1.y, h_ST_EVA.u[1]) annotation (Line(points={{-159,-160},{-140,
                      -160},{-140,-150},{-122,-150}}, color={0,0,127}));
              connect(LOAD_EVA1.y, w_ST_EVA.u[1]) annotation (Line(points={{-159,-160},{-150,
                      -160},{-140,-160},{-140,-180},{-122,-180}}, color={0,0,127}));
              connect(LOAD_EVA2.y, h_MS_EVA.u[1]) annotation (Line(points={{179,-110},{170,-110},
                      {160,-110},{160,-50},{142,-50}}, color={0,0,127}));
              connect(LOAD_EVA2.y, w_MS_EVA.u[1]) annotation (Line(points={{179,-110},{160,-110},
                      {160,-80},{142,-80}}, color={0,0,127}));
              connect(LOAD_EVA2.y, p_ST_EVA.u[1]) annotation (Line(points={{179,-110},{160,-110},
                      {160,-180},{142,-180}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-340,
                        -260},{340,260}}),        graphics={Text(
                      extent={{-210,110},{-170,90}},
                      lineColor={0,0,255},
                      textString="SH"), Text(
                      extent={{0,110},{40,90}},
                      lineColor={0,0,255},
                      textString="RH"), Text(
                      extent={{210,110},{250,90}},
                      lineColor={0,0,255},
                      textString="ECO"),Text(
                      extent={{-18,-130},{22,-150}},
                      lineColor={0,0,255},
                      textString="EVA"),
                    Text(
                      extent={{-300,-20},{-208,-104}},
                      lineColor={28,108,200},
                      textString="NOTA BENE:
Con 20 nodi
non va ancora")}),                        Icon(coordinateSystem(extent={{-340,-260},{
                        340,260}})),
                experiment(StopTime=8e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign;

            model test_heatExchangers_offDesign_HPH
              "Test model of the MS_HPH, from nominal load to 20% load, steady-state initialisation"

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,120},{-100,140}})));

              ThermoPower.Water.SourceMassFlow sourceMS3(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=true,
                w0=619.8,
                h=110237) annotation (Placement(transformation(extent={{-30,-20},
                        {-10,0}})));

              ThermoPower.Water.SourceMassFlow sourceSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=24.51,
                h=1062835)
                annotation (Placement(transformation(extent={{-30,-120},{-10,-100}})));
              ThermoPower.Water.SinkPressure sinkSteam3(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17382090)
                annotation (Placement(transformation(extent={{30,40},{50,60}})));
              ThermoPower.Water.SinkPressure sinkMS3(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=220963) annotation (Placement(transformation(extent={{60,-20},
                        {80,0}})));

              ThermoPower.Water.PressDrop PDMSHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(0.29037)*10^5,
                rhonom=1905.6,
                wnom=11.95)    annotation (Placement(transformation(extent={{30,
                        -20},{50,0}})));

              ThermoPower.Water.PressDrop PDSteamHPH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.17906)*10^5,
                rhonom=747.382,
                wnom=0.4717)         annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={10,20})));
              Components.HE HPH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.536143, gamma_nom=3958.9),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.447465, gamma_nom=2197.5),
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Vhot=0.05554,
                Vcold=0.02017,
                Shot=7.188,
                Scold=6.02,
                Mm=68.23,
                nominalColdFlow=0.4717,
                nominalHotFlow=11.96,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.ShellAndTube (
                    Nw=10,
                    Ntp=2,
                    inletTubeAtTop=false,
                    inletShellAtTop=false),
                Nhex=21,
                nominalColdPressure=17400000,
                nominalHotPressure=400000,
                nominalColdInletTemperature=518.15,
                nominalColdOutletTemperature=564.15,
                nominalHotInletTemperature=569.15,
                nominalHotOutletTemperature=563.15) annotation (Placement(
                    transformation(extent={{0,-20},{20,0}})));

              Modelica.Blocks.Tables.CombiTable1D p_ST_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                    70,126.1e5; 80,141.3e5; 90,157.8e5; 100,173.5e5])
                annotation (Placement(transformation(extent={{-10,90},{10,110}})));
              Modelica.Blocks.Tables.CombiTable1D h_MS_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                    70,91538; 80,97902; 90,103659; 100,110023])
                annotation (Placement(transformation(extent={{-50,50},{-30,70}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_HPH(
                  smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                    20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365;
                    80,9.56; 90,10.76; 100,11.95])
                annotation (Placement(transformation(extent={{-50,20},{-30,40}})));

              //Real load = sourceMS2.w/sourceMS2.w0;
              Modelica.Blocks.Sources.Ramp LOAD_HPH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-90,0})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_HPH(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1231872; 30,1252286; 40,1261764; 50,1256708; 60,1117992; 70,1062175;
                    80,1062373; 90,1062591; 100,1062835])
                annotation (Placement(transformation(extent={{-50,-50},{-30,-30}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_HPH(
                                                          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    70,0; 80,0; 90,0.1245; 100,0.4717])
                annotation (Placement(transformation(extent={{-50,-80},{-30,-60}})));
              Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                t_ramp=4e6,
                load_end=100) annotation (Placement(transformation(extent={{-120,
                        -138},{-80,-98}})));
            equation
              connect(sinkMS3.flange, PDMSHPH.outlet) annotation (Line(
                  points={{60,-10},{50,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.outlet, sinkSteam3.flange) annotation (Line(
                  points={{10,30},{10,50},{30,50}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam3.flange, HPH.inletCold) annotation (Line(
                  points={{-10,-110},{10,-110},{10,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS3.flange, HPH.inletHot) annotation (Line(
                  points={{-10,-10},{0,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(HPH.outletHot, PDMSHPH.inlet) annotation (Line(
                  points={{20,-10},{30,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamHPH.inlet, HPH.outletCold) annotation (Line(
                  points={{10,10},{10,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(p_ST_HPH.y[1], sinkSteam3.in_p0) annotation (Line(points={{11,100},
                      {11,100},{36,100},{36,58.8}},       color={0,0,127}));
              connect(h_MS_HPH.y[1], sourceMS3.in_h) annotation (Line(points={{-29,60},{-16,
                      60},{-16,-4}},     color={0,0,127}));
              connect(w_MS_HPH.y[1], sourceMS3.in_w0) annotation (Line(points={{-29,30},{-24,
                      30},{-24,-4}},     color={0,0,127}));
              connect(LOAD_HPH.y, h_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,-40},{-52,-40}}, color={0,0,127}));
              connect(LOAD_HPH.y, w_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,-70},{-52,-70}}, color={0,0,127}));
              connect(h_ST_HPH.y[1], sourceSteam3.in_h) annotation (Line(points=
                     {{-29,-40},{-16,-40},{-16,-104}}, color={0,0,127}));
              connect(w_ST_HPH.y[1], sourceSteam3.in_w0) annotation (Line(
                    points={{-29,-70},{-24,-70},{-24,-104}}, color={0,0,127}));
              connect(LOAD_HPH.y, p_ST_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-74,0},{-70,0},{-70,100},{-12,100}}, color={0,0,127}));
              connect(LOAD_HPH.y, h_MS_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,60},{-52,60}}, color={0,0,127}));
              connect(LOAD_HPH.y, w_MS_HPH.u[1]) annotation (Line(points={{-79,
                      0},{-70,0},{-70,30},{-52,30}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -140},{120,140}}),        graphics={
                                        Text(
                      extent={{10,-30},{50,-50}},
                      lineColor={0,0,255},
                      textString="HPH")}),Icon(coordinateSystem(extent={{-120,-140},{120,140}})),
                experiment(StopTime=4e+006, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_heatExchangers_offDesign_HPH;

            model test_smallRH
              "Test model to set the RH to the system without bypass"

              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                use_in_h=false,
                w0=238.6,
                p0=1050000,
                h=519092)
                annotation (Placement(transformation(extent={{-10,0},{10,20}})));
              ThermoPower.Water.SourceMassFlow sourceSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=84.94,
                h=3081212)
                annotation (Placement(transformation(extent={{-10,-100},{10,-80}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=4733745)
                annotation (Placement(transformation(extent={{50,58},{70,78}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=915515)
                annotation (Placement(transformation(extent={{80,0},{100,20}})));
              ThermoPower.Water.PressDrop PDMSRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_lin,
                dpnom=(1.34485)*10^5,
                rhonom=1796.9,
                wnom=4.601)
                annotation (Placement(transformation(extent={{50,0},{70,20}})));
              ThermoPower.Water.PressDrop PDSteamRH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(0.47256)*10^5,
                rhonom=12.775,
                wnom=2.029)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={30,40})));
              Components.HE RH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                redeclare model HeatTransferCold =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.798347, gamma_nom=963.6),
                redeclare model HeatTransferHot =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.320782, gamma_nom=2690.3),
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                Nhex=5,
                nominalColdFlow=2.029,
                nominalHotFlow=4.601,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54,
                nominalColdPressure=4781000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=633.25,
                nominalColdOutletTemperature=824.15,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=734.05)
                annotation (Placement(transformation(extent={{20,0},{40,20}})));

              Modelica.Blocks.Tables.CombiTable1D p_ST_RH(        smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,8.839e5; 30,13.32e5; 40,17.87e5; 50,21.61e5; 60,27.45e5; 70,32.69e5;
                    80,37.23e5; 90,42.09e5; 100,47.32e5])
                annotation (Placement(transformation(extent={{10,90},{30,110}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_RH(            smoothness=
                    Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[20,3242e3;
                    30,3230e3; 40,3218e3; 50,3204e3; 60,3186e3; 70,3159e3; 80,3137e3; 90,3113e3;
                    100,3103e3])
                annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_RH(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.3738; 30,0.5824; 40,0.8001; 50,1.026; 60,1.262; 70,1.456; 80,1.649;
                    90,1.845; 100,2.029])
                annotation (Placement(transformation(extent={{-30,-70},{-10,-50}})));
              Modelica.Blocks.Tables.CombiTable1D w_MS_RH(
                                   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.9209; 30,1.381; 40,1.842; 50,2.302; 60,2.75; 70,3.221; 80,3.681; 90,
                    4.143; 100,4.601])
                annotation (Placement(transformation(extent={{-30,30},{-10,50}})));
              Modelica.Blocks.Sources.Ramp LOAD_RH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-70,10})));
              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              Auxiliaries.Components.loadCalculator loadCalc(
                load_start=100,
                t_start=0,
                load_end=100,
                t_ramp=0) annotation (Placement(transformation(extent={{-110,-110},
                        {-70,-70}})));

            equation
              connect(sinkMS.flange,PDMSRH. outlet) annotation (Line(
                  points={{80,10},{70,10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.outlet,sinkSteam. flange) annotation (Line(
                  points={{30,50},{30,68},{50,68}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange,RH. inletCold) annotation (Line(
                  points={{10,-90},{30,-90},{30,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange,RH. inletHot) annotation (Line(
                  points={{10,10},{20,10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(RH.outletHot,PDMSRH. inlet) annotation (Line(
                  points={{40,10},{50,10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamRH.inlet,RH. outletCold) annotation (Line(
                  points={{30,30},{30,20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(w_ST_RH.y[1],sourceSteam. in_w0) annotation (Line(
                  points={{-9,-60},{-4,-60},{-4,-84}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_RH.y[1],sourceSteam. in_h) annotation (Line(
                  points={{-9,-30},{4,-30},{4,-84}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_MS_RH.y[1],sourceMS. in_w0) annotation (Line(
                  points={{-9,40},{-4,40},{-4,16}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_RH.y[1],sinkSteam. in_p0) annotation (Line(
                  points={{31,100},{56,100},{56,76.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(LOAD_RH.y,p_ST_RH. u[1]) annotation (Line(points={{-59,10},{-50,10},{-50,
                      100},{8,100}},        color={0,0,127}));
              connect(LOAD_RH.y,w_MS_RH. u[1]) annotation (Line(points={{-59,10},{-50,10},{-50,
                      40},{-32,40}},        color={0,0,127}));
              connect(LOAD_RH.y,h_ST_RH. u[1]) annotation (Line(points={{-59,10},{-50,10},{-50,
                      -30},{-32,-30}},    color={0,0,127}));
              connect(LOAD_RH.y,w_ST_RH. u[1]) annotation (Line(points={{-59,10},{-50,10},{-50,
                      -60},{-32,-60}},    color={0,0,127}));
              annotation (
                Icon(coordinateSystem(preserveAspectRatio=false, extent={{-120,-120},{120,120}})),
                Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,-120},{120,
                        120}}), graphics={
                                        Text(
                      extent={{30,-10},{70,-30}},
                      lineColor={0,0,255},
                      textString="RH")}),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput);
            end test_smallRH;

            model test_HE_shell
              "Test model of the HE_shell component, with data of theMS_HPH, from nominal load to 20% load, steady-state initialisation"

              inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
                annotation (Placement(transformation(extent={{-120,120},{-100,140}})));

              //Real load = sourceMS2.w/sourceMS2.w0;
              Auxiliaries.Components.loadCalculator loadCalc(
                t_start=100,
                load_end=100,
                t_ramp=10,
                load_start=95)
                              annotation (Placement(transformation(extent={{-120,
                        -138},{-80,-98}})));
              ThermoPower.Water.SourceMassFlow sourceMS(
                allowFlowReversal=false,
                G=0,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                use_in_w0=true,
                w0=381.3,
                p0=1000000,
                h=519092)
                annotation (Placement(transformation(extent={{-30,-10},{-10,10}})));
              ThermoPower.Water.SourceMassFlow sourceSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                use_in_h=true,
                w0=91.28,
                h=2755127)
                annotation (Placement(transformation(extent={{-30,-110},{-10,
                        -90}})));
              ThermoPower.Water.SinkPressure sinkSteam(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=true,
                p0=17132400)
                annotation (Placement(transformation(extent={{30,50},{50,70}})));
              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=855401)
                annotation (Placement(transformation(extent={{60,-10},{80,10}})));
              ThermoPower.Water.PressDrop PDMSSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                dpnom=(10.5 - 8.55401)*10^5,
                rhonom=1797.2,
                wnom=7.349)
                annotation (Placement(transformation(extent={{30,-10},{50,10}})));
              ThermoPower.Water.PressDrop PDSteamSH(
                FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                dpnom=(172 - 171.0324)*10^5,
                rhonom=50.398,
                wnom=1.757)                    annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=90,
                    origin={10,30})));
              Components.HE_shell_ts SH(
                cm=500,
                nominalColdDeltaP=0,
                nominalHotDeltaP=0,
                redeclare package coldMedium =
                    Modelica.Media.Water.WaterIF97_ph,
                redeclare model HeatExchangerTopology =
                    ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
                redeclare package hotMedium =
                    PreFlexMS.Media.MoltenSalt60_40_quad,
                generateInitCode=true,
                hotFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                coldFluid(FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction),
                nominalColdFlow=1.757,
                nominalHotFlow=7.35,
                Nhex=5,
                Vhot_bundle=0.234,
                Vcold_bundle=0.053,
                Vcold_man=0.001119,
                Shot_bundle=22.8,
                Scold_bundle=17.385,
                L_tubesheet=0.141,
                L_man=0.15,
                L_shell=16.8,
                omega_shell=0.5287,
                D_ext_shell=0.1683,
                D_int_shell=0.15408,
                D_ext_ts=0.3935,
                s_ins=0.14,
                Mm_bundle=303.39,
                Mm_shell=480.7,
                Mm_ts=136.27,
                Mm_man=144.97,
                km=21.5,
                rhom=7950,
                Mi=273.4,
                ci=1030,
                ki=0.07,
                Vcold_tubesheet=0.0004448,
                redeclare model HeatTransferHot_bundle =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=2848.1, alpha=0.28867),
                redeclare model HeatTransferHot_shell =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=100, alpha=0.6),
                redeclare model HeatTransferCold_man =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (alpha=0.5, gamma_nom=500),
                redeclare model HeatTransferCold_bundle =
                    ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                    (gamma_nom=1996.5, alpha=0.847436),
                Nr=20,
                nominalColdPressure=17200000,
                nominalHotPressure=1050000,
                nominalColdInletTemperature=646.55,
                nominalColdOutletTemperature=823.96,
                nominalHotInletTemperature=838.65,
                nominalHotOutletTemperature=733.58,
                T_amb=298.15) annotation (Placement(transformation(extent={{0,-10},
                        {20,10}})));

              Modelica.Blocks.Tables.CombiTable1D w_MS_SH(
                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,1.471; 30,2.207; 40,2.942; 50,3.678; 60,4.41; 70,5.144; 80,5.879; 90,
                    6.617; 100,7.349])
                annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
              Modelica.Blocks.Tables.CombiTable1D h_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,2752e3; 30,2751.7e3; 40,2751.2e3; 50,2745.5e3; 60,2834.3e3; 70,2817.3e3;
                    80,2799.2e3; 90,2780.1e3; 100,2756.1e3])
                annotation (Placement(transformation(extent={{-50,-40},{-30,-20}})));
              Modelica.Blocks.Tables.CombiTable1D w_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,1.436;
                    90,1.605; 100,1.757])
                annotation (Placement(transformation(extent={{-50,-80},{-30,-60}})));
              Modelica.Blocks.Tables.CombiTable1D p_ST_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                    20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.6e5; 70,124.1e5;
                    80,139.7e5; 90,155.1e5; 100,171e5])      annotation (Placement(
                    transformation(extent={{-10,80},{10,100}})));
              Modelica.Blocks.Sources.Ramp LOAD_SH(
                height=loadCalc.load_end - loadCalc.load_start,
                duration=loadCalc.t_ramp,
                offset=loadCalc.load_start,
                startTime=loadCalc.t_start) annotation (Placement(transformation(
                    extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={-90,0})));
            equation
              connect(sinkMS.flange,PDMSSH. outlet) annotation (Line(
                  points={{60,0},{50,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.outlet,sinkSteam. flange) annotation (Line(
                  points={{10,40},{10,60},{30,60}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceSteam.flange,SH. inletCold) annotation (Line(
                  points={{-10,-100},{10,-100},{10,-10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange,SH. inletHot) annotation (Line(
                  points={{-10,0},{0,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(SH.outletHot,PDMSSH. inlet) annotation (Line(
                  points={{20,0},{30,0}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(PDSteamSH.inlet,SH. outletCold) annotation (Line(
                  points={{10,20},{10,10}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(w_MS_SH.y[1],sourceMS. in_w0) annotation (Line(
                  points={{-29,30},{-24,30},{-24,6}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(w_ST_SH.y[1],sourceSteam. in_w0) annotation (Line(
                  points={{-29,-70},{-24,-70},{-24,-94}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(h_ST_SH.y[1],sourceSteam. in_h) annotation (Line(
                  points={{-29,-30},{-16,-30},{-16,-94}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(p_ST_SH.y[1],sinkSteam. in_p0) annotation (Line(
                  points={{11,90},{36,90},{36,68.8}},
                  color={0,0,127},
                  smooth=Smooth.None));
              connect(LOAD_SH.y,p_ST_SH. u[1]) annotation (Line(points={{-79,0},
                      {-70,0},{-70,90},{-12,90}},
                                              color={0,0,127}));
              connect(LOAD_SH.y,w_MS_SH. u[1]) annotation (Line(points={{-79,0},
                      {-70,0},{-70,30},{-52,30}},
                                              color={0,0,127}));
              connect(LOAD_SH.y,h_ST_SH. u[1]) annotation (Line(points={{-79,0},
                      {-70,0},{-70,-30},{-52,-30}},
                                            color={0,0,127}));
              connect(LOAD_SH.y,w_ST_SH. u[1]) annotation (Line(points={{-79,0},
                      {-70,0},{-70,-70},{-52,-70}},
                                            color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -140},{120,140}}), graphics={       Text(
                      extent={{10,-20},{50,-40}},
                      lineColor={0,0,255},
                      textString="SH")}), Icon(coordinateSystem(extent={{-120,-140},{120,140}})),
                experiment(StopTime=50000, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput);
            end test_HE_shell;
          end HE;

          package OTSG "Package of whole OTSG test models"

            model test_OTSG_100 "Test model of the OTSG at 100% load"

              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=2.228,
                use_in_w0=true,
                h=1002.3e3)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceDES(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                h=1002.3e3,
                w0=0.272) annotation (Placement(transformation(extent={{100,30},
                        {80,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4732000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1050000,
                h=519092)   annotation (Placement(transformation(extent={{-60,
                        90},{-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=100000)  annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              Control.Old.plant_controller_HPpart_highLoad controllers(
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                load_start=100,
                load_end=100,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                t_start_ramp=0,
                Kp_valveBP=1,
                Ti_valveBP=1,
                Td_valveBP=0,
                Nd_valveBP=20,
                CSmin_valveBP=0.1,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                useTS_valveTURB=false,
                DT_SH_sp(displayUnit="K") = 293.15,
                CSmax_pumpFW=0.3,
                Td_pumpFW=0,
                Ta_pumpFW=2,
                CSstart_pumpFW=0,
                TS_pumpFW=0.26,
                useTS_pumpFW=false,
                Kp_pumpFW=-0.0006,
                Ti_pumpFW=100,
                T_FW_sp=518.15,
                T_MS_sp=558.15) annotation (Placement(transformation(extent={{-92,
                        -2},{-68,22}})));
              Modelica.Icons.SignalBus signalBus
                annotation (Placement(transformation(extent={{-70,-30},{-50,-10}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              OTSG_init100_5nodes_lin
                                   OTSG annotation (Placement(transformation(
                      extent={{-40,-40},{20,60}})));
              ThermoPower.Water.ValveVap valveVap(
                Fxt_full=0.4542722663,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=1.757,
                thetanom=1,
                Av=1.323592727e-4,
                pnom=17100000,
                dpnom=12000000)
                annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={50,70})));
              Modelica.Blocks.Sources.Constant theta_DES(k=1) annotation (
                  Placement(transformation(extent={{100,80},{80,100}})));
            equation
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-40,100},
                      {-40,100},{-26.6667,100},{-26.6667,61.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{20,100},
                      {-6.66667,100},{-6.66667,61.6667}},
                                           color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-20},{60,-20}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{21.6667,
                      -28.3333},{40,-28.3333},{40,-3.33333},{21.6667,-3.33333}},
                                                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -26.6667,-41.6667},{-26.6667,-60},{-30,-60}},
                                            color={0,0,255}));
              connect(OTSG.RH_in, sourceDES.flange) annotation (Line(points={{21.6667,
                      46.6667},{70,46.6667},{70,40},{80,40}},         color={0,
                      0,255}));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-100},{74,-100},{74,-26}},
                  color={255,204,51},
                  thickness=0.5));
              connect(valveVap.outlet, OTSG.RH_in) annotation (Line(points={{60,70},
                      {60,70},{70,70},{70,46.6667},{21.6667,46.6667}},
                    color={0,0,255}));
              connect(OTSG.SH_out, valveVap.inlet) annotation (Line(points={{6.66667,
                      61.6667},{6.66667,70},{40,70}},         color={0,0,255}));
              connect(theta_DES.y, valveVap.theta) annotation (Line(points={{79,
                      90},{50,90},{50,78}}, color={0,0,127}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}}), graphics={Text(
                      extent={{42,38},{106,-12}},
                      lineColor={0,0,255},
                      lineThickness=0.5,
                      textString="Il modello del pilota � tarato correttamente, ma 
non si riescono a riprodurre le condizioni volute 
all'RH, poich� l'elevata temperatura all'ingresso 
e l'enorme superficie tende ad alzare molto la T_RH. 
In sostanza per avere 460�C all'uscita lato sale devo
alzare la T_in lato vapore a 380�C, ovvero con una 
portata di desuperheating pari a 0.21 kg/s
NTU_RH = 4.8!!!")}),                                         Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}})),
                experiment(StopTime=20000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_100;

            model test_OTSG_50 "Test model of the OTSG at 50% load"

              OTSG_init50_5nodes_lin_ECO_complete OTSG annotation (Placement(
                    transformation(extent={{-40,-40},{20,60}})));
              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=true,
                w0=46.95,
                h=1082.37e3)
                annotation (Placement(transformation(extent={{80,-10},{60,-30}})));
              ThermoPower.Water.SourceMassFlow sourceDES(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                h=943.2e3,
                w0=0.1091) annotation (Placement(transformation(extent={{100,30},
                        {80,50}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=2260000)
                annotation (Placement(transformation(extent={{20,90},{40,110}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                h=519092) annotation (Placement(transformation(extent={{-60,90},
                        {-40,110}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=261078) annotation (Placement(transformation(extent={{-30,-70},
                        {-50,-50}})));

              inner ThermoPower.System system(
                  allowFlowReversal=false, initOpt=ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-120,100},{-100,120}})));
              Control.Schemes_old.plant_controller_HPpart_lowLoad controllers(
                Td_pumpSEP=0,
                Nd_pumpSEP=1,
                actuatorGain_pumpSEP=1,
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                TS_pumpFW=0,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                load_start=50,
                load_end=50,
                CSstart_pumpSEP=0,
                TS_pumpSEP=0,
                useTS_valveTURB=true,
                Kp_valveBP=10,
                Ti_valveBP=10,
                Td_valveBP=0,
                Nd_valveBP=20,
                CSmin_valveBP=0,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                t_start_ramp=0,
                useTS_pumpFW=false,
                Ta_pumpFW=2,
                Ta_pumpMS=2,
                Ta_valveTURB=0.3,
                Ta_pumpHPH=2,
                Td_pumpFW=0,
                Ti_pumpFW=50,
                P_mec_sp=79725800,
                l_sp=3.1,
                CSstart_pumpFW=2.435,
                CSmin_pumpFW=0.1,
                CSmax_pumpFW=13,
                Kp_pumpFW=20,
                useTS_pumpSEP=false,
                Ta_pumpSEP=2,
                CSmax_pumpSEP=0.3,
                Ti_pumpSEP=50,
                CSmin_pumpSEP=-0.99,
                p_sp=17610000,
                T_FW_sp=553.15,
                T_MS_sp=558.15,
                Kp_pumpSEP=0.01) annotation (Placement(transformation(extent={{
                        -92,-2},{-68,22}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-104,32},{-90,48}})));
              Modelica.Icons.SignalBus signalBus annotation (Placement(
                    transformation(extent={{-70,-30},{-50,-10}})));
              ThermoPower.Water.ValveVap valveVap(
                Fxt_full=0.4542722663,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=1.757,
                thetanom=1,
                Av=1.323592727e-4,
                pnom=17100000,
                dpnom=12000000)
                annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={50,70})));
              Modelica.Blocks.Sources.Constant theta_DES(k=1) annotation (
                  Placement(transformation(extent={{100,80},{80,100}})));
            equation
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(
                  points={{21.6667,-28.3333},{40,-28.3333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_in, sourceDES.flange) annotation (Line(
                  points={{21.6667,46.6667},{70,46.6667},{70,40},{80,40}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                  points={{-40,100},{-26.6667,100},{-26.6667,61.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(sinkMS.flange, OTSG.MS_out) annotation (Line(
                  points={{-30,-60},{-26,-60},{-26,-41.6667},{-26.6667,-41.6667}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.RH_out, sinkRH.flange) annotation (Line(
                  points={{-6.66667,61.6667},{-6.66667,100},{20,100}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(OTSG.SEP_out, sourceFW.flange) annotation (Line(
                  points={{21.6667,-3.33333},{40,-3.33333},{40,-20},{60,-20}},
                  color={0,0,255},
                  smooth=Smooth.None));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-67.4,10},{-67.4,10},{-42.3333,10}},
                  color={255,204,51},
                  thickness=0.5));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-89.3,40},{-80,40},{-80,22.8}}, color={0,0,127}));
              connect(controllers.signalBus, signalBus) annotation (Line(
                  points={{-67.4,10},{-64,10},{-60,10},{-60,-20}},
                  color={255,204,51},
                  thickness=0.5));
              connect(signalBus.pumpFW_CS, sourceFW.in_w0) annotation (Line(
                  points={{-60,-20},{-60,-20},{-60,-80},{6,-80},{74,-80},{74,
                      -26}},
                  color={255,204,51},
                  thickness=0.5));
              connect(valveVap.outlet, OTSG.RH_in) annotation (Line(points={{60,70},
                      {70,70},{70,46.6667},{21.6667,46.6667}},     color={0,0,
                      255}));
              connect(theta_DES.y, valveVap.theta) annotation (Line(points={{79,
                      90},{50,90},{50,78}}, color={0,0,127}));
              connect(OTSG.SH_out, valveVap.inlet) annotation (Line(points={{6.66667,
                      61.6667},{6.66667,70},{40,70}},         color={0,0,255}));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                        -120},{120,120}}), graphics={Text(
                      extent={{48,34},{112,-16}},
                      lineColor={0,0,255},
                      lineThickness=0.5,
                      textString="Il modello del pilota � tarato correttamente, ma 
non si riescono a riprodurre le condizioni volute 
all'RH, poich� l'elevata temperatura all'ingresso 
e l'enorme superficie tende ad alzare molto la T_RH. 
In sostanza per avere 470�C all'uscita lato sale devo
alzare la T_in lato vapore a 406�C, ovvero con una 
portata di desuperheating pari a 0.109 kg/s
NTU_RH = 4.8!!!")}),                                         Icon(coordinateSystem(
                      extent={{-120,-120},{120,120}}, preserveAspectRatio=false)),
                experiment(StopTime=5000),
                __Dymola_experimentSetupOutput,
                Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model has to be initialized  in steady-state, through the system component, so that the pressure terms do no influence the mass flow balances. The OTSG can be selected between the 5 nodes and 20 nodes model. </span></p>
</html>"));
            end test_OTSG_50;

            model test_OTSG_FWsensitivity "Test model of the OTSG at 100% load"

              ThermoPower.Water.SourceMassFlow sourceFW(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                w0=2.228,
                use_in_w0=true,
                h=1002.3e3)
                annotation (Placement(transformation(extent={{122,26},{102,6}})));
              ThermoPower.Water.SourceMassFlow sourceDES(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_w0=false,
                h=1002.3e3,
                w0=0.272) annotation (Placement(transformation(extent={{60,50},
                        {40,70}})));
              ThermoPower.Water.SinkPressure sinkRH(
                allowFlowReversal=false,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                use_in_p0=false,
                p0=4732000)
                annotation (Placement(transformation(extent={{-34,110},{-14,130}})));
              ThermoPower.Water.SourcePressure sourceMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=1050000,
                h=519092)   annotation (Placement(transformation(extent={{-100,
                        110},{-80,130}})));

              ThermoPower.Water.SinkPressure sinkMS(
                allowFlowReversal=false,
                redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
                p0=100000)  annotation (Placement(transformation(extent={{-70,-50},
                        {-90,-30}})));

              inner ThermoPower.System system(allowFlowReversal=false, initOpt=
                    ThermoPower.Choices.Init.Options.fixedState)
                annotation (Placement(transformation(extent={{-160,140},{-140,
                        160}})));
              Control.Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_base
                controllers(
                Td_pumpHPH=0,
                Nd_pumpHPH=1,
                actuatorGain_pumpHPH=1,
                Ta_pumpHPH=5,
                actuatorGain_pumpFW=1,
                actuatorGain_pumpMS=1,
                Ta_pumpMS=5,
                Td_valveTURB=0,
                Nd_valveTURB=1,
                actuatorGain_valveTURB=1,
                CSmin_pumpFW=-0.3,
                CSmin_pumpHPH=-0.5,
                CSmax_pumpHPH=0.5,
                CSstart_pumpHPH=0,
                TS_pumpHPH=0,
                CSmin_pumpMS=-0.9,
                CSmax_pumpMS=1,
                CSstart_pumpMS=0,
                TS_pumpMS=0,
                CSmin_valveTURB=-0.9,
                CSmax_valveTURB=0.65,
                CSstart_valveTURB=0,
                TS_valveTURB=0,
                t_ramp=0,
                load_start=100,
                load_end=100,
                Nd_pumpFW=30,
                Kp_pumpHPH=0.6461,
                Ti_pumpHPH=19.05,
                Kp_pumpMS=1.2e-7,
                Ti_pumpMS=114.3,
                Td_pumpMS=28.57,
                Nd_pumpMS=20,
                Ti_valveTURB=95.23,
                Kp_valveTURB=-0.0000014,
                Ta_valveTURB=2,
                useTS_pumpHPH=true,
                useTS_pumpMS=true,
                t_start_ramp=0,
                Kp_valveBP=1,
                Ti_valveBP=1,
                Td_valveBP=0,
                Nd_valveBP=20,
                CSmin_valveBP=0.1,
                CSmax_valveBP=1,
                CSstart_valveBP=0.6,
                actuatorGain_valveBP=1,
                Ta_valveBP=0.3,
                useTS_valveBP=true,
                TS_valveBP=0,
                DT_SH_sp(displayUnit="K") = 293.15,
                CSmax_pumpFW=0.3,
                Td_pumpFW=0,
                Ta_pumpFW=2,
                CSstart_pumpFW=0,
                Kp_pumpFW=-0.0006,
                Ti_pumpFW=100,
                useTS_pumpFW=true,
                TS_pumpFW=-0.0314951,
                useTS_valveTURB=true,
                T_FW_sp=518.15,
                T_MS_sp=558.15) annotation (Placement(transformation(extent={{-132,
                        18},{-108,42}})));
              Modelica.Blocks.Sources.RealExpression Power_sensor(y=0)
                annotation (Placement(transformation(extent={{-144,52},{-130,68}})));
              OTSG_init100_5nodes_lin
                                   OTSG annotation (Placement(transformation(
                      extent={{-80,-20},{-20,80}})));
              ThermoPower.Water.ValveVap valveVap(
                Fxt_full=0.4542722663,
                redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
                wnom=1.757,
                thetanom=1,
                Av=1.323592727e-4,
                pnom=17100000,
                dpnom=12000000)
                annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                    rotation=0,
                    origin={10,90})));
              Modelica.Blocks.Sources.Constant theta_DES(k=0.975)
                                                              annotation (
                  Placement(transformation(extent={{60,100},{40,120}})));
              Modelica.Blocks.Sources.Sine sine(
                amplitude=0.342,
                phase=0,
                offset=0,
                freqHz=9.6)
                annotation (Placement(transformation(extent={{-70,-136},{-50,
                        -116}})));
              Modelica.Blocks.Math.Abs noise
                annotation (Placement(transformation(extent={{-40,-136},{-20,
                        -116}})));
              Modelica.Blocks.Math.Add add
                annotation (Placement(transformation(extent={{80,-60},{100,-40}})));
              Modelica.Blocks.Sources.Step     FW_media(
                startTime=26,
                height=0,
                offset=1.703)
                annotation (Placement(transformation(extent={{0,-50},{20,-30}})));
              Modelica.Blocks.Logical.Switch switch1
                annotation (Placement(transformation(extent={{40,-78},{60,-58}})));
              Modelica.Blocks.Sources.BooleanStep booleanStep(             startValue=
                    true, startTime=50010)
                annotation (Placement(transformation(extent={{0,-100},{20,-80}})));
              Modelica.Blocks.Math.Add add1(k1=-1)
                annotation (Placement(transformation(extent={{0,-130},{20,-110}})));
              Modelica.Blocks.Sources.Constant const3(k=0.228)
                annotation (Placement(transformation(extent={{-40,-100},{-20,
                        -80}})));
              Modelica.Blocks.Sources.Constant const1(k=0)
                annotation (Placement(transformation(extent={{-40,-70},{-20,-50}})));
            equation
              connect(sourceMS.flange, OTSG.MS_in) annotation (Line(points={{-80,120},
                      {-80,120},{-66.6667,120},{-66.6667,81.6667}},
                                                     color={0,0,255}));
              connect(sinkRH.flange, OTSG.RH_out) annotation (Line(points={{-34,120},
                      {-46.6667,120},{-46.6667,81.6667}},
                                           color={0,0,255}));
              connect(OTSG.FW_in, sourceFW.flange) annotation (Line(points={{
                      -18.3333,-8.33333},{0,-8.33333},{0,16},{102,16}},
                                                     color={0,0,255}));
              connect(OTSG.FW_in, OTSG.SEP_out) annotation (Line(points={{
                      -18.3333,-8.33333},{0,-8.33333},{0,16.6667},{-18.3333,
                      16.6667}},                       color={0,0,255}));
              connect(OTSG.MS_out, sinkMS.flange) annotation (Line(points={{
                      -66.6667,-21.6667},{-66.6667,-40},{-70,-40}},
                                            color={0,0,255}));
              connect(OTSG.RH_in, sourceDES.flange) annotation (Line(points={{
                      -18.3333,66.6667},{30,66.6667},{30,60},{40,60}},color={0,
                      0,255}));
              connect(Power_sensor.y, controllers.u_Pmec) annotation (Line(
                    points={{-129.3,60},{-120,60},{-120,42.8}},
                                                             color={0,0,127}));
              connect(valveVap.outlet, OTSG.RH_in) annotation (Line(points={{20,90},
                      {20,90},{30,90},{30,66.6667},{-18.3333,66.6667}},
                    color={0,0,255}));
              connect(OTSG.SH_out, valveVap.inlet) annotation (Line(points={{
                      -33.3333,81.6667},{-33.3333,90},{0,90}},color={0,0,255}));
              connect(theta_DES.y, valveVap.theta) annotation (Line(points={{39,110},
                      {10,110},{10,98}},    color={0,0,127}));
              connect(FW_media.y,add. u1) annotation (Line(points={{21,-40},{50,
                      -40},{50,-44},{78,-44}},
                                            color={0,0,127}));
              connect(switch1.y,add. u2) annotation (Line(points={{61,-68},{66,
                      -68},{66,-56},{78,-56}},
                                           color={0,0,127}));
              connect(booleanStep.y,switch1. u2) annotation (Line(points={{21,-90},
                      {26,-90},{26,-68},{38,-68}},   color={255,0,255}));
              connect(const3.y,add1. u1) annotation (Line(points={{-19,-90},{
                      -10,-90},{-10,-114},{-2,-114}},
                                             color={0,0,127}));
              connect(add1.y,switch1. u3) annotation (Line(points={{21,-120},{
                      32,-120},{32,-76},{38,-76}},
                                  color={0,0,127}));
              connect(const1.y, switch1.u1) annotation (Line(points={{-19,-60},
                      {-19,-60},{38,-60}}, color={0,0,127}));
              connect(add.y, sourceFW.in_w0) annotation (Line(points={{101,-50},
                      {106,-50},{116,-50},{116,10}}, color={0,0,127}));
              connect(noise.y, add1.u2) annotation (Line(points={{-19,-126},{
                      -10.5,-126},{-2,-126}}, color={0,0,127}));
              connect(sine.y, noise.u) annotation (Line(points={{-49,-126},{-42,
                      -126},{-42,-126}}, color={0,0,127}));
              connect(controllers.signalBus, OTSG.signalBus) annotation (Line(
                  points={{-107.4,30},{-82.3333,30}},
                  color={255,204,51},
                  thickness=0.5));
              annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-160,
                        -160},{160,160}})),                  Icon(coordinateSystem(
                      extent={{-160,-160},{160,160}})),
                experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
                __Dymola_experimentSetupOutput,
                Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The model can be initialized both in steady-state and fixed-state way, through the system component. The OTSG can be selected between the 5 nodes and 20 nodes model. Computational time are acceptable in both cases.</span></p>
</html>"));
            end test_OTSG_FWsensitivity;
          end OTSG;

        end Test;

      end OTSG;

      package WSC "Package containing the water/steam cycle models"
        model WSC_100 "Model of the water/steam cycle at nominal load"
          extends BaseClasses.BaseWSC;
          Components.Deaerator
                    deaerator(
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            h_start=1.2e6,
            L=1.6,
            H=0.866025,
            zl_start=0.5,
            redeclare package Medium = Medium,
            p_start=2717000)
            annotation (Placement(transformation(extent={{-18,-8},{74,84}})));
          ThermoPower.Water.SourceMassFlow pumpCOND(
            redeclare package Medium = Medium,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{194,54},{174,74}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow1(
            redeclare package Medium = Medium,
            use_in_w0=false,
            use_in_h=false)
            annotation (Placement(transformation(extent={{-44,24},{-24,4}})));
          ThermoPower.Water.ValveVap valveRH_COND(redeclare package Medium = Medium, Kv=
               5.80538e-6,
            Av=2.2150594e-3,
            wnom=2.03,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=4731000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-120,250},{-100,230}})));
          ThermoPower.Water.SensP sensP_RH(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-210,246},{-190,226}})));
          ThermoPower.Water.SensP sensP_SH(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-190,134},{-170,154}})));
          ThermoPower.Water.ValveVap valveSH_RH(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            wnom=1.757,
            thetanom=0.8,
            Av=1.6681872e-4,
            pnom=17100000,
            dpnom=12220000) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-140,100})));
          ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium = Medium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-10,-138})));
          ThermoPower.Water.ValveVap valveRH_DEA(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            wnom=0.11,
            Av=2.3151914e-3,
            pnom=4731000,
            dpnom=2014000,
            thetanom=0.9)   annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={-20,130})));
          ThermoPower.Water.SensT sensT_COND(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{4,246},{24,226}})));
          ThermoPower.Water.ValveVap valveDEA_RH(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            Av=1.5366437e-5,
            wnom=0.66,
            thetanom=0.8,
            pnom=17400000,
            dpnom=12770000)
                          annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=270,
                origin={-80,170})));
          ThermoPower.Water.ValveVap valveDEA_SH(redeclare package Medium = Medium, Kv=5.80538e-6,
            Av=6.3328346e-6,
            wnom=0.272,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17400000,
            dpnom=12620000)
            annotation (Placement(transformation(extent={{-100,50},{-120,70}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              =                                                                  Medium,
              use_in_p0=true)
            annotation (Placement(transformation(extent={{174,250},{194,230}})));
          Modelica.Blocks.Tables.CombiTable1D p_cond(table=[20,1.776e5 - 1e5;
                30,2.025e5 - 1e5; 40,3.523e5 - 1e5; 50,5.985e5 - 1e5; 60,
                9.847e5 - 1e5; 70,15.2e5 - 1e5; 80,22.87e5 - 1e5; 90,33.53e5 -
                1e5; 100,47.31e5 - 1e5])             annotation (Placement(
                transformation(extent={{140,180},{160,200}})));
          Modelica.Blocks.Tables.CombiTable1D h_condLS(table=[20,229.7e3; 30,
                223.2e3; 40,318.3e3; 50,414e3; 60,509e3; 70,598.1e3; 80,689.2e3;
                90,782.8e3; 100,875.5e3])              annotation (Placement(
                transformation(extent={{140,100},{160,120}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(
                transformation(extent={{20,140},{60,180}}), iconTransformation(
                  extent={{120,-330},{160,-290}})));
          Modelica.Blocks.Sources.RealExpression condensingTemperature(y=
                Modelica.Media.Water.WaterIF97_ph.saturationTemperature(p_cond.y[
                1]))
            annotation (Placement(transformation(extent={{80,220},{60,240}})));
          Modelica.Blocks.Math.Add add(k1=-1) annotation (Placement(
                transformation(
                extent={{-4,-4},{4,4}},
                rotation=270,
                origin={40,220})));
          ThermoPower.Water.Mixer DEA_SH(
            redeclare package Medium = Medium,
            V=0.001,
            S=0.06,
            gamma=0,
            Cm=0,
            FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            hstart=3150e3,
            pstart=4781000) annotation (Placement(transformation(extent={{-138,
                    50},{-158,70}})));
          Auxiliaries.Components.pump_constEfficiency pumpFW(
            use_in_w0=true,
            w0=1.757,
            eta_iso=0.8945) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={26,-50})));
          Auxiliaries.Components.EletHeater eletHeater(
            redeclare package Medium = Medium,
            V=0.14,
            S=50,
            H=0,
            gamma=1500,
            Mm=90,
            cm=500) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-10,-210})));
          ThermoPower.Water.SensP sensP annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-24,80})));
        equation
          connect(deaerator.water_in, pumpCOND.flange) annotation (Line(
              points={{39.8286,64.2857},{87.1714,64.2857},{87.1714,64},{174,64}},
              color={0,0,255},
              thickness=0.5));

          connect(sourceMassFlow1.flange, deaerator.drained_in) annotation (Line(points={{-24,14},
                  {-24,14},{-24,15},{-14.7143,15}},          color={0,0,255}));
          connect(RH_in,sensP_RH. flange) annotation (Line(points={{-250,240},{-200,240}},
                                  color={0,0,255},
              thickness=0.5));
          connect(sensP_RH.flange, valveRH_COND.inlet) annotation (Line(points={{-200,240},
                  {-200,240},{-120,240}}, color={0,0,255},
              thickness=0.5));
          connect(sensP_SH.flange, SH_in) annotation (Line(points={{-180,140},{-204,140},
                  {-204,140},{-250,140},{-250,140}}, color={0,0,255},
              thickness=0.5));
          connect(sensP_SH.flange, valveSH_RH.inlet) annotation (Line(points={{-180,140},
                  {-140,140},{-140,110}}, color={0,0,255},
              thickness=0.5));

          connect(SEP_in, flowJoin.in2) annotation (Line(
              points={{-250,-130},{-14,-130},{-14,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP_RH.flange, valveRH_DEA.inlet) annotation (Line(points={{-200,
                  240},{-180,240},{-160,240},{-160,190},{-20,190},{-20,140}},
                                                                         color={0,0,255},
              thickness=0.5));

          connect(sensT_COND.outlet, sinkPressure.flange)
            annotation (Line(points={{20,240},{174,240}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
              points={{40,160},{114,160},{188,160},{188,70}},
              color={255,204,51},
              thickness=0.5));

          connect(signalBus.pumpCOND_PV, deaerator.level) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,11.7143},{
                  70.7143,11.7143}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_COND_CS, valveRH_COND.theta) annotation (
              Line(
              points={{40,160},{40,160},{40,210},{-110,210},{-110,232}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_COND_PV, sensP_RH.p) annotation (Line(
              points={{40,160},{40,160},{40,210},{-110,210},{-192,210},{-192,
                  230}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSH_RH_PV, sensP_SH.p) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,150},{-172,150}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_DEA_CS, valveRH_DEA.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,150},{-60,128},{-60,130},
                  {-28,130}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSH_RH_CS, valveSH_RH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-132,100}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDEA_SH_CS, valveDEA_SH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-110,100},{-110,68}},
              color={255,204,51},
              thickness=0.5));

          connect(signalBus.load, h_condLS.u[1]) annotation (Line(
              points={{40,160},{40,160},{40,112},{40,110},{138,110}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.load, p_cond.u[1]) annotation (Line(
              points={{40,160},{40,160},{40,196},{40,190},{138,190}},
              color={255,204,51},
              thickness=0.5));
          connect(p_cond.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  161,190},{180,190},{180,231.2}}, color={0,0,127}));
          connect(h_condLS.y[1], pumpCOND.in_h) annotation (Line(points={{161,
                  110},{180,110},{180,70}}, color={0,0,127}));
          connect(signalBus.valveDEA_RH_CS, valveDEA_RH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,170},{-72,170}},
              color={255,204,51},
              thickness=0.5));
          connect(condensingTemperature.y, add.u1) annotation (Line(points={{59,
                  230},{42.4,230},{42.4,224.8}}, color={0,0,127}));
          connect(sensT_COND.T, add.u2) annotation (Line(points={{22,230},{37.6,
                  230},{37.6,224.8}}, color={0,0,127}));
          connect(signalBus.valveDEA_RH_PV, add.y) annotation (Line(
              points={{40,160},{40,215.6},{40,215.6}},
              color={255,204,51},
              thickness=0.5));
          connect(valveSH_RH.outlet, DEA_SH.in1) annotation (Line(
              points={{-140,90},{-140,90},{-140,66}},
              color={0,0,255},
              thickness=0.5));
          connect(DEA_SH.in2, valveDEA_SH.outlet) annotation (Line(
              points={{-140,54},{-132,54},{-132,60},{-120,60}},
              color={0,0,255},
              thickness=0.5));
          connect(SH_out, DEA_SH.out) annotation (Line(
              points={{-250,60},{-158,60}},
              color={0,0,255},
              thickness=0.5));
          connect(valveDEA_RH.outlet, sensT_COND.inlet) annotation (Line(
              points={{-80,180},{-80,180},{-80,240},{8,240}},
              color={0,0,255},
              thickness=0.5));
          connect(valveRH_COND.outlet, sensT_COND.inlet) annotation (Line(
              points={{-100,240},{8,240}},
              color={0,0,255},
              thickness=0.5));
          connect(deaerator.drained_out, pumpFW.infl) annotation (Line(
              points={{28,1.85714},{28,-42}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, valveDEA_SH.inlet) annotation (Line(
              points={{33,-56},{33,-80},{-80,-80},{-80,60},{-100,60}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, flowJoin.in1) annotation (Line(
              points={{33,-56},{33,-132},{-6,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, valveDEA_RH.inlet) annotation (Line(
              points={{33,-56},{33,-80},{-80,-80},{-80,160}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,12},{100,-50},{
                  35,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(flowJoin.out, eletHeater.inlet) annotation (Line(
              points={{-10,-144},{-10,-144},{-10,-200}},
              color={0,0,255},
              thickness=0.5));
          connect(eletHeater.outlet, FW_out) annotation (Line(
              points={{-10,-220},{-10,-310}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.eletHEAT_CS, eletHeater.Q_th) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,-210},{-2,-210}},
              color={255,204,51},
              thickness=0.5));

          connect(valveRH_DEA.outlet, sensP.flange) annotation (Line(
              points={{-20,120},{-20,80}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP.flange, deaerator.steam_in) annotation (Line(
              points={{-20,80},{-20,44.5714},{15.5143,44.5714}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveRH_DEA_PV, sensP.p) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-30,100},{-30,88}},
              color={255,204,51},
              thickness=0.5));

        end WSC_100;

        model WSC_50 "Model of the water/steam cycle at partial load"
          extends BaseClasses.BaseWSC;
          Components.Deaerator
                    deaerator(
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            L=1.6,
            H=0.866025,
            zl_start=0.5,
            redeclare package Medium = Medium,
            phase(fixed=true),
            h_start=1e6,
            p_start=2200000)
            annotation (Placement(transformation(extent={{-18,-8},{74,84}})));
          ThermoPower.Water.SourceMassFlow pumpCOND(
            redeclare package Medium = Medium,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{194,54},{174,74}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow1(
            redeclare package Medium = Medium,
            use_in_w0=false,
            use_in_h=false)
            annotation (Placement(transformation(extent={{-44,24},{-24,4}})));
          ThermoPower.Water.ValveVap valveRH_COND(redeclare package Medium = Medium, Kv=
               5.80538e-6,
            Av=2.2150594e-3,
            wnom=2.03,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=4731000,
            dpnom=100000)
            annotation (Placement(transformation(extent={{-120,250},{-100,230}})));
          ThermoPower.Water.SensP sensP_RH(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-210,246},{-190,226}})));
          ThermoPower.Water.SensP sensP_SH(
            redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{-190,134},{-170,154}})));
          ThermoPower.Water.ValveVap valveSH_RH(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            wnom=1.757,
            thetanom=0.8,
            Av=1.6681872e-4,
            pnom=17100000,
            dpnom=12220000) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-140,100})));
          ThermoPower.Water.FlowJoin flowJoin(redeclare package Medium = Medium)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-10,-138})));
          ThermoPower.Water.ValveVap valveRH_DEA(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            wnom=0.11,
            Av=2.3151914e-3,
            thetanom=0.9,
            CheckValve=true,
            pnom=4731000,
            dpnom=2014000,
            pin_start=2265000,
            pout_start=2000)
                            annotation (Placement(transformation(
                extent={{-10,10},{10,-10}},
                rotation=270,
                origin={-20,130})));
          ThermoPower.Water.SensT sensT_COND(redeclare package Medium = Medium)
            annotation (Placement(transformation(extent={{4,246},{24,226}})));
          ThermoPower.Water.ValveVap valveDEA_RH(
            Fxt_full=0.4542722663,
            redeclare package Medium = Medium,
            Av=1.5366437e-5,
            wnom=0.66,
            thetanom=0.8,
            pnom=17400000,
            dpnom=12770000)
                          annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=270,
                origin={-80,170})));
          ThermoPower.Water.ValveVap valveDEA_SH(redeclare package Medium = Medium, Kv=5.80538e-6,
            Av=6.3328346e-6,
            wnom=0.272,
            thetanom=0.8,
            Fxt_full=0.4542722663,
            pnom=17400000,
            dpnom=12620000)
            annotation (Placement(transformation(extent={{-100,44},{-120,64}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              =                                                                  Medium,
              use_in_p0=true)
            annotation (Placement(transformation(extent={{174,250},{194,230}})));
          Modelica.Blocks.Tables.CombiTable1D p_cond(table=[20,1.776e5 - 1e5;
                30,2.025e5 - 1e5; 40,3.523e5 - 1e5; 50,5.985e5 - 1e5; 60,
                9.847e5 - 1e5; 70,15.2e5 - 1e5; 80,22.87e5 - 1e5; 90,33.53e5 -
                1e5; 100,47.31e5 - 1e5])             annotation (Placement(
                transformation(extent={{140,180},{160,200}})));
          Modelica.Blocks.Tables.CombiTable1D h_condLS(table=[20,229.7e3; 30,
                223.2e3; 40,318.3e3; 50,414e3; 60,509e3; 70,598.1e3; 80,689.2e3;
                90,782.8e3; 100,875.5e3; 110,875.5e3]) annotation (Placement(
                transformation(extent={{140,100},{160,120}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(
                transformation(extent={{20,140},{60,180}}), iconTransformation(
                  extent={{120,-330},{160,-290}})));
          Modelica.Blocks.Sources.RealExpression condensingTemperature(y=
                Modelica.Media.Water.WaterIF97_ph.saturationTemperature(p_cond.y[
                1]))
            annotation (Placement(transformation(extent={{80,220},{60,240}})));
          Modelica.Blocks.Math.Add add(k1=-1) annotation (Placement(
                transformation(
                extent={{-4,-4},{4,4}},
                rotation=270,
                origin={40,220})));
          ThermoPower.Water.Mixer DEA_SH(
            redeclare package Medium = Medium,
            V=0.001,
            S=0.06,
            gamma=0,
            Cm=0,
            FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            hstart=3150e3,
            pstart=2290000) annotation (Placement(transformation(extent={{-138,
                    50},{-158,70}})));
          Auxiliaries.Components.pump_constEfficiency pumpFW(
            use_in_w0=true,
            w0=1.757,
            eta_iso=0.8945) annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={26,-50})));
          Auxiliaries.Components.EletHeater eletHeater(
            redeclare package Medium = Medium,
            V=0.14,
            S=50,
            H=0,
            gamma=1500,
            Mm=90,
            cm=500,
            noInitialPressure=false,
            hstart=1256.2e3,
            pstart=17500000,
            Tmstart=563.15)
                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={-10,-210})));
          ThermoPower.Water.SensP sensP annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-24,80})));
          ThermoPower.Water.SensW sensW annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={38,-92})));
          ThermoPower.Water.SensT sensT annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=270,
                origin={38,-116})));
        equation
          connect(deaerator.water_in, pumpCOND.flange) annotation (Line(
              points={{39.8286,64.2857},{87.1714,64.2857},{87.1714,64},{174,64}},
              color={0,0,255},
              thickness=0.5));

          connect(sourceMassFlow1.flange, deaerator.drained_in) annotation (Line(points={{-24,14},
                  {-24,14},{-24,15},{-14.7143,15}},          color={0,0,255}));
          connect(RH_in,sensP_RH. flange) annotation (Line(points={{-250,240},{-200,240}},
                                  color={0,0,255},
              thickness=0.5));
          connect(sensP_RH.flange, valveRH_COND.inlet) annotation (Line(points={{-200,240},
                  {-200,240},{-120,240}}, color={0,0,255},
              thickness=0.5));
          connect(sensP_SH.flange, SH_in) annotation (Line(points={{-180,140},{-204,140},
                  {-204,140},{-250,140},{-250,140}}, color={0,0,255},
              thickness=0.5));
          connect(sensP_SH.flange, valveSH_RH.inlet) annotation (Line(points={{-180,140},
                  {-140,140},{-140,110}}, color={0,0,255},
              thickness=0.5));

          connect(SEP_in, flowJoin.in2) annotation (Line(
              points={{-250,-130},{-14,-130},{-14,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP_RH.flange, valveRH_DEA.inlet) annotation (Line(points={{-200,
                  240},{-180,240},{-160,240},{-160,190},{-20,190},{-20,140}},
                                                                         color={0,0,255},
              thickness=0.5));

          connect(sensT_COND.outlet, sinkPressure.flange)
            annotation (Line(points={{20,240},{174,240}}, color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpCOND_CS, pumpCOND.in_w0) annotation (Line(
              points={{40,160},{114,160},{188,160},{188,70}},
              color={255,204,51},
              thickness=0.5));

          connect(signalBus.pumpCOND_PV, deaerator.level) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,11.7143},{
                  70.7143,11.7143}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_COND_CS, valveRH_COND.theta) annotation (
              Line(
              points={{40,160},{40,160},{40,210},{-110,210},{-110,232}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_COND_PV, sensP_RH.p) annotation (Line(
              points={{40,160},{40,160},{40,210},{-110,210},{-192,210},{-192,
                  230}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSH_RH_PV, sensP_SH.p) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,150},{-172,150}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveRH_DEA_CS, valveRH_DEA.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,150},{-60,128},{-60,130},
                  {-28,130}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveSH_RH_CS, valveSH_RH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-132,100}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveDEA_SH_CS, valveDEA_SH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-110,100},{-110,62}},
              color={255,204,51},
              thickness=0.5));

          connect(signalBus.load, h_condLS.u[1]) annotation (Line(
              points={{40,160},{40,160},{40,112},{40,110},{138,110}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.load, p_cond.u[1]) annotation (Line(
              points={{40,160},{40,160},{40,196},{40,190},{138,190}},
              color={255,204,51},
              thickness=0.5));
          connect(p_cond.y[1], sinkPressure.in_p0) annotation (Line(points={{
                  161,190},{180,190},{180,231.2}}, color={0,0,127}));
          connect(h_condLS.y[1], pumpCOND.in_h) annotation (Line(points={{161,
                  110},{180,110},{180,70}}, color={0,0,127}));
          connect(signalBus.valveDEA_RH_CS, valveDEA_RH.theta) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,170},{-72,170}},
              color={255,204,51},
              thickness=0.5));
          connect(condensingTemperature.y, add.u1) annotation (Line(points={{59,
                  230},{42.4,230},{42.4,224.8}}, color={0,0,127}));
          connect(sensT_COND.T, add.u2) annotation (Line(points={{22,230},{37.6,
                  230},{37.6,224.8}}, color={0,0,127}));
          connect(signalBus.valveDEA_RH_PV, add.y) annotation (Line(
              points={{40,160},{40,215.6},{40,215.6}},
              color={255,204,51},
              thickness=0.5));
          connect(valveSH_RH.outlet, DEA_SH.in1) annotation (Line(
              points={{-140,90},{-140,90},{-140,66}},
              color={0,0,255},
              thickness=0.5));
          connect(DEA_SH.in2, valveDEA_SH.outlet) annotation (Line(
              points={{-140,54},{-132,54},{-120,54}},
              color={0,0,255},
              thickness=0.5));
          connect(SH_out, DEA_SH.out) annotation (Line(
              points={{-250,60},{-158,60}},
              color={0,0,255},
              thickness=0.5));
          connect(valveDEA_RH.outlet, sensT_COND.inlet) annotation (Line(
              points={{-80,180},{-80,180},{-80,240},{8,240}},
              color={0,0,255},
              thickness=0.5));
          connect(valveRH_COND.outlet, sensT_COND.inlet) annotation (Line(
              points={{-100,240},{8,240}},
              color={0,0,255},
              thickness=0.5));
          connect(deaerator.drained_out, pumpFW.infl) annotation (Line(
              points={{28,1.85714},{28,-42}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, valveDEA_SH.inlet) annotation (Line(
              points={{33,-56},{33,-80},{-80,-80},{-80,54},{-100,54}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, valveDEA_RH.inlet) annotation (Line(
              points={{33,-56},{33,-80},{-80,-80},{-80,160}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.pumpFW_CS, pumpFW.in_w0) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,12},{100,-50},{
                  35,-50}},
              color={255,204,51},
              thickness=0.5));
          connect(flowJoin.out, eletHeater.inlet) annotation (Line(
              points={{-10,-144},{-10,-144},{-10,-200}},
              color={0,0,255},
              thickness=0.5));
          connect(eletHeater.outlet, FW_out) annotation (Line(
              points={{-10,-220},{-10,-310}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.eletHEAT_CS, eletHeater.Q_th) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,-210},{-2,-210}},
              color={255,204,51},
              thickness=0.5));

          connect(valveRH_DEA.outlet, sensP.flange) annotation (Line(
              points={{-20,120},{-20,80}},
              color={0,0,255},
              thickness=0.5));
          connect(sensP.flange, deaerator.steam_in) annotation (Line(
              points={{-20,80},{-20,44.5714},{15.5143,44.5714}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.valveRH_DEA_PV, sensP.p) annotation (Line(
              points={{40,160},{40,160},{-60,160},{-60,100},{-30,100},{-30,88}},
              color={255,204,51},
              thickness=0.5));

          connect(sensT.outlet, flowJoin.in1) annotation (Line(
              points={{34,-122},{34,-132},{-6,-132}},
              color={0,0,255},
              thickness=0.5));
          connect(sensW.outlet, sensT.inlet) annotation (Line(
              points={{34,-98},{34,-98},{34,-110}},
              color={0,0,255},
              thickness=0.5));
          connect(pumpFW.outfl, sensW.inlet) annotation (Line(
              points={{33,-56},{34,-56},{34,-86}},
              color={0,0,255},
              thickness=0.5));
          connect(signalBus.eletHEAT_PV_low_w, sensW.w) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,-100},{44,-100}},
              color={255,204,51},
              thickness=0.5));

          connect(signalBus.eletHEAT_PV_low_T, sensT.T) annotation (Line(
              points={{40,160},{40,160},{40,110},{100,110},{100,-124},{44,-124}},
              color={255,204,51},
              thickness=0.5));

        end WSC_50;
      end WSC;
    end HeatExchangers;

    package Plants
      "Package containing partial/complete models of the power plant"

      package Test
        "Package containing some test model on the HP part of the plant"

        package HotStart
          "Package containing models for pilot hot start simulation "

          model Pilot_IO_20_100_20_normal
            "Model of the pilot for hot start simulation from 20 to 100% and again to 20% load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,150},{
                      -98,170}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              ECO1(
                Shot=77.459*0.8/2,
                Scold=63.904*0.8/2,
                outletCold(m_flow(start=-2.4))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
              separator(noInitialLevel=false, zl_start=2.5))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=6.961e-5,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              useTS_pumpMS=true,
              T_FW_sp=558.15,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,0;
                      60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])))
                              annotation (Placement(transformation(extent={{-240,
                      -80},{-180,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            ComponentEmulator.turbineEmulator turbineEmulator(
              eta_iso_HPT=0.865,
              eta_iso_IPT=0.895,
              a=-0.05741,
              b=0.0612)
              annotation (Placement(transformation(extent={{-192,92},{-224,124}})));
            Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
              annotation (Placement(transformation(extent={{-250,162},{-230,182}})));
            Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                  end]) annotation (Placement(transformation(extent={{-250,148},
                      {-230,168}})));
            Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
              annotation (Placement(transformation(extent={{-250,134},{-230,154}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-152,118},{-172,138}})));
            Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                  end]) annotation (Placement(transformation(extent={{-152,104},
                      {-172,124}})));
            Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
              annotation (Placement(transformation(extent={{-152,90},{-172,110}})));
            Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
              annotation (Placement(transformation(extent={{-152,76},{-172,96}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              duration=900,
              startTime=5000) annotation (Placement(transformation(extent={{-320,
                      -20},{-300,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-262,-44},{-254,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-288,-50},{-268,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              height=80,
              duration=600,
              offset=0,
              startTime=10000)
                              annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              duration=600,
              offset=0,
              height=-80,
              startTime=15000)
                              annotation (Placement(transformation(extent={{-320,
                      -80},{-300,-60}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-177.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points={{-229,
                    144},{-212.8,144},{-212.8,125.6}},    color={0,0,127}));
            connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points={{-229,
                    158},{-220,158},{-203.2,158},{-203.2,125.6}},   color={0,0,
                    127}));
            connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points={{-229,
                    172},{-195.2,172},{-195.2,125.6}},      color={0,0,127}));
            connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points={{-173,
                    128},{-180,128},{-180,120.8},{-190.4,120.8}},   color={0,0,
                    127}));
            connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points={{-190.4,
                    112.8},{-180,112.8},{-180,114},{-173,114}},     color={0,0,
                    127}));
            connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points={{-190.4,
                    103.2},{-180,103.2},{-180,100},{-173,100}},     color={0,0,
                    127}));
            connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                  points={{-173,86},{-180,86},{-180,95.2},{-190.4,95.2}}, color={
                    0,0,127}));
            connect(signalBus.pumpMS_PV, turbineEmulator.P_mec) annotation (
                Line(
                points={{-160,20},{-160,20},{-160,58},{-160,60},{-240,60},{-240,
                    108},{-225.6,108}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-253.6,-40},{
                    -242.727,-40}}, color={0,0,127}));
            connect(gain.y, turbineEmulator.load) annotation (Line(points={{
                    -253.6,-40},{-250,-40},{-250,134},{-220.8,134},{-220.8,
                    125.6}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-299,-10},{-296,
                    -10},{-296,-32},{-290,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-299,-40},{-296,
                    -40},{-290,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-267,-40},{-262.8,
                    -40},{-262.8,-40}}, color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-299,-70},{-296,
                    -70},{-296,-48},{-290,-48}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=20000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_IO_20_100_20_normal;

          model Pilot_IO_50_20_warmKeeping
            "Model of the pilot for hot start simulation from 50% to warm keeping condition"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_no_pumpMS        OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              ECO1(
                Shot=77.459*0.8/2,
                Scold=63.904*0.8/2,
                outletCold(m_flow(start=-2.4))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
              separator(noInitialLevel=false, zl_start=2.5))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=6.961e-5,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              useTS_pumpMS=true,
              fullyDecentralized(valveSH_RH_lim(uMin=0.001)),
              T_FW_sp=558.15,
              WSCcontroller(
                control_valveRH_COND(table_p_RH(table=[5,8.651e5; 20,8.651e5;
                        30,13.19e5; 40,17.83e5; 50,22.6e5; 60,27.39e5; 70,
                        32.65e5; 80,37.19e5; 90,42.05e5; 100,47.31e5])),
                control_valveDEA_RH(valveDEA_RH_lim(uMin=0.001)),
                control_valveDEA_SH(valveDEA_SH_lim(uMin=0.001))))
                              annotation (Placement(transformation(extent={{-240,
                      -80},{-180,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,20},{-140,60}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              duration=900,
              startTime=2000) annotation (Placement(transformation(extent={{-320,
                      -20},{-300,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-262,-44},{-254,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-288,-50},{-268,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              offset=0,
              duration=5000,
              startTime=4000,
              height=0)       annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              duration=600,
              offset=0,
              startTime=15000,
              height=0)       annotation (Placement(transformation(extent={{-320,
                      -80},{-300,-60}})));
            Auxiliaries.Components.MSmixer_simp mSmixer annotation (Placement(
                  transformation(extent={{-210,110},{-110,190}})));
            Modelica.Blocks.Sources.Constant Pmec_PV(k=0) annotation (Placement(
                  transformation(extent={{-220,30},{-200,50}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-177.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,40}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-253.6,-40},{
                    -242.727,-40}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-299,-10},{-296,
                    -10},{-296,-32},{-290,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-299,-40},{-296,
                    -40},{-290,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-267,-40},{-262.8,
                    -40},{-262.8,-40}}, color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-299,-70},{-296,
                    -70},{-296,-48},{-290,-48}}, color={0,0,127}));
            connect(mSmixer.flangeB, OTSG.MS_in) annotation (Line(
                points={{-110,150},{-110,150},{-88.8889,150},{-88.8889,77.8}},
                color={255,0,0},
                thickness=0.5));
            connect(mSmixer.signalBus, signalBus) annotation (Line(
                points={{-160,110},{-160,110},{-160,42},{-160,40}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(signalBus.pumpMS_PV, Pmec_PV.y) annotation (Line(
                points={{-160,40},{-158,40},{-199,40}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=10000, __Dymola_NumberOfIntervals=5000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_IO_50_20_warmKeeping;

          model Pilot_IO_50_20_warmKeeping_100
            "Model of the pilot for hot start simulation from warm keeping conditions to fully operative conditions"

            Modelica.SIunits.Mass M_MS_tot;

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_no_pumpMS        OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              ECO1(
                Shot=77.459*0.8/2,
                Scold=63.904*0.8/2,
                outletCold(m_flow(start=-2.4))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.1*3.705e-5))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=6.961e-5,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              useTS_pumpMS=true,
              WSCcontroller(
                control_valveRH_COND(table_p_RH(table=[5,8.651e5; 20,8.651e5; 30,13.19e5;
                        40,17.83e5; 50,22.6e5; 60,27.39e5; 70,32.65e5; 80,37.19e5; 90,42.05e5;
                        100,47.31e5])),
                control_valveDEA_RH(valveDEA_RH_lim(uMin=0.001)),
                control_valveDEA_SH(valveDEA_SH_lim(uMin=0.001))),
              fullyDecentralized(valveSH_RH_lim(uMin=0.001)),
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-240,
                      -80},{-180,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,20},{-140,60}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              duration=900,
              startTime=2000) annotation (Placement(transformation(extent={{-320,
                      -20},{-300,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-262,-44},{-254,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-288,-50},{-268,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              offset=0,
              height=80,
              duration=1080,
              startTime=20000)
                              annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              duration=600,
              offset=0,
              startTime=15000,
              height=0)       annotation (Placement(transformation(extent={{-320,
                      -80},{-300,-60}})));
            Auxiliaries.Components.MSmixer_simp mixerMS annotation (Placement(
                  transformation(extent={{-210,110},{-110,190}})));
            Modelica.Blocks.Sources.Constant Pmec_PV(k=0) annotation (Placement(
                  transformation(extent={{-220,30},{-200,50}})));
          equation

            if time >= 20000 and time <= 21080 then
              der(M_MS_tot) = mixerMS.hotPump.w;
            else
              der(M_MS_tot) = 0;
            end if;

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-177.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,40}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-253.6,-40},{
                    -242.727,-40}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-299,-10},{-296,
                    -10},{-296,-32},{-290,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-299,-40},{-296,
                    -40},{-290,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-267,-40},{-262.8,
                    -40},{-262.8,-40}}, color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-299,-70},{-296,
                    -70},{-296,-48},{-290,-48}}, color={0,0,127}));
            connect(mixerMS.flangeB, OTSG.MS_in) annotation (Line(
                points={{-110,150},{-110,150},{-88.8889,150},{-88.8889,77.8}},
                color={255,0,0},
                thickness=0.5));
            connect(mixerMS.signalBus, signalBus) annotation (Line(
                points={{-160,110},{-160,110},{-160,42},{-160,40}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(signalBus.pumpMS_PV, Pmec_PV.y) annotation (Line(
                points={{-160,40},{-158,40},{-199,40}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=6250),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_IO_50_20_warmKeeping_100;

          model Pilot_IO_50_20_warmKeeping_100_shell
            "Model of the pilot for hot start simulation from warm keeping conditions to fully operative conditions"

            Modelica.SIunits.Mass M_MS_tot;

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_no_pumpMS_shell  OTSG(
              PDSteamECO2(pin(start=9080000, fixed=false)),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              ECO1(
                Shot_bundle=77.459*0.8/2,
                Scold_bundle=63.904*0.8/2,
                outletCold(m_flow(start=-2.4)),
                nominalColdInletTemperature=558.15,
                nominalColdOutletTemperature=558.15,
                nominalHotInletTemperature=558.15,
                nominalHotOutletTemperature=558.15),
              EVA1(Shot_bundle=67.796*0.8, Scold_bundle=53.152*0.8),
              EVA2(Shot_bundle=9.971*0.8, Scold_bundle=7.616*0.8),
              SH(Shot_bundle=22.8*0.95, Scold_bundle=17.385*0.95),
              ECO2(Shot_bundle=77.459*0.8/2, Scold_bundle=63.904*0.8/2),
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot_bundle=0.425*0.54,
                Vcold_bundle=0.106*0.54,
                Shot_bundle=27.935*0.54,
                Scold_bundle=24.995*0.54,
                Mm_bundle=210.313*0.54),
              HPH(
                nominalColdOutletTemperature=558.15,
                nominalHotInletTemperature=558.15,
                nominalHotOutletTemperature=558.15),
              valveLiq(Av=0.2*3.705e-5))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=6.961e-5,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              useTS_pumpMS=true,
              fullyDecentralized(valveSH_RH_lim(uMin=0.001)),
              control_wHPH(table_w_HPH(table=[5,0.002; 20,0.02; 30,0.02; 40,
                      0.02; 50,0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,
                      0.4717])),
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              WSCcontroller(
                control_valveRH_COND(table_p_RH(table=[5,8.651e5; 20,8.651e5;
                        30,13.19e5; 40,17.83e5; 50,22.6e5; 60,27.39e5; 70,
                        32.65e5; 80,37.19e5; 90,42.05e5; 100,47.31e5])),
                control_valveDEA_RH(valveDEA_RH_lim(uMin=0.001)),
                control_valveDEA_SH(valveDEA_SH_lim(uMin=0.001))),
              CSmin_valveSH_RH_high=-5e-7,
              CSmax_valveSH_RH_high=5e-7,
              T_FW_sp=558.15,
              l_min=0.15,
              l_max=0.3)      annotation (Placement(transformation(extent={{-240,
                      -80},{-180,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,20},{-140,60}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              duration=900,
              startTime=2000) annotation (Placement(transformation(extent={{-320,
                      -20},{-300,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-262,-44},{-254,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-288,-50},{-268,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              offset=0,
              height=80,
              duration=1080,
              startTime=20000)
                              annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              duration=600,
              offset=0,
              startTime=15000,
              height=0)       annotation (Placement(transformation(extent={{-320,
                      -80},{-300,-60}})));
            Auxiliaries.Components.MSmixer_simp mixerMS annotation (Placement(
                  transformation(extent={{-210,110},{-110,190}})));
            Modelica.Blocks.Sources.Constant Pmec_PV(k=0) annotation (Placement(
                  transformation(extent={{-220,30},{-200,50}})));
          equation

            if time >= 20000 and time <= 21080 then
              der(M_MS_tot) = mixerMS.hotPump.w;
            else
              der(M_MS_tot) = 0;
            end if;

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-177.273,-40},{-177.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,40}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-253.6,-40},{
                    -242.727,-40}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-299,-10},{-296,
                    -10},{-296,-32},{-290,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-299,-40},{-296,
                    -40},{-290,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-267,-40},{-262.8,
                    -40},{-262.8,-40}}, color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-299,-70},{-296,
                    -70},{-296,-48},{-290,-48}}, color={0,0,127}));
            connect(mixerMS.flangeB, OTSG.MS_in) annotation (Line(
                points={{-110,150},{-110,150},{-88.8889,150},{-88.8889,77.8}},
                color={255,0,0},
                thickness=0.5));
            connect(mixerMS.signalBus, signalBus) annotation (Line(
                points={{-160,110},{-160,110},{-160,42},{-160,40}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(signalBus.pumpMS_PV, Pmec_PV.y) annotation (Line(
                points={{-160,40},{-158,40},{-199,40}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=6250),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_IO_50_20_warmKeeping_100_shell;

          model Pilot_IO_50_20_warmKeeping_100_shell_ts
            "Model of the pilot for hot start simulation from warm keeping conditions to fully operative conditions"

            Modelica.SIunits.Mass M_MS_tot;

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-320,220},{-300,240}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=100000) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes_no_pumpMS_shell_ts
                                                                    OTSG(
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.1*3.705e-5),
              ECO1(
                Shot_bundle=77.459*0.8/2,
                Scold_bundle=63.904*0.8/2,
                outletCold(m_flow(start=-2.4))),
              EVA1(Shot_bundle=67.796*0.8, Scold_bundle=53.152*0.8),
              EVA2(Shot_bundle=9.971*0.8, Scold_bundle=7.616*0.8),
              SH(Shot_bundle=22.8*0.95, Scold_bundle=17.385*0.95),
              ECO2(Shot_bundle=77.459*0.8/2, Scold_bundle=63.904*0.8/2),
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot_bundle=0.425*0.54,
                Vcold_bundle=0.106*0.54,
                Shot_bundle=27.935*0.54,
                Scold_bundle=24.995*0.54,
                Mm_bundle=210.313*0.54))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Kp_pumpMS_low=6.961e-5,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              useTS_pumpMS=true,
              WSCcontroller(
                control_valveRH_COND(table_p_RH(table=[5,8.651e5; 20,8.651e5; 30,13.19e5;
                        40,17.83e5; 50,22.6e5; 60,27.39e5; 70,32.65e5; 80,37.19e5; 90,42.05e5;
                        100,47.31e5])),
                control_valveDEA_RH(valveDEA_RH_lim(uMin=0.001)),
                control_valveDEA_SH(valveDEA_SH_lim(uMin=0.001))),
              T_FW_sp=558.15,
              fullyDecentralized(valveSH_RH_lim(uMin=0.001)))
                              annotation (Placement(transformation(extent={{-240,
                      -80},{-180,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,20},{-140,60}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              duration=900,
              startTime=2000) annotation (Placement(transformation(extent={{-320,
                      -20},{-300,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-262,-44},{-254,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-288,-50},{-268,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              offset=0,
              height=80,
              duration=1080,
              startTime=20000)
                              annotation (Placement(transformation(extent={{-320,
                      -50},{-300,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              duration=600,
              offset=0,
              startTime=15000,
              height=0)       annotation (Placement(transformation(extent={{-320,
                      -80},{-300,-60}})));
            Auxiliaries.Components.MSmixer_simp mixerMS annotation (Placement(
                  transformation(extent={{-210,110},{-110,190}})));
            Modelica.Blocks.Sources.Constant Pmec_PV(k=0) annotation (Placement(
                  transformation(extent={{-220,30},{-200,50}})));
          equation

            if time >= 20000 and time <= 21080 then
              der(M_MS_tot) = mixerMS.hotPump.w;
            else
              der(M_MS_tot) = 0;
            end if;

            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-177.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-177.273,-40},{-160,-40},{-160,40}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-253.6,-40},{
                    -242.727,-40}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-299,-10},{-296,
                    -10},{-296,-32},{-290,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-299,-40},{-296,
                    -40},{-290,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-267,-40},{-262.8,
                    -40},{-262.8,-40}}, color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-299,-70},{-296,
                    -70},{-296,-48},{-290,-48}}, color={0,0,127}));
            connect(mixerMS.flangeB, OTSG.MS_in) annotation (Line(
                points={{-110,150},{-110,150},{-88.8889,150},{-88.8889,77.8}},
                color={255,0,0},
                thickness=0.5));
            connect(mixerMS.signalBus, signalBus) annotation (Line(
                points={{-160,110},{-160,110},{-160,42},{-160,40}},
                color={255,204,51},
                thickness=0.5), Text(
                string="%second",
                index=1,
                extent={{6,3},{6,3}}));
            connect(signalBus.pumpMS_PV, Pmec_PV.y) annotation (Line(
                points={{-160,40},{-158,40},{-199,40}},
                color={255,204,51},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                      -240},{320,240}}, preserveAspectRatio=false)),
              experiment(StopTime=25000, __Dymola_NumberOfIntervals=6250),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_IO_50_20_warmKeeping_100_shell_ts;
        end HotStart;

        package StaticMaps
          "Package containing models to evaluate the static performance of the pilot"

          model Pilot_staticMaps_pcond_nom
            "Model of the pilot for performance static maps evaluation"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=true,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Sources.Ramp load(
              height=-30,
              offset=50,
              startTime=5000,
              duration=500000)
                              annotation (Placement(transformation(extent={{-360,
                      -20},{-340,0}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-300,-44},{-292,-36}})));
            Modelica.Blocks.Math.Add3 add annotation (Placement(transformation(
                    extent={{-328,-50},{-308,-30}})));
            Modelica.Blocks.Sources.Ramp load1(
              offset=0,
              height=80,
              startTime=550000,
              duration=2000)  annotation (Placement(transformation(extent={{-360,
                      -50},{-340,-30}})));
            Modelica.Blocks.Sources.Ramp load2(
              offset=0,
              height=-40,
              duration=600000,
              startTime=600000)
                              annotation (Placement(transformation(extent={{-360,
                      -80},{-340,-60}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Sources.Ramp T_amb(
              duration=10,
              offset=301.15,
              startTime=100,
              height=0) annotation (Placement(transformation(extent={{-280,132},
                      {-260,152}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-291.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(load.y, add.u1) annotation (Line(points={{-339,-10},{-336,
                    -10},{-336,-32},{-330,-32}}, color={0,0,127}));
            connect(load1.y, add.u2) annotation (Line(points={{-339,-40},{-336,
                    -40},{-330,-40}}, color={0,0,127}));
            connect(add.y, gain.u) annotation (Line(points={{-307,-40},{-300.8,
                    -40}},              color={0,0,127}));
            connect(load2.y, add.u3) annotation (Line(points={{-339,-70},{-336,
                    -70},{-336,-48},{-330,-48}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-243,142}}, color={0,0,127}));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-291.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(StopTime=1.2e+006, __Dymola_NumberOfIntervals=20000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_pcond_nom;

          model Pilot_staticMaps_lowLoad_5_25degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              T_min=278.15,
              T_max=298.15,
              startTime=5000)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(StopTime=1.265e+006, __Dymola_NumberOfIntervals=
                    1001000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_5_25degC;

          model Pilot_staticMaps_lowLoad_26_45degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3]))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              T_min=278.15,
              T_max=298.15,
              startTime=5000)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(StopTime=1.23e+006, __Dymola_NumberOfIntervals=1000000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_26_45degC;

          model Pilot_staticMaps_highLoad_5_25degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=278.15,
              T_max=298.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-44,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=50,
              height=50,
              startTime=5000,
              duration=200)  annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(StopTime=1.23e+006, __Dymola_NumberOfIntervals=1000000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_5_25degC;

          model Pilot_staticMaps_highLoad_26_45degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              Kp_pumpMS_high=0.0001295,
              Kp_pumpFW_high=-0.1*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=299.15,
              T_max=318.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-44,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              offset=50,
              height=50,
              startTime=5000,
              duration=100)  annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(StopTime=1.23e+006, __Dymola_NumberOfIntervals=1000000),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_26_45degC;

          model Pilot_staticMaps_lowLoad_5_9degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=278.15,
              T_max=282.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_5_9degC;

          model Pilot_staticMaps_lowLoad_10_14degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=283.15,
              T_max=287.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_10_14degC;

          model Pilot_staticMaps_lowLoad_15_19degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=288.15,
              T_max=292.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_15_19degC;

          model Pilot_staticMaps_lowLoad_20_24degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=293.15,
              T_max=297.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_20_24degC;

          model Pilot_staticMaps_lowLoad_25_29degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=298.15,
              T_max=302.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_25_29degC;

          model Pilot_staticMaps_lowLoad_30_34degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=303.15,
              T_max=307.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_30_34degC;

          model Pilot_staticMaps_lowLoad_35_39degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=308.15,
              T_max=312.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=50000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_35_39degC;

          model Pilot_staticMaps_lowLoad_40_45degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Kp_valveDEA_SH=-0.1134,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Ti_pumpMS_high=54.23,
              Td_pumpMS_high=3.098,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Kp_pumpFW_high=-0.01579,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Kp_eletHEAT=1.529e5,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Kp_valveSH_RH_high=-1.241e-13,
              Ti_valveSH_RH_high=3.845,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSmin_valveSH_RH_high=-0.1,
              CSmax_valveSH_RH_high=0.1,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              CSmin_valveSH_RH_low=-0.1,
              CSmax_valveSH_RH_low=0.1,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Kp_pumpCOND=180,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_valveRH_COND=-2.9e-8*0.1,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_high=0.1*0.0001295,
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              load_switch=56,
              T_FW_sp=558.15,
              fullyDecentralized(control_wFW_low(table_l_sp(table=[20,3; 30,3;
                        40,3; 50,3; 55,3; 60,3; 70,3; 80,3; 90,3; 100,3],
                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments))),
              control_wSEP(table_T_FW(table=[20,558.15; 30,558.15; 40,558.15;
                      50,558.15; 60,558.15; 70,558.15; 80,518.15; 90,518.15;
                      100,518.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)))
                              annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=313.15,
              T_max=318.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              amplitude=-35,
              startTime=10000)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              duration=1000,
              offset=50,
              startTime=100,
              height=5)      annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=370000,
                __Dymola_NumberOfIntervals=60000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_lowLoad_40_45degC;

          model Pilot_staticMaps_highLoad_5_9degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=278.15,
              T_max=282.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=30000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_5_9degC;

          model Pilot_staticMaps_highLoad_10_14degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=283.15,
              T_max=287.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=20000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_10_14degC;

          model Pilot_staticMaps_highLoad_15_19degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=288.15,
              T_max=292.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=24000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_15_19degC;

          model Pilot_staticMaps_highLoad_20_24degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=293.15,
              T_max=297.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=45000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_20_24degC;

          model Pilot_staticMaps_highLoad_25_29degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=298.15,
              T_max=302.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=45000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_25_29degC;

          model Pilot_staticMaps_highLoad_30_34degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=303.15,
              T_max=307.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=45000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_30_34degC;

          model Pilot_staticMaps_highLoad_35_39degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15]))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=308.15,
              T_max=312.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=310000,
                __Dymola_NumberOfIntervals=45000,
                __Dymola_Algorithm="Cvode"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_35_39degC;

          model Pilot_staticMaps_highLoad_40_45degC
            "Model of the pilot for performance static maps evaluation @ low load"

            inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
              annotation (Placement(transformation(extent={{-360,220},{-340,240}})));
            ThermoPower.Water.SourcePressure sourceMS(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              h=518322) annotation (Placement(transformation(extent={{-118,90},
                      {-98,110}})));
            ThermoPower.Water.SinkPressure sinkMS3(
              allowFlowReversal=false,
              redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
              p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                      {-120,-170}})));
            HeatExchangers.OTSG.OTSG_init50_5nodes                  OTSG(
              RH(
                coldFluid(w(start=2, fixed=false), noInitialPressure=true),
                Vhot=0.425*0.54,
                Vcold=0.106*0.54,
                Shot=27.935*0.54,
                Scold=24.995*0.54,
                Mm=210.313*0.54),
              SH(Shot=22.8*0.95, Scold=17.385*0.95),
              EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
              EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
              PDSteamECO2(pin(start=9080000, fixed=false)),
              HPH(inletCold(m_flow(start=0.2))),
              PDSteamECO1(pin(start=9100000, fixed=false)),
              separator(noInitialLevel=false, zl_start=2.5),
              valveLiq(Av=0.04*3.7e-5),
              ECO1(
                outletCold(m_flow(start=-2.4)),
                Shot=77.459*0.5/2,
                Scold=63.904*0.5/2),
              ECO2(Shot=77.459*0.5/2, Scold=63.904*0.5/2))
              annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
            Control.Schemes.PilotControlSchemes.WSController_fullyDecentralized
              DCS(
              actuatorGain_pumpHPH=1,
              actuatorGain_pumpFW=1,
              actuatorGain_pumpMS=1,
              Ta_pumpFW=2,
              Ta_pumpHPH=2,
              Ta_pumpMS=2,
              Td_valveRH_DEA=0,
              Nd_valveRH_DEA=30,
              CSmin_valveRH_DEA=-1,
              CSmax_valveRH_DEA=1,
              CSstart_valveRH_DEA=0,
              actuatorGain_valveRH_DEA=1,
              Ta_valveRH_DEA=0.3,
              TS_valveRH_DEA=0,
              Td_valveRH_COND=0,
              Nd_valveRH_COND=30,
              CSmin_valveRH_COND=-1,
              CSmax_valveRH_COND=1,
              CSstart_valveRH_COND=0,
              actuatorGain_valveRH_COND=1,
              Ta_valveRH_COND=0.3,
              TS_valveRH_COND=0,
              Td_pumpCOND=0,
              Nd_pumpCOND=30,
              CSmin_pumpCOND=0,
              CSmax_pumpCOND=5,
              actuatorGain_pumpCOND=1,
              Ta_pumpCOND=2,
              TS_pumpCOND=0,
              Td_valveDEA_SH=0,
              Nd_valveDEA_SH=30,
              CSmin_valveDEA_SH=-1,
              CSmax_valveDEA_SH=1,
              CSstart_valveDEA_SH=0,
              actuatorGain_valveDEA_SH=1,
              Ta_valveDEA_SH=0.3,
              TS_valveDEA_SH=0,
              Td_valveDEA_RH=0,
              Nd_valveDEA_RH=30,
              CSmin_valveDEA_RH=-1,
              CSmax_valveDEA_RH=1,
              CSstart_valveDEA_RH=0,
              actuatorGain_valveDEA_RH=1,
              Ta_valveDEA_RH=0.3,
              TS_valveDEA_RH=0,
              CSstart_pumpCOND=2.6,
              l_dea_sp=0.45,
              Td_pumpSEP=0,
              Nd_pumpSEP=30,
              CSstart_pumpSEP=0,
              actuatorGain_pumpSEP=1,
              Ta_pumpSEP=2,
              TS_pumpSEP=0,
              DT_sh_COND_sp(displayUnit="K") = 10,
              CSmin_pumpSEP=-0.5,
              Ti_valveRH_COND=0.5283,
              Ti_valveDEA_SH=285.7,
              Ti_valveDEA_RH=0.3121,
              Kp_valveDEA_RH=-0.007726,
              CSmax_pumpSEP=1,
              load_switch=55,
              use_valveSEP=true,
              useTS_pumpFW_high=false,
              useTS_pumpFW_low=false,
              useTS_pumpCOND=false,
              useTS_valveRH_DEA=false,
              useTS_valveRH_COND=false,
              useTS_eletHEAT=false,
              useTS_valveDEA_SH=false,
              useTS_valveDEA_RH=false,
              Nd_pumpMS_high=20,
              CSmin_pumpMS_high=-3,
              CSmax_pumpMS_high=3,
              CSstart_pumpMS_high=0,
              TS_pumpMS_high=0,
              Ti_pumpMS_low=46.63,
              Td_pumpMS_low=6.736,
              Nd_pumpMS_low=20,
              CSmin_pumpMS_low=-3,
              CSmax_pumpMS_low=3,
              CSstart_pumpMS_low=0,
              TS_pumpMS_low=0,
              Ti_pumpFW_high=191.3,
              Td_pumpFW_high=0,
              Nd_pumpFW_high=20,
              CSmin_pumpFW_high=-0.2,
              CSmax_pumpFW_high=0.2,
              CSstart_pumpFW_high=0,
              TS_pumpFW_high=0,
              l_sp=3,
              Ti_pumpFW_low=714.2,
              Td_pumpFW_low=0,
              Nd_pumpFW_low=20,
              CSmin_pumpFW_low=0,
              CSmax_pumpFW_low=3,
              CSstart_pumpFW_low=0.9,
              TS_pumpFW_low=0,
              Kp_valveRH_DEA=1.007e-6,
              Ti_valveRH_DEA=142.8,
              Ti_eletHEAT=571.4,
              Td_eletHEAT=0,
              Nd_eletHEA=20,
              CSmin_eletHEAT=0,
              CSmax_eletHEAT=2e5,
              CSstart_eletHEAT=120e3,
              actuatorGain_eletHEAT=1,
              Ta_eletHEAT=0.3,
              TS_eletHEAT=0,
              load_min=55,
              actuatorGain_valveSEP=1,
              Ta_valveSEP=0.3,
              dec_wMS_wFW=0,
              dec_wFW_wMS=0,
              Kp_pumpFW_low=4.841,
              Ti_pumpSEP=29.4,
              useTS_valveSH_RH_high=false,
              Td_valveSH_RH_high=0,
              Nd_valveSH_RH_high=20,
              CSstart_valveSH_RH_high=0,
              TS_valveSH_RH_high=0,
              Kp_valveSH_RH_low=-3.194e-13,
              Ti_valveSH_RH_low=9.681,
              Td_valveSH_RH_low=0,
              Nd_valveSH_RH_low=20,
              TS_valveSH_RH_low=0,
              actuatorGain_valveSH_RH=1,
              Ta_valveSH_RH=0.3,
              CSstart_valveSH_RH_low=0,
              useTS_valveSH_RH_low=false,
              Ti_pumpCOND=381,
              useTS_pumpSEP=false,
              Kp_pumpSEP=0.1*0.3915,
              DT_sh_sp=293.15,
              l_min=0.15,
              l_max=0.3,
              control_wHPH(table_w_HPH(table=[20,0.02; 30,0.02; 40,0.02; 50,
                      0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245; 100,0.4717])),
              Kp_pumpMS_low=0.1*6.961e-5,
              useTS_pumpMS=false,
              Ti_valveSH_RH_high=3.845,
              CSmin_valveSH_RH_high=-1e-7,
              CSmax_valveSH_RH_high=1e-7,
              CSmin_valveSH_RH_low=-1e-7,
              CSmax_valveSH_RH_low=1e-7,
              fullyDecentralized(control_wFW_high_PI(table_DT_sh_sp(table=[20,
                        293.15; 30,293.15; 40,293.15; 50,293.15; 55,293.15; 60,
                        293.15; 70,293.15; 80,293.15; 90,293.15; 100,293.15]))),
              WSCcontroller(control_eletHEAT(table_T_FW(table=[20,518.15; 30,
                        518.15; 40,518.15; 50,518.15; 60,518.15; 70,518.15; 80,
                        518.15; 90,518.15; 100,518.15])), control_wCOND(
                    pumpCOND_lim(uMax=10))),
              Kp_valveDEA_SH=-0.1134,
              Kp_pumpCOND=180,
              Kp_valveSH_RH_high=-1.241e-13,
              Kp_valveRH_COND=-2.9e-8,
              Kp_eletHEAT=1.529e5,
              Kp_pumpMS_high=0.0001295,
              Ti_pumpMS_high=54,
              Td_pumpMS_high=3,
              Kp_pumpFW_high=-0.5*0.01579,
              T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                      -80},{-200,0}})));

            HeatExchangers.WSC.WSC_50  WSC(deaerator(w_small=1e4, h_start=
                    0.95e6))               annotation (Placement(transformation(
                    extent={{80,-108},{300,160}})));
            Modelica.Blocks.Sources.RealExpression T_in_IPT(y=OTSG.RH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,22},
                      {-240,42}})));
            Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
              annotation (Placement(transformation(extent={{-260,50},{-240,70}})));
            Modelica.Blocks.Sources.RealExpression T_in_HPT(y=OTSG.SH.coldFluid.T[
                  end]) annotation (Placement(transformation(extent={{-260,36},
                      {-240,56}})));

            Modelica.Icons.SignalBus signalBus annotation (Placement(
                  transformation(extent={{-180,0},{-140,40}})));
            Modelica.Blocks.Math.Gain gain(k=1) annotation (Placement(
                  transformation(extent={{-292,-44},{-284,-36}})));
            ComponentEmulator.turbineExtractionCondenserEmulator
              turbineExtractionCondenserEmulator(
              UA=246474.4,
              w_air=181.737,
              cp_air=1020,
              eta_mec=0.98) annotation (Placement(transformation(extent={{-240,
                      100},{-180,160}})));
            Modelica.Blocks.Math.Gain gain1(k=0.01)
                                                annotation (Placement(
                  transformation(extent={{-266,114},{-258,122}})));
            Auxiliaries.Components.StepSequence
                                    T_amb(
              offset=T_amb.T_min,
              T=60000,
              startTime=5000,
              T_min=313.15,
              T_max=318.15)
              annotation (Placement(transformation(extent={{-280,132},{-260,152}})));
            Auxiliaries.Components.ModulatedTrapezoid
                                          modulatedTrapezoid(
              rising=50000,
              width=10000,
              falling=50000,
              period=120000,
              offset=0,
              startTime=10000,
              amplitude=54)
              annotation (Placement(transformation(extent={{-320,-100},{-300,
                      -80}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
              annotation (Placement(transformation(extent={{-360,-80},{-340,-60}})));
            Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
              annotation (Placement(transformation(extent={{-360,-112},{-340,
                      -92}})));
            Modelica.Blocks.Sources.Ramp ramp(
              startTime=5000,
              duration=1000,
              height=0,
              offset=56)     annotation (Placement(transformation(extent={{-360,
                      -40},{-340,-20}})));
            Modelica.Blocks.Math.Add add annotation (Placement(transformation(
                    extent={{-310,-46},{-298,-34}})));
          equation
            connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
                points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));
            connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
                points={{-98,100},{-88.8889,100},{-88.8889,77.8}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5));

            connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
                points={{-197.273,-40},{-197.273,-40},{-125.444,-40}},
                color={255,204,51},
                thickness=0.5));

            connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                    43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                    -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                  color={0,0,255},
                thickness=0.5));
            connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                    -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                    77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
                thickness=0.5));
            connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                    77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
                thickness=0.5));
            connect(DCS.signalBus, WSC.signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,-220},{254.167,-220},{
                    254.167,-112.467}},
                color={255,204,51},
                thickness=0.5));
            connect(DCS.signalBus, signalBus) annotation (Line(
                points={{-197.273,-40},{-160,-40},{-160,20}},
                color={255,204,51},
                thickness=0.5));
            connect(gain.y, DCS.load) annotation (Line(points={{-283.6,-40},{
                    -262.727,-40}}, color={0,0,127}));
            connect(signalBus.pumpMS_PV, turbineExtractionCondenserEmulator.Pm)
              annotation (Line(
                points={{-160,20},{-160,20},{-160,136},{-177,136}},
                color={255,204,51},
                thickness=0.5));
            connect(w_in_HPT.y, turbineExtractionCondenserEmulator.w_SH)
              annotation (Line(points={{-239,60},{-228,60},{-228,80},{-228,97}},
                  color={0,0,127}));
            connect(T_in_HPT.y, turbineExtractionCondenserEmulator.T_SH)
              annotation (Line(points={{-239,46},{-210,46},{-210,97}}, color={0,
                    0,127}));
            connect(T_in_IPT.y, turbineExtractionCondenserEmulator.T_RH)
              annotation (Line(points={{-239,32},{-192,32},{-192,97}}, color={0,
                    0,127}));
            connect(gain1.y, turbineExtractionCondenserEmulator.load)
              annotation (Line(points={{-257.6,118},{-243,118}}, color={0,0,127}));
            connect(gain.y, gain1.u) annotation (Line(points={{-283.6,-40},{
                    -280,-40},{-280,118},{-266.8,118}}, color={0,0,127}));
            connect(T_amb.y, turbineExtractionCondenserEmulator.T_amb)
              annotation (Line(points={{-259,142},{-251.5,142},{-243,142}},
                  color={0,0,127}));
            connect(booleanConstant.y,modulatedTrapezoid. cond1) annotation (Line(
                  points={{-339,-70},{-332,-70},{-332,-84},{-322,-84}},
                                                              color={255,0,255}));
            connect(booleanConstant1.y,modulatedTrapezoid. cond2) annotation (Line(
                  points={{-339,-102},{-332,-102},{-332,-96},{-322,-96}},
                                                                  color={255,0,255}));
            connect(add.y, gain.u) annotation (Line(points={{-297.4,-40},{-296,
                    -40},{-292.8,-40}}, color={0,0,127}));
            connect(ramp.y, add.u1) annotation (Line(points={{-339,-30},{-320,
                    -30},{-320,-36.4},{-311.2,-36.4}}, color={0,0,127}));
            connect(modulatedTrapezoid.y, add.u2) annotation (Line(points={{
                    -299,-90},{-286,-90},{-286,-54},{-320,-54},{-320,-43.6},{
                    -311.2,-43.6}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-360,-240},{360,240}},
                    preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-360,
                      -240},{360,240}}, preserveAspectRatio=false)),
              experiment(
                StopTime=370000,
                __Dymola_NumberOfIntervals=24000,
                __Dymola_Algorithm="Dassl"),
              __Dymola_experimentSetupOutput,
              Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
          end Pilot_staticMaps_highLoad_40_45degC;
        end StaticMaps;
      end Test;

    end Plants;

    package Control "Package containing control schemes of the power plant"

      package Schemes
        "Package containing the control models for the OTSG and power plant"
        package BaseClasses
          "Package containing base classes for control models/schemes"
          partial model BasePlantController
            "Base model of the plant control system"

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{160,-20},{200,20}}),iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={240,0})));
            Modelica.Blocks.Interfaces.RealInput load annotation (Placement(
                  transformation(extent={{-220,-20},{-180,20}}),
                  iconTransformation(extent={{-260,-20},{-220,20}})));
          equation

            connect(signalBus.load, load) annotation (Line(
                points={{180,0},{-10,0},{-200,0}},
                color={255,255,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-220,
                      -300},{220,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-220,-300},{220,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-220,300},{220,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid),
                    Text(
                    extent={{-200,140},{200,-120}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="DCS")}));
          end BasePlantController;

          partial model BasePowerPressureController
            "Base model of the power/pressure/FW control system"

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{300,-60},{340,-20}}),
                                                 iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={422,0})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-350,-20},{-310,20}}),
                  iconTransformation(extent={{-440,-20},{-400,20}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-220,370},{-180,410}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-320,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveSH_RHhigh_bool
              annotation (Placement(transformation(extent={{-220,-190},{-180,-150}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-160,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWlow_bool annotation (
                Placement(transformation(extent={{-220,-50},{-180,-10}}),
                                                                       iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={320,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-220,10},{-180,50}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={160,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveSH_RHlow_bool
              annotation (Placement(transformation(extent={{-220,-310},{-180,-270}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,460})));
          equation

            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -440},{400,440}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-440},{400,440}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="Power-pressure-FW
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-398,438},{402,-440}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end BasePowerPressureController;

          partial model BaseWSCcontroller
            "Base model of the WSC control system"

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{300,-60},{340,-20}}),
                                                 iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={422,0})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-350,-20},{-310,20}}),
                  iconTransformation(extent={{-440,-20},{-400,20}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpCOND_bool annotation (Placement(
                  transformation(extent={{-160,380},{-120,420}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-220,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveRH_DEA_bool
              annotation (Placement(transformation(extent={{-160,240},{-120,280}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveRH_COND_bool
              annotation (Placement(transformation(extent={{-160,100},{-120,140}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={240,460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveDEA_SH_bool annotation (
                Placement(transformation(extent={{-160,-180},{-120,-140}}),
                                                                       iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={0,-460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveDEA_RH_bool annotation (
                Placement(transformation(extent={{-160,-40},{-120,0}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={220,-460})));
            Modelica.Blocks.Interfaces.BooleanInput TS_eletHEAT_bool
              annotation (Placement(transformation(extent={{-160,-320},{-120,
                      -280}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-220,-460})));
          equation

            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -440},{400,440}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-440},{400,440}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="WSC
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,440},{400,-440}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end BaseWSCcontroller;
        end BaseClasses;

        package SingleControllers
          "Package containing the models of the single controllers"

          model control_wMS_high "Model of the mechanical power controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            IndustrialControlSystems.Controllers.PID PID_pumpMS_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpMS_high,
              CSmax=CSmax_pumpMS_high,
              CS_start=CSstart_pumpMS_high,
              Kp=Kp_pumpMS_high,
              Ti=Ti_pumpMS_high,
              Td=Td_pumpMS_high,
              N=Nd_pumpMS_high) annotation (Placement(transformation(extent={{-80,
                      -120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS_high(k=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_high
              annotation (Placement(transformation(extent={{80,-154},{100,-134}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,
                      -68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-200,120},{-160,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Math.Add add_dec annotation (Placement(
                  transformation(extent={{20,-92},{40,-72}})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={32,-20}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={120,-220})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={0,-50})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{-32,-30},{-12,-10}})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{40,-140},{0,-100}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-120,-210})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                  [20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,
                  9.56; 90,10.76; 100,11.95]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.33208e6; 30,0.574166e6; 40,0.832126e6; 50,1.09638e6; 60,
                  1.35348e6; 70,1.54355e6; 80,1.72769e6; 90,1.90308e6; 100,
                  2.08556e6])
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
          equation

            connect(PV, PID_pumpMS_high.PV) annotation (Line(points={{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}},
                                                       color={0,0,127}));
            connect(add_dec.y, add_high.u1) annotation (Line(points={{41,-82},{
                    60,-82},{60,-138},{78,-138}},
                                         color={0,0,127}));
            connect(PID_pumpMS_high.CS, add_dec.u2) annotation (Line(points={{-42,
                    -100},{0,-100},{0,-88},{18,-88}},      color={0,0,127}));
            connect(switch_dec.y, add_dec.u1) annotation (Line(points={{0,-61},
                    {0,-76},{18,-76}},  color={0,0,127}));
            connect(const.y, switch_dec.u1) annotation (Line(points={{-11,-20},
                    {-8,-20},{-8,-38}},color={0,0,127}));
            connect(dec_in, switch_dec.u3) annotation (Line(points={{32,-20},{8,
                    -20},{8,-38}},     color={0,0,127}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},
                    {-160,-88},{-160,40},{-122,40}},  color={0,0,127}));
            connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-180,140},
                    {-90,140},{-90,70},{-82,70}},   color={255,0,255}));
            connect(or1.y, PID_pumpMS_high.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}},       color={255,0,255}));
            connect(or1.y, switch_dec.u2) annotation (Line(points={{-59,70},{0,
                    70},{0,-38}},      color={255,0,255}));
            connect(not1.y, or2.u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},    color={255,0,255}));
            connect(add_dec.y, dec_out) annotation (Line(points={{41,-82},{60,
                    -82},{60,-120},{20,-120}}, color={0,0,127}));
            connect(pumpMS_TS_high.y, PID_pumpMS_high.TR) annotation (Line(
                  points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(add_high.y, switch_ts.u3) annotation (Line(points={{101,
                    -144},{120,-144},{120,-88},{138,-88}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80}},           color={0,0,127}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {40,40},{38,40}}, color={255,0,255}));
            connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-180,140},
                    {-82,140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,
                    -40},{120,-72},{138,-72}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            connect(load, table_w_MS_high.u[1]) annotation (Line(points={{-180,
                    -88},{-160,-88},{-160,-150},{-82,-150}}, color={0,0,127}));
            connect(table_w_MS_high.y[1], add_high.u2) annotation (Line(points=
                    {{-59,-150},{10,-150},{78,-150}}, color={0,0,127}));
            connect(load, table_P_MEC.u[1]) annotation (Line(points={{-180,-88},
                    {-161,-88},{-142,-88}}, color={0,0,127}));
            connect(table_P_MEC.y[1], PID_pumpMS_high.SP) annotation (Line(
                  points={{-119,-88},{-76,-88}},           color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_MS_high

controller")}));
          end control_wMS_high;

          model control_wMS_low "Model of the mechanical power controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpMS_bool annotation (Placement(
                  transformation(extent={{-200,120},{-160,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpMS_low,
              CSmax=CSmax_pumpMS_low,
              CS_start=CSstart_pumpMS_low,
              Kp=Kp_pumpMS_low,
              Ti=Ti_pumpMS_low,
              Td=Td_pumpMS_low,
              N=Nd_pumpMS_low) annotation (Placement(transformation(extent={{-80,
                      -120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS_low(k=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_low annotation (Placement(
                  transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.GreaterThreshold lessThreshold(threshold=load_switch)
              annotation (Placement(transformation(extent={{-120,30},{-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(transformation(
                    extent={{70,-60},{110,-20}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(transformation(
                    extent={{-160,-140},{-120,-100}}),iconTransformation(extent={{-240,
                      -20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(transformation(
                    extent={{180,-100},{220,-60}}), iconTransformation(extent={{200,-10},{
                      220,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS_low(smoothness=
                  Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=
                  [20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,
                  9.56; 90,10.76; 100,11.95]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.33208e6; 30,0.574166e6; 40,0.832126e6; 50,1.09638e6; 60,
                  1.35348e6; 70,1.54355e6; 80,1.72769e6; 90,1.90308e6; 100,
                  2.08556e6])
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
          equation

            connect(lessThreshold.y, or1.u2)
              annotation (Line(points={{-99,40},{-90,40},{-90,62},{-82,62}},
                                                             color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},
                    {-160,-88},{-160,40},{-122,40}},
                                            color={0,0,127}));
            connect(TS_pumpMS_bool, or1.u1) annotation (Line(points={{-180,140},
                    {-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));

            connect(not1.y, or2.u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},
                  color={255,0,255}));
            connect(PV, PID_pumpMS_low.PV) annotation (Line(points={{-140,-120},
                    {-120,-120},{-100,-120},{-100,-102},{-76,-102}},
                                                       color={0,0,127}));
            connect(pumpMS_TS_low.y, PID_pumpMS_low.TR) annotation (Line(points=
                   {{-79,-50},{-72,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(or1.y, PID_pumpMS_low.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}}, color={255,0,255}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80},{200,-80}}, color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,
                    -40},{120,-72},{138,-72}}, color={0,0,127}));
            connect(TS_pumpMS_bool, not1.u) annotation (Line(points={{-180,140},
                    {-82,140},{20,140},{20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {38,40},{38,40}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            connect(add_low.y, switch_ts.u3) annotation (Line(points={{41,-106},
                    {82,-106},{120,-106},{120,-88},{138,-88}}, color={0,0,127}));
            connect(PID_pumpMS_low.CS, add_low.u1) annotation (Line(points={{
                    -42,-100},{18,-100},{18,-100}}, color={0,0,127}));
            connect(load, table_w_MS_low.u[1]) annotation (Line(points={{-180,
                    -88},{-160,-88},{-160,-150},{-82,-150}}, color={0,0,127}));
            connect(table_w_MS_low.y[1], add_low.u2) annotation (Line(points={{
                    -59,-150},{-10,-150},{-10,-112},{18,-112}}, color={0,0,127}));
            connect(table_P_MEC.y[1], PID_pumpMS_low.SP) annotation (Line(
                  points={{-119,-88},{-76,-88},{-76,-88}}, color={0,0,127}));
            connect(load, table_P_MEC.u[1]) annotation (Line(points={{-180,-88},
                    {-142,-88},{-142,-88}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-186,170},{174,-190}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_MS low

controller")}));
          end control_wMS_low;

          model control_Yt_high "Model of the pressure controller at high load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- valveSH_RH_high
            parameter Real Kp_valveSH_RH_high "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_high
              "Controller integral time"                                                  annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real Nd_valveSH_RH_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmin_valveSH_RH_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmax_valveSH_RH_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSstart_valveSH_RH_high "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real TS_valveSH_RH_high "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));

            IndustrialControlSystems.Controllers.PI PID_valveSH_RH_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveSH_RH_high,
              CSmax=CSmax_valveSH_RH_high,
              CS_start=CSstart_valveSH_RH_high,
              Kp=Kp_valveSH_RH_high,
              Ti=Ti_valveSH_RH_high)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant valveSH_RH_TS_high(k=TS_valveSH_RH_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_high
              annotation (Placement(transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveSH_RHhigh_bool
              annotation (Placement(transformation(extent={{-200,120},{-160,160}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},{-100,
                      50}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
                  40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
                  100,171e5])
              annotation (Placement(transformation(extent={{-80,-200},{-60,-180}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,
                  0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,
                  1.436; 90,1.605; 100,1.757]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Math.Division division1 annotation (Placement(
                  transformation(extent={{-40,-180},{-20,-160}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_SH(
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
          equation
            connect(valveSH_RH_TS_high.y, PID_valveSH_RH_high.TR)
              annotation (Line(points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(PID_valveSH_RH_high.CS, add_high.u1) annotation (Line(points={{-42,-100},
                    {18,-100}},                     color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,-40},{120,-72},
                    {138,-72}}, color={0,0,127}));
            connect(switch_ts.y, CS)
              annotation (Line(points={{161,-80},{200,-80}}, color={0,0,127}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,40},{-122,40}}, color={0,0,127}));
            connect(lessThreshold.y, or2.u2)
              annotation (Line(points={{-99,40},{-30,40},{38,40}}, color={255,0,255}));
            connect(TS_valveSH_RHhigh_bool, not1.u) annotation (Line(points={{-180,140},{-80,
                    140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS_valveSH_RHhigh_bool, or1.u1) annotation (Line(points={{-180,140},{-90,
                    140},{-90,70},{-82,70}}, color={255,0,255}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},{-90,40},{-90,
                    62},{-82,62}}, color={255,0,255}));
            connect(not1.y, or2.u1)
              annotation (Line(points={{20,99},{20,48},{38,48}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{70,48},{80,48},
                    {80,-80},{138,-80}}, color={255,0,255}));
            connect(or1.y, PID_valveSH_RH_high.TS)
              annotation (Line(points={{-59,70},{-52,70},{-52,-84}}, color={255,0,255}));
            connect(add_high.y, switch_ts.u3) annotation (Line(points={{41,-106},{120,-106},
                    {120,-88},{138,-88}}, color={0,0,127}));
            connect(PV, PID_valveSH_RH_high.PV) annotation (Line(points={{-140,-120},{-100,
                    -120},{-100,-102},{-76,-102}}, color={0,0,127}));
            connect(valveSH_RH_sourceP.y[1],division1. u2) annotation (Line(
                  points={{-59,-190},{-51,-190},{-51,-176},{-42,-176}},
                                                                    color={0,0,
                    127}));
            connect(valveSH_RH_sourceW.y[1],division1. u1) annotation (Line(
                  points={{-59,-150},{-51,-150},{-51,-164},{-42,-164}},
                                                                    color={0,0,
                    127}));
            connect(load, table_P_SH.u[1]) annotation (Line(points={{-180,-88},
                    {-142,-88}}, color={0,0,127}));
            connect(table_P_SH.y[1], PID_valveSH_RH_high.SP) annotation (Line(
                  points={{-119,-88},{-76,-88}}, color={0,0,127}));
            connect(division1.y, add_high.u2) annotation (Line(points={{-19,
                    -170},{0,-170},{0,-112},{18,-112}}, color={0,0,127}));
            connect(load, valveSH_RH_sourceW.u[1]) annotation (Line(points={{
                    -180,-88},{-170,-88},{-160,-88},{-160,-170},{-100,-170},{
                    -100,-150},{-82,-150}}, color={0,0,127}));
            connect(load, valveSH_RH_sourceP.u[1]) annotation (Line(points={{
                    -180,-88},{-160,-88},{-160,-170},{-100,-170},{-100,-190},{
                    -82,-190}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,182},{180,-178}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="p_eva_high

controller")}));
          end control_Yt_high;

          model control_Yt_low "Model of the pressure controller for low load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- valveSH_RH_low
            parameter Real Kp_valveSH_RH_low "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_low
              "Controller integral time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real Nd_valveSH_RH_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmin_valveSH_RH_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmax_valveSH_RH_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSstart_valveSH_RH_low "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real TS_valveSH_RH_low "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-108},{-160,-68}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            IndustrialControlSystems.Controllers.PI PID_valveSH_RH_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_valveSH_RH_low,
              CSmax=CSmax_valveSH_RH_low,
              CS_start=CSstart_valveSH_RH_low,
              Kp=Kp_valveSH_RH_low,
              Ti=Ti_valveSH_RH_low)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant valveSH_RH_TS_low(k=TS_valveSH_RH_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Add add_low
              annotation (Placement(transformation(extent={{20,-116},{40,-96}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveSH_RHlow_bool
              annotation (Placement(transformation(extent={{-200,120},{-160,160}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Logical.GreaterThreshold
                                                  lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},{-100,
                      50}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={90,-40}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-140},{-120,-100}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_SH(
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,-98},{-120,-78}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
                  40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
                  100,171e5])
              annotation (Placement(transformation(extent={{-80,-200},{-60,-180}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,
                  0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,
                  1.436; 90,1.605; 100,1.757]) annotation (Placement(
                  transformation(extent={{-80,-160},{-60,-140}})));
            Modelica.Blocks.Math.Division division1 annotation (Placement(
                  transformation(extent={{-40,-180},{-20,-160}})));
          equation
            connect(valveSH_RH_TS_low.y, PID_valveSH_RH_low.TR)
              annotation (Line(points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(PID_valveSH_RH_low.CS, add_low.u1) annotation (Line(points={{-42,-100},
                    {18,-100}},                      color={0,0,127}));
            connect(lessThreshold.y, or1.u2) annotation (Line(points={{-99,40},{-90,40},{-90,
                    62},{-82,62}}, color={255,0,255}));
            connect(not1.y, or2.u1)
              annotation (Line(points={{20,99},{20,48},{38,48}}, color={255,0,255}));
            connect(TS_valveSH_RHlow_bool, not1.u) annotation (Line(points={{-180,140},{-80,
                    140},{20,140},{20,122}}, color={255,0,255}));
            connect(TS_valveSH_RHlow_bool, or1.u1) annotation (Line(points={{-180,140},{-136,
                    140},{-90,140},{-90,70},{-82,70}}, color={255,0,255}));
            connect(or1.y, PID_valveSH_RH_low.TS)
              annotation (Line(points={{-59,70},{-52,70},{-52,-84}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2)
              annotation (Line(points={{-99,40},{38,40},{38,40}}, color={255,0,255}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{72,48},{80,48},
                    {80,-80},{138,-80}}, color={255,0,255}));
            connect(TS, switch_ts.u1) annotation (Line(points={{90,-40},{120,-40},{120,-72},
                    {138,-72}}, color={0,0,127}));
            connect(add_low.y, switch_ts.u3) annotation (Line(points={{41,-106},{80,-106},
                    {120,-106},{120,-88},{138,-88}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{180,-80},{180,-80},
                    {200,-80}}, color={0,0,127}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-88},{-160,-88},
                    {-160,40},{-122,40}}, color={0,0,127}));
            connect(PV, PID_valveSH_RH_low.PV) annotation (Line(points={{-140,-120},{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}}, color={0,0,127}));
            connect(valveSH_RH_sourceP.y[1],division1. u2) annotation (Line(
                  points={{-59,-190},{-51,-190},{-51,-176},{-42,-176}},
                                                                    color={0,0,
                    127}));
            connect(valveSH_RH_sourceW.y[1],division1. u1) annotation (Line(
                  points={{-59,-150},{-51,-150},{-51,-164},{-42,-164}},
                                                                    color={0,0,
                    127}));
            connect(load, valveSH_RH_sourceP.u[1]) annotation (Line(points={{
                    -180,-88},{-160,-88},{-160,-170},{-100,-170},{-100,-190},{
                    -82,-190}}, color={0,0,127}));
            connect(load, valveSH_RH_sourceW.u[1]) annotation (Line(points={{
                    -180,-88},{-160,-88},{-160,-170},{-100,-170},{-100,-150},{
                    -82,-150}}, color={0,0,127}));
            connect(division1.y, add_low.u2) annotation (Line(points={{-19,-170},
                    {0,-170},{0,-112},{18,-112}}, color={0,0,127}));
            connect(load, table_P_SH.u[1]) annotation (Line(points={{-180,-88},
                    {-161,-88},{-142,-88}}, color={0,0,127}));
            connect(table_P_SH.y[1], PID_valveSH_RH_low.SP) annotation (Line(
                  points={{-119,-88},{-76,-88}},           color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="p_eva_low

controller")}));
          end control_Yt_low;

          model control_wFW_high_PI
            "Model of the w_FW control for high load with PI controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW_high(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_high,
              CSmax=CSmax_pumpFW_high,
              CS_start=CSstart_pumpFW_high,
              Kp=Kp_pumpFW_high,
              Ti=Ti_pumpFW_high)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{70,-120},{90,-100}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{108,-154},{128,-134}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={0,-50})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{-32,-30},{-12,-10}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={50,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={20,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={32,-20}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{84,-60},{124,-20}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{40,-140},{0,-100}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{20,-92},{40,-72}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-160,-142},{-120,-102}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-140,-96},{-120,-76}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  0.53; 30,0.8; 40,1.09; 50,1.37; 60,1.66; 70,1.91; 80,2.16; 90,
                  2.42; 100,2.69]) annotation (Placement(transformation(extent=
                      {{-80,-160},{-60,-140}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{91,-110},{91,
                    -110},{90,-110},{100,-110},{100,-138},{106,-138}},
                                          color={0,0,127}));

            connect(const.y,switch_dec. u1) annotation (Line(points={{-11,-20},
                    {-8,-20},{-8,-38}},color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{32,-20},{8,
                    -20},{8,-38}},     color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{0,
                    70},{0,-38}},      color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{20,99},{20,48},{
                    38,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(PID_pumpFW_high.CS, add_dec_FW.u2)
              annotation (Line(points={{-42,-100},{0,-100},{0,-88},{18,-88}},
                                                                    color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{
                    -2.22045e-015,-61},{0,-61},{0,-76},{18,-76}},
                                                 color={0,0,127}));
            connect(or1.y, PID_pumpFW_high.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}},
                                color={255,0,255}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{41,-82},{50,-82},{50,-104},{68,-104}},
                                                                    color={0,0,127}));
            connect(PV, PID_pumpFW_high.PV) annotation (Line(points={{-140,-122},
                    {-100,-122},{-100,-102},{-76,-102}},
                                            color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(pumpFW_TS_high.y, PID_pumpFW_high.TR) annotation (Line(
                  points={{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{41,-82},{
                    40,-82},{50,-82},{50,-104},{50,-120},{20,-120}}, color={0,0,
                    127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{174,
                    -80},{174,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{129,-144},{
                    132,-144},{132,-88},{138,-88}}, color={0,0,127}));
            connect(TS, switch_ts.u1) annotation (Line(points={{104,-40},{132,
                    -40},{132,-72},{138,-72}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{61,48},{80,
                    48},{80,-80},{138,-80}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-80,140},{20,140},{20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-30,40},{38,40}}, color={255,0,255}));
            connect(table_DT_sh_sp.y[1], PID_pumpFW_high.SP) annotation (Line(
                  points={{-119,-86},{-100,-86},{-100,-88},{-76,-88}}, color={0,
                    0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-161,-86},{-142,-86}}, color={0,0,127}));
            connect(table_w_FW_high.y[1], add.u2) annotation (Line(points={{-59,
                    -150},{106,-150}}, color={0,0,127}));
            connect(table_w_FW_high.y[1], product.u2) annotation (Line(points={
                    {-59,-150},{0,-150},{60,-150},{60,-116},{68,-116}}, color={
                    0,0,127}));
            connect(load, table_w_FW_high.u[1]) annotation (Line(points={{-180,
                    -86},{-160,-86},{-160,-150},{-82,-150}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_PI;

          model control_wFW_high_4th
            "Model of the w_FW controller for high load with 4th order controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-10,-40},{10,-20}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{88,-130},{108,-110}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{120,-150},{140,-130}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-150,-70},{-130,-50}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={40,-10})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,10},{28,30}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={160,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={80,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={60,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={72,20}),  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{100,-70},{140,-30}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{60,-100},{20,-60}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{52,-50},{72,-30}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-170,-152},{-130,-112}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
              annotation (Placement(transformation(extent={{-110,-120},{-90,
                      -100}})));
            Modelica.Blocks.Continuous.StateSpace controller4th_pumpFW_high(
              A=A,
              B=B,
              C=C,
              D=D)
              annotation (Placement(transformation(extent={{-56,-120},{-16,-80}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
                uMin=CSmin_pumpFW_high)
              annotation (Placement(transformation(extent={{-6,-110},{14,-90}})));
            Modelica.Blocks.Logical.Switch switch_TS
              annotation (Placement(transformation(extent={{28,-52},{40,-40}})));
            Modelica.Blocks.Logical.Switch switch_err annotation (Placement(
                  transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=0,
                  origin={-76,-80})));
            Modelica.Blocks.Sources.Constant const1(
                                                   k=0)
              annotation (Placement(transformation(extent={{-110,-60},{-90,-40}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-150,-114},{-130,
                      -94}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  0.53; 30,0.8; 40,1.09; 50,1.37; 60,1.66; 70,1.91; 80,2.16; 90,
                  2.42; 100,2.69]) annotation (Placement(transformation(extent=
                      {{-60,-156},{-40,-136}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{109,-120},{109,
                    -120},{104,-120},{114,-120},{114,-134},{118,-134}},
                                          color={0,0,127}));

            connect(const.y,switch_dec. u1) annotation (Line(points={{29,20},{
                    32,20},{32,2}},    color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{72,20},{48,
                    20},{48,2}},       color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{40,
                    70},{40,2}},       color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{60,99},{60,48},{
                    68,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{40,-21},
                    {40,-21},{40,-34},{50,-34}}, color={0,0,127}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{73,-40},{80,-40},{80,-114},{86,-114}},
                                                                    color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(PV, DT_sh_error.u2) annotation (Line(points={{-150,-132},{
                    -120,-132},{-120,-116},{-112,-116}},
                                             color={0,0,127}));
            connect(controller4th_pumpFW_high.y[1], pumpFW_lim_adim.u)
              annotation (Line(points={{-14,-100},{-14,-100},{-8,-100}},
                                                                      color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{73,-40},{
                    80,-40},{80,-80},{40,-80}},
                                     color={0,0,127}));
            connect(switch_TS.y, add_dec_FW.u2)
              annotation (Line(points={{40.6,-46},{50,-46},{50,-46}}, color={0,0,127}));
            connect(pumpFW_lim_adim.y, switch_TS.u3) annotation (Line(points={{15,-100},
                    {20,-100},{20,-50.8},{26.8,-50.8}},
                                                   color={0,0,127}));
            connect(or1.y, switch_TS.u2) annotation (Line(points={{-59,70},{-40,
                    70},{-40,-46},{26.8,-46}},
                                 color={255,0,255}));
            connect(pumpFW_TS_high.y, switch_TS.u1) annotation (Line(points={{
                    11,-30},{20,-30},{20,-41.2},{26.8,-41.2}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{171,-80},{175.5,
                    -80},{175.5,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{141,-140},{
                    144,-140},{144,-88},{148,-88}}, color={0,0,127}));
            connect(switch_ts.u1, TS) annotation (Line(points={{148,-72},{148,
                    -72},{146,-72},{146,-72},{144,-72},{144,-50},{120,-50},{120,
                    -50}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{91,48},{100,
                    48},{100,-80},{148,-80}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-15.5,40},{68,40}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-60,140},{60,140},{60,122}}, color={255,0,255}));
            connect(DT_sh_error.y, switch_err.u3) annotation (Line(points={{-89,
                    -110},{-84,-110},{-84,-83.2},{-80.8,-83.2}}, color={0,0,127}));
            connect(const1.y, switch_err.u1) annotation (Line(points={{-89,-50},
                    {-84,-50},{-84,-76.8},{-80.8,-76.8}}, color={0,0,127}));
            connect(lessThreshold.y, switch_err.u2) annotation (Line(points={{
                    -99,40},{-90,40},{-90,0},{-120,0},{-120,-80},{-80.8,-80}},
                  color={255,0,255}));
            connect(switch_err.y, controller4th_pumpFW_high.u[1]) annotation (
                Line(points={{-71.6,-80},{-68,-80},{-68,-100},{-60,-100}},
                  color={0,0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-166,-86},{-160,-86},{-160,-104},{-152,-104}}, color=
                    {0,0,127}));
            connect(table_DT_sh_sp.y[1], DT_sh_error.u1) annotation (Line(
                  points={{-129,-104},{-120,-104},{-112,-104}}, color={0,0,127}));
            connect(table_w_FW_high.y[1], add.u2) annotation (Line(points={{-39,
                    -146},{80,-146},{118,-146}}, color={0,0,127}));
            connect(load, table_w_FW_high.u[1]) annotation (Line(points={{-180,
                    -86},{-160,-86},{-160,-146},{-62,-146}}, color={0,0,127}));
            connect(table_w_FW_high.y[1], product.u2) annotation (Line(points={
                    {-39,-146},{80,-146},{80,-126},{86,-126}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_4th;

          model control_wFW_high_10th
            "Model of the w_FW controller for high load with 10th order controller"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,120},{-200,160}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_high(k=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-10,-40},{10,-20}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{88,-130},{108,-110}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{120,-150},{140,-130}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWhigh_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                    iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Sources.Constant DT_sh_SP(k=DT_sh_sp)
              annotation (Placement(transformation(extent={{-150,-80},{-130,-60}})));
            Modelica.Blocks.Logical.Switch switch_dec annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=270,
                  origin={40,-10})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,10},{28,30}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold=
                  load_switch) annotation (Placement(transformation(extent={{-120,30},
                      {-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={160,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={80,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={60,110})));
            Modelica.Blocks.Interfaces.RealInput dec_in annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={72,20}),  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={-120,-220})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(
                  transformation(extent={{100,-70},{140,-30}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Interfaces.RealOutput dec_out annotation (Placement(
                  transformation(extent={{60,-100},{20,-60}}),
                  iconTransformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={120,-210})));
            Modelica.Blocks.Math.Add add_dec_FW
              annotation (Placement(transformation(extent={{52,-50},{72,-30}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(
                  transformation(extent={{180,-100},{220,-60}}),
                  iconTransformation(extent={{200,-10},{220,10}})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(
                  transformation(extent={{-170,-152},{-130,-112}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add DT_sh_error(k2=-1)
              annotation (Placement(transformation(extent={{-110,-120},{-90,-100}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim_adim(uMax=CSmax_pumpFW_high,
                uMin=CSmin_pumpFW_high)
              annotation (Placement(transformation(extent={{-6,-110},{14,-90}})));
            Modelica.Blocks.Logical.Switch switch_TS
              annotation (Placement(transformation(extent={{28,-52},{40,-40}})));
            Modelica.Blocks.Logical.Switch switch_err annotation (Placement(
                  transformation(
                  extent={{-4,-4},{4,4}},
                  rotation=0,
                  origin={-76,-80})));
            Modelica.Blocks.Sources.Constant const1(
                                                   k=0)
              annotation (Placement(transformation(extent={{-110,-60},{-90,-40}})));
            Modelica.Blocks.Continuous.StateSpace controller10th_pumpFW_high(
              A=A,
              B=B,
              C=C,
              D=D)
              annotation (Placement(transformation(extent={{-56,-120},{-16,-80}})));
            Modelica.Blocks.Tables.CombiTable1D table_DT_sh_sp(
                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,273.15; 30,273.15; 40,273.15; 50,273.15; 55,273.15; 60,
                  DT_sh_sp; 70,DT_sh_sp; 80,DT_sh_sp; 90,DT_sh_sp; 100,DT_sh_sp])
              annotation (Placement(transformation(extent={{-150,-112},{-130,
                      -92}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW_high(smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments, table=[20,
                  0.53; 30,0.8; 40,1.09; 50,1.37; 60,1.66; 70,1.91; 80,2.16; 90,
                  2.42; 100,2.69]) annotation (Placement(transformation(extent=
                      {{-60,-156},{-40,-136}})));
          equation
            connect(product.y, add.u1) annotation (Line(points={{109,-120},{109,-120},{104,
                    -120},{114,-120},{114,-134},{118,-134}},
                                          color={0,0,127}));

            connect(const.y,switch_dec. u1) annotation (Line(points={{29,20},{
                    32,20},{32,2}},    color={0,0,127}));
            connect(dec_in,switch_dec. u3) annotation (Line(points={{72,20},{48,
                    20},{48,2}},       color={0,0,127}));
            connect(lessThreshold.y,or1. u2) annotation (Line(points={{-99,40},
                    {-90,40},{-90,62},{-82,62}},
                                color={255,0,255}));
            connect(or1.y,switch_dec. u2) annotation (Line(points={{-59,70},{40,
                    70},{40,2}},       color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{60,99},{60,48},{
                    68,48}},    color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}},
                                           color={0,0,127}));
            connect(switch_dec.y, add_dec_FW.u1) annotation (Line(points={{40,-21},
                    {40,-21},{40,-34},{50,-34}}, color={0,0,127}));
            connect(add_dec_FW.y, product.u1)
              annotation (Line(points={{73,-40},{80,-40},{80,-114},{86,-114}},
                                                                    color={0,0,127}));
            connect(TS_pumpFWhigh_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-90,140},{-90,70},{-82,70}},
                                          color={255,0,255}));
            connect(PV, DT_sh_error.u2) annotation (Line(points={{-150,-132},{-120,-132},{
                    -120,-116},{-112,-116}}, color={0,0,127}));
            connect(add_dec_FW.y, dec_out) annotation (Line(points={{73,-40},{
                    80,-40},{80,-80},{40,-80}},
                                     color={0,0,127}));
            connect(switch_TS.y, add_dec_FW.u2)
              annotation (Line(points={{40.6,-46},{50,-46},{50,-46}}, color={0,0,127}));
            connect(pumpFW_lim_adim.y, switch_TS.u3) annotation (Line(points={{15,-100},{20,
                    -100},{20,-50.8},{26.8,-50.8}},color={0,0,127}));
            connect(or1.y, switch_TS.u2) annotation (Line(points={{-59,70},{-40,
                    70},{-40,-46},{26.8,-46}},
                                 color={255,0,255}));
            connect(pumpFW_TS_high.y, switch_TS.u1) annotation (Line(points={{
                    11,-30},{20,-30},{20,-41.2},{26.8,-41.2}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{171,-80},{175.5,
                    -80},{175.5,-80},{200,-80}}, color={0,0,127}));
            connect(add.y, switch_ts.u3) annotation (Line(points={{141,-140},{144,-140},{144,
                    -88},{148,-88}},                color={0,0,127}));
            connect(switch_ts.u1, TS) annotation (Line(points={{148,-72},{148,
                    -72},{146,-72},{146,-72},{144,-72},{144,-50},{120,-50},{120,
                    -50}}, color={0,0,127}));
            connect(or2.y, switch_ts.u2) annotation (Line(points={{91,48},{100,
                    48},{100,-80},{148,-80}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-15.5,40},{68,40}}, color={255,0,255}));
            connect(TS_pumpFWhigh_bool, not1.u) annotation (Line(points={{-180,
                    140},{-60,140},{60,140},{60,122}}, color={255,0,255}));
            connect(DT_sh_error.y, switch_err.u3) annotation (Line(points={{-89,-110},{-84,
                    -110},{-84,-83.2},{-80.8,-83.2}}, color={0,0,127}));
            connect(const1.y, switch_err.u1) annotation (Line(points={{-89,-50},{-84,-50},
                    {-84,-76.8},{-80.8,-76.8}}, color={0,0,127}));
            connect(lessThreshold.y, switch_err.u2) annotation (Line(points={{-99,40},{-90,
                    40},{-90,0},{-120,0},{-120,-80},{-80.8,-80}}, color={255,0,255}));
            connect(pumpFW_lim_adim.u, controller10th_pumpFW_high.y[1]) annotation (Line(
                  points={{-8,-100},{-12,-100},{-14,-100}}, color={0,0,127}));
            connect(switch_err.y, controller10th_pumpFW_high.u[1]) annotation (Line(
                  points={{-71.6,-80},{-68,-80},{-68,-100},{-60,-100}}, color={0,0,127}));
            connect(table_DT_sh_sp.y[1], DT_sh_error.u1) annotation (Line(
                  points={{-129,-102},{-124,-102},{-120,-102},{-120,-104},{-112,
                    -104}}, color={0,0,127}));
            connect(load, table_DT_sh_sp.u[1]) annotation (Line(points={{-180,
                    -86},{-160,-86},{-160,-102},{-152,-102}}, color={0,0,127}));
            connect(load, table_w_FW_high.u[1]) annotation (Line(points={{-180,
                    -86},{-160,-86},{-160,-146},{-62,-146}}, color={0,0,127}));
            connect(table_w_FW_high.y[1], add.u2) annotation (Line(points={{-39,
                    -146},{40,-146},{118,-146}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_high

controller")}));
          end control_wFW_high_10th;

          model control_wFW_low "Model of the w_FW for low load"

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-106},{-160,-66}}),
                  iconTransformation(extent={{-240,100},{-200,140}})));
            Modelica.Blocks.Sources.Constant l_SP(k=l_sp)
              annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW_low(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpFW_low,
              CSmax=CSmax_pumpFW_low,
              CS_start=CSstart_pumpFW_low,
              Kp=Kp_pumpFW_low,
              Ti=Ti_pumpFW_low)
              annotation (Placement(transformation(extent={{-80,-120},{-40,-80}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS_low(
                                                       k=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpFWlow_bool annotation (
                Placement(transformation(extent={{-200,120},{-160,160}}),
                                                                       iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={-100,220})));
            Modelica.Blocks.Interfaces.RealInput PV annotation (Placement(transformation(
                    extent={{-160,-140},{-120,-100}}),iconTransformation(extent={{-240,
                      -20},{-200,20}})));
            Modelica.Blocks.Interfaces.RealOutput CS annotation (Placement(transformation(
                    extent={{180,-100},{220,-60}}), iconTransformation(extent={{200,-10},{
                      220,10}})));
            Modelica.Blocks.Logical.Or or1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,70})));
            Modelica.Blocks.Logical.GreaterThreshold lessThreshold(threshold=load_switch)
              annotation (Placement(transformation(extent={{-120,30},{-100,50}})));
            Modelica.Blocks.Logical.Switch switch_ts annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={150,-80})));
            Modelica.Blocks.Logical.And or2 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={10,48})));
            Modelica.Blocks.Logical.Not not1 annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=270,
                  origin={-20,110})));
            Modelica.Blocks.Interfaces.RealInput TS annotation (Placement(transformation(
                    extent={{60,-50},{100,-10}}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={100,220})));
            Modelica.Blocks.Tables.CombiTable1D table_l_sp(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,l_sp; 30,l_sp; 40,l_sp; 50,l_sp; 55,1; 60,0; 70,0; 80,0;
                  90,0; 100,0])
                             annotation (Placement(transformation(extent={{-140,
                      -98},{-120,-78}})));
          equation

            connect(lessThreshold.y,or1. u2)
              annotation (Line(points={{-99,40},{-90,40},{-90,62},{-82,62}},
                                                             color={255,0,255}));
            connect(or2.y,switch_ts. u2) annotation (Line(points={{21,48},{40,
                    48},{40,-80},{58,-80},{58,-80},{138,-80},{138,-80}},
                          color={255,0,255}));
            connect(not1.y,or2. u1) annotation (Line(points={{-20,99},{-20,48},
                    {-2,48}},
                  color={255,0,255}));
            connect(TS,switch_ts. u1) annotation (Line(points={{80,-30},{120,
                    -30},{120,-72},{138,-72}},
                               color={0,0,127}));
            connect(PV, PID_pumpFW_low.PV) annotation (Line(points={{-140,-120},
                    {-100,-120},{-100,-102},{-76,-102}}, color={0,0,127}));
            connect(TS_pumpFWlow_bool, or1.u1) annotation (Line(points={{-180,
                    140},{-180,140},{-90,140},{-90,70},{-82,70}}, color={255,0,
                    255}));
            connect(or1.y, PID_pumpFW_low.TS) annotation (Line(points={{-59,70},
                    {-52,70},{-52,-84}}, color={255,0,255}));
            connect(load, lessThreshold.u) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,40},{-122,40}}, color={0,0,127}));
            connect(pumpFW_TS_low.y, PID_pumpFW_low.TR) annotation (Line(points=
                   {{-79,-50},{-60,-50},{-60,-84}}, color={0,0,127}));
            connect(switch_ts.y, CS) annotation (Line(points={{161,-80},{200,
                    -80},{200,-80}}, color={0,0,127}));
            connect(TS_pumpFWlow_bool, not1.u) annotation (Line(points={{-180,
                    140},{-20,140},{-20,122}}, color={255,0,255}));
            connect(lessThreshold.y, or2.u2) annotation (Line(points={{-99,40},
                    {-50.5,40},{-2,40}}, color={255,0,255}));
            connect(table_l_sp.y[1], PID_pumpFW_low.SP) annotation (Line(points=
                   {{-119,-88},{-76,-88}}, color={0,0,127}));
            connect(load, table_l_sp.u[1]) annotation (Line(points={{-180,-86},
                    {-160,-86},{-160,-88},{-142,-88}}, color={0,0,127}));
            connect(PID_pumpFW_low.CS, switch_ts.u3) annotation (Line(points={{
                    -42,-100},{40,-100},{120,-100},{120,-88},{138,-88}}, color=
                    {0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_FW_low

controller")}));
          end control_wFW_low;

          model control_wHPH "Model of the w_HPH controller"

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-20},{120,20}})));
            FullScale_245degC.Graphics.Label_output pumpHPH_CS
              annotation (Placement(transformation(extent={{140,-6},{178,6}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(         uMin=0, uMax=
                  0.55)
              annotation (Placement(transformation(extent={{-20,-10},{0,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[5,
                  0.002; 20,0.02; 30,0.02; 40,0.02; 50,0.02; 60,0.02; 70,0.02;
                  80,0.02; 90,0.1245; 100,0.4717])
                                                annotation (Placement(
                  transformation(extent={{-80,-10},{-60,10}})));
          equation
            connect(signalBus.pumpHPH_CS,pumpHPH_dynamic. y) annotation (Line(
                points={{140,-60},{140,-38},{142,-38},{142,-16},{122,-16},{122,
                    0}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpHPH_lim.y, pumpHPH_dynamic.u) annotation (Line(points={
                    {1,0},{38.5,0},{76,0}}, color={0,0,127}));
            connect(load, table_w_HPH.u[1]) annotation (Line(points={{-180,0},{
                    -131,0},{-82,0}}, color={0,0,127}));
            connect(table_w_HPH.y[1], pumpHPH_lim.u) annotation (Line(points={{
                    -59,0},{-40.5,0},{-22,0}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_HPH

controller")}));
          end control_wHPH;

          model control_wCOND "Model of the w_COND controller"

            //-- pumpCOND --
            parameter Modelica.SIunits.Length l_dea_sp
              "Deaerator level set point"                                          annotation (Dialog(tab="pumpCOND"));
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-20}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder pumpCOND_dynamic(
              k=actuatorGain_pumpCOND,
              T=Ta_pumpCOND,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,20},{140,60}})));
            IndustrialControlSystems.Controllers.PI PI_pumpCOND(
              AntiWindup=true,
              CSmin=CSmin_pumpCOND,
              CSmax=CSmax_pumpCOND,
              CS_start=CSstart_pumpCOND,
              Kp=Kp_pumpCOND,
              Ti=Ti_pumpCOND,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant pumpCOND_TS(k=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpCOND_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input pumpCOND_PV
              annotation (Placement(transformation(extent={{-140,44},{-98,32}})));
            FullScale_245degC.Graphics.Label_output pumpCOND_CS
              annotation (Placement(transformation(extent={{162,34},{204,46}})));
            Modelica.Blocks.Nonlinear.Limiter pumpCOND_lim(        uMin=0, uMax=3)
              annotation (Placement(transformation(extent={{20,30},{40,50}})));
            Modelica.Blocks.Sources.Constant l_DEA_SP(k=l_dea_sp)
              annotation (Placement(transformation(extent={{-180,42},{-160,62}})));
          equation
            connect(TS_pumpCOND_bool, PI_pumpCOND.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(pumpCOND_TS.y, PI_pumpCOND.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.pumpCOND_CS, pumpCOND_dynamic.y) annotation (Line(
                points={{140,-20},{156,-20},{156,18},{142,18},{142,40}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpCOND_PV, PI_pumpCOND.PV) annotation (Line(
                points={{140,-20},{178,-20},{178,-134},{-84,-134},{-84,36},{-78,36},{-78,38},
                    {-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(pumpCOND_lim.y, pumpCOND_dynamic.u) annotation (Line(points={{41,40},{
                    41,40},{96,40}},          color={0,0,127}));
            connect(PI_pumpCOND.CS, pumpCOND_lim.u)
              annotation (Line(points={{-42,40},{18,40}}, color={0,0,127}));
            connect(l_DEA_SP.y, PI_pumpCOND.SP)
              annotation (Line(points={{-159,52},{-76,52}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_COND

controller")}));
          end control_wCOND;

          model control_eletHEAT "Model of the electric heaters controller"

            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration";

            //-- eletHEAT --
            parameter Real Kp_eletHEAT "Controller proportional gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ti_eletHEAT
              "Controller integral time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Td_eletHEAT
              "Controller derivative time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real Nd_eletHEAT
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmin_eletHEAT
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmax_eletHEAT
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="eletHEAT"));
            parameter Real CSstart_eletHEAT "Start value of CS" annotation (Dialog(tab="eletHEAT"));
            parameter Real actuatorGain_eletHEAT "Actuator gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ta_eletHEAT
              "Actuator time constant"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real TS_eletHEAT "Tracking signal" annotation (Dialog(tab="eletHEAT"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-30},{-160,10}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={144,-70}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder eletHEAT_dynamic(
              k=actuatorGain_eletHEAT,
              T=Ta_eletHEAT,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{104,-30},{144,10}})));
            IndustrialControlSystems.Controllers.PI PI_eletHEAT(
              AntiWindup=true,
              CSmin=CSmin_eletHEAT,
              CSmax=CSmax_eletHEAT,
              CS_start=CSstart_eletHEAT,
              Kp=Kp_eletHEAT,
              Ti=Ti_eletHEAT,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant eletHEAT_TS(k=TS_eletHEAT)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_eletHEAT_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input eletHEAT_PV
              annotation (Placement(transformation(extent={{-140,44},{-98,32}})));
            FullScale_245degC.Graphics.Label_output eletHEAT_CS
              annotation (Placement(transformation(extent={{166,-16},{208,-4}})));
            Modelica.Blocks.Nonlinear.Limiter eletHEAT_lim(        uMin=0, uMax=2e5)
              annotation (Placement(transformation(extent={{70,-20},{90,0}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(                                              table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,518.15; 70,
                  518.15; 80,518.15; 90,518.15; 100,518.15], smoothness=
                  Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW1(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,479.15; 30,497.45; 40,510.65; 50,521.35; 60,521.35; 70,521.35; 80,521.35;
                  90,521.35; 100,521.35])
              annotation (Placement(transformation(extent={{-140,-60},{-120,-40}})));
            Modelica.Blocks.Math.Add add(k2=-1) annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,-64})));
            Modelica.Blocks.Math.Gain gain(k=4186)
              annotation (Placement(transformation(extent={{0,-90},{20,-70}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{-38,-100},{-18,-80}})));
            Modelica.Blocks.Logical.LessEqualThreshold    greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-120,-20},{-100,0}})));
            Modelica.Blocks.Logical.Switch switch_eletHEAT
              annotation (Placement(transformation(extent={{40,0},{60,-20}})));
            Modelica.Blocks.Tables.CombiTable1D table_Q_EH(table=[20,91e3; 30,
                  76e3; 40,100e3; 50,124e3; 60,141e3; 70,86e3; 80,94e3; 90,72e3;
                  100,0], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{0,-140},{20,-120}})));
          equation
            connect(TS_eletHEAT_bool, PI_eletHEAT.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(eletHEAT_TS.y, PI_eletHEAT.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.eletHEAT_CS, eletHEAT_dynamic.y) annotation (Line(
                points={{144,-70},{160,-70},{160,-32},{146,-32},{146,-10}},
                color={256,256,256},
                thickness=0.5));

            connect(eletHEAT_lim.y, eletHEAT_dynamic.u) annotation (Line(points={{91,-10},
                    {100,-10}},               color={0,0,127}));
            connect(table_T_FW.y[1], PI_eletHEAT.SP) annotation (Line(points={{-119,60},{-100,
                    60},{-100,52},{-76,52}}, color={0,0,127}));
            connect(load, table_T_FW.u[1]) annotation (Line(points={{-180,-10},{-160,-10},
                    {-160,60},{-142,60}}, color={0,0,127}));
            connect(add.y,product. u1) annotation (Line(points={{-59,-64},{-49,
                    -64},{-49,-84},{-40,-84}},
                              color={0,0,127}));
            connect(gain.u,product. y)
              annotation (Line(points={{-2,-80},{-6,-80},{-17,-80},{-17,-90}},
                                                                 color={0,0,127}));
            connect(table_T_FW1.y[1],add. u1) annotation (Line(points={{-119,
                    -50},{-119,-50},{-96,-50},{-90,-50},{-90,-58},{-82,-58}},
                                       color={0,0,127}));
            connect(signalBus.eletHEAT_PV_low_T,add. u2) annotation (Line(
                points={{144,-70},{144,-70},{144,-168},{-90,-168},{-90,-70},{
                    -82,-70}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.eletHEAT_PV_low_w,product. u2) annotation (Line(
                points={{144,-70},{144,-70},{144,-168},{-90,-168},{-90,-96},{-40,-96}},
                color={255,204,51},
                thickness=0.5));
            connect(load, table_T_FW1.u[1]) annotation (Line(points={{-180,-10},
                    {-160,-10},{-160,-50},{-142,-50}},
                                            color={0,0,127}));
            connect(signalBus.eletHEAT_PV_high, PI_eletHEAT.PV) annotation (Line(
                points={{144,-70},{144,-70},{144,-168},{-188,-168},{-188,28},{
                    -84,28},{-84,38},{-76,38}},
                color={255,204,51},
                thickness=0.5));
            connect(switch_eletHEAT.y, eletHEAT_lim.u)
              annotation (Line(points={{61,-10},{64.5,-10},{68,-10}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-180,-10},{-122,-10}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_eletHEAT.u2) annotation (
                Line(points={{-99,-10},{-30,-10},{38,-10}}, color={255,0,255}));
            connect(PI_eletHEAT.CS, switch_eletHEAT.u3) annotation (Line(points=
                   {{-42,40},{-12,40},{30,40},{30,-2},{38,-2}}, color={0,0,127}));
            connect(load, table_Q_EH.u[1]) annotation (Line(points={{-180,-10},
                    {-180,-10},{-160,-10},{-160,-130},{-2,-130}}, color={0,0,
                    127}));
            connect(gain.y, switch_eletHEAT.u1) annotation (Line(points={{21,
                    -80},{30,-80},{30,-18},{38,-18}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="Q_EH

controller")}));
          end control_eletHEAT;

          model control_wSEP "Model of the w_SEP controller"

            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration";

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-212,-90},{-172,-50}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={128,-132}),
                                    iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=true,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-92,100})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={124,-70})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-132,130},{-112,150}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_pumpSEP_bool annotation (Placement(
                  transformation(extent={{-32,120},{-72,160}}),
                                                              iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Logical.Switch switch_SEP
              annotation (Placement(transformation(extent={{42,-80},{62,-60}})));
            Modelica.Blocks.Logical.LessEqualThreshold    greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-92,-80},{-72,-60}})));
            Modelica.Blocks.Math.Product product2 annotation (Placement(
                  transformation(extent={{-58,96},{-38,116}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(
                    extent={{-22,90},{-2,110}})));
            FullScale_245degC.Graphics.Label_input pumpSEP_PV annotation (
                Placement(transformation(extent={{-166,104},{-126,92}})));
            FullScale_245degC.Graphics.Label_output pumpSEP_CS annotation (
                Placement(transformation(extent={{164,-76},{202,-64}})));
            Modelica.Blocks.Sources.Constant const(k=0)
              annotation (Placement(transformation(extent={{8,-120},{28,-100}})));
            Modelica.Blocks.Nonlinear.Limiter pumpSEP_lim(uMax=120, uMin=0)
              annotation (Placement(transformation(extent={{72,-80},{92,-60}})));
            Modelica.Blocks.Math.Division division
              annotation (Placement(transformation(extent={{-28,-26},{-8,-6}})));
            Modelica.Blocks.Math.Product product1 annotation (Placement(
                  transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={18,-10})));
            Modelica.Blocks.Sources.Constant const1(k=2.75)
              annotation (Placement(transformation(extent={{-62,-40},{-42,-20}})));
            Modelica.Blocks.Math.Add add1(k1=-1)
              annotation (Placement(transformation(extent={{-62,-14},{-42,6}})));
            Modelica.Blocks.Sources.Constant const2(k=0.25) annotation (
                Placement(transformation(extent={{-92,10},{-72,30}})));
            FullScale_245degC.Graphics.Label_input pumpFW_PV_low annotation (
                Placement(transformation(extent={{-132,-4},{-86,-16}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85;
                  70,518.15; 80,518.15; 90,518.15; 100,518.15]) annotation (
                Placement(transformation(extent={{-170,110},{-150,130}})));
            Modelica.Blocks.Tables.CombiTable1D table_wSEP(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0.5022; 20,1.595; 30,1.898; 40,2.009; 50,1.534; 60,0; 70,0; 80,
                  0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-94,42},{-74,62}})));
          equation
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{128,-132},{128,-110},{168,-110},{168,-82},{146,-82},{
                    146,-70}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{128,-132},{128,-174},{-206,-174},{-206,-54},{-140,-54},
                    {-140,-40},{-138,-40},{-138,18},{-114,18},{-114,96},{-112,
                    96},{-112,98},{-108,98}},
                color={256,256,256},
                thickness=0.5));
            connect(pumpSEP_TS.y, PID_pumpSEP.TR)
              annotation (Line(points={{-111,140},{-92,140},{-92,116}},
                                                                    color={0,0,127}));
            connect(TS_pumpSEP_bool, PID_pumpSEP.TS)
              annotation (Line(points={{-52,140},{-52,140},{-84,140},{-84,138},
                    {-84,116}},                                     color={255,0,255}));

            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-192,-70},{-192,-70},{-94,-70}},
                                                                   color={0,0,127}));
            connect(PID_pumpSEP.CS, product2.u1) annotation (Line(points={{-74,
                    100},{-68,100},{-68,112},{-60,112}}, color={0,0,127}));
            connect(product2.y, add2.u1)
              annotation (Line(points={{-37,106},{-24,106}}, color={0,0,127}));
            connect(switch_SEP.y, pumpSEP_lim.u) annotation (Line(points={{63,-70},
                    {64,-70},{66,-70},{70,-70}},
                                      color={0,0,127}));
            connect(pumpSEP_lim.y, pumpSEP_dynamic.u)
              annotation (Line(points={{93,-70},{94,-70},{96,-70},{100,-70}},
                                                        color={0,0,127}));
            connect(const.y, switch_SEP.u3) annotation (Line(points={{29,-110},
                    {29,-110},{32,-110},{32,-78},{40,-78}},              color=
                    {0,0,127}));
            connect(division.y, product1.u2) annotation (Line(points={{-7,-16},
                    {6,-16}},         color={0,0,127}));
            connect(add2.y, product1.u1) annotation (Line(points={{-1,100},{2,
                    100},{2,-4},{6,-4}}, color={0,0,127}));
            connect(const1.y, division.u2)
              annotation (Line(points={{-41,-30},{-36,-30},{-36,-22},{-30,-22}},
                                                          color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_SEP.u2) annotation (Line(
                  points={{-71,-70},{-44,-70},{-16,-70},{40,-70}},
                                                  color={255,0,255}));
            connect(const2.y, add1.u1) annotation (Line(points={{-71,20},{-68,
                    20},{-68,2},{-64,2}},         color={0,0,127}));
            connect(add1.y, division.u1) annotation (Line(points={{-41,-4},{-40,
                    -4},{-36,-4},{-36,-10},{-30,-10}},
                                          color={0,0,127}));
            connect(product1.y, switch_SEP.u1) annotation (Line(points={{29,-10},
                    {32,-10},{32,-62},{40,-62}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, add1.u2) annotation (Line(
                points={{128,-132},{128,-132},{128,-174},{-206,-174},{-206,-54},
                    {-126,-54},{-126,-40},{-64,-40},{-64,-10}},
                thickness=0.5,
                color={255,255,255}));
            connect(table_T_FW.y[1], PID_pumpSEP.SP) annotation (Line(points={{
                    -149,120},{-140,120},{-140,112},{-108,112}}, color={0,0,127}));
            connect(load, table_T_FW.u[1]) annotation (Line(points={{-192,-70},
                    {-180,-70},{-180,-68},{-180,120},{-172,120}}, color={0,0,
                    127}));
            connect(table_wSEP.y[1], add2.u2) annotation (Line(points={{-73,52},
                    {-30,52},{-30,94},{-24,94}}, color={0,0,127}));
            connect(table_wSEP.y[1], product2.u2) annotation (Line(points={{-73,
                    52},{-64,52},{-64,100},{-60,100}}, color={0,0,127}));
            connect(load, table_wSEP.u[1]) annotation (Line(points={{-192,-70},
                    {-180,-70},{-180,52},{-96,52}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="w_SEP

controller")}));
          end control_wSEP;

          model control_valveSEP "Model of the on/off separator drain valve"

            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-60},{-160,-20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={160,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Logical.Switch switch annotation (Placement(transformation(
                  extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,-80})));
            Modelica.Blocks.Sources.Constant const(k=1)
              annotation (Placement(transformation(extent={{-80,-40},{-60,-20}})));
            Modelica.Blocks.Sources.Constant const1(k=0)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-70,-130})));
            Modelica.Blocks.Continuous.FirstOrder valveSEP_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSEP,
              T=Ta_valveSEP)
                   annotation (Placement(transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=0,
                  origin={100,0})));
            Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=load_min)
              annotation (Placement(transformation(extent={{-120,-70},{-100,-50}})));
            Modelica.Blocks.Logical.Hysteresis hysteresis(uLow=l_min, uHigh=l_max)
              annotation (Placement(transformation(extent={{-120,-110},{-100,
                      -90}})));
            Modelica.Blocks.Logical.And and1
              annotation (Placement(transformation(extent={{-80,-90},{-60,-70}})));
            Modelica.Blocks.Logical.Switch switch_IO annotation (Placement(
                  transformation(
                  extent={{-10,10},{10,-10}},
                  rotation=0,
                  origin={30,0})));
            Modelica.Blocks.Interfaces.BooleanInput useValveSEP annotation (
                Placement(transformation(extent={{-40,-20},{0,20}}),
                  iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,220})));
            Modelica.Blocks.Sources.Constant const2(k=0)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-10,40})));
            FullScale_245degC.Graphics.Label_input pumpFW_PV_low annotation (
                Placement(transformation(extent={{-188,-94},{-142,-106}})));
            FullScale_245degC.Graphics.Label_output valveSEP_CS
              annotation (Placement(transformation(extent={{142,-6},{180,6}})));
          equation

            connect(greaterThreshold.y,and1. u1) annotation (Line(points={{-99,-60},
                    {-88,-60},{-88,-80},{-82,-80}}, color={255,0,255}));
            connect(hysteresis.y, and1.u2) annotation (Line(points={{-99,-100},
                    {-88,-100},{-88,-88},{-82,-88}},
                                     color={255,0,255}));
            connect(and1.y, switch.u2)
              annotation (Line(points={{-59,-80},{-59,-80},{-22,-80}},
                                                        color={255,0,255}));
            connect(load, greaterThreshold.u) annotation (Line(points={{-180,
                    -40},{-180,-40},{-142,-40},{-140,-40},{-140,-60},{-122,-60}},
                                                 color={0,0,127}));
            connect(signalBus.valveSEP_CS, valveSEP_dynamic.y) annotation (Line(
                points={{160,-60},{126,-60},{126,-10},{124,-10},{124,0},{122,0}},
                color={255,255,255},
                thickness=0.5));
            connect(const.y, switch.u1)
              annotation (Line(points={{-59,-30},{-40,-30},{-40,-72},{-22,-72}},
                                                                      color={0,0,127}));
            connect(const1.y, switch.u3) annotation (Line(points={{-59,-130},{
                    -40,-130},{-40,-88},{-22,-88}},
                              color={0,0,127}));
            connect(useValveSEP, switch_IO.u2) annotation (Line(points={{-20,0},
                    {18,0}},        color={255,0,255}));
            connect(switch.y, switch_IO.u1) annotation (Line(points={{1,-80},{
                    10,-80},{10,-8},{18,-8}}, color={0,0,127}));
            connect(const2.y, switch_IO.u3) annotation (Line(points={{1,40},{10,
                    40},{10,8},{18,8}}, color={0,0,127}));
            connect(switch_IO.y, valveSEP_dynamic.u) annotation (Line(points={{
                    41,0},{58,0},{76,0}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, hysteresis.u) annotation (Line(
                points={{160,-60},{160,-60},{160,-180},{-124,-180},{-124,-114},
                    {-124,-100},{-122,-100}},
                color={255,255,255},
                thickness=0.5));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,-200},
                      {200,200}}, preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valve_SEP

controller")}));
          end control_valveSEP;

          model control_valveRH_DEA "Model of the p_dea controller"

            //-- valveRH_DEA --
            parameter Real Kp_valveRH_DEA "Controller proportional gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ti_valveRH_DEA
              "Controller integral time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Td_valveRH_DEA
              "Controller derivative time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real Nd_valveRH_DEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmin_valveRH_DEA
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmax_valveRH_DEA
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSstart_valveRH_DEA "Start value of CS" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real actuatorGain_valveRH_DEA "Actuator gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ta_valveRH_DEA
              "Actuator time constant"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real TS_valveRH_DEA "Tracking signal" annotation (Dialog(tab="valveRH_DEA"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_DEA_dynamic(
              k=actuatorGain_valveRH_DEA,
              T=Ta_valveRH_DEA,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,-20},{140,20}})));
            IndustrialControlSystems.Controllers.PI PI_valveRH_DEA(
              AntiWindup=true,
              CSmin=CSmin_valveRH_DEA,
              CSmax=CSmax_valveRH_DEA,
              CS_start=CSstart_valveRH_DEA,
              Kp=Kp_valveRH_DEA,
              Ti=Ti_valveRH_DEA,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,50},{-40,90}})));
            Modelica.Blocks.Sources.Constant valveRH_DEA_TS(k=TS_valveRH_DEA)
              annotation (Placement(transformation(extent={{-100,100},{-80,120}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveRH_DEA_bool annotation (Placement(
                  transformation(extent={{0,90},{-40,130}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input valveRH_DEA_PV
              annotation (Placement(transformation(extent={{-146,74},{-98,62}})));
            FullScale_245degC.Graphics.Label_output valveRH_DEA_CS
              annotation (Placement(transformation(extent={{164,-6},{210,6}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_DEA_lim(                uMax=1, uMin=
                  0.001)
              annotation (Placement(transformation(extent={{60,-10},{80,10}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{-20,30},{0,50}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_DEA(                                                                 table=[
                  20,8.636e5; 30,12.9e5; 40,17.32e5; 50,22.02e5; 60,26.78e5; 70,26.97e5; 80,
                  27.03e5; 90,27.04e5; 100,27.05e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,80},{-120,100}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_DEA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,0.8; 70,0.6; 80,0.4; 90,0.2; 100,
                  0.2])
              annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
            Modelica.Blocks.Logical.LessEqualThreshold    greaterEqualThreshold(threshold=
                 55)
              annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
            Modelica.Blocks.Logical.Switch switch_valveRH_DEA
              annotation (Placement(transformation(extent={{20,10},{40,-10}})));
            Modelica.Blocks.Sources.Constant CS_lowLoad(k=1)
              annotation (Placement(transformation(extent={{-20,-50},{0,-30}})));
          equation
            connect(TS_valveRH_DEA_bool, PI_valveRH_DEA.TS) annotation (Line(points={{-20,110},
                    {-20,110},{-52,110},{-52,86}},
                                            color={255,0,255}));
            connect(valveRH_DEA_TS.y, PI_valveRH_DEA.TR)
              annotation (Line(points={{-79,110},{-60,110},{-60,86}},
                                                                    color={0,0,127}));
            connect(signalBus.valveRH_DEA_CS, valveRH_DEA_dynamic.y) annotation (Line(
                points={{140,-60},{156,-60},{156,-22},{142,-22},{142,0}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveRH_DEA_PV, PI_valveRH_DEA.PV) annotation (Line(
                points={{140,-60},{178,-60},{178,-144},{-196,-144},{-196,60},{-80,60},{-80,
                    68},{-76,68}},
                color={256,256,256},
                thickness=0.5));

            connect(valveRH_DEA_lim.y, valveRH_DEA_dynamic.u) annotation (Line(points={{81,0},{
                    81,0},{96,0}},            color={0,0,127}));
            connect(table_p_DEA.y[1], PI_valveRH_DEA.SP) annotation (Line(points={{-119,90},
                    {-100,90},{-100,82},{-76,82}}, color={0,0,127}));
            connect(load, table_p_DEA.u[1]) annotation (Line(points={{-180,0},{-164,0},{-160,
                    0},{-160,90},{-142,90}}, color={0,0,127}));
            connect(load, table_thetaRH_DEA.u[1]) annotation (Line(points={{-180,0},{-160,
                    0},{-160,20},{-62,20}}, color={0,0,127}));
            connect(table_thetaRH_DEA.y[1], add.u2) annotation (Line(points={{-39,20},{-30,
                    20},{-30,34},{-22,34}}, color={0,0,127}));
            connect(PI_valveRH_DEA.CS, add.u1) annotation (Line(points={{-42,70},{-30,70},
                    {-30,46},{-22,46}}, color={0,0,127}));
            connect(switch_valveRH_DEA.y, valveRH_DEA_lim.u)
              annotation (Line(points={{41,0},{58,0}}, color={0,0,127}));
            connect(CS_lowLoad.y, switch_valveRH_DEA.u1) annotation (Line(points={{1,-40},
                    {10,-40},{10,-8},{18,-8}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-180,0},{-141,0},{-102,0}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_valveRH_DEA.u2)
              annotation (Line(points={{-79,0},{-30.5,0},{18,0}}, color={255,0,255}));
            connect(add.y, switch_valveRH_DEA.u3)
              annotation (Line(points={{1,40},{10,40},{10,8},{18,8}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valveRH_DEA

controller")}));
          end control_valveRH_DEA;

          model control_valveRH_COND "Model of the p_RH controller"

            //-- valveRH_COND --
            parameter Real Kp_valveRH_COND "Controller proportional gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ti_valveRH_COND
              "Controller integral time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Td_valveRH_COND
              "Controller derivative time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real Nd_valveRH_COND
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmin_valveRH_COND
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmax_valveRH_COND
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSstart_valveRH_COND "Start value of CS" annotation (Dialog(tab="valveRH_COND"));
            parameter Real actuatorGain_valveRH_COND "Actuator gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ta_valveRH_COND
              "Actuator time constant"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real TS_valveRH_COND "Tracking signal" annotation (Dialog(tab="valveRH_COND"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_COND_dynamic(
              k=actuatorGain_valveRH_COND,
              T=Ta_valveRH_COND,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,-20},{140,20}})));
            IndustrialControlSystems.Controllers.PI PI_valveRH_COND(
              AntiWindup=true,
              CSmin=CSmin_valveRH_COND,
              CSmax=CSmax_valveRH_COND,
              CS_start=CSstart_valveRH_COND,
              Kp=Kp_valveRH_COND,
              Ti=Ti_valveRH_COND,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveRH_COND_TS(k=TS_valveRH_COND)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveRH_COND_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input valveRH_COND_PV
              annotation (Placement(transformation(extent={{-146,44},{-98,32}})));
            FullScale_245degC.Graphics.Label_output valveRH_COND_CS
              annotation (Placement(transformation(extent={{164,-6},{210,6}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_COND_lim(                uMax=1, uMin=
                  0.001)
              annotation (Placement(transformation(extent={{60,-10},{80,10}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,-10},{40,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_COND(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,0.8; 70,0.6; 80,0.4; 90,0.2; 100,
                  0.2])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_RH(
                table=[20,8.651e5; 30,13.19e5; 40,17.83e5; 50,22.6e5; 60,27.39e5; 70,32.65e5;
                  80,37.19e5; 90,42.05e5; 100,47.31e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
          equation
            connect(TS_valveRH_COND_bool, PI_valveRH_COND.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveRH_COND_TS.y, PI_valveRH_COND.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveRH_COND_CS, valveRH_COND_dynamic.y) annotation (Line(
                points={{140,-60},{156,-60},{156,-22},{142,-22},{142,0}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveRH_COND_PV, PI_valveRH_COND.PV) annotation (Line(
                points={{140,-60},{178,-60},{178,-174},{-196,-174},{-196,30},{-80,30},{-80,
                    38},{-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(valveRH_COND_lim.y, valveRH_COND_dynamic.u) annotation (Line(points={{81,0},{
                    81,0},{96,0}},            color={0,0,127}));
            connect(add.y, valveRH_COND_lim.u)
              annotation (Line(points={{41,0},{58,0}},        color={0,0,127}));
            connect(load, table_thetaRH_COND.u[1]) annotation (Line(points={{-180,0},{-160,
                    0},{-160,-10},{-62,-10}}, color={0,0,127}));
            connect(table_thetaRH_COND.y[1], add.u2) annotation (Line(points={{-39,-10},{0,
                    -10},{0,-6},{18,-6}}, color={0,0,127}));
            connect(PI_valveRH_COND.CS, add.u1)
              annotation (Line(points={{-42,40},{0,40},{0,6},{18,6}}, color={0,0,127}));
            connect(table_p_RH.y[1], PI_valveRH_COND.SP) annotation (Line(
                  points={{-119,60},{-100,60},{-100,52},{-76,52}}, color={0,0,
                    127}));
            connect(load, table_p_RH.u[1]) annotation (Line(points={{-180,0},{
                    -160,0},{-160,60},{-142,60}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valveRH_COND

controller")}));
          end control_valveRH_COND;

          model control_valveDEA_SH "Model of the T_MSout,RH controller"

            //-- valveDEA_SH --
            parameter Real Kp_valveDEA_SH "Controller proportional gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_SH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Td_valveDEA_SH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Nd_valveDEA_SH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmin_valveDEA_SH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmax_valveDEA_SH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSstart_valveDEA_SH "Start value of CS" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real actuatorGain_valveDEA_SH "Actuator gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_SH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real TS_valveDEA_SH "Tracking signal" annotation (Dialog(tab="valveDEA_SH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_SH_dynamic(
              k=actuatorGain_valveDEA_SH,
              T=Ta_valveDEA_SH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,-20},{140,20}})));
            IndustrialControlSystems.Controllers.PI PI_valveDEA_SH(
              AntiWindup=true,
              CSmin=CSmin_valveDEA_SH,
              CSmax=CSmax_valveDEA_SH,
              CS_start=CSstart_valveDEA_SH,
              Kp=Kp_valveDEA_SH,
              Ti=Ti_valveDEA_SH,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveDEA_SH_TS(k=TS_valveDEA_SH)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveDEA_SH_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input valveDEA_SH_PV
              annotation (Placement(transformation(extent={{-146,44},{-98,32}})));
            FullScale_245degC.Graphics.Label_output valveDEA_SH_CS
              annotation (Placement(transformation(extent={{164,-6},{210,6}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_SH_lim(                uMax=1, uMin=
                  0.001)
              annotation (Placement(transformation(extent={{60,-10},{80,10}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-20},{-160,20}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,-10},{40,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,0.8; 70,0.6; 80,0.4; 90,0.2; 100,
                  0.2])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_RH_out(
                table=[20,473.3 + 273.15; 30,471.4 + 273.15; 40,470 + 273.15; 50,468.3 + 273.15;
                  60,465.5 + 273.15; 70,463 + 273.15; 80,461.4 + 273.15; 90,459.4 + 273.15;
                  100,460.8 + 273.15], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-140,50},{-120,70}})));
          equation
            connect(TS_valveDEA_SH_bool, PI_valveDEA_SH.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveDEA_SH_TS.y, PI_valveDEA_SH.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveDEA_SH_CS, valveDEA_SH_dynamic.y) annotation (Line(
                points={{140,-60},{156,-60},{156,-22},{142,-22},{142,0}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveDEA_SH_PV, PI_valveDEA_SH.PV) annotation (Line(
                points={{140,-60},{178,-60},{178,-174},{-196,-174},{-196,30},{-80,30},{-80,
                    38},{-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(valveDEA_SH_lim.y, valveDEA_SH_dynamic.u) annotation (Line(points={{81,0},{
                    81,0},{96,0}},            color={0,0,127}));
            connect(add.y, valveDEA_SH_lim.u)
              annotation (Line(points={{41,0},{58,0}},        color={0,0,127}));
            connect(load, table_thetaDEA_SH.u[1]) annotation (Line(points={{-180,0},{-160,
                    0},{-160,-10},{-62,-10}}, color={0,0,127}));
            connect(table_thetaDEA_SH.y[1], add.u2) annotation (Line(points={{-39,-10},{0,
                    -10},{0,-6},{18,-6}}, color={0,0,127}));
            connect(PI_valveDEA_SH.CS, add.u1)
              annotation (Line(points={{-42,40},{0,40},{0,6},{18,6}}, color={0,0,127}));
            connect(load, table_T_RH_out.u[1]) annotation (Line(points={{-180,0},
                    {-160,0},{-160,60},{-142,60}}, color={0,0,127}));
            connect(table_T_RH_out.y[1], PI_valveDEA_SH.SP) annotation (Line(
                  points={{-119,60},{-100,60},{-100,52},{-76,52}}, color={0,0,
                    127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valveDEA_SH

controller")}));
          end control_valveDEA_SH;

          model control_valveDEA_RH "Model of the DT_RH.cond controller"

            //-- valveDEA_RH --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_COND_sp
              "Degree of superheating at condenser inlet set point"                                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Kp_valveDEA_RH "Controller proportional gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_RH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Td_valveDEA_RH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Nd_valveDEA_RH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmin_valveDEA_RH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmax_valveDEA_RH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSstart_valveDEA_RH "Start value of CS" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real actuatorGain_valveDEA_RH "Actuator gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_RH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real TS_valveDEA_RH "Tracking signal" annotation (Dialog(tab="valveDEA_RH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={140,-60}),iconTransformation(
                  extent={{-20,20},{20,-20}},
                  rotation=90,
                  origin={210,0})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_RH_dynamic(
              k=actuatorGain_valveDEA_RH,
              T=Ta_valveDEA_RH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{100,-20},{140,20}})));
            IndustrialControlSystems.Controllers.PI PI_valveDEA_RH(
              AntiWindup=true,
              CSmin=CSmin_valveDEA_RH,
              CSmax=CSmax_valveDEA_RH,
              CS_start=CSstart_valveDEA_RH,
              Kp=Kp_valveDEA_RH,
              Ti=Ti_valveDEA_RH,
              useTS=true)
              annotation (Placement(transformation(extent={{-80,20},{-40,60}})));
            Modelica.Blocks.Sources.Constant valveDEA_RH_TS(k=TS_valveDEA_RH)
              annotation (Placement(transformation(extent={{-100,70},{-80,90}})));
            Modelica.Blocks.Interfaces.BooleanInput TS_valveDEA_RH_bool annotation (Placement(
                  transformation(extent={{0,60},{-40,100}}), iconTransformation(
                  extent={{20,-20},{-20,20}},
                  rotation=90,
                  origin={0,220})));
            FullScale_245degC.Graphics.Label_input valveDEA_RH_PV
              annotation (Placement(transformation(extent={{-146,44},{-98,32}})));
            FullScale_245degC.Graphics.Label_output valveDEA_RH_CS
              annotation (Placement(transformation(extent={{164,-6},{210,6}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_RH_lim(                uMax=1, uMin=
                  0.001)
              annotation (Placement(transformation(extent={{60,-10},{80,10}})));
            Modelica.Blocks.Interfaces.RealInput load
              annotation (Placement(transformation(extent={{-200,-30},{-160,10}}),
                  iconTransformation(extent={{-240,-20},{-200,20}})));
            Modelica.Blocks.Math.Add add
              annotation (Placement(transformation(extent={{20,-10},{40,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,0.8; 70,0.6; 80,0.4; 90,0.2; 100,
                  0.2])
              annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
            Modelica.Blocks.Sources.Constant DT_SH_COND_SP(k=DT_sh_COND_sp)
              annotation (Placement(transformation(extent={{-180,42},{-160,62}})));
          equation
            connect(TS_valveDEA_RH_bool, PI_valveDEA_RH.TS) annotation (Line(points={{-20,80},{-20,
                    80},{-52,80},{-52,56}}, color={255,0,255}));
            connect(valveDEA_RH_TS.y, PI_valveDEA_RH.TR)
              annotation (Line(points={{-79,80},{-60,80},{-60,56}}, color={0,0,127}));
            connect(signalBus.valveDEA_RH_CS, valveDEA_RH_dynamic.y) annotation (Line(
                points={{140,-60},{156,-60},{156,-22},{142,-22},{142,0}},
                color={256,256,256},
                thickness=0.5));
            connect(signalBus.valveDEA_RH_PV, PI_valveDEA_RH.PV) annotation (Line(
                points={{140,-60},{178,-60},{178,-174},{-196,-174},{-196,30},{-80,30},{-80,
                    38},{-76,38}},
                color={256,256,256},
                thickness=0.5));

            connect(valveDEA_RH_lim.y, valveDEA_RH_dynamic.u) annotation (Line(points={{81,0},{
                    81,0},{96,0}},            color={0,0,127}));
            connect(add.y, valveDEA_RH_lim.u)
              annotation (Line(points={{41,0},{58,0}},        color={0,0,127}));
            connect(load, table_thetaDEA_RH.u[1]) annotation (Line(points={{-180,-10},{-180,
                    -10},{-62,-10}},          color={0,0,127}));
            connect(table_thetaDEA_RH.y[1], add.u2) annotation (Line(points={{-39,-10},{0,
                    -10},{0,-6},{18,-6}}, color={0,0,127}));
            connect(PI_valveDEA_RH.CS, add.u1)
              annotation (Line(points={{-42,40},{0,40},{0,6},{18,6}}, color={0,0,127}));
            connect(DT_SH_COND_SP.y, PI_valveDEA_RH.SP)
              annotation (Line(points={{-159,52},{-76,52}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(extent={{-200,-200},{200,200}},
                    preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-200,
                      -200},{200,200}},
                                  preserveAspectRatio=false), graphics={Rectangle(
                    extent={{-200,200},{200,-200}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    lineThickness=0.5), Text(
                    extent={{-180,180},{180,-180}},
                    lineColor={0,0,0},
                    lineThickness=0.5,
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid,
                    textString="valveDEA_RH

controller")}));
          end control_valveDEA_RH;
        end SingleControllers;

        package PowerPressureFWcontrollers
          "Package containing power/pressure/FW control schemes"

          model fullyDecentralized
            "Control schemes with fully decentralized control logic"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveSH_RH --
            parameter Real actuatorGain_valveSH_RH "Actuator gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ta_valveSH_RH
              "Actuator time constant"                                             annotation (Dialog(tab="valveSH_RH"));

            //-- valveSH_RH_high
            parameter Real Kp_valveSH_RH_high "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_high
              "Controller integral time"                                                  annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real Nd_valveSH_RH_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmin_valveSH_RH_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmax_valveSH_RH_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSstart_valveSH_RH_high "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real TS_valveSH_RH_high "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));

            //-- valveSH_RH_low
            parameter Real Kp_valveSH_RH_low "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_low
              "Controller integral time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real Nd_valveSH_RH_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmin_valveSH_RH_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmax_valveSH_RH_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSstart_valveSH_RH_low "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real TS_valveSH_RH_low "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"
                                   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveSH_RH_high=Kp_valveSH_RH_high,
              Ti_valveSH_RH_high=Ti_valveSH_RH_high,
              Td_valveSH_RH_high=Td_valveSH_RH_high,
              Nd_valveSH_RH_high=Nd_valveSH_RH_high,
              CSmin_valveSH_RH_high=CSmin_valveSH_RH_high,
              CSmax_valveSH_RH_high=CSmax_valveSH_RH_high,
              CSstart_valveSH_RH_high=CSstart_valveSH_RH_high,
              TS_valveSH_RH_high=TS_valveSH_RH_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveSH_RH_low=Kp_valveSH_RH_low,
              Ti_valveSH_RH_low=Ti_valveSH_RH_low,
              Td_valveSH_RH_low=Td_valveSH_RH_low,
              Nd_valveSH_RH_low=Nd_valveSH_RH_low,
              CSmin_valveSH_RH_low=CSmin_valveSH_RH_low,
              CSmax_valveSH_RH_low=CSmax_valveSH_RH_low,
              CSstart_valveSH_RH_low=CSstart_valveSH_RH_low,
              TS_valveSH_RH_low=TS_valveSH_RH_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_PI control_wFW_high_PI(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(uMax=15, uMin=0)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(          uMin=0, uMax=3.5)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveSH_RH_lim(uMax=1, uMin=0.001)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveSH_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSH_RH,
              T=Ta_valveSH_RH)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 9.06913488751826e-10,0.00999999977648258; 2.18218243475121e-09,0.0199999995529652;
                  3.46627393454924e-09,0.0299999993294477; 4.75013051115525e-09,0.0399999991059303;
                  6.0339799823339e-09,0.0500000007450581; 7.31780902540891e-09,0.0599999986588955;
                  8.60163851257312e-09,0.0700000002980232; 9.88546844382654e-09,0.0799999982118607;
                  1.11692957105447e-08,0.0900000035762787; 1.24531229772629e-08,0.100000001490116;
                  1.3736950243981e-08,0.109999999403954; 1.50207775106992e-08,0.119999997317791;
                  1.63046056655958e-08,0.129999995231628; 1.75884320441355e-08,0.140000000596046;
                  1.88722601990321e-08,0.150000005960464; 2.01560865775718e-08,0.159999996423721;
                  2.14399147324684e-08,0.170000001788139; 2.27237411110082e-08,0.180000007152557;
                  2.40075692659048e-08,0.189999997615814; 2.52913956444445e-08,0.200000002980232;
                  2.65752220229842e-08,0.209999993443489; 2.78590501778808e-08,0.219999998807907;
                  2.91428765564206e-08,0.230000004172325; 3.04267047113171e-08,0.239999994635582;
                  3.17105310898569e-08,0.25; 3.29943574683966e-08,0.259999990463257; 3.42781873996501e-08,
                  0.270000010728836; 3.55620137781898e-08,0.280000001192093; 3.68458401567295e-08,
                  0.28999999165535; 3.81296665352693e-08,0.300000011920929; 3.94134964665227e-08,
                  0.310000002384186; 4.06973228450624e-08,0.319999992847443; 4.19811492236022e-08,
                  0.330000013113022; 4.32649756021419e-08,0.340000003576279; 4.45488019806817e-08,
                  0.349999994039536; 4.58326319119351e-08,0.360000014305115; 4.71164582904748e-08,
                  0.370000004768372; 4.84002846690146e-08,0.379999995231628; 4.96841110475543e-08,
                  0.389999985694885; 5.09679409788077e-08,0.400000005960465; 5.22517673573475e-08,
                  0.409999996423721; 5.35355937358872e-08,0.419999986886978; 5.4819420114427e-08,
                  0.430000007152557; 5.61032464929667e-08,0.439999997615814; 5.73870764242201e-08,
                  0.449999988079071; 5.86709028027599e-08,0.46000000834465; 5.99547291812996e-08,
                  0.469999998807907; 6.12385591125531e-08,0.479999989271164; 6.25223819383791e-08,
                  0.490000009536743; 6.38062118696325e-08,0.5; 6.5090041800886e-08,0.509999990463257;
                  6.6373864626712e-08,0.519999980926514; 6.76576945579654e-08,0.529999971389771;
                  6.89415173837915e-08,0.540000021457672; 7.02253473150449e-08,0.550000011920929;
                  7.15091772462984e-08,0.560000002384186; 7.27930000721244e-08,0.569999992847443;
                  7.40768300033778e-08,0.5799999833107; 7.53606528292039e-08,0.589999973773956;
                  7.66444827604573e-08,0.600000023841858; 7.79283126917107e-08,0.610000014305115;
                  7.92121355175368e-08,0.620000004768372; 8.04959654487902e-08,0.629999995231628;
                  8.17797953800437e-08,0.639999985694885; 8.30636182058697e-08,0.649999976158142;
                  8.43474481371231e-08,0.660000026226044; 8.56312709629492e-08,0.670000016689301;
                  8.69151008942026e-08,0.680000007152557; 8.81989308254561e-08,0.689999997615814;
                  8.94827536512821e-08,0.699999988079071; 9.07665835825355e-08,0.709999978542328;
                  9.20504064083616e-08,0.72000002861023; 9.3334236339615e-08,0.730000019073486;
                  9.46180662708684e-08,0.740000009536743; 9.59018890966945e-08,0.75; 9.71857190279479e-08,
                  0.759999990463257; 9.84695489592014e-08,0.769999980926514; 9.97533717850274e-08,
                  0.779999971389771; 1.01037201716281e-07,0.790000021457672; 1.02321024542107e-07,
                  0.800000011920929; 1.0360485447336e-07,0.810000002384186; 1.04888684404614e-07,
                  0.819999992847443; 1.0617250723044e-07,0.8299999833107; 1.07456337161693e-07,
                  0.839999973773956; 1.08740159987519e-07,0.850000023841858; 1.10023989918773e-07,
                  0.860000014305115; 1.11307819850026e-07,0.870000004768372; 1.12591642675852e-07,
                  0.879999995231628; 1.13875472607106e-07,0.889999985694885; 1.15159295432932e-07,
                  0.899999976158142; 1.16443125364185e-07,0.910000026226044; 1.17726955295439e-07,
                  0.920000016689301; 1.19010778121265e-07,0.930000007152557; 1.20294600947091e-07,
                  0.939999997615814; 1.21578437983771e-07,0.949999988079071; 1.22862260809598e-07,
                  0.959999978542328; 1.24146083635424e-07,0.97000002861023; 1.25429920672104e-07,
                  0.980000019073486; 1.2671374349793e-07,0.990000009536743; 1.27997566323756e-07,
                  1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_PI.dec_out, gamma_FW_MS.u) annotation (Line(points={{
                    -112,111.5},{-112,117.75},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_PI.dec_in) annotation (Line(points={{-148,
                    151},{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_PI.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(valveSH_RH_lim.y, valveSH_RH_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_PI.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_PI.load) annotation (Line(points={{-330,0},{-260,
                    0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,220},{
                    -163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_PI.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,80},{
                    -163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-80},{
                    -163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveSH_RH_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-220},
                    {-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_PI.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveSH_RHhigh_bool, control_Yt_high.TS_valveSH_RHhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveSH_RHlow_bool, control_Yt_low.TS_valveSH_RHlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1]) annotation (Line(points=
                   {{61,-260},{79.5,-260},{98,-260}}, color={0,0,127}));
            connect(table_Y_tTOtheta.y[1], valveSH_RH_lim.u) annotation (Line(
                  points={{121,-260},{130,-260},{138,-260}},            color={
                    0,0,127}));
            connect(signalBus.valveSH_RH_CS, valveSH_RH_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveSH_RH_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},{-163,-340}},
                color={255,204,51},
                thickness=0.5));

            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end fullyDecentralized;

          model staticDecoupled
            "Control schemes with a static decoupler between molten salt and water mass flow rate"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                                  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"
                                   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal"
                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_PI control_wFW_high_PI(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high)
              annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_PI.dec_out, gamma_FW_MS.u) annotation (Line(points={{
                    -112,111.5},{-112,117.75},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_PI.dec_in) annotation (Line(points={{-148,
                    151},{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_PI.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{61,-260},{98,-260}}, color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_PI.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_PI.load) annotation (Line(points={{-330,0},{-260,
                    0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,0},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,220},{-163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_PI.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,80},{-163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-80},{-163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-220},{-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-340},{-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_PI.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled;

          model staticDecoupled_4th
            "Control schemes with a static decoupler between molten salt and water mass flow rate and a 4th order controller on wFW"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[5,5] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[5,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,5] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_4th control_wFW_high_4th(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              A=A,
              B=B,
              C=C,
              D=D) annotation (Placement(transformation(extent={{-160,110},{-100,50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-84,-14},{-56,14}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{36,314},{64,286}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{36,-14},{64,14}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{38,-274},{64,-248}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,
                    340},{0,340},{0,311.2},{33.2,311.2}},
                                               color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,
                    220},{-50,220},{0,220},{0,288.8},{33.2,288.8}},
                                                         color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{65.4,300},{65.4,300},{118,300}},
                                                                     color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_4th.dec_out, gamma_FW_MS.u) annotation (Line(points={
                    {-112,111.5},{-112,111.5},{-112,128}}, color={0,0,127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_4th.dec_in)
              annotation (Line(points={{-148,151},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{65.4,1.77636e-015},{90,0},{118,0}},
                                                        color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_4th.TS) annotation (Line(points={{141,0},
                    {160,0},{160,30},{-115,30},{-115,47}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-54.6,
                    1.77636e-015},{-40,1.77636e-015},{-40,300},{33.2,300}},
                                                 color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-54.6,1.77636e-015},{33.2,1.77636e-015}},
                                                        color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{65.3,-261},{80,-261},{80,-260},{98,-260}},
                                                             color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_4th.CS, switch_FW.u1) annotation (Line(points={{-98.5,
                    80},{0,80},{0,11.2},{33.2,11.2}},
                                              color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,
                    -80},{0,-80},{0,-11.2},{33.2,-11.2}},
                                             color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,
                    -220},{-50,-220},{0,-220},{0,-250.6},{35.4,-250.6}},
                                                             color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,
                    -340},{-48,-340},{0,-340},{0,-271.4},{35.4,-271.4}},
                                                             color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-54.6,
                    1.77636e-015},{-40,1.77636e-015},{-40,-261},{35.4,-261}},
                                                   color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{65.3,
                    -261},{80,-261},{80,-170},{-115,-170},{-115,-187}},
                                                              color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{65.3,
                    -261},{80,-261},{80,-290},{-115,-290},{-115,-307}},
                                                              color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-228,0},{-228,1.77636e-015},{
                    -86.8,1.77636e-015}},                 color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,361},{-163,361}},
                                            color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,241},{-163,241}},
                                            color={0,0,127}));
            connect(load, control_wFW_high_4th.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,59},{-163,59}},
                                             color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-62},{-163,-62}},
                                            color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-199},{-163,-199}},
                                              color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},
                    {-280,0},{-280,-319},{-163,-319}},
                                              color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,-40},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,-40},{320,-40},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,-40},{320,-400},{-250,-400},{-250,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-34},{320,-34},{320,-400},{
                    -250,-400},{-250,220},{-163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_4th.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-40},{320,-40},{320,-400},{
                    -250,-400},{-250,80},{-163,80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-26},{320,-26},{320,-400},{
                    -250,-400},{-250,-80},{-163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-118},{320,-118},{320,-400},{
                    -250,-400},{-250,-220},{-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,-40},{320,-40},{320,-400},{-220,-400},{-220,-340},
                    {-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_4th.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled_4th;

          model staticDecoupled_10th
            "Control schemes with a static decoupler between molten salt and water mass flow rate and a 10th order controller on wFW"
            extends BaseClasses.BasePowerPressureController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));

            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveTURB --
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));

            //-- valveTURB_high
            parameter Real Kp_valveTURB_high "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_high
              "Controller integral time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real Nd_valveTURB_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmin_valveTURB_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSmax_valveTURB_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real CSstart_valveTURB_high "Start value of CS" annotation (Dialog(tab="valveTURB",group="High load tuning"));
            parameter Real TS_valveTURB_high "Tracking signal" annotation (Dialog(tab="valveTURB",group="High load tuning"));

            //-- valveTURB_low
            parameter Real Kp_valveTURB_low "Controller proportional gain" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveTURB_low
              "Controller integral time"                                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveTURB_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real Nd_valveTURB_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmin_valveTURB_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSmax_valveTURB_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real CSstart_valveTURB_low "Start value of CS" annotation (Dialog(tab="valveTURB",group="Low load tuning"));
            parameter Real TS_valveTURB_low "Tracking signal" annotation (Dialog(tab="valveTURB",group="Low load tuning"));

            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real A[18,18] "A matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real B[18,1] "B matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real C[1,18] "C matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real D[1,1] "D matrix of state-space controller form" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"
                                                 annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"
                                      annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain"
                                             annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"
                                                annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS"
                                  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

            SingleControllers.control_wMS_high control_wMS_high(
              load_switch=load_switch,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high)
              annotation (Placement(transformation(extent={{-160,190},{-100,250}})));
            SingleControllers.control_wMS_low control_wMS_low(
              load_switch=load_switch,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low)
              annotation (Placement(transformation(extent={{-160,310},{-100,370}})));
            SingleControllers.control_Yt_high control_Yt_high(
              load_switch=load_switch,
              Kp_valveTURB_high=Kp_valveTURB_high,
              Ti_valveTURB_high=Ti_valveTURB_high,
              Td_valveTURB_high=Td_valveTURB_high,
              Nd_valveTURB_high=Nd_valveTURB_high,
              CSmin_valveTURB_high=CSmin_valveTURB_high,
              CSmax_valveTURB_high=CSmax_valveTURB_high,
              CSstart_valveTURB_high=CSstart_valveTURB_high,
              TS_valveTURB_high=TS_valveTURB_high)
              annotation (Placement(transformation(extent={{-160,-250},{-100,-190}})));
            SingleControllers.control_Yt_low control_Yt_low(
              load_switch=load_switch,
              Kp_valveTURB_low=Kp_valveTURB_low,
              Ti_valveTURB_low=Ti_valveTURB_low,
              Td_valveTURB_low=Td_valveTURB_low,
              Nd_valveTURB_low=Nd_valveTURB_low,
              CSmin_valveTURB_low=CSmin_valveTURB_low,
              CSmax_valveTURB_low=CSmax_valveTURB_low,
              CSstart_valveTURB_low=CSstart_valveTURB_low,
              TS_valveTURB_low=TS_valveTURB_low)
              annotation (Placement(transformation(extent={{-160,-370},{-100,-310}})));
            SingleControllers.control_wFW_high_10th control_wFW_high_10th(
              load_switch=load_switch,
              DT_sh_sp=DT_sh_sp,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              A=A,
              B=B,
              C=C,
              D=D) annotation (Placement(transformation(extent={{-160,110},{-100,
                      50}})));
            SingleControllers.control_wFW_low control_wFW_low(
              load_switch=load_switch,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low)
              annotation (Placement(transformation(extent={{-160,-110},{-100,-50}})));
            Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold=
                 load_switch)
              annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
            Modelica.Blocks.Logical.Switch switch_MS
              annotation (Placement(transformation(extent={{40,310},{60,290}})));
            Modelica.Blocks.Nonlinear.Limiter pumpMS_lim(          uMin=10, uMax=650)
              annotation (Placement(transformation(extent={{120,290},{140,310}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,300})));
            Modelica.Blocks.Math.Gain gamma_FW_MS(k=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=90,
                  origin={-112,140})));
            Modelica.Blocks.Math.Gain gamma_MS_FW(k=dec_wMS_wFW)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,
                  origin={-148,162})));
            Modelica.Blocks.Logical.Switch switch_FW
              annotation (Placement(transformation(extent={{40,-10},{60,10}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=100, uMin=10)
              annotation (Placement(transformation(extent={{120,-10},{140,10}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={220,0})));
            Modelica.Blocks.Logical.Switch switch_Yt
              annotation (Placement(transformation(extent={{40,-270},{60,-250}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[0,0; 1.65313474553841e-06,0.0461462289094925;
                  1.70582109149109e-06,0.0476190485060215; 3.18249249176006e-06,
                  0.095238097012043; 4.01654733650503e-06,0.142857149243355;
                  4.4278240238782e-06,0.190476194024086; 4.64505774289137e-06,
                  0.238095238804817; 4.77075400340254e-06,0.28571429848671;
                  4.8492447604076e-06,0.333333343267441; 4.90129195895861e-06,
                  0.380952388048172; 4.93748166263686e-06,0.428571432828903;
                  4.96362235935521e-06,0.476190477609634; 4.98310009788838e-06,
                  0.523809552192688; 4.99799261888256e-06,0.571428596973419;
                  5.0096291488444e-06,0.61904764175415; 5.0188918976346e-06,
                  0.666666686534882; 5.02638295074576e-06,0.714285731315613;
                  5.03252658745623e-06,0.761904776096344; 5.03762657899642e-06,
                  0.809523820877075; 5.04190666106297e-06,0.857142865657806;
                  5.04553281643894e-06,0.904761910438538; 5.04863191963523e-06,
                  0.952380955219269; 5.05130128658493e-06,1])
              annotation (Placement(transformation(extent={{100,-270},{120,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveTURB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{140,-270},{160,-250}})));
            Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveTURB,
              T=Ta_valveTURB)
              annotation (Placement(transformation(extent={{200,-280},{240,-240}})));
          equation
            connect(control_wMS_low.CS, switch_MS.u3) annotation (Line(points={{-98.5,340},
                    {0,340},{0,308},{38,308}}, color={0,0,127}));
            connect(control_wMS_high.CS, switch_MS.u1) annotation (Line(points={{-98.5,220},
                    {-50,220},{0,220},{0,292},{38,292}}, color={0,0,127}));
            connect(switch_MS.y, pumpMS_lim.u)
              annotation (Line(points={{61,300},{90,300},{118,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, pumpMS_dynamic.u)
              annotation (Line(points={{141,300},{196,300}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_low.TS) annotation (Line(points={{141,300},{
                    160,300},{160,390},{-115,390},{-115,373}}, color={0,0,127}));
            connect(pumpMS_lim.y, control_wMS_high.TS) annotation (Line(points={{141,300},
                    {160,300},{160,270},{-115,270},{-115,253}}, color={0,0,127}));
            connect(control_wFW_high_10th.dec_out, gamma_FW_MS.u) annotation (
                Line(points={{-112,111.5},{-112,111.5},{-112,128}}, color={0,0,
                    127}));
            connect(control_wMS_high.dec_out, gamma_MS_FW.u) annotation (Line(points={{-148,
                    188.5},{-148,181.25},{-148,174}}, color={0,0,127}));
            connect(gamma_MS_FW.y, control_wFW_high_10th.dec_in) annotation (
                Line(points={{-148,151},{-148,132},{-148,113}}, color={0,0,127}));
            connect(gamma_FW_MS.y, control_wMS_high.dec_in)
              annotation (Line(points={{-112,151},{-112,187}}, color={0,0,127}));
            connect(switch_FW.y, pumpFW_lim.u)
              annotation (Line(points={{61,0},{118,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, pumpFW_dynamic.u)
              annotation (Line(points={{141,0},{167.5,0},{196,0}}, color={0,0,127}));
            connect(pumpFW_lim.y, control_wFW_high_10th.TS) annotation (Line(
                  points={{141,0},{160,0},{160,30},{-115,30},{-115,47}}, color=
                    {0,0,127}));
            connect(pumpFW_lim.y, control_wFW_low.TS) annotation (Line(points={{141,0},{160,
                    0},{160,-30},{-115,-30},{-115,-47}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_MS.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,300},{38,300}}, color={255,0,255}));
            connect(greaterEqualThreshold.y, switch_FW.u2)
              annotation (Line(points={{-59,0},{38,0}}, color={255,0,255}));
            connect(switch_Yt.y, table_Y_tTOtheta.u[1])
              annotation (Line(points={{61,-260},{98,-260}}, color={0,0,127}));
            connect(valveTURB_lim.y, valveTURB_dynamic.u) annotation (Line(points={{161,-260},
                    {161,-260},{196,-260}}, color={0,0,127}));
            connect(control_wFW_high_10th.CS, switch_FW.u1) annotation (Line(
                  points={{-98.5,80},{0,80},{0,8},{38,8}}, color={0,0,127}));
            connect(control_wFW_low.CS, switch_FW.u3) annotation (Line(points={{-98.5,-80},
                    {0,-80},{0,-8},{38,-8}}, color={0,0,127}));
            connect(control_Yt_high.CS, switch_Yt.u1) annotation (Line(points={{-98.5,-220},
                    {-50,-220},{0,-220},{0,-252},{38,-252}}, color={0,0,127}));
            connect(control_Yt_low.CS, switch_Yt.u3) annotation (Line(points={{-98.5,-340},
                    {-48,-340},{0,-340},{0,-268},{38,-268}}, color={0,0,127}));
            connect(greaterEqualThreshold.y, switch_Yt.u2) annotation (Line(points={{-59,0},
                    {-40,0},{-40,-260},{38,-260}}, color={255,0,255}));
            connect(table_Y_tTOtheta.y[1], valveTURB_lim.u) annotation (Line(points={{121,
                    -260},{121,-260},{138,-260}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_high.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-170},{-115,-170},{-115,-187}}, color={0,0,127}));
            connect(switch_Yt.y, control_Yt_low.TS) annotation (Line(points={{61,-260},{80,
                    -260},{80,-290},{-115,-290},{-115,-307}}, color={0,0,127}));
            connect(load, greaterEqualThreshold.u)
              annotation (Line(points={{-330,0},{-82,0}}, color={0,0,127}));
            connect(load, control_wMS_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,361},{-163,361}}, color={0,0,127}));
            connect(load, control_wMS_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,241},{-163,241}}, color={0,0,127}));
            connect(load, control_wFW_high_10th.load) annotation (Line(points={
                    {-330,0},{-260,0},{-260,59},{-163,59}}, color={0,0,127}));
            connect(load, control_wFW_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-62},{-163,-62}}, color={0,0,127}));
            connect(load, control_Yt_high.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-199},{-163,-199}}, color={0,0,127}));
            connect(load, control_Yt_low.load) annotation (Line(points={{-330,0},{-260,0},
                    {-260,-319},{-163,-319}}, color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{242,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{320,300},{242,300}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
                points={{320,0},{320,0},{320,-260},{242,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_low.PV) annotation (Line(
                points={{320,0},{320,-400},{-220,-400},{-220,340},{-163,340}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_PV, control_wMS_high.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,220},{-163,220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, control_wFW_high_10th.PV)
              annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,80},{-163,
                    80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_low, control_wFW_low.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-80},{-163,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_high.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-220},{-163,-220}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveTURB_PV, control_Yt_low.PV) annotation (Line(
                points={{320,0},{320,0},{320,-400},{-220,-400},{-220,-340},{-163,-340}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_pumpMS_bool, control_wMS_low.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-145,390},{-145,373}}, color={255,0,255}));
            connect(TS_pumpMS_bool, control_wMS_high.TS_pumpMS_bool) annotation (Line(
                  points={{-200,390},{-180,390},{-180,270},{-145,270},{-145,253}}, color={
                    255,0,255}));
            connect(TS_pumpFWhigh_bool, control_wFW_high_10th.TS_pumpFWhigh_bool)
              annotation (Line(points={{-200,30},{-145,30},{-145,47}}, color={
                    255,0,255}));
            connect(TS_pumpFWlow_bool, control_wFW_low.TS_pumpFWlow_bool) annotation (
                Line(points={{-200,-30},{-145,-30},{-145,-47}}, color={255,0,255}));
            connect(TS_valveTURBhigh_bool, control_Yt_high.TS_valveTURBhigh_bool)
              annotation (Line(points={{-200,-170},{-145,-170},{-145,-187}}, color={255,0,
                    255}));
            connect(TS_valveTURBlow_bool, control_Yt_low.TS_valveTURBlow_bool)
              annotation (Line(points={{-200,-290},{-145,-290},{-145,-307}}, color={255,0,
                    255}));
            annotation (Diagram(coordinateSystem(extent={{-400,-440},{400,440}})), Icon(
                  coordinateSystem(extent={{-400,-440},{400,440}})));
          end staticDecoupled_10th;
          annotation ();
        end PowerPressureFWcontrollers;

        package WSCcontrollers
          "Package containing model for water/steam cycle control"

          model WSCcontroller "Model of the water/steam cycle control system"
            extends BaseClasses.BaseWSCcontroller;

            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration";

            //-- pumpCOND --
            parameter Modelica.SIunits.Length l_dea_sp
              "Deaerator level set point"                                          annotation (Dialog(tab="pumpCOND"));
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));

              //-- valveRH_DEA --
            parameter Real Kp_valveRH_DEA "Controller proportional gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ti_valveRH_DEA
              "Controller integral time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Td_valveRH_DEA
              "Controller derivative time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real Nd_valveRH_DEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmin_valveRH_DEA
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmax_valveRH_DEA
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSstart_valveRH_DEA "Start value of CS" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real actuatorGain_valveRH_DEA "Actuator gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ta_valveRH_DEA
              "Actuator time constant"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real TS_valveRH_DEA "Tracking signal" annotation (Dialog(tab="valveRH_DEA"));

            //-- valveRH_COND --
            parameter Real Kp_valveRH_COND "Controller proportional gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ti_valveRH_COND
              "Controller integral time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Td_valveRH_COND
              "Controller derivative time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real Nd_valveRH_COND
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmin_valveRH_COND
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmax_valveRH_COND
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSstart_valveRH_COND "Start value of CS" annotation (Dialog(tab="valveRH_COND"));
            parameter Real actuatorGain_valveRH_COND "Actuator gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ta_valveRH_COND
              "Actuator time constant"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real TS_valveRH_COND "Tracking signal" annotation (Dialog(tab="valveRH_COND"));

            //-- valveDEA_SH --
            parameter Real Kp_valveDEA_SH "Controller proportional gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_SH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Td_valveDEA_SH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Nd_valveDEA_SH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmin_valveDEA_SH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmax_valveDEA_SH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSstart_valveDEA_SH "Start value of CS" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real actuatorGain_valveDEA_SH "Actuator gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_SH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real TS_valveDEA_SH "Tracking signal" annotation (Dialog(tab="valveDEA_SH"));

            //-- valveDEA_RH --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_COND_sp
              "Degree of superheating set-point at condenser inlet set point"  annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Kp_valveDEA_RH "Controller proportional gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_RH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Td_valveDEA_RH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Nd_valveDEA_RH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmin_valveDEA_RH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmax_valveDEA_RH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSstart_valveDEA_RH "Start value of CS" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real actuatorGain_valveDEA_RH "Actuator gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_RH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real TS_valveDEA_RH "Tracking signal" annotation (Dialog(tab="valveDEA_RH"));

            //-- eletHEAT --
            parameter Real Kp_eletHEAT "Controller proportional gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ti_eletHEAT
              "Controller integral time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Td_eletHEAT
              "Controller derivative time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real Nd_eletHEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmin_eletHEAT
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmax_eletHEAT
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSstart_eletHEAT "Start value of CS" annotation (Dialog(tab="eletHEAT"));
            parameter Real actuatorGain_eletHEAT "Actuator gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ta_eletHEAT
              "Actuator time constant"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real TS_eletHEAT "Tracking signal" annotation (Dialog(tab="eletHEAT"));

            SingleControllers.control_wCOND control_wCOND(
              l_dea_sp=l_dea_sp,
              Kp_pumpCOND=Kp_pumpCOND,
              Ti_pumpCOND=Ti_pumpCOND,
              Td_pumpCOND=Td_pumpCOND,
              Nd_pumpCOND=Nd_pumpCOND,
              CSmin_pumpCOND=CSmin_pumpCOND,
              CSmax_pumpCOND=CSmax_pumpCOND,
              CSstart_pumpCOND=CSstart_pumpCOND,
              actuatorGain_pumpCOND=actuatorGain_pumpCOND,
              Ta_pumpCOND=Ta_pumpCOND,
              TS_pumpCOND=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-60,320},{0,380}})));
            SingleControllers.control_valveRH_DEA control_valveRH_DEA(
              Kp_valveRH_DEA=Kp_valveRH_DEA,
              Ti_valveRH_DEA=Ti_valveRH_DEA,
              Td_valveRH_DEA=Td_valveRH_DEA,
              Nd_valveRH_DEA=Nd_valveRH_DEA,
              CSmin_valveRH_DEA=CSmin_valveRH_DEA,
              CSmax_valveRH_DEA=CSmax_valveRH_DEA,
              CSstart_valveRH_DEA=CSstart_valveRH_DEA,
              actuatorGain_valveRH_DEA=actuatorGain_valveRH_DEA,
              Ta_valveRH_DEA=Ta_valveRH_DEA,
              TS_valveRH_DEA=TS_valveRH_DEA)
              annotation (Placement(transformation(extent={{-60,180},{0,240}})));
            SingleControllers.control_valveRH_COND control_valveRH_COND(
              Kp_valveRH_COND=Kp_valveRH_COND,
              Ti_valveRH_COND=Ti_valveRH_COND,
              Td_valveRH_COND=Td_valveRH_COND,
              Nd_valveRH_COND=Nd_valveRH_COND,
              CSmin_valveRH_COND=CSmin_valveRH_COND,
              CSmax_valveRH_COND=CSmax_valveRH_COND,
              CSstart_valveRH_COND=CSstart_valveRH_COND,
              actuatorGain_valveRH_COND=actuatorGain_valveRH_COND,
              Ta_valveRH_COND=Ta_valveRH_COND,
              TS_valveRH_COND=TS_valveRH_COND)
              annotation (Placement(transformation(extent={{-60,40},{0,100}})));
            SingleControllers.control_valveDEA_RH control_valveDEA_RH(
              DT_sh_COND_sp=DT_sh_COND_sp,
              Kp_valveDEA_RH=Kp_valveDEA_RH,
              Ti_valveDEA_RH=Ti_valveDEA_RH,
              Td_valveDEA_RH=Td_valveDEA_RH,
              Nd_valveDEA_RH=Nd_valveDEA_RH,
              CSmin_valveDEA_RH=CSmin_valveDEA_RH,
              CSmax_valveDEA_RH=CSmax_valveDEA_RH,
              CSstart_valveDEA_RH=CSstart_valveDEA_RH,
              actuatorGain_valveDEA_RH=actuatorGain_valveDEA_RH,
              Ta_valveDEA_RH=Ta_valveDEA_RH,
              TS_valveDEA_RH=TS_valveDEA_RH)
              annotation (Placement(transformation(extent={{-60,-100},{0,-40}})));
            SingleControllers.control_valveDEA_SH control_valveDEA_SH(
              Kp_valveDEA_SH=Kp_valveDEA_SH,
              Ti_valveDEA_SH=Ti_valveDEA_SH,
              Td_valveDEA_SH=Td_valveDEA_SH,
              Nd_valveDEA_SH=Nd_valveDEA_SH,
              CSmin_valveDEA_SH=CSmin_valveDEA_SH,
              CSmax_valveDEA_SH=CSmax_valveDEA_SH,
              CSstart_valveDEA_SH=CSstart_valveDEA_SH,
              actuatorGain_valveDEA_SH=actuatorGain_valveDEA_SH,
              Ta_valveDEA_SH=Ta_valveDEA_SH,
              TS_valveDEA_SH=TS_valveDEA_SH)
              annotation (Placement(transformation(extent={{-60,-240},{0,-180}})));
            SingleControllers.control_eletHEAT control_eletHEAT(
              Kp_eletHEAT=Kp_eletHEAT,
              Ti_eletHEAT=Ti_eletHEAT,
              Td_eletHEAT=Td_eletHEAT,
              Nd_eletHEAT=Nd_eletHEA,
              CSmin_eletHEAT=CSmin_eletHEAT,
              CSmax_eletHEAT=CSmax_eletHEAT,
              CSstart_eletHEAT=CSstart_eletHEAT,
              TS_eletHEAT=TS_eletHEAT,
              actuatorGain_eletHEAT=actuatorGain_eletHEAT,
              Ta_eletHEAT=Ta_eletHEAT,
              load_switch=load_switch)
              annotation (Placement(transformation(extent={{-60,-380},{0,-320}})));
          equation
            connect(TS_pumpCOND_bool, control_wCOND.TS_pumpCOND_bool) annotation (Line(
                  points={{-140,400},{-30,400},{-30,383}}, color={255,0,255}));
            connect(TS_valveRH_DEA_bool, control_valveRH_DEA.TS_valveRH_DEA_bool)
              annotation (Line(points={{-140,260},{-30,260},{-30,243}}, color={255,0,255}));
            connect(TS_valveRH_COND_bool, control_valveRH_COND.TS_valveRH_COND_bool)
              annotation (Line(points={{-140,120},{-30,120},{-30,103}}, color={255,0,255}));
            connect(TS_valveDEA_RH_bool, control_valveDEA_RH.TS_valveDEA_RH_bool)
              annotation (Line(points={{-140,-20},{-30,-20},{-30,-37}}, color={255,0,255}));
            connect(TS_valveDEA_SH_bool, control_valveDEA_SH.TS_valveDEA_SH_bool)
              annotation (Line(points={{-140,-160},{-86,-160},{-30,-160},{-30,-177}},
                  color={255,0,255}));
            connect(TS_eletHEAT_bool, control_eletHEAT.TS_eletHEAT_bool) annotation (Line(
                  points={{-140,-300},{-30,-300},{-30,-317}}, color={255,0,255}));
            connect(load, control_valveRH_DEA.load) annotation (Line(points={{-330,0},{-286,
                    0},{-220,0},{-220,210},{-63,210}}, color={0,0,127}));
            connect(load, control_valveRH_COND.load) annotation (Line(points={{-330,0},{-220,
                    0},{-220,70},{-63,70}}, color={0,0,127}));
            connect(load, control_valveDEA_RH.load) annotation (Line(points={{-330,0},{-276,
                    0},{-220,0},{-220,-70},{-63,-70}}, color={0,0,127}));
            connect(load, control_valveDEA_SH.load) annotation (Line(points={{-330,0},{-220,
                    0},{-220,-210},{-63,-210}}, color={0,0,127}));
            connect(load, control_eletHEAT.load) annotation (Line(points={{-330,0},{-220,0},
                    {-220,-350},{-63,-350}}, color={0,0,127}));
            connect(signalBus, control_wCOND.signalBus) annotation (Line(
                points={{320,-40},{270,-40},{220,-40},{220,350},{1.5,350}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, control_valveRH_DEA.signalBus) annotation (Line(
                points={{320,-40},{320,-40},{220,-40},{220,210},{1.5,210}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, control_valveRH_COND.signalBus) annotation (Line(
                points={{320,-40},{320,-40},{220,-40},{220,70},{1.5,70}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, control_eletHEAT.signalBus) annotation (Line(
                points={{320,-40},{320,-40},{220,-40},{220,-350},{1.5,-350}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, control_valveDEA_RH.signalBus) annotation (Line(
                points={{320,-40},{320,-40},{220,-40},{220,-70},{1.5,-70}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus, control_valveDEA_SH.signalBus) annotation (Line(
                points={{320,-40},{320,-40},{220,-40},{220,-210},{1.5,-210}},
                color={255,204,51},
                thickness=0.5));
          end WSCcontroller;
        end WSCcontrollers;

        package LinearizationSchemes
          "Package containing the control schemes for linearization"

          model plant_controller_HPpart_highLoad_base
            "Model of the HP plant control system with basic FF signal"

            //Controllers parameter

            //-- Plant load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveTURB --
            parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ti_valveTURB
              "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Td_valveTURB
              "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
            parameter Real Nd_valveTURB
              "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
            parameter Real CSmin_valveTURB
              "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSmax_valveTURB
              "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
            parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
            parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
            parameter Modelica.SIunits.Time Ta_valveTURB
              "Actuator time constant"                                            annotation (Dialog(tab="valveTURB"));
            parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
            parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

            //-- pumpFW --
            parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
              "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- valveBP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
            parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ti_valveBP
              "Controller integral time"                                          annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Td_valveBP
              "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
            parameter Real Nd_valveBP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
            parameter Real CSmin_valveBP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSmax_valveBP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
            parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
            parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
            parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant"
                                                                                annotation (Dialog(tab="valveBP"));
            parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
            parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

            //-- pumpHPH --
            parameter Modelica.SIunits.Temperature T_MS_sp
              "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
            parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ti_pumpHPH
              "Controller integral time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Td_pumpHPH
              "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
            parameter Real Nd_pumpHPH
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmin_pumpHPH
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSmax_pumpHPH
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
            parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));
            parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
            parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,40},{20,80}}),  iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PID PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW,
              Td=Td_pumpFW,
              N=Nd_pumpFW)
              annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-140})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep2
              annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,240})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,220},{260,260}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,270},{300,290}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,242},{380,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,242},{340,262}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,
                  1.436; 90,1.605; 100,1.757])
                                              annotation (Placement(transformation(
                    extent={{-260,-200},{-240,-180}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-190})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                      -150},{-120,-130}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-180,-144},{-160,-124}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                          smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,0.02; 30,0.02; 40,0.02; 50,0.02; 60,0.02; 70,0.02; 80,0.02;
                  90,0.1245; 100,0.4717])
              annotation (Placement(transformation(extent={{180,-150},{160,-130}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={210,-140})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,
                  9.56; 90,10.76; 100,11.95])
              annotation (Placement(transformation(extent={{240,180},{220,200}})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,230},{100,250}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,190})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,270},{250,290}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={360,160}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,320})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                    -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                    299,280},{280,280},{280,256}},
                                          color={0,0,127}));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,242},{0,240},{38,240}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_pumpMS.SP, table_P_MEC.y[1])
              annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y)
              annotation (Line(points={{362,252},{368,252},{379,252}},
                                                             color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1])
              annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                                 color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                    {-152,-190},{-152,-146},{-142,-146}},color={0,0,127}));
            connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{199,-140},
                    {190,-140},{182,-140}},color={0,0,127}));
            connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                    190},{242,190}}, color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                    190},{131,234},{122,234}}, color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                    240}},          color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                    {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
            connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},
                    {-84,-140}}, color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,-128}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,60},{0,60},{0,-140},{-38,-140}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
                color={255,204,51},
                thickness=0.5));

            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                    280},{272,256}}, color={255,0,255}));
            connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                    -100},{-280,-124}}, color={0,0,127}));
            connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{122,246},{172,
                    246},{220,246},{220,240},{262,240}}, color={0,0,127}));
            connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,-140},
                    {-224,-140},{-224,-128},{-182,-128}}, color={0,0,127}));
            connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                    238},{324,160},{360,160}}, color={0,0,127}));
            connect(pumpHPH_dynamic.u, table_w_HPH.y[1]) annotation (Line(points=
                    {{84,-140},{159,-140},{159,-140}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -300},{400,300}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="PLANT
controller"),     Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,300},{400,-300}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_highLoad_base;

          model plant_controller_HPpart_highLoad_lin
            "Model of the HP plant control system"

            //Controllers parameter

            //-- OTSG load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp_TS
              "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveSH_RH --
            parameter Real Kp_valveSH_RH "Controller proportional gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH
              "Controller integral time"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Td_valveSH_RH
              "Controller derivative time"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Real Nd_valveSH_RH
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSmin_valveSH_RH
              "Minimum value of control signal for scaling"                               annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSmax_valveSH_RH
              "Maximum value of control signal for scaling"                               annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSstart_valveSH_RH "Start value of CS" annotation (Dialog(tab="valveSH_RH"));
            parameter Real actuatorGain_valveSH_RH "Actuator gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ta_valveSH_RH
              "Actuator time constant"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Boolean useTS_valveSH_RH "Tracking reference mode" annotation (Dialog(tab="valveSH_RH"));
            parameter Real TS_valveSH_RH "Tracking signal" annotation (Dialog(tab="valveSH_RH"));

            //-- pumpFW --
            parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
              "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveRH_DEA --
            parameter Real Kp_valveRH_DEA "Controller proportional gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ti_valveRH_DEA
              "Controller integral time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Td_valveRH_DEA
              "Controller derivative time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real Nd_valveRH_DEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmin_valveRH_DEA
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmax_valveRH_DEA
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSstart_valveRH_DEA "Start value of CS" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real actuatorGain_valveRH_DEA "Actuator gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ta_valveRH_DEA
              "Actuator time constant"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Boolean useTS_valveRH_DEA "Tracking reference mode" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real TS_valveRH_DEA "Tracking signal" annotation (Dialog(tab="valveRH_DEA"));

            //-- valveRH_COND --
            parameter Modelica.SIunits.AbsolutePressure p_RH_sp
              "RH pressure set point"  annotation (Dialog(tab="valveRH_COND"));
            parameter Real Kp_valveRH_COND "Controller proportional gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ti_valveRH_COND
              "Controller integral time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Td_valveRH_COND
              "Controller derivative time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real Nd_valveRH_COND
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmin_valveRH_COND
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmax_valveRH_COND
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSstart_valveRH_COND "Start value of CS" annotation (Dialog(tab="valveRH_COND"));
            parameter Real actuatorGain_valveRH_COND "Actuator gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ta_valveRH_COND
              "Actuator time constant"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Boolean useTS_valveRH_COND "Tracking reference mode" annotation (Dialog(tab="valveRH_COND"));
            parameter Real TS_valveRH_COND "Tracking signal" annotation (Dialog(tab="valveRH_COND"));

            //-- pumpCOND --
            parameter Modelica.SIunits.Length l_dea_sp
              "Deaerator level set point"                                          annotation (Dialog(tab="pumpCOND"));
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Boolean useTS_pumpCOND "Tracking reference mode" annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));

            //-- valveDEA_SH --
            parameter Modelica.SIunits.Temperature T_RH_out_sp
              "Molten Salt RH outlet temperature set point"  annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Kp_valveDEA_SH "Controller proportional gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_SH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Td_valveDEA_SH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Nd_valveDEA_SH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmin_valveDEA_SH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmax_valveDEA_SH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSstart_valveDEA_SH "Start value of CS" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real actuatorGain_valveDEA_SH "Actuator gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_SH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Boolean useTS_valveDEA_SH "Tracking reference mode" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real TS_valveDEA_SH "Tracking signal" annotation (Dialog(tab="valveDEA_SH"));

            //-- valveDEA_RH --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_COND_sp
              "Degree of superheating set-point at condenser inlet set point"  annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Kp_valveDEA_RH "Controller proportional gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_RH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Td_valveDEA_RH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Nd_valveDEA_RH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmin_valveDEA_RH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmax_valveDEA_RH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSstart_valveDEA_RH "Start value of CS" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real actuatorGain_valveDEA_RH "Actuator gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_RH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Boolean useTS_valveDEA_RH "Tracking reference mode" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real TS_valveDEA_RH "Tracking signal" annotation (Dialog(tab="valveDEA_RH"));

            //-- eletHEAT --
            parameter Real Kp_eletHEAT "Controller proportional gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ti_eletHEAT
              "Controller integral time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Td_eletHEAT
              "Controller derivative time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real Nd_eletHEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmin_eletHEAT
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmax_eletHEAT
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSstart_eletHEAT "Start value of CS" annotation (Dialog(tab="eletHEAT"));
            parameter Boolean useTS_eletHEAT "Tracking reference mode" annotation (Dialog(tab="eletHEAT"));
            parameter Real TS_eletHEAT "Tracking signal" annotation (Dialog(tab="eletHEAT"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,180},{20,220}}),iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW)
              annotation (Placement(transformation(extent={{-290,360},{-250,400}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-50,380})));
            Modelica.Blocks.Sources.BooleanStep booleanStep2(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-230,410},{-250,430}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-310,410},{-290,430}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-20},{40,20}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,380})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,360},{260,400}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,410},{300,430}})));
            Modelica.Blocks.Continuous.FirstOrder valveSH_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSH_RH,
              T=Ta_valveSH_RH)
              annotation (Placement(transformation(extent={{80,180},{40,220}})));
            IndustrialControlSystems.Controllers.PI  PID_valveSH_RH(
              AntiWindup=true,
              useTS=useTS_valveSH_RH,
              CS_start=CSstart_valveSH_RH,
              CSmin=CSmin_valveSH_RH,
              CSmax=CSmax_valveSH_RH,
              Kp=Kp_valveSH_RH,
              Ti=Ti_valveSH_RH)
              annotation (Placement(transformation(extent={{300,180},{260,220}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep6(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,230},{262,250}})));
            Modelica.Blocks.Sources.Constant valveSH_RH_TS(k=TS_valveSH_RH)
              annotation (Placement(transformation(extent={{320,230},{300,250}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,382},{380,402}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,202},{380,222}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,202},{340,222}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                  518.15; 80,518.15; 90,514.25; 100,504.85])
              annotation (Placement(transformation(extent={{-360,2},{-340,22}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,330})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-130,
                      370},{-110,390}})));
            Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                    extent={{-170,376},{-150,396}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={190,0})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,370},{100,390}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,330})));
            Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                  transformation(extent={{-120,400},{-160,440}}),
                  iconTransformation(extent={{-440,220},{-400,260}})));
            Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                  transformation(extent={{100,400},{140,440}}),iconTransformation(
                    extent={{-440,460},{-400,500}})));
            Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                  transformation(extent={{100,220},{140,260}}), iconTransformation(
                    extent={{-440,340},{-400,380}})));
            Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent={{-210,
                      382},{-190,402}})));
            Modelica.Blocks.Math.Add add10
              annotation (Placement(transformation(extent={{180,376},{160,396}})));
            Modelica.Blocks.Math.Add add3
              annotation (Placement(transformation(extent={{216,196},{196,216}})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{180,190},{160,210}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,150})));
            Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
              annotation (Placement(transformation(extent={{-360,382},{-340,402}})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_DEA_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveRH_DEA,
              T=Ta_valveRH_DEA)
              annotation (Placement(transformation(extent={{-80,180},{-40,220}})));
            IndustrialControlSystems.Controllers.PI PID_valveRH_DEA(
              AntiWindup=true,
              useTS=useTS_valveRH_DEA,
              CSmin=CSmin_valveRH_DEA,
              CSmax=CSmax_valveRH_DEA,
              CS_start=CSstart_valveRH_DEA,
              Kp=Kp_valveRH_DEA,
              Ti=Ti_valveRH_DEA)
              annotation (Placement(transformation(extent={{-300,180},{-260,220}})));
            Modelica.Blocks.Sources.Constant valveRH_DEA_TS(k=TS_valveRH_DEA)
              annotation (Placement(transformation(extent={{-320,230},{-300,250}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-160,
                      190},{-140,210}})));
            Modelica.Blocks.Math.Add add11
              annotation (Placement(transformation(extent={{-220,196},{-200,216}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (Placement(
                  transformation(extent={{-120,220},{-160,260}}), iconTransformation(
                    extent={{-440,100},{-400,140}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={380,290}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,520})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,410},{250,430}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{240,320},{220,340}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep1(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,230},{-260,250}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,2},{-380,22}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_DEA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{-260,140},{-240,160}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,382},{340,402}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_DEA_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,190},{-100,210}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=3, uMin=0.01)
              annotation (Placement(transformation(extent={{-102,370},{-82,390}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=0.6, uMin=0.01)
              annotation (Placement(transformation(extent={{120,-10},{100,10}})));
            Modelica.Blocks.Nonlinear.Limiter valveSH_RH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{116,190},{96,210}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-50,120})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-230})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_COND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveRH_COND,
              T=Ta_valveRH_COND)
              annotation (Placement(transformation(extent={{-80,-200},{-40,-160}})));
            IndustrialControlSystems.Controllers.PI PID_valveRH_COND(
              AntiWindup=true,
              useTS=useTS_valveRH_COND,
              CSmin=CSmin_valveRH_COND,
              CSmax=CSmax_valveRH_COND,
              CS_start=CSstart_valveRH_COND,
              Kp=Kp_valveRH_COND,
              Ti=Ti_valveRH_COND)
              annotation (Placement(transformation(extent={{-300,-200},{-260,-160}})));
            Modelica.Blocks.Sources.Constant valveRH_COND_TS(k=TS_valveRH_COND)
              annotation (Placement(transformation(extent={{-320,-150},{-300,-130}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{-160,
                      -190},{-140,-170}})));
            Modelica.Blocks.Math.Add add6
              annotation (Placement(transformation(extent={{-220,-184},{-200,-164}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep3(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-150},{-260,-130}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_COND(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{-260,-240},{-240,-220}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_COND_lim(
                                                              uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,-190},{-100,-170}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (Placement(
                  transformation(extent={{-120,-160},{-160,-120}}),
                                                                  iconTransformation(
                    extent={{-440,-260},{-400,-220}})));
            Modelica.Blocks.Sources.Constant DT_SH_COND_SP(k=DT_sh_COND_sp)
              annotation (Placement(transformation(extent={{380,-358},{360,-338}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpCOND(
              AntiWindup=true,
              useTS=useTS_pumpCOND,
              useBIAS=false,
              CSmin=CSmin_pumpCOND,
              CSmax=CSmax_pumpCOND,
              CS_start=CSstart_pumpCOND,
              Kp=Kp_pumpCOND,
              Ti=Ti_pumpCOND)
              annotation (Placement(transformation(extent={{-300,-380},{-260,-340}})));
           Modelica.Blocks.Continuous.FirstOrder pumpCOND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpCOND,
              T=Ta_pumpCOND) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-360})));
            Modelica.Blocks.Sources.BooleanStep booleanStep4(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-330},{-260,-310}})));
            Modelica.Blocks.Sources.Constant pumpCOND_TS(
                                                       k=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-320,-330},{-300,-310}})));
            Modelica.Blocks.Math.Add add12
                                          annotation (Placement(transformation(extent={{-200,
                      -364},{-180,-344}})));
            Modelica.Blocks.Sources.Constant l_DEA_SP(k=l_dea_sp)
              annotation (Placement(transformation(extent={{-370,-358},{-350,-338}})));
            Modelica.Blocks.Nonlinear.Limiter pumpCOND_lim(uMax=6, uMin=0.1)
              annotation (Placement(transformation(extent={{-128,-370},{-108,-350}})));
            Modelica.Blocks.Interfaces.RealInput du_w_COND
                                                         annotation (Placement(
                  transformation(extent={{-120,-340},{-160,-300}}),
                  iconTransformation(extent={{-440,-380},{-400,-340}})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_SH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveDEA_SH,
              T=Ta_valveDEA_SH)
              annotation (Placement(transformation(extent={{80,-200},{40,-160}})));
            IndustrialControlSystems.Controllers.PI  PID_valveDEA_SH(
              AntiWindup=true,
              useTS=useTS_valveDEA_SH,
              CS_start=CSstart_valveDEA_SH,
              CSmin=CSmin_valveDEA_SH,
              CSmax=CSmax_valveDEA_SH,
              Kp=Kp_valveDEA_SH,
              Ti=Ti_valveDEA_SH)
              annotation (Placement(transformation(extent={{300,-200},{260,-160}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep7(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,-150},{262,-130}})));
            Modelica.Blocks.Sources.Constant valveDEA_SH_TS(
                                                           k=TS_valveDEA_SH)
              annotation (Placement(transformation(extent={{320,-150},{300,-130}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_RH_out(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,473.3 + 273.15; 30,471.4 + 273.15; 40,470 + 273.15; 50,468.3 + 273.15;
                  60,465.5 + 273.15; 70,463 + 273.15; 80,461.4 + 273.15; 90,459.4 + 273.15;
                  100,460.8 + 273.15])
              annotation (Placement(transformation(extent={{360,-178},{340,-158}})));
            Modelica.Blocks.Math.Add add7
              annotation (Placement(transformation(extent={{210,-184},{190,-164}})));
            Modelica.Blocks.Math.Add add13
              annotation (Placement(transformation(extent={{160,-190},{140,-170}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_SH_lim(
                                                             uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,-190},{100,-170}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (Placement(
                  transformation(extent={{100,-160},{140,-120}}),iconTransformation(
                    extent={{-440,-20},{-400,20}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,-230})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{260,-240},{240,-220}})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveDEA_RH,
              T=Ta_valveDEA_RH)
              annotation (Placement(transformation(extent={{80,-380},{40,-340}})));
            IndustrialControlSystems.Controllers.PI PID_valveDEA_RH(
              AntiWindup=true,
              useTS=useTS_valveDEA_SH,
              CSmin=CSmin_valveDEA_RH,
              CSmax=CSmax_valveDEA_RH,
              CS_start=CSstart_valveDEA_RH,
              Kp=Kp_valveDEA_RH,
              Ti=Ti_valveDEA_RH)
              annotation (Placement(transformation(extent={{300,-380},{260,-340}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep8(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,-330},{262,-310}})));
            Modelica.Blocks.Sources.Constant valveDEA_RH_TS(k=TS_valveDEA_RH)
              annotation (Placement(transformation(extent={{320,-330},{300,-310}})));
            Modelica.Blocks.Math.Add add14
              annotation (Placement(transformation(extent={{210,-364},{190,-344}})));
            Modelica.Blocks.Math.Add add15
              annotation (Placement(transformation(extent={{160,-370},{140,-350}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_RH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,-370},{100,-350}})));
            Modelica.Blocks.Sources.Ramp LOAD13(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,-410})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{260,-420},{240,-400}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (Placement(
                  transformation(extent={{100,-340},{140,-300}}), iconTransformation(
                    extent={{-440,-140},{-400,-100}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,8.651e5; 30,13.19e5; 40,17.83e5; 50,22.6e5; 60,27.39e5; 70,32.65e5;
                  80,37.19e5; 90,42.05e5; 100,47.31e5])
              annotation (Placement(transformation(extent={{-360,-178},{-340,-158}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,-178},{-380,-158}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
                  40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
                  100,171e5])
              annotation (Placement(transformation(extent={{270,100},{250,120}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,
                  0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,
                  1.436; 90,1.605; 100,1.757]) annotation (Placement(
                  transformation(extent={{270,140},{250,160}})));
            Modelica.Blocks.Math.Division division1 annotation (Placement(
                  transformation(extent={{230,120},{210,140}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 9.06913488751826e-10,0.00999999977648258; 2.18218243475121e-09,0.0199999995529652;
                  3.46627393454924e-09,0.0299999993294477; 4.75013051115525e-09,0.0399999991059303;
                  6.0339799823339e-09,0.0500000007450581; 7.31780902540891e-09,0.0599999986588955;
                  8.60163851257312e-09,0.0700000002980232; 9.88546844382654e-09,0.0799999982118607;
                  1.11692957105447e-08,0.0900000035762787; 1.24531229772629e-08,0.100000001490116;
                  1.3736950243981e-08,0.109999999403954; 1.50207775106992e-08,0.119999997317791;
                  1.63046056655958e-08,0.129999995231628; 1.75884320441355e-08,0.140000000596046;
                  1.88722601990321e-08,0.150000005960464; 2.01560865775718e-08,0.159999996423721;
                  2.14399147324684e-08,0.170000001788139; 2.27237411110082e-08,0.180000007152557;
                  2.40075692659048e-08,0.189999997615814; 2.52913956444445e-08,0.200000002980232;
                  2.65752220229842e-08,0.209999993443489; 2.78590501778808e-08,0.219999998807907;
                  2.91428765564206e-08,0.230000004172325; 3.04267047113171e-08,0.239999994635582;
                  3.17105310898569e-08,0.25; 3.29943574683966e-08,0.259999990463257; 3.42781873996501e-08,
                  0.270000010728836; 3.55620137781898e-08,0.280000001192093; 3.68458401567295e-08,
                  0.28999999165535; 3.81296665352693e-08,0.300000011920929; 3.94134964665227e-08,
                  0.310000002384186; 4.06973228450624e-08,0.319999992847443; 4.19811492236022e-08,
                  0.330000013113022; 4.32649756021419e-08,0.340000003576279; 4.45488019806817e-08,
                  0.349999994039536; 4.58326319119351e-08,0.360000014305115; 4.71164582904748e-08,
                  0.370000004768372; 4.84002846690146e-08,0.379999995231628; 4.96841110475543e-08,
                  0.389999985694885; 5.09679409788077e-08,0.400000005960465; 5.22517673573475e-08,
                  0.409999996423721; 5.35355937358872e-08,0.419999986886978; 5.4819420114427e-08,
                  0.430000007152557; 5.61032464929667e-08,0.439999997615814; 5.73870764242201e-08,
                  0.449999988079071; 5.86709028027599e-08,0.46000000834465; 5.99547291812996e-08,
                  0.469999998807907; 6.12385591125531e-08,0.479999989271164; 6.25223819383791e-08,
                  0.490000009536743; 6.38062118696325e-08,0.5; 6.5090041800886e-08,0.509999990463257;
                  6.6373864626712e-08,0.519999980926514; 6.76576945579654e-08,0.529999971389771;
                  6.89415173837915e-08,0.540000021457672; 7.02253473150449e-08,0.550000011920929;
                  7.15091772462984e-08,0.560000002384186; 7.27930000721244e-08,0.569999992847443;
                  7.40768300033778e-08,0.5799999833107; 7.53606528292039e-08,0.589999973773956;
                  7.66444827604573e-08,0.600000023841858; 7.79283126917107e-08,0.610000014305115;
                  7.92121355175368e-08,0.620000004768372; 8.04959654487902e-08,0.629999995231628;
                  8.17797953800437e-08,0.639999985694885; 8.30636182058697e-08,0.649999976158142;
                  8.43474481371231e-08,0.660000026226044; 8.56312709629492e-08,0.670000016689301;
                  8.69151008942026e-08,0.680000007152557; 8.81989308254561e-08,0.689999997615814;
                  8.94827536512821e-08,0.699999988079071; 9.07665835825355e-08,0.709999978542328;
                  9.20504064083616e-08,0.72000002861023; 9.3334236339615e-08,0.730000019073486;
                  9.46180662708684e-08,0.740000009536743; 9.59018890966945e-08,0.75; 9.71857190279479e-08,
                  0.759999990463257; 9.84695489592014e-08,0.769999980926514; 9.97533717850274e-08,
                  0.779999971389771; 1.01037201716281e-07,0.790000021457672; 1.02321024542107e-07,
                  0.800000011920929; 1.0360485447336e-07,0.810000002384186; 1.04888684404614e-07,
                  0.819999992847443; 1.0617250723044e-07,0.8299999833107; 1.07456337161693e-07,
                  0.839999973773956; 1.08740159987519e-07,0.850000023841858; 1.10023989918773e-07,
                  0.860000014305115; 1.11307819850026e-07,0.870000004768372; 1.12591642675852e-07,
                  0.879999995231628; 1.13875472607106e-07,0.889999985694885; 1.15159295432932e-07,
                  0.899999976158142; 1.16443125364185e-07,0.910000026226044; 1.17726955295439e-07,
                  0.920000016689301; 1.19010778121265e-07,0.930000007152557; 1.20294600947091e-07,
                  0.939999997615814; 1.21578437983771e-07,0.949999988079071; 1.22862260809598e-07,
                  0.959999978542328; 1.24146083635424e-07,0.97000002861023; 1.25429920672104e-07,
                  0.980000019073486; 1.2671374349793e-07,0.990000009536743; 1.27997566323756e-07,
                  1])
              annotation (Placement(transformation(extent={{150,190},{130,210}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={298,130})));
            Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,0.53; 30,0.8; 40,1.09; 50,1.37; 60,1.66; 70,1.91; 80,2.16; 90,2.42;
                  100,2.69])
              annotation (Placement(transformation(extent={{-260,320},{-240,340}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,0.02; 30,0.02; 40,0.02; 50,0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245;
                  100,0.4717])
              annotation (Placement(transformation(extent={{160,-10},{140,10}})));
            IndustrialControlSystems.Controllers.PI PID_eletHEAT(
              AntiWindup=true,
              useTS=useTS_valveRH_COND,
              CSmin=CSmin_eletHEAT,
              CSmax=CSmax_eletHEAT,
              CS_start=CSstart_eletHEAT,
              Kp=Kp_eletHEAT,
              Ti=Ti_eletHEAT)
              annotation (Placement(transformation(extent={{-300,-20},{-260,20}})));
            Modelica.Blocks.Sources.Constant eletHEAT_TS(k=TS_eletHEAT)
              annotation (Placement(transformation(extent={{-320,30},{-300,50}})));
            Modelica.Blocks.Math.Add add17
              annotation (Placement(transformation(extent={{-220,-6},{-200,14}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep9(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,30},{-260,50}})));
            Modelica.Blocks.Nonlinear.Limiter eletHEAT_lim(uMin=0, uMax=200000)
              annotation (Placement(transformation(extent={{-120,-10},{-100,10}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_DEA(                                                                 table=[
                  20,8.636e5; 30,12.9e5; 40,17.32e5; 50,22.02e5; 60,26.78e5; 70,26.97e5; 80,
                  27.03e5; 90,27.04e5; 100,27.05e5], smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments)
              annotation (Placement(transformation(extent={{-360,202},{-340,222}})));
            Modelica.Blocks.Sources.Ramp LOAD15(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,202},{-380,222}})));
            Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                  transformation(extent={{-120,40},{-160,80}}), iconTransformation(extent={{-440,
                      -500},{-400,-460}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-262,396},{-262,
                    396},{-262,408},{-262,420},{-251,420}},     color={255,0,255}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,0},{38,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,382},{0,380},{38,380}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveSH_RH.TS) annotation (Line(points={{263,240},
                    {272,240},{272,216}},color={255,0,255}));
            connect(signalBus.valveSH_RH_CS, valveSH_RH_dynamic.y) annotation (Line(
                points={{0,200},{2,200},{38,200}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveSH_RH_PV, PID_valveSH_RH.PV) annotation (Line(
                points={{0,200},{0,200},{0,80},{320,80},{320,198},{296,198}},
                color={255,204,51},
                thickness=0.5));
            connect(table_P_SH.u[1], LOAD2.y)
              annotation (Line(points={{362,212},{379,212}}, color={0,0,127}));
            connect(PID_valveSH_RH.SP, table_P_SH.y[1])
              annotation (Line(points={{296,212},{296,212},{339,212}}, color={0,0,127}));
            connect(product.y, add1.u1)
              annotation (Line(points={{-149,386},{-140,386},{-132,386}},
                                                                 color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,380},{99,380}},
                                    color={0,0,127}));
            connect(add9.y, product.u1) annotation (Line(points={{-189,392},{-180,392},{-172,
                    392}},              color={0,0,127}));
            connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-252,380},{-220,380},
                    {-220,386},{-212,386}},              color={0,0,127}));
            connect(du_w_FW, add9.u1) annotation (Line(points={{-140,420},{-140,420},{-220,
                    420},{-220,398},{-212,398}},         color={0,0,127}));
            connect(du_w_MS, add10.u1) annotation (Line(points={{120,420},{160,420},{200,420},
                    {200,392},{182,392}},color={0,0,127}));
            connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,380},{212,380},
                    {182,380}},                color={0,0,127}));
            connect(du_Y_t, add3.u1) annotation (Line(points={{120,240},{120,240},
                    {220,240},{220,212},{218,212}},
                                                 color={0,0,127}));
            connect(PID_valveSH_RH.CS, add3.u2) annotation (Line(points={{262,200},
                    {218,200}},                      color={0,0,127}));
            connect(add4.u1, add10.y)
              annotation (Line(points={{122,386},{159,386}}, color={0,0,127}));
            connect(add5.u1, add3.y) annotation (Line(points={{182,206},{182,206},
                    {195,206}},    color={0,0,127}));
            connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,392},{-286,392}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,380},{-28,380}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
                points={{0,200},{0,200},{0,280},{-320,280},{-320,378},{-286,378}},
                color={255,204,51},
                thickness=0.5));

            connect(du_thetaRH_DEA, add11.u1) annotation (Line(points={{-140,240},{-230,240},
                    {-230,212},{-222,212}}, color={0,0,127}));
            connect(add11.y, add8.u1) annotation (Line(points={{-199,206},{-199,206},{-162,
                    206}},color={0,0,127}));
            connect(signalBus.valveRH_DEA_CS, valveRH_DEA_dynamic.y) annotation (Line(
                points={{0,200},{-19,200},{-38,200}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_valveRH_DEA.CS, add11.u2)
              annotation (Line(points={{-262,200},{-242,200},{-222,200}},
                                                                       color={0,0,127}));
            connect(signalBus.valveRH_DEA_PV, PID_valveRH_DEA.PV) annotation (Line(
                points={{0,200},{0,200},{0,80},{-320,80},{-320,198},{-296,198}},
                color={255,204,51},
                thickness=0.5));
            connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,290},{320,290},{320,
                    378},{296,378}}, color={0,0,127}));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,420},{272,
                    420},{272,396}}, color={255,0,255}));
            connect(table_w_MS.u[1], LOAD7.y) annotation (Line(points={{242,330},{242,330},
                    {259,330}},           color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,330},{140,330},
                    {140,374},{122,374}},           color={0,0,127}));
            connect(booleanStep1.y, PID_valveRH_DEA.TS) annotation (Line(points={{-261,240},
                    {-272,240},{-272,216}},          color={255,0,255}));
            connect(LOAD1.y, table_T_FW.u[1])
              annotation (Line(points={{-379,12},{-362,12}}, color={0,0,127}));
            connect(LOAD10.y, table_thetaRH_DEA.u[1]) annotation (Line(points={{-279,150},
                    {-270.5,150},{-262,150}}, color={0,0,127}));
            connect(table_thetaRH_DEA.y[1], add8.u2) annotation (Line(points={{-239,150},{
                    -239,150},{-180,150},{-180,194},{-162,194}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,392},{379,392}},
                                          color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{296,392},{339,
                    392}},                         color={0,0,127}));
            connect(add8.y, valveRH_DEA_lim.u)
              annotation (Line(points={{-139,200},{-122,200}},
                                                             color={0,0,127}));
            connect(valveRH_DEA_lim.y, valveRH_DEA_dynamic.u)
              annotation (Line(points={{-99,200},{-84,200}},
                                                           color={0,0,127}));
            connect(pumpFW_dynamic.u, pumpFW_lim.y) annotation (Line(points={{-74,380},{-78,
                    380},{-81,380}},              color={0,0,127}));
            connect(add1.y, pumpFW_lim.u) annotation (Line(points={{-109,380},{-106.5,380},
                    {-104,380}},               color={0,0,127}));
            connect(pumpHPH_dynamic.u, pumpHPH_lim.y)
              annotation (Line(points={{84,0},{99,0}},       color={0,0,127}));
            connect(valveSH_RH_dynamic.u, valveSH_RH_lim.y)
              annotation (Line(points={{84,200},{95,200}},
                                                         color={0,0,127}));
            connect(signalBus.load, LOAD3.y) annotation (Line(
                points={{0,200},{0,200},{0,120},{-39,120}},
                color={255,204,51},
                thickness=0.5));
            connect(du_thetaRH_COND, add6.u1) annotation (Line(points={{-140,-140},{-230,-140},
                    {-230,-168},{-222,-168}},
                                            color={0,0,127}));
            connect(add6.y, add2.u1) annotation (Line(points={{-199,-174},{-199,-174},{-162,
                    -174}},color={0,0,127}));
            connect(PID_valveRH_COND.CS, add6.u2) annotation (Line(points={{-262,-180},{-242,
                    -180},{-222,-180}}, color={0,0,127}));
            connect(booleanStep3.y, PID_valveRH_COND.TS) annotation (Line(points={{-261,-140},
                    {-272,-140},{-272,-164}},
                                            color={255,0,255}));
            connect(LOAD8.y, table_thetaRH_COND.u[1]) annotation (Line(points={{-279,-230},
                    {-270.5,-230},{-262,-230}}, color={0,0,127}));
            connect(table_thetaRH_COND.y[1], add2.u2) annotation (Line(points={{-239,-230},
                    {-239,-230},{-180,-230},{-180,-186},{-162,-186}}, color={0,0,127}));
            connect(add2.y, valveRH_COND_lim.u) annotation (Line(points={{-139,-180},{-130,
                    -180},{-122,-180}}, color={0,0,127}));
            connect(valveRH_COND_lim.y, valveRH_COND_dynamic.u) annotation (Line(points={{-99,
                    -180},{-92.5,-180},{-84,-180}},     color={0,0,127}));
            connect(PID_pumpCOND.TS, booleanStep4.y) annotation (Line(points={{-272,-344},
                    {-272,-344},{-272,-332},{-272,-320},{-261,-320}},color={255,0,255}));
            connect(PID_pumpCOND.CS, add12.u2) annotation (Line(points={{-262,-360},{-202,
                    -360}},                   color={0,0,127}));
            connect(add12.y, pumpCOND_lim.u) annotation (Line(points={{-179,-354},{-156,-354},
                    {-156,-360},{-130,-360}}, color={0,0,127}));
            connect(pumpCOND_lim.y, pumpCOND_dynamic.u) annotation (Line(points={{-107,-360},
                    {-95.5,-360},{-84,-360}}, color={0,0,127}));
            connect(booleanStep7.y, PID_valveDEA_SH.TS) annotation (Line(points={{263,-140},
                    {272,-140},{272,-164}}, color={255,0,255}));
            connect(table_T_RH_out.u[1], LOAD9.y)
              annotation (Line(points={{362,-168},{370,-168},{379,-168}},
                                                               color={0,0,127}));
            connect(PID_valveDEA_SH.SP, table_T_RH_out.y[1]) annotation (Line(points={{296,
                    -168},{296,-168},{339,-168}}, color={0,0,127}));
            connect(du_thetaDEA_SH, add7.u1) annotation (Line(points={{120,-140},{120,-140},
                    {220,-140},{220,-168},{212,-168}}, color={0,0,127}));
            connect(PID_valveDEA_SH.CS, add7.u2) annotation (Line(points={{262,-180},{242,
                    -180},{212,-180}}, color={0,0,127}));
            connect(add13.u1, add7.y)
              annotation (Line(points={{162,-174},{189,-174}}, color={0,0,127}));
            connect(table_thetaDEA_SH.u[1], LOAD11.y)
              annotation (Line(points={{262,-230},{279,-230}}, color={0,0,127}));
            connect(table_thetaDEA_SH.y[1], add13.u2) annotation (Line(points={{239,-230},
                    {210,-230},{180,-230},{180,-186},{162,-186}}, color={0,0,127}));
            connect(booleanStep8.y, PID_valveDEA_RH.TS) annotation (Line(points={{263,-320},
                    {272,-320},{272,-344}}, color={255,0,255}));
            connect(du_thetaDEA_RH, add14.u1) annotation (Line(points={{120,-320},{120,-320},
                    {220,-320},{220,-348},{212,-348}}, color={0,0,127}));
            connect(PID_valveDEA_RH.CS, add14.u2) annotation (Line(points={{262,-360},{242,
                    -360},{212,-360}}, color={0,0,127}));
            connect(add15.u1, add14.y)
              annotation (Line(points={{162,-354},{189,-354}}, color={0,0,127}));
            connect(table_thetaDEA_RH.u[1], LOAD13.y)
              annotation (Line(points={{262,-410},{279,-410}}, color={0,0,127}));
            connect(table_thetaDEA_RH.y[1], add15.u2) annotation (Line(points={{239,-410},
                    {210,-410},{180,-410},{180,-366},{162,-366}}, color={0,0,127}));
            connect(valveDEA_RH_lim.u, add15.y) annotation (Line(points={{122,-360},{139,-360}},
                                 color={0,0,127}));
            connect(valveDEA_SH_lim.u, add13.y)
              annotation (Line(points={{122,-180},{139,-180}}, color={0,0,127}));
            connect(PID_valveDEA_RH.SP, DT_SH_COND_SP.y) annotation (Line(points={{296,-348},
                    {330,-348},{359,-348}}, color={0,0,127}));
            connect(LOAD12.y, table_p_RH.u[1])
              annotation (Line(points={{-379,-168},{-362,-168}}, color={0,0,127}));
            connect(table_p_RH.y[1], PID_valveRH_COND.SP)
              annotation (Line(points={{-339,-168},{-296,-168}}, color={0,0,127}));
            connect(signalBus.valveRH_COND_CS, valveRH_COND_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-180},{-38,-180}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_SH_CS, valveDEA_SH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-180},{38,-180}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-180},{0,-360},{-38,-360}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_RH_CS, valveDEA_RH_dynamic.y) annotation (Line(
                points={{0,200},{0,200},{0,-360},{38,-360}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_COND_PV, PID_valveRH_COND.PV) annotation (Line(
                points={{0,200},{0,200},{0,-260},{-320,-260},{-320,-182},{-296,-182}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_PV, PID_pumpCOND.PV) annotation (Line(
                points={{0,200},{0,200},{0,-360},{0,-442},{0,-440},{-320,-440},{-320,-362},
                    {-296,-362}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_RH_PV, PID_valveDEA_RH.PV) annotation (Line(
                points={{0,200},{0,200},{0,-440},{320,-440},{320,-362},{296,-362}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_SH_PV, PID_valveDEA_SH.PV) annotation (Line(
                points={{0,200},{0,200},{0,-260},{320,-260},{320,-182},{296,-182}},
                color={255,204,51},
                thickness=0.5));
            connect(du_w_COND, add12.u1) annotation (Line(points={{-140,-320},{-180,-320},
                    {-220,-320},{-220,-348},{-202,-348}}, color={0,0,127}));
            connect(l_DEA_SP.y, PID_pumpCOND.SP) annotation (Line(points={{-349,-348},{-296,
                    -348}},             color={0,0,127}));
            connect(valveDEA_SH_dynamic.u, valveDEA_SH_lim.y)
              annotation (Line(points={{84,-180},{99,-180}},           color={0,0,127}));
            connect(valveDEA_RH_dynamic.u, valveDEA_RH_lim.y) annotation (Line(points={{84,-360},
                    {94,-360},{99,-360}},                 color={0,0,127}));
            connect(valveSH_RH_sourceP.y[1], division1.u2) annotation (Line(
                  points={{249,110},{242,110},{242,124},{232,124}}, color={0,0,
                    127}));
            connect(valveSH_RH_sourceW.y[1], division1.u1) annotation (Line(
                  points={{249,150},{244,150},{244,136},{232,136}}, color={0,0,
                    127}));
            connect(division1.y, add5.u2) annotation (Line(points={{209,130},{190,
                    130},{190,194},{182,194}}, color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y) annotation (Line(points={{152,
                    200},{152,200},{159,200}}, color={0,0,127}));
            connect(valveSH_RH_lim.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{118,200},{129,200}}, color={0,0,127}));
            connect(LOAD6.y, valveSH_RH_sourceP.u[1]) annotation (Line(points={{287,130},{
                    280,130},{280,110},{272,110}}, color={0,0,127}));
            connect(LOAD6.y, valveSH_RH_sourceW.u[1]) annotation (Line(points={{287,130},{
                    280,130},{280,150},{272,150}}, color={0,0,127}));
            connect(pumpHPH_lim.u, table_w_HPH.y[1])
              annotation (Line(points={{122,0},{139,0}}, color={0,0,127}));
            connect(table_w_HPH.u[1], LOAD5.y)
              annotation (Line(points={{162,0},{172,0},{179,0}}, color={0,0,127}));
            connect(LOAD4.y, table_w_FW.u[1]) annotation (Line(points={{-279,330},{-270.5,
                    330},{-262,330}}, color={0,0,127}));
            connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,330},{-214,
                    330},{-180,330},{-180,380},{-172,380}}, color={0,0,127}));
            connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,330},{-140,330},
                    {-140,374},{-132,374}}, color={0,0,127}));
            connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-252,
                    380},{-244,380},{-244,400},{-244,402},{-270,402},{-270,396}},
                  color={0,0,127}));
            connect(PID_valveRH_DEA.CS, PID_valveRH_DEA.TR) annotation (Line(
                  points={{-262,200},{-254,200},{-254,222},{-280,222},{-280,216}},
                  color={0,0,127}));
            connect(PID_valveSH_RH.CS, PID_valveSH_RH.TR) annotation (Line(points=
                   {{262,200},{256,200},{256,224},{280,224},{280,216}}, color={0,
                    0,127}));
            connect(PID_valveDEA_SH.CS, PID_valveDEA_SH.TR) annotation (Line(
                  points={{262,-180},{258,-180},{256,-180},{256,-156},{280,-156},{280,-164}},
                                 color={0,0,127}));
            connect(PID_valveDEA_RH.CS, PID_valveDEA_RH.TR) annotation (Line(
                  points={{262,-360},{256,-360},{256,-336},{280,-336},{280,-344}},
                  color={0,0,127}));
            connect(PID_valveRH_COND.CS, PID_valveRH_COND.TR) annotation (Line(
                  points={{-262,-180},{-256,-180},{-256,-158},{-280,-158},{-280,-164}},
                            color={0,0,127}));
            connect(PID_pumpCOND.CS, PID_pumpCOND.TR) annotation (Line(points={{-262,-360},
                    {-256,-360},{-256,-336},{-280,-336},{-280,-344}},
                  color={0,0,127}));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,420},
                    {280,420},{280,396}}, color={0,0,127}));
            connect(du_Q_eletHEAT, add17.u1) annotation (Line(points={{-140,60},{-230,60},
                    {-230,10},{-222,10}}, color={0,0,127}));
            connect(PID_eletHEAT.CS, add17.u2)
              annotation (Line(points={{-262,0},{-222,0},{-222,-2}}, color={0,0,127}));
            connect(booleanStep9.y, PID_eletHEAT.TS) annotation (Line(points={{-261,40},{-272,
                    40},{-272,16}}, color={255,0,255}));
            connect(LOAD15.y,table_p_DEA. u[1]) annotation (Line(points={{-379,212},{-374,
                    212},{-370,212},{-362,212}}, color={0,0,127}));
            connect(PID_eletHEAT.CS, PID_eletHEAT.TR) annotation (Line(points={{-262,0},{-254,
                    0},{-254,22},{-280,22},{-280,16}}, color={0,0,127}));
            connect(table_T_FW.y[1], PID_eletHEAT.SP)
              annotation (Line(points={{-339,12},{-318,12},{-296,12}}, color={0,0,127}));
            connect(add17.y, eletHEAT_lim.u) annotation (Line(points={{-199,4},{-160,
                    4},{-160,0},{-122,0}}, color={0,0,127}));
            connect(signalBus.eletHEAT_CS, eletHEAT_lim.y) annotation (Line(
                points={{0,200},{0,200},{0,0},{-99,0}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.eletHEAT_PV_high, PID_eletHEAT.PV) annotation (Line(
                points={{0,200},{0,200},{0,-80},{-320,-80},{-320,-2},{-296,-2}},
                color={255,204,51},
                thickness=0.5));
            connect(table_p_DEA.y[1], PID_valveRH_DEA.SP)
              annotation (Line(points={{-339,212},{-296,212}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -500},{400,500}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-500},{400,500}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="DCS"),
                  Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,500},{400,-500}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_highLoad_lin;

          model plant_controller_HPpart_lowLoad_lin
            "Model of the HP plant control system"

            //Controllers parameter

            //-- OTSG load --
            parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
            parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));
            parameter Modelica.SIunits.Time t_start_ramp_TS
              "Tracking signal mode start time [s]"                                     annotation (Dialog(tab="Plant load"));
            parameter Boolean TS_start = true
              "Tracking reference mode on FB loop"                                 annotation (Dialog(tab="Plant load"));

            //-- pumpMS --
            parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ti_pumpMS
              "Controller integral time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Td_pumpMS
              "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
            parameter Real Nd_pumpMS
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
            parameter Real CSmin_pumpMS
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSmax_pumpMS
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
            parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
            parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
            parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

            //-- valveSH_RH --
            parameter Real Kp_valveSH_RH "Controller proportional gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH
              "Controller integral time"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Td_valveSH_RH
              "Controller derivative time"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Real Nd_valveSH_RH
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSmin_valveSH_RH
              "Minimum value of control signal for scaling"                               annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSmax_valveSH_RH
              "Maximum value of control signal for scaling"                               annotation (Dialog(tab="valveSH_RH"));
            parameter Real CSstart_valveSH_RH "Start value of CS" annotation (Dialog(tab="valveSH_RH"));
            parameter Real actuatorGain_valveSH_RH "Actuator gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ta_valveSH_RH
              "Actuator time constant"                                             annotation (Dialog(tab="valveSH_RH"));
            parameter Boolean useTS_valveSH_RH "Tracking reference mode" annotation (Dialog(tab="valveSH_RH"));
            parameter Real TS_valveSH_RH "Tracking signal" annotation (Dialog(tab="valveSH_RH"));

            //-- pumpFW --
            parameter Modelica.SIunits.Length l_SEP_sp
              "Separator level set point"     annotation (Dialog(tab="pumpFW"));
            parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ti_pumpFW
              "Controller integral time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Td_pumpFW
              "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
            parameter Real Nd_pumpFW
              "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
            parameter Real CSmin_pumpFW
              "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSmax_pumpFW
              "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
            parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
            parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
            parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- valveRH_DEA --
            parameter Real Kp_valveRH_DEA "Controller proportional gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ti_valveRH_DEA
              "Controller integral time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Td_valveRH_DEA
              "Controller derivative time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real Nd_valveRH_DEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmin_valveRH_DEA
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmax_valveRH_DEA
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSstart_valveRH_DEA "Start value of CS" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real actuatorGain_valveRH_DEA "Actuator gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ta_valveRH_DEA
              "Actuator time constant"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Boolean useTS_valveRH_DEA "Tracking reference mode" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real TS_valveRH_DEA "Tracking signal" annotation (Dialog(tab="valveRH_DEA"));

            //-- valveRH_COND --
            parameter Real Kp_valveRH_COND "Controller proportional gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ti_valveRH_COND
              "Controller integral time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Td_valveRH_COND
              "Controller derivative time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real Nd_valveRH_COND
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmin_valveRH_COND
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmax_valveRH_COND
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSstart_valveRH_COND "Start value of CS" annotation (Dialog(tab="valveRH_COND"));
            parameter Real actuatorGain_valveRH_COND "Actuator gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ta_valveRH_COND
              "Actuator time constant"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Boolean useTS_valveRH_COND "Tracking reference mode" annotation (Dialog(tab="valveRH_COND"));
            parameter Real TS_valveRH_COND "Tracking signal" annotation (Dialog(tab="valveRH_COND"));

            //-- pumpCOND --
            parameter Modelica.SIunits.Length l_dea_sp
              "Deaerator level set point"                                          annotation (Dialog(tab="pumpCOND"));
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Boolean useTS_pumpCOND "Tracking reference mode" annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));

            //-- valveDEA_SH --
            parameter Real Kp_valveDEA_SH "Controller proportional gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_SH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Td_valveDEA_SH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Nd_valveDEA_SH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmin_valveDEA_SH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmax_valveDEA_SH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSstart_valveDEA_SH "Start value of CS" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real actuatorGain_valveDEA_SH "Actuator gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_SH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Boolean useTS_valveDEA_SH "Tracking reference mode" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real TS_valveDEA_SH "Tracking signal" annotation (Dialog(tab="valveDEA_SH"));

            //-- valveDEA_RH --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_COND_sp
              "Degree of superheating set-point at condenser inlet set point"  annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Kp_valveDEA_RH "Controller proportional gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_RH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Td_valveDEA_RH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Nd_valveDEA_RH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmin_valveDEA_RH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmax_valveDEA_RH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSstart_valveDEA_RH "Start value of CS" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real actuatorGain_valveDEA_RH "Actuator gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_RH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Boolean useTS_valveDEA_RH "Tracking reference mode" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real TS_valveDEA_RH "Tracking signal" annotation (Dialog(tab="valveDEA_RH"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point"   annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Boolean useTS_pumpSEP "Tracking reference mode" annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSUB --
            parameter Modelica.SIunits.TemperatureDifference DT_sc_sp
              "Evaporator inlet subcooling set point"   annotation (Dialog(tab="valveSUB"));
            parameter Real Kp_valveSUB "Controller proportional gain" annotation (Dialog(tab="valveSUB"));
            parameter Modelica.SIunits.Time Ti_valveSUB
              "Controller integral time"                                           annotation (Dialog(tab="valveSUB"));
            parameter Modelica.SIunits.Time Td_valveSUB
              "Controller derivative time"                                           annotation (Dialog(tab="valveSUB"));
            parameter Real Nd_valveSUB
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveSUB"));
            parameter Real CSmin_valveSUB
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveSUB"));
            parameter Real CSmax_valveSUB
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveSUB"));
            parameter Real CSstart_valveSUB "Start value of CS" annotation (Dialog(tab="valveSUB"));
            parameter Real actuatorGain_valveSUB "Actuator gain" annotation (Dialog(tab="valveSUB"));
            parameter Modelica.SIunits.Time Ta_valveSUB
              "Actuator time constant"                                           annotation (Dialog(tab="valveSUB"));
            parameter Boolean useTS_valveSUB "Tracking reference mode" annotation (Dialog(tab="valveSUB"));
            parameter Real TS_valveSUB "Tracking signal" annotation (Dialog(tab="valveSUB"));

            Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                    extent={{-20,240},{20,280}}),iconTransformation(
                  extent={{-40,-40},{40,40}},
                  rotation=90,
                  origin={420,0})));
            IndustrialControlSystems.Controllers.PI  PID_pumpFW(
              AntiWindup=true,
              useTS=useTS_pumpFW,
              useBIAS=false,
              CSmin=CSmin_pumpFW,
              CSmax=CSmax_pumpFW,
              CS_start=CSstart_pumpFW,
              Kp=Kp_pumpFW,
              Ti=Ti_pumpFW)
              annotation (Placement(transformation(extent={{-290,420},{-250,460}})));
           Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpFW,
              T=Ta_pumpFW) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-50,440})));
            Modelica.Blocks.Sources.BooleanStep booleanStep2(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-230,470},{-250,490}})));
            Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
              annotation (Placement(transformation(extent={{-310,470},{-290,490}})));
            Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
              k=actuatorGain_pumpHPH,
              T=Ta_pumpHPH,
              initType=Modelica.Blocks.Types.Init.SteadyState)
              annotation (Placement(transformation(extent={{80,-440},{40,-400}})));
           Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpMS,
              T=Ta_pumpMS)
                   annotation (Placement(transformation(
                  extent={{-20,20},{20,-20}},
                  rotation=180,
                  origin={60,440})));
            IndustrialControlSystems.Controllers.PID PID_pumpMS(
              AntiWindup=true,
              useTS=useTS_pumpMS,
              CSmin=CSmin_pumpMS,
              CSmax=CSmax_pumpMS,
              CS_start=CSstart_pumpMS,
              Kp=Kp_pumpMS,
              Ti=Ti_pumpMS,
              Td=Td_pumpMS,
              N=Nd_pumpMS)
              annotation (Placement(transformation(extent={{300,420},{260,460}})));
            Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
              annotation (Placement(transformation(extent={{320,470},{300,490}})));
            Modelica.Blocks.Continuous.FirstOrder valveSH_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSH_RH,
              T=Ta_valveSH_RH)
              annotation (Placement(transformation(extent={{80,240},{40,280}})));
            IndustrialControlSystems.Controllers.PI  PID_valveSH_RH(
              AntiWindup=true,
              useTS=useTS_valveSH_RH,
              CS_start=CSstart_valveSH_RH,
              CSmin=CSmin_valveSH_RH,
              CSmax=CSmax_valveSH_RH,
              Kp=Kp_valveSH_RH,
              Ti=Ti_valveSH_RH)
              annotation (Placement(transformation(extent={{300,240},{260,280}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep6(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,290},{262,310}})));
            Modelica.Blocks.Sources.Constant valveSH_RH_TS(k=TS_valveSH_RH)
              annotation (Placement(transformation(extent={{320,290},{300,310}})));
            Modelica.Blocks.Sources.Ramp LOAD(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,442},{380,462}})));
            Modelica.Blocks.Sources.Ramp LOAD2(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,262},{380,282}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5;
                  80,139.7e5; 90,155.1e5; 100,171e5])
              annotation (Placement(transformation(extent={{360,262},{340,282}})));
            Modelica.Blocks.Sources.Ramp LOAD5(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={190,-420})));
            Modelica.Blocks.Math.Add add4
              annotation (Placement(transformation(extent={{120,430},{100,450}})));
            Modelica.Blocks.Sources.Ramp LOAD7(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={270,390})));
            Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                  transformation(extent={{-120,460},{-160,500}}),
                  iconTransformation(extent={{-440,230},{-400,270}})));
            Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                  transformation(extent={{100,460},{140,500}}),iconTransformation(
                    extent={{-440,430},{-400,470}})));
            Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                  transformation(extent={{100,280},{140,320}}), iconTransformation(
                    extent={{-440,330},{-400,370}})));
            Modelica.Blocks.Math.Add add9 annotation (Placement(transformation(extent={{-198,
                      436},{-178,456}})));
            Modelica.Blocks.Math.Add add10
              annotation (Placement(transformation(extent={{180,436},{160,456}})));
            Modelica.Blocks.Math.Add add3
              annotation (Placement(transformation(extent={{216,256},{196,276}})));
            Modelica.Blocks.Math.Add add5
              annotation (Placement(transformation(extent={{180,250},{160,270}})));
            Modelica.Blocks.Sources.Ramp LOAD10(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,210})));
            Modelica.Blocks.Sources.Constant l_SEP_SP(k=l_SEP_sp)
              annotation (Placement(transformation(extent={{-360,442},{-340,462}})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_DEA_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveRH_DEA,
              T=Ta_valveRH_DEA)
              annotation (Placement(transformation(extent={{-80,240},{-40,280}})));
            IndustrialControlSystems.Controllers.PI PID_valveRH_DEA(
              AntiWindup=true,
              useTS=useTS_valveRH_DEA,
              CSmin=CSmin_valveRH_DEA,
              CSmax=CSmax_valveRH_DEA,
              CS_start=CSstart_valveRH_DEA,
              Kp=Kp_valveRH_DEA,
              Ti=Ti_valveRH_DEA)
              annotation (Placement(transformation(extent={{-300,240},{-260,280}})));
            Modelica.Blocks.Sources.Constant valveRH_DEA_TS(k=TS_valveRH_DEA)
              annotation (Placement(transformation(extent={{-320,290},{-300,310}})));
            Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-160,
                      250},{-140,270}})));
            Modelica.Blocks.Math.Add add11
              annotation (Placement(transformation(extent={{-220,256},{-200,276}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (Placement(
                  transformation(extent={{-120,280},{-160,320}}), iconTransformation(
                    extent={{-440,130},{-400,170}})));
            Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                  transformation(
                  extent={{-20,-20},{20,20}},
                  rotation=180,
                  origin={380,350}), iconTransformation(
                  extent={{-20,-20},{20,20}},
                  rotation=270,
                  origin={0,520})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep5
              annotation (Placement(transformation(extent={{230,470},{250,490}})));
            Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                               smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,9.56; 90,10.76;
                  100,11.95])
              annotation (Placement(transformation(extent={{240,380},{220,400}})));
            Modelica.Blocks.Sources.Ramp LOAD1(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,262},{-380,282}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_DEA(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,0.8; 70,0.6; 80,0.4; 90,0.2; 100,
                  0.2])
              annotation (Placement(transformation(extent={{-260,200},{-240,220}})));
            Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                  20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                  51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                  82.3774e6])
              annotation (Placement(transformation(extent={{360,442},{340,462}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_DEA_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,250},{-100,270}})));
            Modelica.Blocks.Nonlinear.Limiter pumpFW_lim(uMax=3, uMin=0.01)
              annotation (Placement(transformation(extent={{-120,430},{-100,450}})));
            Modelica.Blocks.Nonlinear.Limiter pumpHPH_lim(uMax=0.6, uMin=0.01)
              annotation (Placement(transformation(extent={{120,-430},{100,-410}})));
            Modelica.Blocks.Nonlinear.Limiter valveSH_RH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{116,250},{96,270}})));
            Modelica.Blocks.Sources.Ramp LOAD3(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-52,180})));
            Modelica.Blocks.Sources.Ramp LOAD8(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-130})));
            Modelica.Blocks.Continuous.FirstOrder valveRH_COND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveRH_COND,
              T=Ta_valveRH_COND)
              annotation (Placement(transformation(extent={{-80,-100},{-40,-60}})));
            IndustrialControlSystems.Controllers.PI PID_valveRH_COND(
              AntiWindup=true,
              useTS=useTS_valveRH_COND,
              CSmin=CSmin_valveRH_COND,
              CSmax=CSmax_valveRH_COND,
              CS_start=CSstart_valveRH_COND,
              Kp=Kp_valveRH_COND,
              Ti=Ti_valveRH_COND)
              annotation (Placement(transformation(extent={{-300,-100},{-260,-60}})));
            Modelica.Blocks.Sources.Constant valveRH_COND_TS(k=TS_valveRH_COND)
              annotation (Placement(transformation(extent={{-320,-50},{-300,-30}})));
            Modelica.Blocks.Math.Add add2 annotation (Placement(transformation(extent={{-160,
                      -90},{-140,-70}})));
            Modelica.Blocks.Math.Add add6
              annotation (Placement(transformation(extent={{-220,-84},{-200,-64}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep3(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-50},{-260,-30}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaRH_COND(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{-260,-140},{-240,-120}})));
            Modelica.Blocks.Nonlinear.Limiter valveRH_COND_lim(
                                                              uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,-90},{-100,-70}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (Placement(
                  transformation(extent={{-120,-60},{-160,-20}}), iconTransformation(
                    extent={{-440,-170},{-400,-130}})));
            Modelica.Blocks.Sources.Constant DT_SH_COND_SP(k=DT_sh_COND_sp)
              annotation (Placement(transformation(extent={{380,-258},{360,-238}})));
            IndustrialControlSystems.Controllers.PI  PID_pumpCOND(
              AntiWindup=true,
              useTS=useTS_pumpCOND,
              useBIAS=false,
              CSmin=CSmin_pumpCOND,
              CSmax=CSmax_pumpCOND,
              CS_start=CSstart_pumpCOND,
              Kp=Kp_pumpCOND,
              Ti=Ti_pumpCOND)
              annotation (Placement(transformation(extent={{-300,-280},{-260,-240}})));
           Modelica.Blocks.Continuous.FirstOrder pumpCOND_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_pumpCOND,
              T=Ta_pumpCOND) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,-260})));
            Modelica.Blocks.Sources.BooleanStep booleanStep4(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,-230},{-260,-210}})));
            Modelica.Blocks.Sources.Constant pumpCOND_TS(
                                                       k=TS_pumpCOND)
              annotation (Placement(transformation(extent={{-320,-230},{-300,-210}})));
            Modelica.Blocks.Math.Add add12
                                          annotation (Placement(transformation(extent={{-200,
                      -264},{-180,-244}})));
            Modelica.Blocks.Sources.Constant l_DEA_SP(k=l_dea_sp)
              annotation (Placement(transformation(extent={{-370,-258},{-350,-238}})));
            Modelica.Blocks.Nonlinear.Limiter pumpCOND_lim(uMax=6, uMin=0.1)
              annotation (Placement(transformation(extent={{-128,-270},{-108,-250}})));
            Modelica.Blocks.Interfaces.RealInput du_w_cond
                                                         annotation (Placement(
                  transformation(extent={{-120,-240},{-160,-200}}),
                  iconTransformation(extent={{-440,-270},{-400,-230}})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_SH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveDEA_SH,
              T=Ta_valveDEA_SH)
              annotation (Placement(transformation(extent={{80,-100},{40,-60}})));
            IndustrialControlSystems.Controllers.PI  PID_valveDEA_SH(
              AntiWindup=true,
              useTS=useTS_valveDEA_SH,
              CS_start=CSstart_valveDEA_SH,
              CSmin=CSmin_valveDEA_SH,
              CSmax=CSmax_valveDEA_SH,
              Kp=Kp_valveDEA_SH,
              Ti=Ti_valveDEA_SH)
              annotation (Placement(transformation(extent={{300,-100},{260,-60}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep7(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,-50},{262,-30}})));
            Modelica.Blocks.Sources.Constant valveDEA_SH_TS(
                                                           k=TS_valveDEA_SH)
              annotation (Placement(transformation(extent={{320,-50},{300,-30}})));
            Modelica.Blocks.Sources.Ramp LOAD9(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{400,-78},{380,-58}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_RH_out(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,473.3 + 273.15; 30,471.4 + 273.15; 40,470 + 273.15; 50,468.3 + 273.15;
                  60,465.5 + 273.15; 70,463 + 273.15; 80,461.4 + 273.15; 90,459.4 + 273.15;
                  100,460.8 + 273.15])
              annotation (Placement(transformation(extent={{360,-78},{340,-58}})));
            Modelica.Blocks.Math.Add add7
              annotation (Placement(transformation(extent={{210,-84},{190,-64}})));
            Modelica.Blocks.Math.Add add13
              annotation (Placement(transformation(extent={{160,-90},{140,-70}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_SH_lim(
                                                             uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,-90},{100,-70}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (Placement(
                  transformation(extent={{100,-60},{140,-20}}),  iconTransformation(
                    extent={{-440,30},{-400,70}})));
            Modelica.Blocks.Sources.Ramp LOAD11(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,-130})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_SH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{260,-140},{240,-120}})));
            Modelica.Blocks.Continuous.FirstOrder valveDEA_RH_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveDEA_RH,
              T=Ta_valveDEA_RH)
              annotation (Placement(transformation(extent={{80,-280},{40,-240}})));
            IndustrialControlSystems.Controllers.PI PID_valveDEA_RH(
              AntiWindup=true,
              useTS=useTS_valveDEA_SH,
              CSmin=CSmin_valveDEA_RH,
              CSmax=CSmax_valveDEA_RH,
              CS_start=CSstart_valveDEA_RH,
              Kp=Kp_valveDEA_RH,
              Ti=Ti_valveDEA_RH)
              annotation (Placement(transformation(extent={{300,-280},{260,-240}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep8(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{242,-230},{262,-210}})));
            Modelica.Blocks.Sources.Constant valveDEA_RH_TS(k=TS_valveDEA_RH)
              annotation (Placement(transformation(extent={{320,-230},{300,-210}})));
            Modelica.Blocks.Math.Add add14
              annotation (Placement(transformation(extent={{210,-264},{190,-244}})));
            Modelica.Blocks.Math.Add add15
              annotation (Placement(transformation(extent={{160,-270},{140,-250}})));
            Modelica.Blocks.Nonlinear.Limiter valveDEA_RH_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{120,-270},{100,-250}})));
            Modelica.Blocks.Sources.Ramp LOAD13(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={290,-310})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaDEA_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[4,0.8; 20,0.8; 30,0.8; 40,0.8; 50,0.8; 60,0.8; 70,0.8; 80,0.8; 90,0.8;
                  100,0.8])
              annotation (Placement(transformation(extent={{260,-320},{240,-300}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (Placement(
                  transformation(extent={{100,-240},{140,-200}}), iconTransformation(
                    extent={{-440,-70},{-400,-30}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_RH(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
                table=[20,8.651e5; 30,13.19e5; 40,17.83e5; 50,22.6e5; 60,27.39e5; 70,32.65e5;
                  80,37.19e5; 90,42.05e5; 100,47.31e5])
              annotation (Placement(transformation(extent={{-360,-78},{-340,-58}})));
            Modelica.Blocks.Sources.Ramp LOAD12(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-400,-78},{-380,-58}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
                  40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
                  100,171e5])
              annotation (Placement(transformation(extent={{270,160},{250,180}})));
            Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,
                  0.3336; 30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,
                  1.436; 90,1.605; 100,1.757]) annotation (Placement(
                  transformation(extent={{270,200},{250,220}})));
            Modelica.Blocks.Math.Division division1 annotation (Placement(
                  transformation(extent={{230,180},{210,200}})));
            Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                  0; 9.06913488751826e-10,0.00999999977648258; 2.18218243475121e-09,0.0199999995529652;
                  3.46627393454924e-09,0.0299999993294477; 4.75013051115525e-09,0.0399999991059303;
                  6.0339799823339e-09,0.0500000007450581; 7.31780902540891e-09,0.0599999986588955;
                  8.60163851257312e-09,0.0700000002980232; 9.88546844382654e-09,0.0799999982118607;
                  1.11692957105447e-08,0.0900000035762787; 1.24531229772629e-08,0.100000001490116;
                  1.3736950243981e-08,0.109999999403954; 1.50207775106992e-08,0.119999997317791;
                  1.63046056655958e-08,0.129999995231628; 1.75884320441355e-08,0.140000000596046;
                  1.88722601990321e-08,0.150000005960464; 2.01560865775718e-08,0.159999996423721;
                  2.14399147324684e-08,0.170000001788139; 2.27237411110082e-08,0.180000007152557;
                  2.40075692659048e-08,0.189999997615814; 2.52913956444445e-08,0.200000002980232;
                  2.65752220229842e-08,0.209999993443489; 2.78590501778808e-08,0.219999998807907;
                  2.91428765564206e-08,0.230000004172325; 3.04267047113171e-08,0.239999994635582;
                  3.17105310898569e-08,0.25; 3.29943574683966e-08,0.259999990463257; 3.42781873996501e-08,
                  0.270000010728836; 3.55620137781898e-08,0.280000001192093; 3.68458401567295e-08,
                  0.28999999165535; 3.81296665352693e-08,0.300000011920929; 3.94134964665227e-08,
                  0.310000002384186; 4.06973228450624e-08,0.319999992847443; 4.19811492236022e-08,
                  0.330000013113022; 4.32649756021419e-08,0.340000003576279; 4.45488019806817e-08,
                  0.349999994039536; 4.58326319119351e-08,0.360000014305115; 4.71164582904748e-08,
                  0.370000004768372; 4.84002846690146e-08,0.379999995231628; 4.96841110475543e-08,
                  0.389999985694885; 5.09679409788077e-08,0.400000005960465; 5.22517673573475e-08,
                  0.409999996423721; 5.35355937358872e-08,0.419999986886978; 5.4819420114427e-08,
                  0.430000007152557; 5.61032464929667e-08,0.439999997615814; 5.73870764242201e-08,
                  0.449999988079071; 5.86709028027599e-08,0.46000000834465; 5.99547291812996e-08,
                  0.469999998807907; 6.12385591125531e-08,0.479999989271164; 6.25223819383791e-08,
                  0.490000009536743; 6.38062118696325e-08,0.5; 6.5090041800886e-08,0.509999990463257;
                  6.6373864626712e-08,0.519999980926514; 6.76576945579654e-08,0.529999971389771;
                  6.89415173837915e-08,0.540000021457672; 7.02253473150449e-08,0.550000011920929;
                  7.15091772462984e-08,0.560000002384186; 7.27930000721244e-08,0.569999992847443;
                  7.40768300033778e-08,0.5799999833107; 7.53606528292039e-08,0.589999973773956;
                  7.66444827604573e-08,0.600000023841858; 7.79283126917107e-08,0.610000014305115;
                  7.92121355175368e-08,0.620000004768372; 8.04959654487902e-08,0.629999995231628;
                  8.17797953800437e-08,0.639999985694885; 8.30636182058697e-08,0.649999976158142;
                  8.43474481371231e-08,0.660000026226044; 8.56312709629492e-08,0.670000016689301;
                  8.69151008942026e-08,0.680000007152557; 8.81989308254561e-08,0.689999997615814;
                  8.94827536512821e-08,0.699999988079071; 9.07665835825355e-08,0.709999978542328;
                  9.20504064083616e-08,0.72000002861023; 9.3334236339615e-08,0.730000019073486;
                  9.46180662708684e-08,0.740000009536743; 9.59018890966945e-08,0.75; 9.71857190279479e-08,
                  0.759999990463257; 9.84695489592014e-08,0.769999980926514; 9.97533717850274e-08,
                  0.779999971389771; 1.01037201716281e-07,0.790000021457672; 1.02321024542107e-07,
                  0.800000011920929; 1.0360485447336e-07,0.810000002384186; 1.04888684404614e-07,
                  0.819999992847443; 1.0617250723044e-07,0.8299999833107; 1.07456337161693e-07,
                  0.839999973773956; 1.08740159987519e-07,0.850000023841858; 1.10023989918773e-07,
                  0.860000014305115; 1.11307819850026e-07,0.870000004768372; 1.12591642675852e-07,
                  0.879999995231628; 1.13875472607106e-07,0.889999985694885; 1.15159295432932e-07,
                  0.899999976158142; 1.16443125364185e-07,0.910000026226044; 1.17726955295439e-07,
                  0.920000016689301; 1.19010778121265e-07,0.930000007152557; 1.20294600947091e-07,
                  0.939999997615814; 1.21578437983771e-07,0.949999988079071; 1.22862260809598e-07,
                  0.959999978542328; 1.24146083635424e-07,0.97000002861023; 1.25429920672104e-07,
                  0.980000019073486; 1.2671374349793e-07,0.990000009536743; 1.27997566323756e-07,
                  1])
              annotation (Placement(transformation(extent={{150,250},{130,270}})));
            Modelica.Blocks.Sources.Ramp LOAD6(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={298,190})));
            Modelica.Blocks.Tables.CombiTable1D table_w_HPH(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
                table=[20,0.02; 30,0.02; 40,0.02; 50,0.02; 60,0.02; 70,0.02; 80,0.02; 90,0.1245;
                  100,0.4717])
              annotation (Placement(transformation(extent={{160,-430},{140,-410}})));
            Modelica.Blocks.Sources.Constant T_MS_SP(k=T_FW_sp)
              annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
            IndustrialControlSystems.Controllers.PI PID_pumpSEP(
              AntiWindup=true,
              useTS=useTS_pumpSEP,
              CSmin=CSmin_pumpSEP,
              CSmax=CSmax_pumpSEP,
              CS_start=CSstart_pumpSEP,
              Kp=Kp_pumpSEP,
              Ti=Ti_pumpSEP) annotation (Placement(transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-280,60})));
           Modelica.Blocks.Continuous.FirstOrder pumpSEP_dynamic(
              k=actuatorGain_pumpSEP,
              T=Ta_pumpSEP,
              initType=Modelica.Blocks.Types.Init.SteadyState) annotation (Placement(
                  transformation(
                  extent={{20,20},{-20,-20}},
                  rotation=180,
                  origin={-60,60})));
            Modelica.Blocks.Sources.Constant pumpSEP_TS(k=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
            Modelica.Blocks.Math.Product product4
                                                 annotation (Placement(transformation(
                    extent={{-180,56},{-160,76}})));
            Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,50},
                      {-120,70}})));
            Modelica.Blocks.Sources.Ramp LOAD4(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,10})));
            Modelica.Blocks.Math.Add add16
              annotation (Placement(transformation(extent={{-220,62},{-200,82}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep9(
                startValue=TS_start, startTime=t_start_ramp_TS)
              annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
            Modelica.Blocks.Tables.CombiTable1D table_wSEP(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  0.5022; 20,1.595; 30,1.898; 40,2.009; 50,1.534; 60,0; 70,0; 80,
                  0; 90,0; 100,0])
              annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
            Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                  transformation(extent={{-120,80},{-160,120}}), iconTransformation(
                    extent={{-440,-370},{-400,-330}})));
            Modelica.Blocks.Nonlinear.Limiter eletHEAT_lim(uMin=0, uMax=200000)
              annotation (Placement(transformation(extent={{60,50},{40,70}})));
            Modelica.Blocks.Sources.Ramp LOAD14(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{280,100},{260,120}})));
            Modelica.Blocks.Tables.CombiTable1D table_T_FW1(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,479.15; 30,497.45; 40,510.65; 50,521.35; 60,521.35; 70,521.35; 80,521.35;
                  90,521.35; 100,521.35])
              annotation (Placement(transformation(extent={{240,100},{220,120}})));
            Modelica.Blocks.Math.Add add(k2=-1) annotation (Placement(transformation(
                  extent={{10,-10},{-10,10}},
                  rotation=0,
                  origin={190,90})));
            Modelica.Blocks.Math.Gain gain(k=4186)
              annotation (Placement(transformation(extent={{120,50},{100,70}})));
            Modelica.Blocks.Math.Product product
              annotation (Placement(transformation(extent={{160,50},{140,70}})));
            Modelica.Blocks.Sources.Ramp LOAD15(
              height=load_end - load_start,
              duration=t_ramp,
              offset=load_start,
              startTime=t_start_ramp)
              annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                  rotation=0,
                  origin={-290,-470})));
            Modelica.Blocks.Continuous.FirstOrder valveSUB_dynamic(
              initType=Modelica.Blocks.Types.Init.SteadyState,
              k=actuatorGain_valveSUB,
              T=Ta_valveSUB)
              annotation (Placement(transformation(extent={{-80,-440},{-40,-400}})));
            IndustrialControlSystems.Controllers.PI PID_valveSUB(
              AntiWindup=true,
              useTS=useTS_valveRH_DEA,
              CSmin=CSmin_valveSUB,
              CSmax=CSmax_valveSUB,
              CS_start=CSstart_valveSUB,
              Kp=Kp_valveSUB,
              Ti=Ti_valveSUB)
              annotation (Placement(transformation(extent={{-300,-440},{-260,-400}})));
            Modelica.Blocks.Sources.Constant valveSUB(k=TS_valveSUB)
              annotation (Placement(transformation(extent={{-320,-390},{-300,-370}})));
            Modelica.Blocks.Math.Add add17
                                          annotation (Placement(transformation(extent={{-160,
                      -430},{-140,-410}})));
            Modelica.Blocks.Math.Add add18
              annotation (Placement(transformation(extent={{-220,-424},{-200,-404}})));
            Modelica.Blocks.Tables.CombiTable1D table_thetaSUB(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                  1; 20,1; 30,1; 40,1; 50,1; 60,1; 70,1; 80,1; 90,1; 100,1])
              annotation (Placement(transformation(extent={{-260,-480},{-240,-460}})));
            Modelica.Blocks.Nonlinear.Limiter valveSUB_lim(uMax=1, uMin=0)
              annotation (Placement(transformation(extent={{-120,-430},{-100,-410}})));
            Modelica.Blocks.Interfaces.RealInput du_thetaSUB annotation (Placement(
                  transformation(extent={{-120,-400},{-160,-360}}), iconTransformation(
                    extent={{-440,-470},{-400,-430}})));
            Modelica.Blocks.Sources.Constant DT_SC_SP(k=DT_sc_sp)
              annotation (Placement(transformation(extent={{-368,-418},{-348,-398}})));
            Modelica.Blocks.Tables.CombiTable1D table_p_DEA(
                                                           smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                  20,8.636e5; 30,12.9e5; 40,17.32e5; 50,22.02e5; 60,26.78e5; 70,26.97e5; 80,
                  27.03e5; 90,27.04e5; 100,27.05e5])
              annotation (Placement(transformation(extent={{-360,262},{-340,282}})));
            Modelica.Blocks.Sources.BooleanConstant
                                                booleanStep10
              annotation (Placement(transformation(extent={{-240,-390},{-260,-370}})));
            Modelica.Blocks.Sources.BooleanStep booleanStep1(
                startTime=t_start_ramp_TS, startValue=TS_start)
              annotation (Placement(transformation(extent={{-240,290},{-260,310}})));
          equation
            connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-262,456},{-262,
                    456},{-262,468},{-262,480},{-251,480}},     color={255,0,255}));
            connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,58},{0,-420},{38,-420}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,442},{0,440},{38,440}},
                color={255,204,51},
                thickness=0.5));
            connect(booleanStep6.y, PID_valveSH_RH.TS) annotation (Line(points={{263,300},
                    {272,300},{272,276}},color={255,0,255}));
            connect(signalBus.valveSH_RH_CS, valveSH_RH_dynamic.y) annotation (Line(
                points={{0,260},{2,260},{38,260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveSH_RH_PV, PID_valveSH_RH.PV) annotation (Line(
                points={{0,260},{0,260},{0,140},{320,140},{320,258},{296,258}},
                color={255,204,51},
                thickness=0.5));
            connect(table_P_SH.u[1], LOAD2.y)
              annotation (Line(points={{362,272},{379,272}}, color={0,0,127}));
            connect(PID_valveSH_RH.SP, table_P_SH.y[1])
              annotation (Line(points={{296,272},{296,272},{339,272}}, color={0,0,127}));
            connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,440},{99,440}},
                                    color={0,0,127}));
            connect(PID_pumpFW.CS, add9.u2) annotation (Line(points={{-252,440},{-200,440}},
                                                         color={0,0,127}));
            connect(du_w_FW, add9.u1) annotation (Line(points={{-140,480},{-140,480},{-220,
                    480},{-220,452},{-200,452}},         color={0,0,127}));
            connect(du_w_MS, add10.u1) annotation (Line(points={{120,480},{160,480},{200,480},
                    {200,452},{182,452}},color={0,0,127}));
            connect(PID_pumpMS.CS, add10.u2) annotation (Line(points={{262,440},{212,440},
                    {182,440}},                color={0,0,127}));
            connect(du_Y_t, add3.u1) annotation (Line(points={{120,300},{120,300},{220,300},
                    {220,272},{218,272}},        color={0,0,127}));
            connect(PID_valveSH_RH.CS, add3.u2) annotation (Line(points={{262,260},{218,260}},
                                                     color={0,0,127}));
            connect(add4.u1, add10.y)
              annotation (Line(points={{122,446},{159,446}}, color={0,0,127}));
            connect(add5.u1, add3.y) annotation (Line(points={{182,266},{182,266},{195,266}},
                                   color={0,0,127}));
            connect(l_SEP_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,452},{-286,452}},
                                        color={0,0,127}));
            connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,440},{-28,440}},
                color={255,204,51},
                thickness=0.5));

            connect(du_thetaRH_DEA, add11.u1) annotation (Line(points={{-140,300},{-230,300},
                    {-230,272},{-222,272}}, color={0,0,127}));
            connect(add11.y, add8.u1) annotation (Line(points={{-199,266},{-199,266},{-162,
                    266}},color={0,0,127}));
            connect(signalBus.valveRH_DEA_CS, valveRH_DEA_dynamic.y) annotation (Line(
                points={{0,260},{-19,260},{-38,260}},
                color={255,204,51},
                thickness=0.5));
            connect(PID_valveRH_DEA.CS, add11.u2)
              annotation (Line(points={{-262,260},{-242,260},{-222,260}},
                                                                       color={0,0,127}));
            connect(signalBus.valveRH_DEA_PV, PID_valveRH_DEA.PV) annotation (Line(
                points={{0,260},{0,260},{0,140},{-320,140},{-320,258},{-296,258}},
                color={255,204,51},
                thickness=0.5));
            connect(u_Pmec, PID_pumpMS.PV) annotation (Line(points={{380,350},{320,350},{320,
                    438},{296,438}}, color={0,0,127}));
            connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,480},{272,
                    480},{272,456}}, color={255,0,255}));
            connect(table_w_MS.u[1], LOAD7.y) annotation (Line(points={{242,390},{242,390},
                    {259,390}},           color={0,0,127}));
            connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,390},{140,390},
                    {140,434},{122,434}},           color={0,0,127}));
            connect(LOAD10.y, table_thetaRH_DEA.u[1]) annotation (Line(points={{-279,210},
                    {-270.5,210},{-262,210}}, color={0,0,127}));
            connect(table_thetaRH_DEA.y[1], add8.u2) annotation (Line(points={{-239,210},{
                    -239,212},{-180,212},{-180,254},{-162,254}}, color={0,0,127}));
            connect(table_P_MEC.u[1], LOAD.y) annotation (Line(points={{362,452},{379,452}},
                                          color={0,0,127}));
            connect(PID_pumpMS.SP, table_P_MEC.y[1]) annotation (Line(points={{296,452},{339,
                    452}},                         color={0,0,127}));
            connect(add8.y, valveRH_DEA_lim.u)
              annotation (Line(points={{-139,260},{-122,260}},
                                                             color={0,0,127}));
            connect(valveRH_DEA_lim.y, valveRH_DEA_dynamic.u)
              annotation (Line(points={{-99,260},{-84,260}},
                                                           color={0,0,127}));
            connect(pumpFW_dynamic.u, pumpFW_lim.y) annotation (Line(points={{-74,440},{-99,
                    440}},                        color={0,0,127}));
            connect(pumpHPH_dynamic.u, pumpHPH_lim.y)
              annotation (Line(points={{84,-420},{99,-420}}, color={0,0,127}));
            connect(valveSH_RH_dynamic.u, valveSH_RH_lim.y)
              annotation (Line(points={{84,260},{95,260}},
                                                         color={0,0,127}));
            connect(signalBus.load, LOAD3.y) annotation (Line(
                points={{0,260},{0,260},{0,180},{-41,180}},
                color={255,204,51},
                thickness=0.5));
            connect(du_thetaRH_COND, add6.u1) annotation (Line(points={{-140,-40},{-230,-40},
                    {-230,-68},{-222,-68}}, color={0,0,127}));
            connect(add6.y, add2.u1) annotation (Line(points={{-199,-74},{-199,-74},{-162,
                    -74}}, color={0,0,127}));
            connect(PID_valveRH_COND.CS, add6.u2) annotation (Line(points={{-262,-80},{-242,
                    -80},{-222,-80}},   color={0,0,127}));
            connect(booleanStep3.y, PID_valveRH_COND.TS) annotation (Line(points={{-261,-40},
                    {-272,-40},{-272,-64}}, color={255,0,255}));
            connect(LOAD8.y, table_thetaRH_COND.u[1]) annotation (Line(points={{-279,-130},
                    {-270.5,-130},{-262,-130}}, color={0,0,127}));
            connect(table_thetaRH_COND.y[1], add2.u2) annotation (Line(points={{-239,-130},
                    {-239,-130},{-180,-130},{-180,-86},{-162,-86}},   color={0,0,127}));
            connect(add2.y, valveRH_COND_lim.u) annotation (Line(points={{-139,-80},{-130,
                    -80},{-122,-80}},   color={0,0,127}));
            connect(valveRH_COND_lim.y, valveRH_COND_dynamic.u) annotation (Line(points={{-99,-80},
                    {-92.5,-80},{-84,-80}},             color={0,0,127}));
            connect(PID_pumpCOND.TS, booleanStep4.y) annotation (Line(points={{-272,-244},
                    {-272,-244},{-272,-232},{-272,-220},{-261,-220}},color={255,0,255}));
            connect(PID_pumpCOND.CS, add12.u2) annotation (Line(points={{-262,-260},{-202,
                    -260}},                   color={0,0,127}));
            connect(add12.y, pumpCOND_lim.u) annotation (Line(points={{-179,-254},{-156,-254},
                    {-156,-260},{-130,-260}}, color={0,0,127}));
            connect(pumpCOND_lim.y, pumpCOND_dynamic.u) annotation (Line(points={{-107,-260},
                    {-95.5,-260},{-84,-260}}, color={0,0,127}));
            connect(booleanStep7.y, PID_valveDEA_SH.TS) annotation (Line(points={{263,-40},
                    {272,-40},{272,-64}},   color={255,0,255}));
            connect(table_T_RH_out.u[1], LOAD9.y)
              annotation (Line(points={{362,-68},{370,-68},{379,-68}},
                                                               color={0,0,127}));
            connect(PID_valveDEA_SH.SP, table_T_RH_out.y[1]) annotation (Line(points={{296,-68},
                    {296,-68},{339,-68}},         color={0,0,127}));
            connect(du_thetaDEA_SH, add7.u1) annotation (Line(points={{120,-40},{120,-40},
                    {220,-40},{220,-68},{212,-68}},    color={0,0,127}));
            connect(PID_valveDEA_SH.CS, add7.u2) annotation (Line(points={{262,-80},{242,-80},
                    {212,-80}},        color={0,0,127}));
            connect(add13.u1, add7.y)
              annotation (Line(points={{162,-74},{189,-74}},   color={0,0,127}));
            connect(table_thetaDEA_SH.u[1], LOAD11.y)
              annotation (Line(points={{262,-130},{279,-130}}, color={0,0,127}));
            connect(table_thetaDEA_SH.y[1], add13.u2) annotation (Line(points={{239,-130},
                    {210,-130},{180,-130},{180,-86},{162,-86}},   color={0,0,127}));
            connect(booleanStep8.y, PID_valveDEA_RH.TS) annotation (Line(points={{263,-220},
                    {272,-220},{272,-244}}, color={255,0,255}));
            connect(du_thetaDEA_RH, add14.u1) annotation (Line(points={{120,-220},{120,-220},
                    {220,-220},{220,-248},{212,-248}}, color={0,0,127}));
            connect(PID_valveDEA_RH.CS, add14.u2) annotation (Line(points={{262,-260},{242,
                    -260},{212,-260}}, color={0,0,127}));
            connect(add15.u1, add14.y)
              annotation (Line(points={{162,-254},{189,-254}}, color={0,0,127}));
            connect(table_thetaDEA_RH.u[1], LOAD13.y)
              annotation (Line(points={{262,-310},{279,-310}}, color={0,0,127}));
            connect(table_thetaDEA_RH.y[1], add15.u2) annotation (Line(points={{239,-310},
                    {210,-310},{180,-310},{180,-266},{162,-266}}, color={0,0,127}));
            connect(valveDEA_RH_lim.u, add15.y) annotation (Line(points={{122,-260},{139,-260}},
                                 color={0,0,127}));
            connect(valveDEA_SH_lim.u, add13.y)
              annotation (Line(points={{122,-80},{139,-80}},   color={0,0,127}));
            connect(PID_valveDEA_RH.SP, DT_SH_COND_SP.y) annotation (Line(points={{296,-248},
                    {330,-248},{359,-248}}, color={0,0,127}));
            connect(LOAD12.y, table_p_RH.u[1])
              annotation (Line(points={{-379,-68},{-362,-68}},   color={0,0,127}));
            connect(table_p_RH.y[1], PID_valveRH_COND.SP)
              annotation (Line(points={{-339,-68},{-296,-68}},   color={0,0,127}));
            connect(signalBus.valveRH_COND_CS, valveRH_COND_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,-80},{-38,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_SH_CS, valveDEA_SH_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,-80},{38,-80}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_CS, pumpCOND_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,-80},{0,-260},{-38,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_RH_CS, valveDEA_RH_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,-260},{38,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveRH_COND_PV, PID_valveRH_COND.PV) annotation (Line(
                points={{0,260},{0,260},{0,-160},{-320,-160},{-320,-82},{-296,-82}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpCOND_PV, PID_pumpCOND.PV) annotation (Line(
                points={{0,260},{0,260},{0,-260},{0,-342},{0,-340},{-320,-340},{-320,-262},
                    {-296,-262}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_RH_PV, PID_valveDEA_RH.PV) annotation (Line(
                points={{0,260},{0,260},{0,-340},{320,-340},{320,-262},{296,-262}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.valveDEA_SH_PV, PID_valveDEA_SH.PV) annotation (Line(
                points={{0,260},{0,260},{0,-160},{320,-160},{320,-82},{296,-82}},
                color={255,204,51},
                thickness=0.5));
            connect(du_w_cond, add12.u1) annotation (Line(points={{-140,-220},{-180,-220},
                    {-220,-220},{-220,-248},{-202,-248}}, color={0,0,127}));
            connect(l_DEA_SP.y, PID_pumpCOND.SP) annotation (Line(points={{-349,-248},{-296,
                    -248}},             color={0,0,127}));
            connect(valveDEA_SH_dynamic.u, valveDEA_SH_lim.y)
              annotation (Line(points={{84,-80},{99,-80}},             color={0,0,127}));
            connect(valveDEA_RH_dynamic.u, valveDEA_RH_lim.y) annotation (Line(points={{84,-260},
                    {94,-260},{99,-260}},                 color={0,0,127}));
            connect(valveSH_RH_sourceP.y[1], division1.u2) annotation (Line(
                  points={{249,170},{242,170},{242,184},{232,184}}, color={0,0,
                    127}));
            connect(valveSH_RH_sourceW.y[1], division1.u1) annotation (Line(
                  points={{249,210},{244,210},{244,196},{232,196}}, color={0,0,
                    127}));
            connect(division1.y, add5.u2) annotation (Line(points={{209,190},{190,190},{190,
                    254},{182,254}},           color={0,0,127}));
            connect(table_Y_tTOtheta.u[1], add5.y) annotation (Line(points={{152,260},{152,
                    260},{159,260}},           color={0,0,127}));
            connect(valveSH_RH_lim.u, table_Y_tTOtheta.y[1])
              annotation (Line(points={{118,260},{129,260}}, color={0,0,127}));
            connect(LOAD6.y, valveSH_RH_sourceP.u[1]) annotation (Line(points={{287,190},{
                    280,190},{280,170},{272,170}}, color={0,0,127}));
            connect(LOAD6.y, valveSH_RH_sourceW.u[1]) annotation (Line(points={{287,190},{
                    280,190},{280,210},{272,210}}, color={0,0,127}));
            connect(pumpHPH_lim.u, table_w_HPH.y[1])
              annotation (Line(points={{122,-420},{139,-420}},
                                                         color={0,0,127}));
            connect(table_w_HPH.u[1], LOAD5.y)
              annotation (Line(points={{162,-420},{172,-420},{179,-420}},
                                                                 color={0,0,127}));
            connect(PID_pumpFW.CS, PID_pumpFW.TR) annotation (Line(points={{-252,440},{-244,
                    440},{-244,460},{-244,462},{-270,462},{-270,456}},
                  color={0,0,127}));
            connect(PID_valveSH_RH.CS, PID_valveSH_RH.TR) annotation (Line(points={{262,260},
                    {256,260},{256,284},{280,284},{280,276}},           color={0,
                    0,127}));
            connect(PID_valveDEA_SH.CS, PID_valveDEA_SH.TR) annotation (Line(
                  points={{262,-80},{258,-80},{256,-80},{256,-56},{280,-56},{280,-64}},
                                 color={0,0,127}));
            connect(PID_valveDEA_RH.CS, PID_valveDEA_RH.TR) annotation (Line(
                  points={{262,-260},{256,-260},{256,-236},{280,-236},{280,-244}},
                  color={0,0,127}));
            connect(PID_valveRH_COND.CS, PID_valveRH_COND.TR) annotation (Line(
                  points={{-262,-80},{-256,-80},{-256,-58},{-280,-58},{-280,-64}},
                            color={0,0,127}));
            connect(PID_pumpCOND.CS, PID_pumpCOND.TR) annotation (Line(points={{-262,-260},
                    {-256,-260},{-256,-236},{-280,-236},{-280,-244}},
                  color={0,0,127}));
            connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,480},{280,480},
                    {280,456}},           color={0,0,127}));
            connect(add9.y, pumpFW_lim.u) annotation (Line(points={{-177,446},{-140,446},{
                    -140,440},{-122,440}}, color={0,0,127}));
            connect(signalBus.pumpFW_PV_low, PID_pumpFW.PV) annotation (Line(
                points={{0,260},{0,260},{0,360},{-320,360},{-320,438},{-286,438}},
                color={255,204,51},
                thickness=0.5));
            connect(product4.y,add1. u1) annotation (Line(points={{-159,66},{-142,66}},
                                color={0,0,127}));
            connect(add1.y,pumpSEP_dynamic. u) annotation (Line(points={{-119,60},{-101.5,
                    60},{-84,60}},        color={0,0,127}));
            connect(add16.y, product4.u1)
              annotation (Line(points={{-199,72},{-192,72},{-182,72}}, color={0,0,127}));
            connect(du_w_SEP, add16.u1) annotation (Line(points={{-140,100},{-184,100},{-230,
                    100},{-230,78},{-222,78}},color={0,0,127}));
            connect(PID_pumpSEP.CS, add16.u2) annotation (Line(points={{-262,60},{-230,60},
                    {-230,66},{-222,66}},
                                       color={0,0,127}));
            connect(PID_pumpSEP.CS,PID_pumpSEP. TR) annotation (Line(points={{-262,60},{-256,
                    60},{-252,60},{-252,84},{-280,84},{-280,76}},       color={0,0,
                    127}));
            connect(booleanStep9.y,PID_pumpSEP. TS) annotation (Line(points={{-261,100},{-272,
                    100},{-272,76}}, color={255,0,255}));
            connect(T_MS_SP.y,PID_pumpSEP. SP) annotation (Line(points={{-339,72},{-318,72},
                    {-296,72}},                     color={0,0,127}));
            connect(LOAD4.y,table_wSEP. u[1]) annotation (Line(points={{-279,10},{-279,10},
                    {-262,10}},           color={0,0,127}));
            connect(table_wSEP.y[1],add1. u2) annotation (Line(points={{-239,10},{-150,10},
                    {-150,54},{-142,54}},           color={0,0,127}));
            connect(table_wSEP.y[1],product4. u2) annotation (Line(points={{-239,10},{-216,
                    10},{-190,10},{-190,60},{-182,60}},           color={0,0,127}));
            connect(signalBus.pumpSEP_PV, PID_pumpSEP.PV) annotation (Line(
                points={{0,260},{0,-12},{-320,-12},{-320,58},{-296,58}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.pumpSEP_CS, pumpSEP_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,60},{-38,60}},
                color={255,204,51},
                thickness=0.5));
            connect(add.y, product.u1) annotation (Line(points={{179,90},{170,90},{170,66},
                    {162,66}},color={0,0,127}));
            connect(gain.u, product.y)
              annotation (Line(points={{122,60},{139,60}},       color={0,0,127}));
            connect(eletHEAT_lim.u, gain.y)
              annotation (Line(points={{62,60},{99,60}},      color={0,0,127}));
            connect(table_T_FW1.y[1], add.u1) annotation (Line(points={{219,110},{208,110},
                    {208,96},{202,96}},color={0,0,127}));
            connect(signalBus.eletHEAT_CS, eletHEAT_lim.y) annotation (Line(
                points={{0,260},{0,260},{0,60},{39,60}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.eletHEAT_PV_low_T, add.u2) annotation (Line(
                points={{0,260},{0,260},{0,140},{320,140},{320,84},{202,84}},
                color={255,204,51},
                thickness=0.5));
            connect(signalBus.eletHEAT_PV_low_w, product.u2) annotation (Line(
                points={{0,260},{0,260},{0,140},{320,140},{320,54},{162,54}},
                color={255,204,51},
                thickness=0.5));
            connect(table_T_FW1.u[1], LOAD14.y)
              annotation (Line(points={{242,110},{259,110}},
                                                           color={0,0,127}));
            connect(du_thetaSUB, add18.u1) annotation (Line(points={{-140,-380},{-230,-380},
                    {-230,-408},{-222,-408}}, color={0,0,127}));
            connect(add18.y, add17.u1) annotation (Line(points={{-199,-414},{-199,-414},{-162,
                    -414}}, color={0,0,127}));
            connect(PID_valveSUB.CS, add18.u2) annotation (Line(points={{-262,-420},{-242,
                    -420},{-222,-420}}, color={0,0,127}));
            connect(table_thetaSUB.y[1], add17.u2) annotation (Line(points={{-239,-470},{-239,
                    -468},{-180,-468},{-180,-426},{-162,-426}}, color={0,0,127}));
            connect(add17.y, valveSUB_lim.u)
              annotation (Line(points={{-139,-420},{-122,-420}}, color={0,0,127}));
            connect(valveSUB_lim.y, valveSUB_dynamic.u)
              annotation (Line(points={{-99,-420},{-84,-420}}, color={0,0,127}));
            connect(DT_SC_SP.y, PID_valveSUB.SP) annotation (Line(points={{-347,-408},{-321.5,
                    -408},{-296,-408}}, color={0,0,127}));
            connect(LOAD15.y, table_thetaSUB.u[1]) annotation (Line(points={{-279,-470},{-270.5,
                    -470},{-262,-470}}, color={0,0,127}));
            connect(signalBus.valveSUB_PV, PID_valveSUB.PV) annotation (Line(
                points={{0,260},{0,260},{0,-420},{0,-502},{-320,-502},{-320,-422},{-296,-422}},
                color={255,204,51},
                thickness=0.5));

            connect(signalBus.valveSUB_CS, valveSUB_dynamic.y) annotation (Line(
                points={{0,260},{0,260},{0,-420},{-38,-420}},
                color={255,204,51},
                thickness=0.5));
            connect(LOAD1.y, table_p_DEA.u[1]) annotation (Line(points={{-379,
                    272},{-362,272}},       color={0,0,127}));
            connect(table_p_DEA.y[1], PID_valveRH_DEA.SP) annotation (Line(points={{-339,
                    272},{-320,272},{-296,272}},                  color={0,0,127}));
            connect(booleanStep10.y, PID_valveSUB.TS) annotation (Line(points={{
                    -261,-380},{-272,-380},{-272,-404}}, color={255,0,255}));
            connect(PID_valveRH_DEA.CS, PID_valveRH_DEA.TR) annotation (Line(
                  points={{-262,260},{-254,260},{-254,284},{-280,284},{-280,276}},
                  color={0,0,127}));
            connect(booleanStep1.y, PID_valveRH_DEA.TS) annotation (Line(points={
                    {-261,300},{-272,300},{-272,276}}, color={255,0,255}));
            connect(valveSUB.y, PID_valveSUB.TR) annotation (Line(points={{-299,
                    -380},{-290,-380},{-280,-380},{-280,-404}}, color={0,0,127}));
            annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                      -500},{400,500}})),           Icon(coordinateSystem(
                    preserveAspectRatio=false, extent={{-400,-500},{400,500}}), graphics={
                    Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                    Text(
                    extent={{-360,240},{360,-240}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    textString="DCS"),
                  Rectangle(
                    extent={{-100,100},{100,-100}},
                    pattern=LinePattern.None,
                    lineColor={0,0,0},
                    lineThickness=0.5),
                  Rectangle(
                    extent={{-400,500},{400,-500}},
                    lineColor={0,0,0},
                    lineThickness=0.5)}));
          end plant_controller_HPpart_lowLoad_lin;
        end LinearizationSchemes;

        package PilotControlSchemes "Package containing plant control schemes"

          model WSController_fullyDecentralized
            "Plant controller model with PI/PID controller and fully decentralized control logic"

          extends
              PreFlexMS.Pilot_245degC.Control.Schemes.BaseClasses.BasePlantController;

            //-- General settings --
            parameter Real load_switch
              "Plant load limit for switching from dry to wet separator configuration"
                                                                                       annotation (Dialog(tab="General settings"));
            parameter Boolean use_valveSEP
              "On/Off signal for separator drain valve"                              annotation (Dialog(tab="General settings"));
            parameter Boolean useTS_pumpMS "FF only on MS pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveSH_RH_high
              "FF only on turbine valve (@high load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveSH_RH_low
              "FF only on turbine valve (@low load)"                                      annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_high
              "FF only on FW pump (@high load)"                                   annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpFW_low "FF only on FW pump (@low load)"
                                                                                annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpSEP "FF only on SEP pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_pumpCOND "FF only on COND pump" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveRH_DEA "FF only on RH-DEA valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveRH_COND "FF only on RH-COND valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_eletHEAT "FF only on electric heaters" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveDEA_SH "FF only on DEA-SH valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Boolean useTS_valveDEA_RH "FF only on DEA-RH valve" annotation (Dialog(tab="General settings",group="Tracking"));
            parameter Real dec_wMS_wFW
              "Decoupling gain from MS control to FW control" annotation (Dialog(tab="General"));
            parameter Real dec_wFW_wMS
              "Decoupling gain from FW control to MS control" annotation (Dialog(tab="General"));
            //-- pumpMS --
            parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
            parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));

            //-- pumpMS_high --
            parameter Real Kp_pumpMS_high "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_high
              "Controller derivative time"                                              annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real Nd_pumpMS_high
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmin_pumpMS_high
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSmax_pumpMS_high
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real CSstart_pumpMS_high "Start value of CS" annotation (Dialog(tab="pumpMS",group="High load tuning"));
            parameter Real TS_pumpMS_high "Tracking signal" annotation (Dialog(tab="pumpMS",group="High load tuning"));

            //-- pumpMS_low --
            parameter Real Kp_pumpMS_low "Controller proportional gain" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_pumpMS_low
              "Controller integral time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_pumpMS_low
              "Controller derivative time"                                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real Nd_pumpMS_low
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmin_pumpMS_low
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSmax_pumpMS_low
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real CSstart_pumpMS_low "Start value of CS" annotation (Dialog(tab="pumpMS",group="Low load tuning"));
            parameter Real TS_pumpMS_low "Tracking signal" annotation (Dialog(tab="pumpMS",group="Low load tuning"));

            //-- valveSH_RH --
            parameter Real actuatorGain_valveSH_RH "Actuator gain" annotation (Dialog(tab="valveSH_RH"));
            parameter Modelica.SIunits.Time Ta_valveSH_RH
              "Actuator time constant"                                             annotation (Dialog(tab="valveSH_RH"));

            //-- valveSH_RH_high
            parameter Real Kp_valveSH_RH_high "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_high
              "Controller integral time"                                                  annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_high
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real Nd_valveSH_RH_high
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmin_valveSH_RH_high
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSmax_valveSH_RH_high
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real CSstart_valveSH_RH_high "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));
            parameter Real TS_valveSH_RH_high "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="High load tuning"));

            //-- valveSH_RH_low
            parameter Real Kp_valveSH_RH_low "Controller proportional gain" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Ti_valveSH_RH_low
              "Controller integral time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Modelica.SIunits.Time Td_valveSH_RH_low
              "Controller derivative time"                                                 annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real Nd_valveSH_RH_low
              "Controller derivative action up to Nd/Td rad/s"                                annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmin_valveSH_RH_low
              "Minimum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSmax_valveSH_RH_low
              "Maximum value of control signal for scaling"                                   annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real CSstart_valveSH_RH_low "Start value of CS" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));
            parameter Real TS_valveSH_RH_low "Tracking signal" annotation (Dialog(tab="valveSH_RH",group="Low load tuning"));

            //-- pumpFW --
            parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
            parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));

            //-- pumpFW_high --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_sp
              "Degree of superheating set point"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Kp_pumpFW_high "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_high
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Modelica.SIunits.Time Td_pumpFW_high
              "Controller derivative time"                                             annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real Nd_pumpFW_high
              "Controller derivative action up to Nd/Td rad/s"                               annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmin_pumpFW_high "Minimum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSmax_pumpFW_high "Maximum value of control signal"   annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real CSstart_pumpFW_high "Start value of CS"  annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));
            parameter Real TS_pumpFW_high "Tracking signal" annotation (Dialog(tab="pumpFW",group="Degree of superheating control"));

            //-- pumpFW_low --
            parameter Modelica.SIunits.Height l_sp "Tank level set point"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Kp_pumpFW_low "Controller proportional gain" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Ti_pumpFW_low
              "Controller integral time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Modelica.SIunits.Time Td_pumpFW_low
              "Controller derivative time"                                              annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real Nd_pumpFW_low
              "Controller derivative action up to Nd/Td rad/s"                            annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmin_pumpFW_low "Minimum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSmax_pumpFW_low "Maximum value of control signal"  annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real CSstart_pumpFW_low "Start value of CS" annotation (Dialog(tab="pumpFW",group="Separator level control"));
            parameter Real TS_pumpFW_low "Tracking signal" annotation (Dialog(tab="pumpFW",group="Separator level control"));

              //-- pumpCOND --
            parameter Modelica.SIunits.Length l_dea_sp
              "Deaerator level set point"                                          annotation (Dialog(tab="pumpCOND"));
            parameter Real Kp_pumpCOND "Controller proportional gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ti_pumpCOND
              "Controller integral time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Td_pumpCOND
              "Controller derivative time"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real Nd_pumpCOND
              "Controller derivative action up to Nd/Td rad/s"                          annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmin_pumpCOND
              "Minimum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSmax_pumpCOND
              "Maximum value of control signal for scaling"                             annotation (Dialog(tab="pumpCOND"));
            parameter Real CSstart_pumpCOND "Start value of CS" annotation (Dialog(tab="pumpCOND"));
            parameter Real actuatorGain_pumpCOND "Actuator gain" annotation (Dialog(tab="pumpCOND"));
            parameter Modelica.SIunits.Time Ta_pumpCOND
              "Actuator time constant"                                           annotation (Dialog(tab="pumpCOND"));
            parameter Real TS_pumpCOND "Tracking signal" annotation (Dialog(tab="pumpCOND"));

              //-- valveRH_DEA --
            parameter Real Kp_valveRH_DEA "Controller proportional gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ti_valveRH_DEA
              "Controller integral time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Td_valveRH_DEA
              "Controller derivative time"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real Nd_valveRH_DEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmin_valveRH_DEA
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSmax_valveRH_DEA
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_DEA"));
            parameter Real CSstart_valveRH_DEA "Start value of CS" annotation (Dialog(tab="valveRH_DEA"));
            parameter Real actuatorGain_valveRH_DEA "Actuator gain" annotation (Dialog(tab="valveRH_DEA"));
            parameter Modelica.SIunits.Time Ta_valveRH_DEA
              "Actuator time constant"                                              annotation (Dialog(tab="valveRH_DEA"));
            parameter Real TS_valveRH_DEA "Tracking signal" annotation (Dialog(tab="valveRH_DEA"));

            //-- valveRH_COND --
            parameter Real Kp_valveRH_COND "Controller proportional gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ti_valveRH_COND
              "Controller integral time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Td_valveRH_COND
              "Controller derivative time"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real Nd_valveRH_COND
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmin_valveRH_COND
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSmax_valveRH_COND
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveRH_COND"));
            parameter Real CSstart_valveRH_COND "Start value of CS" annotation (Dialog(tab="valveRH_COND"));
            parameter Real actuatorGain_valveRH_COND "Actuator gain" annotation (Dialog(tab="valveRH_COND"));
            parameter Modelica.SIunits.Time Ta_valveRH_COND
              "Actuator time constant"                                               annotation (Dialog(tab="valveRH_COND"));
            parameter Real TS_valveRH_COND "Tracking signal" annotation (Dialog(tab="valveRH_COND"));

            //-- valveDEA_SH --
            parameter Modelica.SIunits.Temperature T_RH_out_sp
              "Molten Salt RH outlet temperature set point"  annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Kp_valveDEA_SH "Controller proportional gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_SH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Td_valveDEA_SH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real Nd_valveDEA_SH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmin_valveDEA_SH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSmax_valveDEA_SH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_SH"));
            parameter Real CSstart_valveDEA_SH "Start value of CS" annotation (Dialog(tab="valveDEA_SH"));
            parameter Real actuatorGain_valveDEA_SH "Actuator gain" annotation (Dialog(tab="valveDEA_SH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_SH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_SH"));
            parameter Real TS_valveDEA_SH "Tracking signal" annotation (Dialog(tab="valveDEA_SH"));

            //-- valveDEA_RH --
            parameter Modelica.SIunits.TemperatureDifference DT_sh_COND_sp
              "Degree of superheating set-point at condenser inlet set point"  annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Kp_valveDEA_RH "Controller proportional gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ti_valveDEA_RH
              "Controller integral time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Td_valveDEA_RH
              "Controller derivative time"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real Nd_valveDEA_RH
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmin_valveDEA_RH
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSmax_valveDEA_RH
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="valveDEA_RH"));
            parameter Real CSstart_valveDEA_RH "Start value of CS" annotation (Dialog(tab="valveDEA_RH"));
            parameter Real actuatorGain_valveDEA_RH "Actuator gain" annotation (Dialog(tab="valveDEA_RH"));
            parameter Modelica.SIunits.Time Ta_valveDEA_RH
              "Actuator time constant"                                              annotation (Dialog(tab="valveDEA_RH"));
            parameter Real TS_valveDEA_RH "Tracking signal" annotation (Dialog(tab="valveDEA_RH"));

            //-- eletHEAT --
            parameter Real Kp_eletHEAT "Controller proportional gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ti_eletHEAT
              "Controller integral time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Td_eletHEAT
              "Controller derivative time"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real Nd_eletHEA
              "Controller derivative action up to Nd/Td rad/s"                             annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmin_eletHEAT
              "Minimum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSmax_eletHEAT
              "Maximum value of control signal for scaling"                                annotation (Dialog(tab="eletHEAT"));
            parameter Real CSstart_eletHEAT "Start value of CS" annotation (Dialog(tab="eletHEAT"));
            parameter Real actuatorGain_eletHEAT "Actuator gain" annotation (Dialog(tab="eletHEAT"));
            parameter Modelica.SIunits.Time Ta_eletHEAT
              "Actuator time constant"                                           annotation (Dialog(tab="eletHEAT"));
            parameter Real TS_eletHEAT "Tracking signal" annotation (Dialog(tab="eletHEAT"));

            //-- pumpHPH --
            parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
            parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpHPH"));

            //-- pumpSEP --
            parameter Modelica.SIunits.Temperature T_FW_sp
              "Feedwater inlet temperature set point" annotation (Dialog(tab="pumpSEP"));
            parameter Real Kp_pumpSEP "Controller proportional gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ti_pumpSEP
              "Controller integral time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Td_pumpSEP
              "Controller derivative time"                                          annotation (Dialog(tab="pumpSEP"));
            parameter Real Nd_pumpSEP
              "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmin_pumpSEP
              "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSmax_pumpSEP
              "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpSEP"));
            parameter Real CSstart_pumpSEP "Start value of CS" annotation (Dialog(tab="pumpSEP"));
            parameter Real actuatorGain_pumpSEP "Actuator gain" annotation (Dialog(tab="pumpSEP"));
            parameter Modelica.SIunits.Time Ta_pumpSEP "Actuator time constant"
                                                                                annotation (Dialog(tab="pumpSEP"));
            parameter Real TS_pumpSEP "Tracking signal" annotation (Dialog(tab="pumpSEP"));

            //-- valveSEP --
            parameter Real l_min "Switch off level" annotation (Dialog(tab="valveSEP"));
            parameter Real l_max "Switch on level" annotation (Dialog(tab="valveSEP"));
            parameter Real load_min "Switch on load" annotation (Dialog(tab="valveSEP"));
            parameter Real actuatorGain_valveSEP "Actuator gain" annotation (Dialog(tab="valveSEP"));
            parameter Modelica.SIunits.Time Ta_valveSEP
              "Actuator time constant"                                           annotation (Dialog(tab="valveSEP"));

            PowerPressureFWcontrollers.fullyDecentralized fullyDecentralized(
              actuatorGain_pumpMS=actuatorGain_pumpMS,
              Ta_pumpMS=Ta_pumpMS,
              actuatorGain_valveSH_RH=actuatorGain_valveSH_RH,
              Ta_valveSH_RH=Ta_valveSH_RH,
              actuatorGain_pumpFW=actuatorGain_pumpFW,
              Ta_pumpFW=Ta_pumpFW,
              DT_sh_sp=DT_sh_sp,
              Kp_pumpFW_high=Kp_pumpFW_high,
              Ti_pumpFW_high=Ti_pumpFW_high,
              Td_pumpFW_high=Td_pumpFW_high,
              Nd_pumpFW_high=Nd_pumpFW_high,
              CSmin_pumpFW_high=CSmin_pumpFW_high,
              CSmax_pumpFW_high=CSmax_pumpFW_high,
              CSstart_pumpFW_high=CSstart_pumpFW_high,
              TS_pumpFW_high=TS_pumpFW_high,
              l_sp=l_sp,
              Kp_pumpFW_low=Kp_pumpFW_low,
              Ti_pumpFW_low=Ti_pumpFW_low,
              Td_pumpFW_low=Td_pumpFW_low,
              Nd_pumpFW_low=Nd_pumpFW_low,
              CSmin_pumpFW_low=CSmin_pumpFW_low,
              CSmax_pumpFW_low=CSmax_pumpFW_low,
              CSstart_pumpFW_low=CSstart_pumpFW_low,
              TS_pumpFW_low=TS_pumpFW_low,
              Kp_pumpMS_high=Kp_pumpMS_high,
              Ti_pumpMS_high=Ti_pumpMS_high,
              Td_pumpMS_high=Td_pumpMS_high,
              Nd_pumpMS_high=Nd_pumpMS_high,
              CSmin_pumpMS_high=CSmin_pumpMS_high,
              CSmax_pumpMS_high=CSmax_pumpMS_high,
              CSstart_pumpMS_high=CSstart_pumpMS_high,
              TS_pumpMS_high=TS_pumpMS_high,
              Kp_pumpMS_low=Kp_pumpMS_low,
              Ti_pumpMS_low=Ti_pumpMS_low,
              Td_pumpMS_low=Td_pumpMS_low,
              Nd_pumpMS_low=Nd_pumpMS_low,
              CSmin_pumpMS_low=CSmin_pumpMS_low,
              CSmax_pumpMS_low=CSmax_pumpMS_low,
              CSstart_pumpMS_low=CSstart_pumpMS_low,
              TS_pumpMS_low=TS_pumpMS_low,
              Kp_valveSH_RH_high=Kp_valveSH_RH_high,
              Ti_valveSH_RH_high=Ti_valveSH_RH_high,
              Td_valveSH_RH_high=Td_valveSH_RH_high,
              Nd_valveSH_RH_high=Nd_valveSH_RH_high,
              CSmin_valveSH_RH_high=CSmin_valveSH_RH_high,
              CSmax_valveSH_RH_high=CSmax_valveSH_RH_high,
              CSstart_valveSH_RH_high=CSstart_valveSH_RH_high,
              TS_valveSH_RH_high=TS_valveSH_RH_high,
              Kp_valveSH_RH_low=Kp_valveSH_RH_low,
              Ti_valveSH_RH_low=Ti_valveSH_RH_low,
              Td_valveSH_RH_low=Td_valveSH_RH_low,
              Nd_valveSH_RH_low=Nd_valveSH_RH_low,
              CSmin_valveSH_RH_low=CSmin_valveSH_RH_low,
              CSmax_valveSH_RH_low=CSmax_valveSH_RH_low,
              CSstart_valveSH_RH_low=CSstart_valveSH_RH_low,
              TS_valveSH_RH_low=TS_valveSH_RH_low,
              load_switch=load_switch,
              dec_wMS_wFW=dec_wMS_wFW,
              dec_wFW_wMS=dec_wFW_wMS)
              annotation (Placement(transformation(extent={{-40,140},{14,200}})));
            SingleControllers.control_wHPH control_wHPH(actuatorGain_pumpHPH=
                  actuatorGain_pumpHPH, Ta_pumpHPH=Ta_pumpHPH)
              annotation (Placement(transformation(extent={{-40,-80},{0,-40}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_MS(
              k=useTS_pumpMS) annotation (Placement(transformation(extent={{-80,210},{-60,
                      230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_high(k=useTS_valveSH_RH_high)
              annotation (Placement(transformation(extent={{-80,240},{-60,260}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_high(k=useTS_pumpFW_high)
                                   annotation (Placement(transformation(extent={{60,260},{
                      40,280}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_FW_low(
              k=useTS_pumpFW_low) annotation (Placement(transformation(extent={{60,210},{40,
                      230}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_COND(k=useTS_pumpCOND)
              annotation (Placement(transformation(extent={{-80,90},{-60,110}})));
            SingleControllers.control_wSEP control_wSEP(
              load_switch=load_switch,
              T_FW_sp=T_FW_sp,
              Kp_pumpSEP=Kp_pumpSEP,
              Ti_pumpSEP=Ti_pumpSEP,
              Td_pumpSEP=Td_pumpSEP,
              Nd_pumpSEP=Nd_pumpSEP,
              CSmin_pumpSEP=CSmin_pumpSEP,
              CSmax_pumpSEP=CSmax_pumpSEP,
              CSstart_pumpSEP=CSstart_pumpSEP,
              actuatorGain_pumpSEP=actuatorGain_pumpSEP,
              Ta_pumpSEP=Ta_pumpSEP,
              TS_pumpSEP=TS_pumpSEP)
              annotation (Placement(transformation(extent={{-40,-180},{0,-140}})));
            Modelica.Blocks.Sources.BooleanConstant TS_w_SEP(k=useTS_pumpSEP)
                              annotation (Placement(transformation(extent={{-80,-120},{-60,
                      -100}})));
            Modelica.Blocks.Sources.BooleanConstant TS_Y_t_low(k=useTS_valveSH_RH_low)
              annotation (Placement(transformation(extent={{-80,270},{-60,290}})));
            SingleControllers.control_valveSEP control_valveSEP(
              load_min=load_min,
              actuatorGain_valveSEP=actuatorGain_valveSEP,
              Ta_valveSEP=Ta_valveSEP,
              l_min=l_min,
              l_max=l_max)                                      annotation (
                Placement(transformation(extent={{-40,-280},{0,-240}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_SEP(k=use_valveSEP)
                               annotation (Placement(transformation(extent={{-80,-220},{-60,
                      -200}})));
            WSCcontrollers.WSCcontroller WSCcontroller(
              load_switch=load_switch,
              l_dea_sp=l_dea_sp,
              Kp_pumpCOND=Kp_pumpCOND,
              Ti_pumpCOND=Ti_pumpCOND,
              Td_pumpCOND=Td_pumpCOND,
              Nd_pumpCOND=Nd_pumpCOND,
              CSmin_pumpCOND=CSmin_pumpCOND,
              CSmax_pumpCOND=CSmax_pumpCOND,
              CSstart_pumpCOND=CSstart_pumpCOND,
              actuatorGain_pumpCOND=actuatorGain_pumpCOND,
              Ta_pumpCOND=Ta_pumpCOND,
              TS_pumpCOND=TS_pumpCOND,
              Kp_valveRH_DEA=Kp_valveRH_DEA,
              Ti_valveRH_DEA=Ti_valveRH_DEA,
              Td_valveRH_DEA=Td_valveRH_DEA,
              Nd_valveRH_DEA=Nd_valveRH_DEA,
              CSmin_valveRH_DEA=CSmin_valveRH_DEA,
              CSmax_valveRH_DEA=CSmax_valveRH_DEA,
              CSstart_valveRH_DEA=CSstart_valveRH_DEA,
              actuatorGain_valveRH_DEA=actuatorGain_valveRH_DEA,
              Ta_valveRH_DEA=Ta_valveRH_DEA,
              TS_valveRH_DEA=TS_valveRH_DEA,
              Kp_valveRH_COND=Kp_valveRH_COND,
              Ti_valveRH_COND=Ti_valveRH_COND,
              Td_valveRH_COND=Td_valveRH_COND,
              Nd_valveRH_COND=Nd_valveRH_COND,
              CSmin_valveRH_COND=CSmin_valveRH_COND,
              CSmax_valveRH_COND=CSmax_valveRH_COND,
              CSstart_valveRH_COND=CSstart_valveRH_COND,
              actuatorGain_valveRH_COND=actuatorGain_valveRH_COND,
              Ta_valveRH_COND=Ta_valveRH_COND,
              TS_valveRH_COND=TS_valveRH_COND,
              Kp_valveDEA_SH=Kp_valveDEA_SH,
              Ti_valveDEA_SH=Ti_valveDEA_SH,
              Td_valveDEA_SH=Td_valveDEA_SH,
              Nd_valveDEA_SH=Nd_valveDEA_SH,
              CSmin_valveDEA_SH=CSmin_valveDEA_SH,
              CSmax_valveDEA_SH=CSmax_valveDEA_SH,
              CSstart_valveDEA_SH=CSstart_valveDEA_SH,
              actuatorGain_valveDEA_SH=actuatorGain_valveDEA_SH,
              Ta_valveDEA_SH=Ta_valveDEA_SH,
              TS_valveDEA_SH=TS_valveDEA_SH,
              DT_sh_COND_sp=DT_sh_COND_sp,
              Kp_valveDEA_RH=Kp_valveDEA_RH,
              Ti_valveDEA_RH=Ti_valveDEA_RH,
              Td_valveDEA_RH=Td_valveDEA_RH,
              Nd_valveDEA_RH=Nd_valveDEA_RH,
              CSmin_valveDEA_RH=CSmin_valveDEA_RH,
              CSmax_valveDEA_RH=CSmax_valveDEA_RH,
              CSstart_valveDEA_RH=CSstart_valveDEA_RH,
              actuatorGain_valveDEA_RH=actuatorGain_valveDEA_RH,
              Ta_valveDEA_RH=Ta_valveDEA_RH,
              TS_valveDEA_RH=TS_valveDEA_RH,
              Kp_eletHEAT=Kp_eletHEAT,
              Ti_eletHEAT=Ti_eletHEAT,
              Td_eletHEAT=Td_eletHEAT,
              Nd_eletHEA=Nd_eletHEA,
              CSmin_eletHEAT=CSmin_eletHEAT,
              CSmax_eletHEAT=CSmax_eletHEAT,
              CSstart_eletHEAT=CSstart_eletHEAT,
              actuatorGain_eletHEAT=actuatorGain_eletHEAT,
              Ta_eletHEAT=Ta_eletHEAT,
              TS_eletHEAT=TS_eletHEAT)
              annotation (Placement(transformation(extent={{-40,30},{14,90}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_RH_DEA(k=useTS_valveRH_DEA)
              annotation (Placement(transformation(extent={{-120,110},{-100,130}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_RH_COND(k=useTS_valveRH_COND)
              annotation (Placement(transformation(extent={{60,100},{40,120}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_DEA_SH(k=useTS_valveDEA_SH)
              annotation (Placement(transformation(extent={{-120,-30},{-100,-10}})));
            Modelica.Blocks.Sources.BooleanConstant TS_elet_HEAT(k=useTS_eletHEAT)
              annotation (Placement(transformation(extent={{-80,0},{-60,20}})));
            Modelica.Blocks.Sources.BooleanConstant TS_valve_DEA_RH(k=useTS_valveDEA_RH)
              annotation (Placement(transformation(extent={{60,0},{40,20}})));
            Modelica.Blocks.Sources.Constant valveSUB(k=1) annotation (
                Placement(transformation(extent={{120,-40},{140,-20}})));
          equation
            connect(fullyDecentralized.signalBus, signalBus) annotation (Line(
                points={{15.485,170},{180,170},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(control_wHPH.signalBus, signalBus) annotation (Line(
                points={{1,-60},{1,-60},{180,-60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_MS.y, fullyDecentralized.TS_pumpMS_bool) annotation (Line(points={{-59,220},
                    {-34.6,220},{-34.6,201.364}},      color={255,0,255}));
            connect(TS_w_FW_high.y, fullyDecentralized.TS_pumpFWhigh_bool) annotation (
                Line(points={{39,270},{-2.2,270},{-2.2,201.364}},
                                                                color={255,0,255}));
            connect(TS_w_FW_low.y, fullyDecentralized.TS_pumpFWlow_bool) annotation (Line(
                  points={{39,220},{8.6,220},{8.6,201.364}}, color={255,0,255}));
            connect(load, fullyDecentralized.load) annotation (Line(points={{-200,0},{-160,
                    0},{-160,170},{-41.35,170}},
                                               color={0,0,127}));
            connect(load, control_wHPH.load) annotation (Line(points={{-200,0},{-200,0},{-160,
                    0},{-160,-60},{-42,-60}},    color={0,0,127}));
            connect(load, control_wSEP.load) annotation (Line(points={{-200,0},{-160,0},{-160,
                    -160},{-42,-160}},  color={0,0,127}));
            connect(signalBus, control_wSEP.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-160},{1,-160}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_w_SEP.y, control_wSEP.TS_pumpSEP_bool) annotation (Line(points={{-59,
                    -110},{-20,-110},{-20,-138}},   color={255,0,255}));
            connect(TS_Y_t_high.y, fullyDecentralized.TS_valveSH_RHhigh_bool) annotation (
                Line(points={{-59,250},{-44,250},{-23.8,250},{-23.8,201.364}},
                                                                           color={255,0,255}));
            connect(TS_Y_t_low.y, fullyDecentralized.TS_valveSH_RHlow_bool) annotation (
                Line(points={{-59,280},{-32,280},{-13,280},{-13,201.364}}, color={255,0,255}));
            connect(load, control_valveSEP.load) annotation (Line(points={{-200,0},{-160,0},
                    {-160,-260},{-42,-260}},            color={0,0,127}));
            connect(signalBus, control_valveSEP.signalBus) annotation (Line(
                points={{180,0},{180,0},{180,-42},{180,-260},{1,-260}},
                color={255,204,51},
                thickness=0.5));
            connect(TS_valve_SEP.y, control_valveSEP.useValveSEP) annotation (Line(points={{-59,
                    -210},{-20,-210},{-20,-238}},  color={255,0,255}));
            connect(WSCcontroller.signalBus, signalBus) annotation (Line(
                points={{15.485,60},{94,60},{180,60},{180,0}},
                color={255,204,51},
                thickness=0.5));
            connect(load,WSCcontroller. load) annotation (Line(points={{-200,0},{-160,0},{
                    -160,60},{-41.35,60}}, color={0,0,127}));
            connect(TS_w_COND.y,WSCcontroller. TS_pumpCOND_bool) annotation (Line(points={{-59,100},
                    {-27.85,100},{-27.85,91.3636}},           color={255,0,255}));
            connect(TS_valve_RH_COND.y,WSCcontroller. TS_valveRH_COND_bool) annotation (
                Line(points={{39,110},{3.2,110},{3.2,91.3636}}, color={255,0,255}));
            connect(TS_valve_RH_DEA.y,WSCcontroller. TS_valveRH_DEA_bool) annotation (
                Line(points={{-99,120},{-13,120},{-13,91.3636}}, color={255,0,255}));
            connect(TS_valve_DEA_RH.y,WSCcontroller. TS_valveDEA_RH_bool) annotation (
                Line(points={{39,10},{1.85,10},{1.85,28.6364}}, color={255,0,255}));
            connect(TS_valve_DEA_SH.y,WSCcontroller. TS_valveDEA_SH_bool) annotation (
                Line(points={{-99,-20},{-64,-20},{-13,-20},{-13,28.6364}}, color={255,0,255}));
            connect(TS_elet_HEAT.y, WSCcontroller.TS_eletHEAT_bool) annotation (Line(
                  points={{-59,10},{-27.85,10},{-27.85,28.6364}}, color={255,0,255}));
            connect(signalBus.valveSUB_CS, valveSUB.y) annotation (Line(
                points={{180,0},{180,-30},{141,-30}},
                color={255,204,51},
                thickness=0.5));
            annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
                  coordinateSystem(preserveAspectRatio=false)));
          end WSController_fullyDecentralized;

        end PilotControlSchemes;

      end Schemes;

      package Linearization "Test for process linearization and PID tuning"

        model Pilot_IO_100_DTsh
          "Model of the pilot for linearization at 100% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin_ECO_complete
                                                      OTSG(
            HPH(coldFluid(w(start=0.47, fixed=false))),
            FW_in(p(start=17400000, fixed=false)),
            RH(coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH_out(p(start=17100000, fixed=false)),
            PDSteamSH2(inlet(p(start=17200000, fixed=false))),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            ECO(Shot=77.459*0.8, Scold=63.904*0.8))        annotation (
              Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Kp_pumpFW=-0.01,
            Ti_valveSH_RH=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Ti_valveRH_COND=50,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            Ti_valveRH_DEA=250,
            Ti_pumpCOND=100,
            CSstart_pumpCOND=2.6,
            Kp_pumpCOND=10,
            Ti_valveDEA_SH=100,
            Kp_valveDEA_SH=-0.0025,
            Kp_valveDEA_RH=-0.01,
            Ti_valveDEA_RH=100,
            DT_SH_sp(displayUnit="K") = 293.15,
            DT_sh_COND_sp(displayUnit="K") = 10,
            l_dea_sp=0.45,
            Kp_valveSH_RH=-0.0000001,
            Kp_valveRH_COND=-0.001,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            Kp_eletHEAT=540000,
            Ti_eletHEAT=20,
            Td_eletHEAT=0,
            Nd_eletHEA=20,
            CSmin_eletHEAT=0,
            CSmax_eletHEAT=2e5,
            CSstart_eletHEAT=0,
            useTS_eletHEAT=true,
            TS_eletHEAT=0,
            Kp_valveRH_DEA=0.01,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            load_end=100,
            p_RH_sp=4700000,
            T_RH_out_sp=733.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_100 WSC(
            valveDEA_RH(w(start=0.66, fixed=false)),
            valveRH_DEA(w(start=0.11, fixed=false)),
            sensT_COND(h(start=2836.6e3, fixed=false)),
            valveDEA_SH(w(start=0.272, fixed=false)))
                                         annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,220},{-320,260}}),iconTransformation(
                  extent={{-360,220},{-320,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,160},{-320,200}}),
                iconTransformation(extent={{-360,160},{-320,200}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),   iconTransformation(
                  extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,40},{-320,80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-140},{-320,-100}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                transformation(extent={{-360,-260},{-320,-220}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,230},
                    {340,250}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,170},
                    {340,190}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_EVA=OTSG.sensDT_sh.DT_sh annotation (
              Placement(transformation(extent={{320,110},{340,130}}),
                                                                    iconTransformation(
                  extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (Placement(transformation(extent={{320,50},{340,70}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -190},{340,-170}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -250},{340,-230}})));

        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,240},{-270,240},{
                  -270,-1.6},{-261.5,-1.6}},            color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,180},{-280,180},{-280,
                  -11.2},{-261.5,-11.2}},        color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,120},{-340,120},{
                  -304,120},{-290,120},{-290,-20.8},{-261.5,-20.8}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,60},
                  {-300,60},{-300,-30.4},{-261.5,-30.4}},           color={0,0,
                  127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-120},
                  {-340,-120},{-290,-120},{-290,-59.2},{-261.5,-59.2}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-300,-60},{-300,-49.6},{-261.5,-49.6}},              color={
                  0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-340,0},{-310,0},{-310,-40},{-261.5,-40}},
                color={0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255}));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255}));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255}));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255}));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255}));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-140,-40},{-140,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_Q_eletHEAT, DCS.du_Q_eletHEAT) annotation (Line(points={{-340,-240},
                  {-304,-240},{-270,-240},{-270,-78.4},{-261.5,-78.4}}, color={0,0,127}));
          connect(du_w_COND, DCS.du_w_COND) annotation (Line(points={{-340,-180},
                  {-280,-180},{-280,-68.8},{-261.5,-68.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_100_DTsh;

        model Pilot_IO_90_DTsh
          "Model of the pilot for linearization at 100% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin_ECO_complete
                                                      OTSG(
            HPH(coldFluid(w(start=0.47, fixed=false))),
            FW_in(p(start=17400000, fixed=false)),
            RH(coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH_out(p(start=17100000, fixed=false)),
            PDSteamSH2(inlet(p(start=17200000, fixed=false))),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            ECO(Shot=77.459*0.8, Scold=63.904*0.8))        annotation (
              Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            load_start=100,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Kp_pumpFW=-0.01,
            Ti_valveSH_RH=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Ti_valveRH_COND=50,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            Ti_valveRH_DEA=250,
            Ti_pumpCOND=100,
            CSstart_pumpCOND=2.6,
            Kp_pumpCOND=10,
            Ti_valveDEA_SH=100,
            Kp_valveDEA_SH=-0.0025,
            Kp_valveDEA_RH=-0.01,
            Ti_valveDEA_RH=100,
            DT_SH_sp(displayUnit="K") = 293.15,
            DT_sh_COND_sp(displayUnit="K") = 10,
            l_dea_sp=0.45,
            Kp_valveSH_RH=-0.0000001,
            Kp_valveRH_COND=-0.001,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            Kp_eletHEAT=540000,
            Ti_eletHEAT=20,
            Td_eletHEAT=0,
            Nd_eletHEA=20,
            CSmin_eletHEAT=0,
            CSmax_eletHEAT=2e5,
            CSstart_eletHEAT=0,
            useTS_eletHEAT=true,
            TS_eletHEAT=0,
            Kp_valveRH_DEA=0.01,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            load_end=90,
            p_RH_sp=4700000,
            T_RH_out_sp=733.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_100 WSC(
            valveDEA_RH(w(start=0.66, fixed=false)),
            valveRH_DEA(w(start=0.11, fixed=false)),
            sensT_COND(h(start=2836.6e3, fixed=false)),
            valveDEA_SH(w(start=0.272, fixed=false)))
                                         annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,220},{-320,260}}),iconTransformation(
                  extent={{-360,220},{-320,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,160},{-320,200}}),
                iconTransformation(extent={{-360,160},{-320,200}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),   iconTransformation(
                  extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,40},{-320,80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-140},{-320,-100}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                transformation(extent={{-360,-260},{-320,-220}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,230},
                    {340,250}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,170},
                    {340,190}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_EVA=OTSG.sensDT_sh.DT_sh annotation (
              Placement(transformation(extent={{320,110},{340,130}}),
                                                                    iconTransformation(
                  extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (Placement(transformation(extent={{320,50},{340,70}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -190},{340,-170}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -250},{340,-230}})));

        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,240},{-270,240},{
                  -270,-1.6},{-261.5,-1.6}},            color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,180},{-280,180},{-280,
                  -11.2},{-261.5,-11.2}},        color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,120},{-340,120},{
                  -304,120},{-290,120},{-290,-20.8},{-261.5,-20.8}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,60},
                  {-300,60},{-300,-30.4},{-261.5,-30.4}},           color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68.8},{-261.5,-68.8}},             color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-120},
                  {-340,-120},{-290,-120},{-290,-59.2},{-261.5,-59.2}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-300,-60},{-300,-49.6},{-261.5,-49.6}},              color={
                  0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-340,0},{-310,0},{-310,-40},{-261.5,-40}},
                color={0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255}));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255}));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255}));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255}));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255}));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-140,-40},{-140,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_Q_eletHEAT, DCS.du_Q_eletHEAT) annotation (Line(points={{-340,-240},
                  {-304,-240},{-270,-240},{-270,-78.4},{-261.5,-78.4}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_90_DTsh;

        model Pilot_IO_80_DTsh
          "Model of the pilot for linearization at 80% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin_ECO_complete
                                                      OTSG(
            HPH(coldFluid(w(start=0.47, fixed=false))),
            FW_in(p(start=17400000, fixed=false)),
            RH(coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH_out(p(start=17100000, fixed=false)),
            PDSteamSH2(inlet(p(start=17200000, fixed=false))),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            ECO(Shot=77.459*0.8, Scold=63.904*0.8))        annotation (
              Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            DT_SH_sp(displayUnit="K") = 293.15,
            DT_sh_COND_sp(displayUnit="K") = 10,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            Td_eletHEAT=0,
            Nd_eletHEA=20,
            CSmin_eletHEAT=0,
            CSmax_eletHEAT=2e5,
            CSstart_eletHEAT=0,
            useTS_eletHEAT=true,
            TS_eletHEAT=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            load_end=80,
            Kp_pumpMS=0.0001295,
            Ti_pumpMS=54.23,
            Td_pumpMS=3.098,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=3.845,
            Kp_pumpFW=-0.01579,
            Ti_pumpFW=191.3,
            Kp_valveRH_DEA=1.007e-6,
            Ti_valveRH_DEA=142.8,
            Kp_valveRH_COND=-2.899e-8,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180.7,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Kp_valveDEA_RH=-0.0007726,
            Ti_valveDEA_RH=0.3121,
            Kp_eletHEAT=1.529e5,
            Ti_eletHEAT=571.4,
            load_start=80,
            p_RH_sp=4700000,
            T_RH_out_sp=733.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_100 WSC(
            valveDEA_RH(w(start=0.66, fixed=false)),
            valveRH_DEA(w(start=0.11, fixed=false)),
            sensT_COND(h(start=2836.6e3, fixed=false)),
            valveDEA_SH(w(start=0.272, fixed=false)),
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,220},{-320,260}}),iconTransformation(
                  extent={{-360,220},{-320,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,160},{-320,200}}),
                iconTransformation(extent={{-360,160},{-320,200}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),   iconTransformation(
                  extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,40},{-320,80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-140},{-320,-100}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                transformation(extent={{-360,-260},{-320,-220}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,230},
                    {340,250}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,170},
                    {340,190}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_EVA=OTSG.sensDT_sh.DT_sh annotation (
              Placement(transformation(extent={{320,110},{340,130}}),
                                                                    iconTransformation(
                  extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (Placement(transformation(extent={{320,50},{340,70}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -190},{340,-170}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -250},{340,-230}})));

        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,240},{-270,240},{
                  -270,-1.6},{-261.5,-1.6}},            color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,180},{-280,180},{-280,
                  -11.2},{-261.5,-11.2}},        color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,120},{-340,120},{
                  -304,120},{-290,120},{-290,-20.8},{-261.5,-20.8}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,60},
                  {-300,60},{-300,-30.4},{-261.5,-30.4}},           color={0,0,
                  127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-120},
                  {-340,-120},{-290,-120},{-290,-59.2},{-261.5,-59.2}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-300,-60},{-300,-49.6},{-261.5,-49.6}},              color={
                  0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-340,0},{-310,0},{-310,-40},{-261.5,-40}},
                color={0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255}));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255}));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255}));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255}));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255}));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-140,-40},{-140,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_Q_eletHEAT, DCS.du_Q_eletHEAT) annotation (Line(points={{-340,-240},
                  {-304,-240},{-270,-240},{-270,-78.4},{-261.5,-78.4}}, color={0,0,127}));
          connect(du_w_COND, DCS.du_w_COND) annotation (Line(points={{-340,-180},
                  {-280,-180},{-280,-68.8},{-261.5,-68.8}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_80_DTsh;

        model Pilot_IO_70_DTsh
          "Model of the pilot for linearization at 70% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin_ECO_complete
                                                      OTSG(
            HPH(coldFluid(w(start=0.47, fixed=false))),
            FW_in(p(start=17400000, fixed=false)),
            RH(coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH_out(p(start=17100000, fixed=false)),
            PDSteamSH2(inlet(p(start=17200000, fixed=false))),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            ECO(Shot=77.459*0.8, Scold=63.904*0.8))        annotation (
              Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            DT_SH_sp(displayUnit="K") = 293.15,
            DT_sh_COND_sp(displayUnit="K") = 10,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            Td_eletHEAT=0,
            Nd_eletHEA=20,
            CSmin_eletHEAT=0,
            CSmax_eletHEAT=2e5,
            CSstart_eletHEAT=0,
            useTS_eletHEAT=true,
            TS_eletHEAT=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Kp_pumpMS=0.0001295,
            Ti_pumpMS=54.23,
            Td_pumpMS=3.098,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=3.845,
            Kp_pumpFW=-0.01579,
            Ti_pumpFW=191.3,
            Kp_valveRH_DEA=1.007e-6,
            Ti_valveRH_DEA=142.8,
            Kp_valveRH_COND=-2.899e-8,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180.7,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Kp_valveDEA_RH=-0.0007726,
            Ti_valveDEA_RH=0.3121,
            Kp_eletHEAT=1.529e5,
            Ti_eletHEAT=571.4,
            load_start=80,
            load_end=70,
            p_RH_sp=4700000,
            T_RH_out_sp=733.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_100 WSC(
            valveDEA_RH(w(start=0.66, fixed=false)),
            valveRH_DEA(w(start=0.11, fixed=false)),
            sensT_COND(h(start=2836.6e3, fixed=false)),
            valveDEA_SH(w(start=0.272, fixed=false)),
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,220},{-320,260}}),iconTransformation(
                  extent={{-360,220},{-320,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,160},{-320,200}}),
                iconTransformation(extent={{-360,160},{-320,200}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),   iconTransformation(
                  extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,40},{-320,80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-140},{-320,-100}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                transformation(extent={{-360,-260},{-320,-220}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,230},
                    {340,250}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,170},
                    {340,190}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_EVA=OTSG.sensDT_sh.DT_sh annotation (
              Placement(transformation(extent={{320,110},{340,130}}),
                                                                    iconTransformation(
                  extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (Placement(transformation(extent={{320,50},{340,70}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -190},{340,-170}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -250},{340,-230}})));

        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,240},{-270,240},{
                  -270,-1.6},{-261.5,-1.6}},            color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,180},{-280,180},{-280,
                  -11.2},{-261.5,-11.2}},        color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,120},{-340,120},{
                  -304,120},{-290,120},{-290,-20.8},{-261.5,-20.8}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,60},
                  {-300,60},{-300,-30.4},{-261.5,-30.4}},           color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68.8},{-261.5,-68.8}},             color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-120},
                  {-340,-120},{-290,-120},{-290,-59.2},{-261.5,-59.2}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-300,-60},{-300,-49.6},{-261.5,-49.6}},              color={
                  0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-340,0},{-310,0},{-310,-40},{-261.5,-40}},
                color={0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255}));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255}));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255}));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255}));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255}));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-140,-40},{-140,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_Q_eletHEAT, DCS.du_Q_eletHEAT) annotation (Line(points={{-340,-240},
                  {-304,-240},{-270,-240},{-270,-78.4},{-261.5,-78.4}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_70_DTsh;

        model Pilot_IO_60_DTsh
          "Model of the pilot for linearization at 60% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init100_5nodes_lin_ECO_complete
                                                      OTSG(
            HPH(coldFluid(w(start=0.47, fixed=false))),
            FW_in(p(start=17400000, fixed=false)),
            RH(coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH_out(p(start=17100000, fixed=false)),
            PDSteamSH2(inlet(p(start=17200000, fixed=false))),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            ECO(Shot=77.459*0.8, Scold=63.904*0.8))        annotation (
              Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_highLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            CSmin_pumpFW=-0.3,
            CSstart_pumpFW=0,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            CSmax_pumpFW=0.15,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            DT_SH_sp(displayUnit="K") = 293.15,
            DT_sh_COND_sp(displayUnit="K") = 10,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            Td_eletHEAT=0,
            Nd_eletHEA=20,
            CSmin_eletHEAT=0,
            CSmax_eletHEAT=2e5,
            CSstart_eletHEAT=0,
            useTS_eletHEAT=true,
            TS_eletHEAT=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Kp_pumpMS=0.0001295,
            Ti_pumpMS=54.23,
            Td_pumpMS=3.098,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=3.845,
            Kp_pumpFW=-0.01579,
            Ti_pumpFW=191.3,
            Kp_valveRH_DEA=1.007e-6,
            Ti_valveRH_DEA=142.8,
            Kp_valveRH_COND=-2.899e-8,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180.7,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Kp_valveDEA_RH=-0.0007726,
            Ti_valveDEA_RH=0.3121,
            Kp_eletHEAT=1.529e5,
            Ti_eletHEAT=571.4,
            load_start=80,
            load_end=60,
            p_RH_sp=4700000,
            T_RH_out_sp=733.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_100 WSC(
            valveDEA_RH(w(start=0.66, fixed=false)),
            valveRH_DEA(w(start=0.11, fixed=false)),
            sensT_COND(h(start=2836.6e3, fixed=false)),
            valveDEA_SH(w(start=0.272, fixed=false)),
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,220},{-320,260}}),iconTransformation(
                  extent={{-360,220},{-320,260}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,160},{-320,200}}),
                iconTransformation(extent={{-360,160},{-320,200}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),   iconTransformation(
                  extent={{-360,100},{-320,140}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,40},{-320,80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-140},{-320,-100}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_Q_eletHEAT annotation (Placement(
                transformation(extent={{-360,-260},{-320,-220}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,230},
                    {340,250}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,170},
                    {340,190}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_EVA=OTSG.sensDT_sh.DT_sh annotation (
              Placement(transformation(extent={{320,110},{340,130}}),
                                                                    iconTransformation(
                  extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (Placement(transformation(extent={{320,50},{340,70}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,-10},
                    {340,10}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,
                    -130},{340,-110}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -190},{340,-170}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW = OTSG.sensT_FW.T annotation (Placement(transformation(extent={{320,
                    -250},{340,-230}})));

        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,240},{-270,240},{
                  -270,-1.6},{-261.5,-1.6}},            color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,180},{-280,180},{-280,
                  -11.2},{-261.5,-11.2}},        color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,120},{-340,120},{
                  -304,120},{-290,120},{-290,-20.8},{-261.5,-20.8}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,60},
                  {-300,60},{-300,-30.4},{-261.5,-30.4}},           color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68.8},{-261.5,-68.8}},             color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-120},
                  {-340,-120},{-290,-120},{-290,-59.2},{-261.5,-59.2}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-300,-60},{-300,-49.6},{-261.5,-49.6}},              color={
                  0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-340,0},{-310,0},{-310,-40},{-261.5,-40}},
                color={0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255}));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255}));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255}));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255}));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255}));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-140,-40},{-140,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_Q_eletHEAT, DCS.du_Q_eletHEAT) annotation (Line(points={{-340,-240},
                  {-304,-240},{-270,-240},{-270,-78.4},{-261.5,-78.4}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_60_DTsh;

        model Pilot_IO_50_DTsh
          "Model of the pilot for linearization at 100% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin              OTSG(
            RH(
              coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            PDSteamECO2(pin(start=9080000, fixed=false)),
            HPH(inletCold(m_flow(start=0.2))),
            ECO1(
              Shot=77.459*0.8/2,
              Scold=63.904*0.8/2,
              outletCold(m_flow(start=-2.4))),
            PDSteamECO1(pin(start=9100000, fixed=false)),
            ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
            separator(noInitialLevel=false, zl_start=2.5))
            annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lowLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            l_SEP_sp=3,
            Kp_pumpFW=1,
            CSmin_pumpFW=0.01,
            CSmax_pumpFW=3,
            load_start=50,
            Kp_pumpSEP=0.1,
            Ti_pumpSEP=100,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Ti_valveSUB=50,
            Td_valveSUB=0,
            Nd_valveSUB=20,
            CSmin_valveSUB=-1,
            CSmax_valveSUB=1,
            CSstart_valveSUB=0,
            actuatorGain_valveSUB=1,
            Ta_valveSUB=0.3,
            useTS_valveSUB=true,
            TS_valveSUB=0,
            DT_sh_COND_sp(displayUnit="K") = 10,
            DT_sc_sp(displayUnit="K") = 10,
            CSstart_pumpFW=1.37,
            CSmin_pumpSEP=-0.5,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=5,
            Ti_valveRH_DEA=140,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Ti_valveDEA_RH=0.3121,
            Kp_valveDEA_RH=-0.007726,
            CSmax_pumpSEP=1,
            Kp_valveSUB=-0.001,
            Kp_valveRH_DEA=1e-6,
            Kp_valveRH_COND=-2.9e-8,
            load_end=50,
            T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_50  WSC(
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,140},{-320,180}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,120},{-320,160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}),    iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,20},{-320,60}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-120},{-320,-80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-160},{-320,-120}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaSUB annotation (Placement(
                transformation(extent={{-360,-240},{-320,-200}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,170},
                    {340,190}}), iconTransformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,130},
                    {340,150}}), iconTransformation(extent={{320,130},{340,150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_SEP=OTSG.sep_lev annotation (
              Placement(transformation(extent={{320,90},{340,110}}),
                iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (
              Placement(transformation(extent={{320,50},{340,70}}), iconTransformation(
                  extent={{320,10},{340,30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,10},
                    {340,30}}), iconTransformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-30},
                    {340,-10}}), iconTransformation(extent={{320,-110},{340,-90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}}),        iconTransformation(extent={{320,-170},{340,-150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -110},{340,-90}}),  iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW=OTSG.sensT_FW.T annotation (
              Placement(transformation(extent={{320,-150},{340,-130}}),
                iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sc_EVA=OTSG.sensDT_sc.T annotation (
              Placement(transformation(extent={{320,-190},{340,-170}}),
                iconTransformation(extent={{320,-110},{340,-90}})));
        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,160},{-270,160},{
                  -270,-4},{-261.5,-4}},                color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,120},{-280,120},{-280,
                  -12},{-261.5,-12}},            color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,80},{-340,80},{-292,
                  80},{-290,80},{-290,58},{-290,-20},{-261.5,-20}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,40},
                  {-300,40},{-300,-28},{-261.5,-28}},               color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-140},{-290,-140},
                  {-290,-60},{-261.5,-60}},                 color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-100},
                  {-340,-100},{-300,-100},{-300,-52},{-261.5,-52}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-310,-60},{-310,-44},{-261.5,-44}},                  color={
                  0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
              thickness=0.5));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-160,-40},{-160,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-310,0},{-310,-36},{-261.5,-36}}, color={0,0,127}));
          connect(du_w_SEP, DCS.du_w_SEP) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68},{-261.5,-68}},     color={0,0,127}));
          connect(du_thetaSUB, DCS.du_thetaSUB) annotation (Line(points={{-340,-220},{-270,
                  -220},{-270,-76},{-261.5,-76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_50_DTsh;

        model Pilot_IO_40_DTsh
          "Model of the pilot for linearization at 40% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin              OTSG(
            RH(
              coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            PDSteamECO2(pin(start=9080000, fixed=false)),
            HPH(inletCold(m_flow(start=0.2))),
            ECO1(
              Shot=77.459*0.8/2,
              Scold=63.904*0.8/2,
              outletCold(m_flow(start=-2.4))),
            PDSteamECO1(pin(start=9100000, fixed=false)),
            ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
            separator(noInitialLevel=false, zl_start=2.5))
            annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lowLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            l_SEP_sp=3,
            Kp_pumpFW=1,
            CSmin_pumpFW=0.01,
            CSmax_pumpFW=3,
            load_start=50,
            Kp_pumpSEP=0.1,
            Ti_pumpSEP=100,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Ti_valveSUB=50,
            Td_valveSUB=0,
            Nd_valveSUB=20,
            CSmin_valveSUB=-1,
            CSmax_valveSUB=1,
            CSstart_valveSUB=0,
            actuatorGain_valveSUB=1,
            Ta_valveSUB=0.3,
            useTS_valveSUB=true,
            TS_valveSUB=0,
            DT_sh_COND_sp(displayUnit="K") = 10,
            DT_sc_sp(displayUnit="K") = 10,
            CSstart_pumpFW=1.37,
            CSmin_pumpSEP=-0.5,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=5,
            Ti_valveRH_DEA=140,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Ti_valveDEA_RH=0.3121,
            Kp_valveDEA_RH=-0.007726,
            CSmax_pumpSEP=1,
            Kp_valveSUB=-0.001,
            Kp_valveRH_DEA=1e-6,
            Kp_valveRH_COND=-2.9e-8,
            load_end=40,
            T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_50  WSC(
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,140},{-320,180}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,120},{-320,160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}),    iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,20},{-320,60}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-120},{-320,-80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-160},{-320,-120}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaSUB annotation (Placement(
                transformation(extent={{-360,-240},{-320,-200}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,170},
                    {340,190}}), iconTransformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,130},
                    {340,150}}), iconTransformation(extent={{320,130},{340,150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_SEP=OTSG.sep_lev annotation (
              Placement(transformation(extent={{320,90},{340,110}}),
                iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (
              Placement(transformation(extent={{320,50},{340,70}}), iconTransformation(
                  extent={{320,10},{340,30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,10},
                    {340,30}}), iconTransformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-30},
                    {340,-10}}), iconTransformation(extent={{320,-110},{340,-90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}}),        iconTransformation(extent={{320,-170},{340,-150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -110},{340,-90}}),  iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW=OTSG.sensT_FW.T annotation (
              Placement(transformation(extent={{320,-150},{340,-130}}),
                iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sc_EVA=OTSG.sensDT_sc.T annotation (
              Placement(transformation(extent={{320,-190},{340,-170}}),
                iconTransformation(extent={{320,-110},{340,-90}})));
        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,160},{-270,160},{
                  -270,-4},{-261.5,-4}},                color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,120},{-280,120},{-280,
                  -12},{-261.5,-12}},            color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,80},{-340,80},{-292,
                  80},{-290,80},{-290,58},{-290,-20},{-261.5,-20}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,40},
                  {-300,40},{-300,-28},{-261.5,-28}},               color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-140},{-290,-140},
                  {-290,-60},{-261.5,-60}},                 color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-100},
                  {-340,-100},{-300,-100},{-300,-52},{-261.5,-52}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-310,-60},{-310,-44},{-261.5,-44}},                  color={
                  0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
              thickness=0.5));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-160,-40},{-160,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-310,0},{-310,-36},{-261.5,-36}}, color={0,0,127}));
          connect(du_w_SEP, DCS.du_w_SEP) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68},{-261.5,-68}},     color={0,0,127}));
          connect(du_thetaSUB, DCS.du_thetaSUB) annotation (Line(points={{-340,-220},{-270,
                  -220},{-270,-76},{-261.5,-76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_40_DTsh;

        model Pilot_IO_30_DTsh
          "Model of the pilot for linearization at 30% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin              OTSG(
            RH(
              coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            PDSteamECO2(pin(start=9080000, fixed=false)),
            HPH(inletCold(m_flow(start=0.2))),
            ECO1(
              Shot=77.459*0.8/2,
              Scold=63.904*0.8/2,
              outletCold(m_flow(start=-2.4))),
            PDSteamECO1(pin(start=9100000, fixed=false)),
            ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
            separator(noInitialLevel=false, zl_start=2.5))
            annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lowLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            l_SEP_sp=3,
            Kp_pumpFW=1,
            CSmin_pumpFW=0.01,
            CSmax_pumpFW=3,
            load_start=50,
            Kp_pumpSEP=0.1,
            Ti_pumpSEP=100,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Ti_valveSUB=50,
            Td_valveSUB=0,
            Nd_valveSUB=20,
            CSmin_valveSUB=-1,
            CSmax_valveSUB=1,
            CSstart_valveSUB=0,
            actuatorGain_valveSUB=1,
            Ta_valveSUB=0.3,
            useTS_valveSUB=true,
            TS_valveSUB=0,
            DT_sh_COND_sp(displayUnit="K") = 10,
            DT_sc_sp(displayUnit="K") = 10,
            CSstart_pumpFW=1.37,
            CSmin_pumpSEP=-0.5,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=5,
            Ti_valveRH_DEA=140,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Ti_valveDEA_RH=0.3121,
            Kp_valveDEA_RH=-0.007726,
            CSmax_pumpSEP=1,
            Kp_valveSUB=-0.001,
            Kp_valveRH_DEA=1e-6,
            Kp_valveRH_COND=-2.9e-8,
            load_end=30,
            T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_50  WSC(
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,140},{-320,180}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,120},{-320,160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}),    iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,20},{-320,60}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-120},{-320,-80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-160},{-320,-120}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaSUB annotation (Placement(
                transformation(extent={{-360,-240},{-320,-200}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,170},
                    {340,190}}), iconTransformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,130},
                    {340,150}}), iconTransformation(extent={{320,130},{340,150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_SEP=OTSG.sep_lev annotation (
              Placement(transformation(extent={{320,90},{340,110}}),
                iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (
              Placement(transformation(extent={{320,50},{340,70}}), iconTransformation(
                  extent={{320,10},{340,30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,10},
                    {340,30}}), iconTransformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-30},
                    {340,-10}}), iconTransformation(extent={{320,-110},{340,-90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}}),        iconTransformation(extent={{320,-170},{340,-150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -110},{340,-90}}),  iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW=OTSG.sensT_FW.T annotation (
              Placement(transformation(extent={{320,-150},{340,-130}}),
                iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sc_EVA=OTSG.sensDT_sc.T annotation (
              Placement(transformation(extent={{320,-190},{340,-170}}),
                iconTransformation(extent={{320,-110},{340,-90}})));
        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,160},{-270,160},{
                  -270,-4},{-261.5,-4}},                color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,120},{-280,120},{-280,
                  -12},{-261.5,-12}},            color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,80},{-340,80},{-292,
                  80},{-290,80},{-290,58},{-290,-20},{-261.5,-20}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,40},
                  {-300,40},{-300,-28},{-261.5,-28}},               color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-140},{-290,-140},
                  {-290,-60},{-261.5,-60}},                 color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-100},
                  {-340,-100},{-300,-100},{-300,-52},{-261.5,-52}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-310,-60},{-310,-44},{-261.5,-44}},                  color={
                  0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
              thickness=0.5));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-160,-40},{-160,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-310,0},{-310,-36},{-261.5,-36}}, color={0,0,127}));
          connect(du_w_SEP, DCS.du_w_SEP) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68},{-261.5,-68}},     color={0,0,127}));
          connect(du_thetaSUB, DCS.du_thetaSUB) annotation (Line(points={{-340,-220},{-270,
                  -220},{-270,-76},{-261.5,-76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_30_DTsh;

        model Pilot_IO_20_DTsh
          "Model of the pilot for linearization at 20% load"

          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.fixedState)
            annotation (Placement(transformation(extent={{-260,220},{-240,240}})));
          ThermoPower.Water.SourcePressure sourceMS(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            h=518322) annotation (Placement(transformation(extent={{-118,150},{
                    -98,170}})));
          ThermoPower.Water.SinkPressure sinkMS3(
            allowFlowReversal=false,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad,
            p0=261078) annotation (Placement(transformation(extent={{-100,-190},
                    {-120,-170}})));
          HeatExchangers.OTSG.OTSG_init50_5nodes_lin              OTSG(
            RH(
              coldFluid(w(start=2, fixed=false), noInitialPressure=true),
              Vhot=0.425*0.54,
              Vcold=0.106*0.54,
              Shot=27.935*0.54,
              Scold=24.995*0.54,
              Mm=210.313*0.54),
            SH(Shot=22.8*0.95, Scold=17.385*0.95),
            EVA2(Shot=9.971*0.8, Scold=7.616*0.8),
            EVA1(Shot=67.796*0.8, Scold=53.152*0.8),
            PDSteamECO2(pin(start=9080000, fixed=false)),
            HPH(inletCold(m_flow(start=0.2))),
            ECO1(
              Shot=77.459*0.8/2,
              Scold=63.904*0.8/2,
              outletCold(m_flow(start=-2.4))),
            PDSteamECO1(pin(start=9100000, fixed=false)),
            ECO2(Shot=77.459*0.8/2, Scold=63.904*0.8/2),
            separator(noInitialLevel=false, zl_start=2.5))
            annotation (Placement(transformation(extent={{-120,-154},{20,74}})));
          Schemes.LinearizationSchemes.plant_controller_HPpart_lowLoad_lin DCS(
            actuatorGain_pumpHPH=1,
            actuatorGain_pumpFW=1,
            actuatorGain_pumpMS=1,
            TS_pumpFW=0,
            CSmin_pumpMS=-0.9,
            CSmax_pumpMS=1,
            CSstart_pumpMS=0,
            TS_pumpMS=0,
            Nd_pumpFW=30,
            Kp_pumpMS=1.2e-7,
            Ti_pumpMS=114.3,
            Td_pumpMS=28.57,
            Nd_pumpMS=20,
            useTS_pumpMS=true,
            Td_pumpFW=0,
            Ta_pumpFW=2,
            Ta_pumpHPH=2,
            Ta_pumpMS=2,
            Ti_pumpFW=50,
            Td_valveSH_RH=0,
            Nd_valveSH_RH=30,
            CSmin_valveSH_RH=-1,
            CSmax_valveSH_RH=1,
            CSstart_valveSH_RH=0,
            actuatorGain_valveSH_RH=1,
            Ta_valveSH_RH=0.3,
            TS_valveSH_RH=0,
            Td_valveRH_DEA=0,
            Nd_valveRH_DEA=30,
            CSmin_valveRH_DEA=-1,
            CSmax_valveRH_DEA=1,
            CSstart_valveRH_DEA=0,
            actuatorGain_valveRH_DEA=1,
            Ta_valveRH_DEA=0.3,
            TS_valveRH_DEA=0,
            Td_valveRH_COND=0,
            Nd_valveRH_COND=30,
            CSmin_valveRH_COND=-1,
            CSmax_valveRH_COND=1,
            CSstart_valveRH_COND=0,
            actuatorGain_valveRH_COND=1,
            Ta_valveRH_COND=0.3,
            TS_valveRH_COND=0,
            Td_pumpCOND=0,
            Nd_pumpCOND=30,
            CSmin_pumpCOND=0,
            CSmax_pumpCOND=5,
            actuatorGain_pumpCOND=1,
            Ta_pumpCOND=2,
            TS_pumpCOND=0,
            Td_valveDEA_SH=0,
            Nd_valveDEA_SH=30,
            CSmin_valveDEA_SH=-1,
            CSmax_valveDEA_SH=1,
            CSstart_valveDEA_SH=0,
            actuatorGain_valveDEA_SH=1,
            Ta_valveDEA_SH=0.3,
            TS_valveDEA_SH=0,
            Td_valveDEA_RH=0,
            Nd_valveDEA_RH=30,
            CSmin_valveDEA_RH=-1,
            CSmax_valveDEA_RH=1,
            CSstart_valveDEA_RH=0,
            actuatorGain_valveDEA_RH=1,
            Ta_valveDEA_RH=0.3,
            TS_valveDEA_RH=0,
            CSstart_pumpCOND=2.6,
            l_dea_sp=0.45,
            TS_start=false,
            useTS_valveSH_RH=true,
            useTS_pumpFW=true,
            useTS_valveRH_DEA=true,
            useTS_valveRH_COND=true,
            useTS_pumpCOND=true,
            useTS_valveDEA_SH=true,
            useTS_valveDEA_RH=true,
            l_SEP_sp=3,
            Kp_pumpFW=1,
            CSmin_pumpFW=0.01,
            CSmax_pumpFW=3,
            load_start=50,
            Kp_pumpSEP=0.1,
            Ti_pumpSEP=100,
            Td_pumpSEP=0,
            Nd_pumpSEP=30,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            useTS_pumpSEP=true,
            TS_pumpSEP=0,
            t_ramp=100000,
            t_start_ramp=10000,
            t_start_ramp_TS=150000,
            Ti_valveSUB=50,
            Td_valveSUB=0,
            Nd_valveSUB=20,
            CSmin_valveSUB=-1,
            CSmax_valveSUB=1,
            CSstart_valveSUB=0,
            actuatorGain_valveSUB=1,
            Ta_valveSUB=0.3,
            useTS_valveSUB=true,
            TS_valveSUB=0,
            DT_sh_COND_sp(displayUnit="K") = 10,
            DT_sc_sp(displayUnit="K") = 10,
            CSstart_pumpFW=1.37,
            CSmin_pumpSEP=-0.5,
            Kp_valveSH_RH=-1.241e-13,
            Ti_valveSH_RH=5,
            Ti_valveRH_DEA=140,
            Ti_valveRH_COND=0.5283,
            Kp_pumpCOND=180,
            Ti_pumpCOND=380.9,
            Kp_valveDEA_SH=-0.1134,
            Ti_valveDEA_SH=285.7,
            Ti_valveDEA_RH=0.3121,
            Kp_valveDEA_RH=-0.007726,
            CSmax_pumpSEP=1,
            Kp_valveSUB=-0.001,
            Kp_valveRH_DEA=1e-6,
            Kp_valveRH_COND=-2.9e-8,
            load_end=20,
            T_FW_sp=558.15) annotation (Placement(transformation(extent={{-260,
                    -80},{-200,0}})));

          HeatExchangers.WSC.WSC_50  WSC(
            deaerator(w_small=1e4))      annotation (Placement(transformation(
                  extent={{80,-108},{300,160}})));
          ComponentEmulator.turbineEmulator turbineEmulator(
            eta_iso_HPT=0.865,
            eta_iso_IPT=0.895,
            a=-0.05741,
            b=0.0612)
            annotation (Placement(transformation(extent={{-188,24},{-220,56}})));
          Modelica.Blocks.Sources.RealExpression w_in_IPT(y=WSC.valveRH_COND.w)
            annotation (Placement(transformation(extent={{-246,94},{-226,114}})));
          Modelica.Blocks.Sources.RealExpression h_in_IPT(y=OTSG.RH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-246,80},{
                    -226,100}})));
          Modelica.Blocks.Sources.RealExpression p_in_IPT(y=WSC.valveRH_COND.p)
            annotation (Placement(transformation(extent={{-246,66},{-226,86}})));
          Modelica.Blocks.Sources.RealExpression load(y=DCS.LOAD3.y)
            annotation (Placement(transformation(extent={{-246,52},{-226,72}})));
          Modelica.Blocks.Sources.RealExpression w_in_HPT(y=WSC.valveSH_RH.w)
            annotation (Placement(transformation(extent={{-148,50},{-168,70}})));
          Modelica.Blocks.Sources.RealExpression h_in_HPT(y=OTSG.SH.coldFluid.h[
                end]) annotation (Placement(transformation(extent={{-148,36},{
                    -168,56}})));
          Modelica.Blocks.Sources.RealExpression p_in_HPT(y=WSC.valveSH_RH.p)
            annotation (Placement(transformation(extent={{-148,22},{-168,42}})));
          Modelica.Blocks.Sources.RealExpression p_out_HPT(y=WSC.DEA_SH.p)
            annotation (Placement(transformation(extent={{-148,8},{-168,28}})));

          Modelica.Blocks.Interfaces.RealInput du_w_MS annotation (Placement(
                transformation(extent={{-360,140},{-320,180}}),iconTransformation(
                  extent={{-360,180},{-320,220}})));
          Modelica.Blocks.Interfaces.RealInput du_Y_t annotation (Placement(
                transformation(extent={{-360,100},{-320,140}}),
                iconTransformation(extent={{-360,120},{-320,160}})));
          Modelica.Blocks.Interfaces.RealInput du_w_FW annotation (Placement(
                transformation(extent={{-360,60},{-320,100}}),    iconTransformation(
                  extent={{-360,60},{-320,100}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_DEA annotation (
              Placement(transformation(extent={{-360,20},{-320,60}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_SH annotation (
              Placement(transformation(extent={{-360,-20},{-320,20}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaDEA_RH annotation (
              Placement(transformation(extent={{-360,-80},{-320,-40}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaRH_COND annotation (
              Placement(transformation(extent={{-360,-120},{-320,-80}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_COND annotation (Placement(
                transformation(extent={{-360,-160},{-320,-120}}),
                iconTransformation(extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_w_SEP annotation (Placement(
                transformation(extent={{-360,-200},{-320,-160}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealInput du_thetaSUB annotation (Placement(
                transformation(extent={{-360,-240},{-320,-200}}), iconTransformation(
                  extent={{-360,-220},{-320,-180}})));
          Modelica.Blocks.Interfaces.RealOutput y_P_mec = turbineEmulator.P_mec annotation (Placement(transformation(extent={{320,170},
                    {340,190}}), iconTransformation(extent={{320,190},{340,210}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_eva = OTSG.SH.coldFluid.p annotation (Placement(transformation(extent={{320,130},
                    {340,150}}), iconTransformation(extent={{320,130},{340,150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_SEP=OTSG.sep_lev annotation (
              Placement(transformation(extent={{320,90},{340,110}}),
                iconTransformation(extent={{320,-210},{340,-190}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_DEA=WSC.deaerator.p annotation (
              Placement(transformation(extent={{320,50},{340,70}}), iconTransformation(
                  extent={{320,10},{340,30}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_MSout_RH=OTSG.sensT_MS_RHout.T  annotation (Placement(transformation(extent={{320,10},
                    {340,30}}), iconTransformation(extent={{320,-50},{340,-30}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sh_COND=WSC.add.y  annotation (Placement(transformation(extent={{320,-30},
                    {340,-10}}), iconTransformation(extent={{320,-110},{340,-90}})));
          Modelica.Blocks.Interfaces.RealOutput y_p_RH=OTSG.RH.coldFluid.p  annotation (Placement(transformation(extent={{320,-70},
                    {340,-50}}),        iconTransformation(extent={{320,-170},{340,-150}})));
          Modelica.Blocks.Interfaces.RealOutput y_l_DEA=WSC.deaerator.zl  annotation (Placement(transformation(extent={{320,
                    -110},{340,-90}}),  iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_T_FW=OTSG.sensT_FW.T annotation (
              Placement(transformation(extent={{320,-150},{340,-130}}),
                iconTransformation(extent={{320,-230},{340,-210}})));
          Modelica.Blocks.Interfaces.RealOutput y_DT_sc_EVA=OTSG.sensDT_sc.T annotation (
              Placement(transformation(extent={{320,-190},{340,-170}}),
                iconTransformation(extent={{320,-110},{340,-90}})));
        equation
          connect(sinkMS3.flange, OTSG.MS_out) annotation (Line(
              points={{-100,-180},{-88.8889,-180},{-88.8889,-157.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));
          connect(sourceMS.flange, OTSG.MS_in) annotation (Line(
              points={{-98,160},{-88.8889,160},{-88.8889,77.8}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5));

          connect(du_w_MS, DCS.du_w_MS) annotation (Line(points={{-340,160},{-270,160},{
                  -270,-4},{-261.5,-4}},                color={0,0,127}));
          connect(du_Y_t, DCS.du_Y_t) annotation (Line(points={{-340,120},{-280,120},{-280,
                  -12},{-261.5,-12}},            color={0,0,127}));
          connect(du_w_FW, DCS.du_w_FW) annotation (Line(points={{-340,80},{-340,80},{-292,
                  80},{-290,80},{-290,58},{-290,-20},{-261.5,-20}},
                color={0,0,127}));
          connect(DCS.signalBus, OTSG.signalBus) annotation (Line(
              points={{-198.5,-40},{-125.444,-40}},
              color={255,204,51},
              thickness=0.5));

          connect(du_thetaRH_DEA, DCS.du_thetaRH_DEA) annotation (Line(points={{-340,40},
                  {-300,40},{-300,-28},{-261.5,-28}},               color={0,0,
                  127}));
          connect(du_w_COND, DCS.du_w_cond) annotation (Line(points={{-340,-140},{-290,-140},
                  {-290,-60},{-261.5,-60}},                 color={0,0,127}));
          connect(du_thetaRH_COND, DCS.du_thetaRH_COND) annotation (Line(points={{-340,-100},
                  {-340,-100},{-300,-100},{-300,-52},{-261.5,-52}},
                color={0,0,127}));
          connect(du_thetaDEA_RH, DCS.du_thetaDEA_RH) annotation (Line(points={{-340,-60},
                  {-310,-60},{-310,-44},{-261.5,-44}},                  color={
                  0,0,127}));
          connect(OTSG.RH_in, WSC.SH_out) annotation (Line(points={{23.8889,
                  43.6},{47.9445,43.6},{47.9445,43.8667},{75.4167,43.8667}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.SEP_out, WSC.SEP_in) annotation (Line(points={{23.8889,
                  -70.4},{49.9445,-70.4},{49.9445,-70.48},{75.4167,-70.48}},
                color={0,0,255},
              thickness=0.5));
          connect(OTSG.FW_in, WSC.FW_out) annotation (Line(points={{23.8889,
                  -127.4},{185.417,-127.4},{185.417,-112.467}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.SH_out, WSC.SH_in) annotation (Line(points={{-11.1111,
                  77.8},{-11.1111,88.5333},{75.4167,88.5333}}, color={0,0,255},
              thickness=0.5));
          connect(OTSG.RH_out, WSC.RH_in) annotation (Line(points={{-42.2222,
                  77.8},{-42.2222,133.2},{75.4167,133.2}}, color={0,0,255},
              thickness=0.5));
          connect(DCS.signalBus, WSC.signalBus) annotation (Line(
              points={{-198.5,-40},{-160,-40},{-160,-220},{254.167,-220},{
                  254.167,-112.467}},
              color={255,204,51},
              thickness=0.5));
          connect(load.y, turbineEmulator.load) annotation (Line(points={{-225,
                  62},{-216.8,62},{-216.8,57.6}}, color={0,0,127}));
          connect(p_in_IPT.y, turbineEmulator.p_in_IPT) annotation (Line(points=
                 {{-225,76},{-208.8,76},{-208.8,57.6}}, color={0,0,127}));
          connect(h_in_IPT.y, turbineEmulator.h_in_IPT) annotation (Line(points=
                 {{-225,90},{-216,90},{-199.2,90},{-199.2,57.6}}, color={0,0,
                  127}));
          connect(w_in_IPT.y, turbineEmulator.w_in_IPT) annotation (Line(points=
                 {{-225,104},{-191.2,104},{-191.2,57.6}}, color={0,0,127}));
          connect(w_in_HPT.y, turbineEmulator.w_in_HPT) annotation (Line(points=
                 {{-169,60},{-176,60},{-176,52.8},{-186.4,52.8}}, color={0,0,
                  127}));
          connect(turbineEmulator.h_in_HPT, h_in_HPT.y) annotation (Line(points=
                 {{-186.4,44.8},{-176,44.8},{-176,46},{-169,46}}, color={0,0,
                  127}));
          connect(turbineEmulator.p_in_HPT, p_in_HPT.y) annotation (Line(points=
                 {{-186.4,35.2},{-176,35.2},{-176,32},{-169,32}}, color={0,0,
                  127}));
          connect(p_out_HPT.y, turbineEmulator.p_out_HPT) annotation (Line(
                points={{-169,18},{-176,18},{-176,27.2},{-186.4,27.2}}, color={
                  0,0,127}));
          connect(turbineEmulator.P_mec, DCS.u_Pmec) annotation (Line(points={{
                  -221.6,40},{-230,40},{-230,1.6}}, color={0,0,127}));
          connect(du_thetaDEA_SH, DCS.du_thetaDEA_SH) annotation (Line(points={{-340,0},
                  {-310,0},{-310,-36},{-261.5,-36}}, color={0,0,127}));
          connect(du_w_SEP, DCS.du_w_SEP) annotation (Line(points={{-340,-180},{-280,-180},
                  {-280,-68},{-261.5,-68}},     color={0,0,127}));
          connect(du_thetaSUB, DCS.du_thetaSUB) annotation (Line(points={{-340,-220},{-270,
                  -220},{-270,-76},{-261.5,-76}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(extent={{-320,-240},{320,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-320,
                    -240},{320,240}}, preserveAspectRatio=false)),
            experiment(StopTime=160000, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>This model is used to evaluate the linear model of the high pressure part of the molten salt power plant at 100&percnt; load. The model is initialised with the control loops closed (false attribute on TS_start), in order to bring the system to the nominal operational point. At 5000 s the control loops are opened, so that the system involves only the process to be linearised. </p>
</html>"));
        end Pilot_IO_20_DTsh;
      end Linearization;

      package Test "Package containing control tests"
        model test_dryWetTransition
          "Test model to check the control switch between dry and wet mode of the separator"

          HeatExchangers.Components.HE ECO(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Shot=2394.2,
            Scold=1855.5,
            Mm=30395,
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.728761, gamma_nom=4400),
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.461561, gamma_nom=2200),
            Vhot=45.011,
            Vcold=5.752,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.23186e+006,1.44947e+006,1.55292e+006,1.61733e+006,
                  1.66591e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {582.675,605.885,616.62,
                623.137}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={199579,192529,183185,168175,136603},
              noInitialPressure=true),
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=5,
            nominalColdPressure=17910000,
            nominalHotPressure=569600,
            nominalColdInletTemperature=553.15,
            nominalColdOutletTemperature=623.79,
            nominalHotInletTemperature=628.75,
            nominalHotOutletTemperature=586.72) annotation (Placement(
                transformation(extent={{-134,-180},{-166,-148}})));

          HeatExchangers.Components.HE_2ph EVA1(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            Mm=43100,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (gamma_nom=2300, alpha=0.447498),
            nominalColdFlow=88.59,
            Vhot=26.587,
            Vcold=8.651,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={1.66561e+006,1.67917e+006,1.69246e+006,1.70577e+006,
                  1.7194e+006,1.74575e+006,1.79332e+006,1.87797e+006,
                  2.02847e+006,2.29575e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {626.054,627.39,628.669,
                629.917,629.888,630.182,630.842,632.016,634.097}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={289063,250302,228476,216201,209301,205481,203503,201573,
                  199646,197679},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=3875,
                gamma_nom_vap=3875,
                gamma_nom_2ph=10000,
                alpha=1.6),
            Shot=2251.9,
            Scold=1765.5,
            nominalColdPressure=17810000,
            nominalColdInletTemperature=623.75,
            nominalColdOutletTemperature=629.32,
            nominalHotInletTemperature=688.04,
            nominalHotOutletTemperature=629.15,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalHotPressure=730800) annotation (Placement(transformation(
                  extent={{-166,-100},{-134,-68}})));

          HeatExchangers.Components.HE_2ph EVA2(
            redeclare model HeatExchangerTopology =
                ThermoPower.Thermal.HeatExchangerTopologies.CounterCurrentFlow,
            cm=500,
            nominalColdDeltaP=0,
            nominalHotDeltaP=0,
            nominalHotFlow=610.6,
            nominalColdFlow=88.59,
            Mm=5182,
            redeclare model HeatTransferHot =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient
                (alpha=0.389637, gamma_nom=2650),
            Vhot=3.905,
            Vcold=1.065,
            coldFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              Nt=1,
              hstart={2.2799e+006,2.32986e+006,2.38391e+006,2.4424e+006,
                  2.50567e+006,2.55859e+006,2.60531e+006,2.65251e+006,
                  2.69972e+006,2.74645e+006}),
            tubeWalls(Tvolstart(displayUnit="K") = {650.941,652.73,654.665,
                656.757,670.379,679.959,684.074,688.573,693.427}),
            hotFluid(
              FFtype=ThermoPower.Choices.Flow1D.FFtypes.NoFriction,
              hstart={355877,349098,342248,335400,328621,320944,311763,303278,
                  295435,288187},
              noInitialPressure=true),
            redeclare model HeatTransferCold =
                ThermoPower.Thermal.HeatTransferFV.FlowDependentHeatTransferCoefficient2ph
                (
                wnom_ht=88.59,
                gamma_nom_liq=2000,
                gamma_nom_2ph=5000,
                gamma_nom_vap=2000,
                alpha=1.1),
            Shot=429.2,
            Scold=338,
            nominalColdPressure=17760000,
            nominalColdInletTemperature=629.15,
            nominalColdOutletTemperature=648.65,
            nominalHotInletTemperature=732.05,
            nominalHotOutletTemperature=687.95,
            redeclare package coldMedium = Modelica.Media.Water.WaterIF97_ph,
            redeclare package hotMedium = PreFlexMS.Media.MoltenSalt60_40_quad,
            Nhex=10,
            nominalHotPressure=730800) annotation (Placement(transformation(
                  extent={{-134,-20},{-166,12}})));

          HeatExchangers.Components.Equilibrium2phVessel separator(
            zl_start=0,
            D=0.56,
            noInitialPressure=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h_start=4e6,
            H=9,
            p_start=17710000)
            annotation (Placement(transformation(extent={{-8,118},{48,174}})));
          ThermoPower.Water.ThroughMassFlow waterPump(
            allowFlowReversal=false,
            use_in_w0=true,
            w0=10,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={20,76})));

          ThermoPower.Water.PressDrop PDSteamEVA1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            dpnom=(0.05828)*10^5,
            wnom=88.59,
            rhonom=168.8,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-44})));
          ThermoPower.Water.PressDrop PDSteamECO2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            rhonom=582.8,
            dpnom=(0.52492/2)*10^5,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                    annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-124})));
          ThermoPower.Water.PressDrop PDSteamEVA2(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.11171)*10^5,
            rhonom=97,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                 annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-120,138})));
          //Overall parameter and variables:
          Modelica.SIunits.Power Q_tot = ECO.Q_Hot + EVA1.Q_Hot + EVA2.Q_Hot;
          Modelica.SIunits.Temperature T_inFW = ECO.coldFluid.T[1];
          Modelica.SIunits.Temperature T_outMS = ECO.hotFluid.T[end];
          Modelica.SIunits.Length sep_lev = separator.zl;
          Modelica.SIunits.Temperature DT_sh = max(0,EVA2.coldFluid.T[end] - EVA2.coldFluid.Ts) + 273.15;
          Modelica.SIunits.Temperature DT_sc = max(0,EVA1.coldFluid.Ts - EVA1.coldFluid.T[1]) + 273.15;
          Real x_EVA1_out = EVA1.coldFluid.x[end];
          Real x_EVA2_out = EVA2.coldFluid.x[end];
          Real load = EVA2.hotFluid.w/EVA2.nominalHotFlow*100;

          ThermoPower.Water.SensT sensT_FW(redeclare package Medium =
                Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{-80,-228},{-100,-208}})));
          ThermoPower.Water.SensT sensT_MS(redeclare package Medium =
                PreFlexMS.Media.MoltenSalt60_40_quad) annotation (Placement(
                transformation(extent={{-180,-158},{-200,-178}})));
          ThermoPower.Water.PressDrop PDSteamECO1(
            FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
            wnom=88.59,
            dpnom=(0.52492/2)*10^5,
            rhonom=767.7,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                                           annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-150,-198})));
          ThermoPower.Water.SourceMassFlow sourceMS5(
            allowFlowReversal=false,
            G=0,
            w0=610.6,
            h=355877,
            p0=730800,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-90,-14},{-110,6}})));
          ThermoPower.Water.SinkPressure sinkSteam5(
            allowFlowReversal=false,
            use_in_p0=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            p0=17748830)
            annotation (Placement(transformation(extent={{26,180},{46,200}})));
          ThermoPower.Water.SinkPressure sinkMS2(
            allowFlowReversal=false,
            p0=404671,
            redeclare package Medium = PreFlexMS.Media.MoltenSalt60_40_quad)
            annotation (Placement(transformation(extent={{-210,-174},{-230,-154}})));
          ThermoPower.Water.SourceMassFlow sourceSteam2(
            allowFlowReversal=false,
            h=1231860,
            w0=88.59,
            p0=17910000,
            use_in_w0=true,
            use_in_h=true,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
            annotation (Placement(transformation(extent={{86,-232},{66,-212}})));
          Modelica.Blocks.Tables.CombiTable1D P_sink_separator(
            tableOnFile=false,
            table=[20,100.1e5; 30,100.3e5; 40,100.6e5; 50,101e5; 60,112.7e5; 70,129.3e5;
                80,145.7e5; 90,162e5; 100,177.1e5],
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
            annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={10,230})));
          Modelica.Blocks.Tables.CombiTable1D H_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,356.5e3; 30,351.2e3; 40,347.3e3; 50,344.1e3; 60,357.8e3; 70,373.4e3;
                80,374.4e3; 90,382.9e3; 100,356.849e3]) annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,70})));
          Modelica.Blocks.Tables.CombiTable1D W_source_EVA2(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,122.1; 30,183.2; 40,244.2; 50,305.3; 60,366.3; 70,427.4; 80,488.4;
                90,549.4; 100,610.6]) annotation (Placement(transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-70,30})));
          Modelica.Blocks.Tables.CombiTable1D H_source_FW(
            tableOnFile=false,
            smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
            table=[20,840.6e3; 30,933.8e3; 40,1004.5e3; 50,1062.5e3; 60,1111.4e3; 70,1126.7e3;
                80,1133.9e3; 90,1182.5e3; 100,1231.9e3]) annotation (Placement(
                transformation(
                extent={{-10,-10},{10,10}},
                rotation=0,
                origin={50,-182})));
          Modelica.Blocks.Sources.Trapezoid LOAD(
            amplitude=-20,
            rising=100,
            width=500,
            falling=100,
            period=5000,
            nperiod=1,
            offset=70,
            startTime=0)
            annotation (Placement(transformation(extent={{-76,-56},{-44,-24}})));
          Schemes_old.SingleControllers.control_w_SEP control_wFW_w_SEP(
            Ti_pumpFW_high=100,
            Td_pumpFW_high=0,
            Nd_pumpFW_high=20,
            CSmax_pumpFW_high=0.2,
            CSstart_pumpFW_high=0,
            TS_pumpFW_high=0,
            l_sp=4,
            Td_pumpFW_low=0,
            Nd_pumpFW_low=20,
            CSmin_pumpFW_low=1,
            CSmax_pumpFW_low=100,
            CSstart_pumpFW_low=60,
            TS_pumpFW_low=0,
            load_switch_FW=55,
            load_sep_ON=55,
            actuatorGain_pumpFW=1,
            Ta_pumpFW=2,
            Td_pumpSEP=0,
            Nd_pumpSEP=20,
            CSmin_pumpSEP=-0.9,
            CSmax_pumpSEP=0.15,
            CSstart_pumpSEP=0,
            actuatorGain_pumpSEP=1,
            Ta_pumpSEP=2,
            TS_pumpSEP=0,
            DT_sh_sp=20,
            Kp_pumpSEP=1,
            Ti_pumpSEP=50,
            Ti_pumpFW_low=50,
            Kp_pumpFW_low=12,
            CSmin_pumpFW_high=-0.95,
            level_sep_ON=3,
            T_MS_sp=558.15,
            Kp_pumpFW_high=-0.01)
            annotation (Placement(transformation(extent={{200,-80},{94,0}})));
          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={238,-40})));
          inner ThermoPower.System system
            annotation (Placement(transformation(extent={{-260,240},{-240,260}})));
          Modelica.Blocks.Sources.BooleanConstant TS_sep(k=true)
            annotation (Placement(transformation(extent={{60,-22},{80,-2}})));
          Modelica.Blocks.Sources.BooleanConstant TS_DTsh(k=false)
            annotation (Placement(transformation(extent={{60,-78},{80,-58}})));
        equation
          connect(ECO.outletCold, PDSteamECO2.inlet) annotation (Line(
              points={{-150,-148},{-150,-134}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(separator.drained_out, waterPump.inlet) annotation (Line(
              points={{20,128},{20,86}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(PDSteamEVA2.outlet, separator.water_in) annotation (Line(
              points={{-110,138},{10,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(PDSteamEVA1.outlet, EVA2.inletCold) annotation (Line(
              points={{-150,-34},{-150,-20}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletCold, PDSteamEVA1.inlet) annotation (Line(
              points={{-150,-68},{-150,-54}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletCold, PDSteamEVA2.inlet) annotation (Line(
              points={{-150,12},{-150,138},{-130,138}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA2.outletHot, EVA1.inletHot) annotation (Line(
              points={{-166,-4},{-190,-4},{-190,-84},{-166,-84}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));
          connect(EVA1.outletHot, ECO.inletHot) annotation (Line(
              points={{-134,-84},{-110,-84},{-110,-164},{-134,-164}},
              color={255,0,0},
              smooth=Smooth.None,
              thickness=0.5,
              arrow={Arrow.None,Arrow.Filled}));

          connect(EVA1.inletCold, PDSteamECO2.outlet) annotation (Line(
              points={{-150,-100},{-150,-114}},
              color={0,0,255},
              thickness=0.5));
          connect(ECO.inletCold, PDSteamECO1.outlet) annotation (Line(
              points={{-150,-180},{-150,-188}},
              color={0,0,255},
              thickness=0.5));
          connect(sensT_FW.outlet, PDSteamECO1.inlet) annotation (Line(
              points={{-96,-222},{-96,-222},{-150,-222},{-150,-208}},
              color={0,0,255},
              thickness=0.5));
          connect(sinkSteam5.flange, separator.steam_out) annotation (Line(
              points={{26,190},{20,190},{20,170}},
              color={0,0,255},
              thickness=0.5));
          connect(H_source_EVA2.y[1], sourceMS5.in_h) annotation (Line(points={{-81,70},
                  {-81,70},{-104,70},{-104,2}}, color={0,0,127}));
          connect(W_source_EVA2.y[1], sourceMS5.in_w0)
            annotation (Line(points={{-81,30},{-96,30},{-96,2}}, color={0,0,127}));
          connect(sinkMS2.flange, sensT_MS.outlet) annotation (Line(
              points={{-210,-164},{-204,-164},{-196,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(sensT_MS.inlet, ECO.outletHot) annotation (Line(
              points={{-184,-164},{-184,-164},{-166,-164}},
              color={255,0,0},
              thickness=0.5));
          connect(H_source_FW.y[1], sourceSteam2.in_h)
            annotation (Line(points={{61,-182},{72,-182},{72,-216}}, color={0,0,127}));
          connect(sensT_FW.inlet, sourceSteam2.flange) annotation (Line(
              points={{-84,-222},{-84,-222},{66,-222}},
              color={0,0,255},
              thickness=0.5));
          connect(EVA2.inletHot, sourceMS5.flange) annotation (Line(
              points={{-134,-4},{-110,-4}},
              color={255,0,0},
              thickness=0.5));
          connect(LOAD.y, H_source_FW.u[1]) annotation (Line(points={{-42.4,-40},{-30,-40},
                  {-30,-182},{38,-182}}, color={0,0,127}));
          connect(LOAD.y, P_sink_separator.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,230},{-2,230}}, color={0,0,127}));
          connect(LOAD.y, W_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-42.4,
                  -39},{-30,-39},{-30,30},{-58,30}}, color={0,0,127}));
          connect(LOAD.y, H_source_EVA2.u[1]) annotation (Line(points={{-42.4,-40},{-30,
                  -40},{-30,70},{-58,70}}, color={0,0,127}));
          connect(sensT_FW.inlet, waterPump.outlet) annotation (Line(
              points={{-84,-222},{20,-222},{20,66}},
              color={0,0,255},
              thickness=0.5));
          connect(LOAD.y, control_wFW_w_SEP.load) annotation (Line(points={{-42.4,
                  -40},{-42.4,-40},{117.556,-40}},
                                         color={0,0,127}));
          connect(control_wFW_w_SEP.signalBus, signalBus) annotation (Line(
              points={{201.963,-40},{201.963,-40},{238,-40}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_CS, waterPump.in_w0) annotation (Line(
              points={{238,-40},{240,-40},{240,80},{26,80}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_low, separator.level) annotation (Line(
              points={{238,-40},{240,-40},{240,70},{240,132},{30,132}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, separator.DT_sh) annotation (Line(
              points={{238,-40},{240,-40},{240,156},{30,156}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpSEP_PV, sensT_MS.T) annotation (Line(
              points={{238,-40},{238,-40},{238,-210},{238,-242},{-198,-242},{-198,-174}},
              color={255,204,51},
              thickness=0.5));

          connect(TS_sep.y, control_wFW_w_SEP.TS_pumpSEP_bool)
            annotation (Line(points={{81,-12},{117.556,-12}},
                                                          color={255,0,255}));
          connect(TS_DTsh.y, control_wFW_w_SEP.TS_pumpFWhigh_bool) annotation (Line(
                points={{81,-68},{117.556,-68}},        color={255,0,255}));
          connect(P_sink_separator.y[1], sinkSteam5.in_p0)
            annotation (Line(points={{21,230},{32,230},{32,198.8}}, color={0,0,127}));
          connect(signalBus.pumpFW_CS, sourceSteam2.in_w0) annotation (Line(
              points={{238,-40},{238,-40},{238,-200},{80,-200},{80,-216}},
              color={255,204,51},
              thickness=0.5));
          annotation (Diagram(coordinateSystem(extent={{-260,-260},{260,260}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(
                  extent={{-260,-260},{260,260}}, preserveAspectRatio=false)),
            experiment(
              StartTime=-5000,
              StopTime=5000,
              __Dymola_NumberOfIntervals=10000),
            __Dymola_experimentSetupOutput,
            Documentation(info="<html>
<p>Test model to check the procedure of the filling and draining of the separator, as function of the plant load. The system is initialized at 70&percnt; load, at 0 s a negative ramp begins in order to reach the 50&percnt; load. At 55&percnt; the separator filling procedure starts, and the FW pump control is switched from degree of superheating to level control. </p>
<p>After 10 min a positive load ramp starts, and the separator is drained in order to get the 70&percnt; load.</p>
<p>OPEN POINTS:</p>
<p>- separator control optimization;</p>
<p>- pump ramp limits (from 0 a 100&percnt; mass flow in ~10-15s).</p>
</html>"));
        end test_dryWetTransition;

        model plant_LP_checkPrimaryLoad
          "Test model to check the extra-power available if the condenser extraction pump is switched off"
          import PreFlexMS;
          PreFlexMS.FullScale_245degC.SteamTurbine.Corps.IPT IPTurb(vap_in(p(
                  start=46.4e5)), vap_out(p(start=4.5e5))) annotation (
              Placement(transformation(extent={{-156,72},{-74,148}})));
          PreFlexMS.FullScale_245degC.SteamTurbine.Corps.LPT LPTurb
            annotation (Placement(transformation(extent={{18,72},{100,148}})));
          inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.noInit)
            annotation (Placement(transformation(extent={{-300,220},{-280,240}})));
          Modelica.Mechanics.Rotational.Sources.ConstantSpeed constantSpeed(w_fixed=314.1592654)
            annotation (Placement(transformation(extent={{150,100},{130,120}})));
          ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            use_in_p0=true,
            p0=11010,
            use_in_h=false)
            annotation (Placement(transformation(extent={{120,150},{140,170}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_FW(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=64.26,
            h=197600,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{160,-130},{140,-110}})));
          PreFlexMS.FullScale_245degC.HeatExchangers.Components.Deaerator
            deaerator(
            h_start=750000,
            L=12,
            H=2.677,
            zl_start=2,
            initOpt=ThermoPower.Choices.Init.Options.fixedState,
            noInitialPressure=true,
            p_start=900000,
            T(start=448.15),
            p(start=900000)) annotation (Placement(transformation(extent={{-128,
                    -164},{-72,-108}})));
          PreFlexMS.FullScale_245degC.HeatExchangers.FeedwaterTrain.Old.LPH_train_controlledLevel
            LPHs(
            pressDrop(pin(start=15.91e5)),
            pressDrop1(pin(start=1441000, fixed=true)),
            pressDrop2(pin(start=1275000, fixed=true)),
            SP4(p(start=5.088e5)),
            SP5(p(start=2.43e5)),
            SP6(p(start=1.035e5)),
            SP7(p(start=0.3807e5)),
            LPH4(T_FW_out(fixed=false)),
            LPH2(T_FW_out(fixed=false)),
            pressDrop3(pin(start=1128000, fixed=true)),
            sinkPressure_DR(p0=36650)) annotation (Placement(transformation(
                  extent={{-60,-160},{120,-80}})));
          PreFlexMS.Auxiliaries.Components.loadCalculator loadCalc(
            load_start=100,
            load_end=100,
            t_ramp=0,
            t_start=0) annotation (Placement(transformation(extent={{-280,-220},
                    {-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,210})));
          Modelica.Blocks.Tables.CombiTable1D IPT_sourceH(table=[20,3594e3; 30,
                3590e3; 40,3586e3; 50,3581e3; 60,3577e3; 70,3573e3; 80,3568e3; 90,
                3563e3; 100,3558e3])                     annotation (Placement(
                transformation(extent={{-220,200},{-200,220}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,180})));
          Modelica.Blocks.Tables.CombiTable1D IPT_sourceP(table=[20,7.507e5; 30,
                12.02e5; 40,16.56e5; 50,21.15e5; 60,25.75e5; 70,30.01e5; 80,35e5;
                90,40.1e5; 100,45.4e5])   annotation (Placement(transformation(
                  extent={{-220,170},{-200,190}})));
          ThermoPower.Water.SourcePressure sourcePressure(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            h=3559700,
            p0=4640000,
            use_in_p0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-200,150},{-180,170}})));
          ThermoPower.Water.SinkPressure sinkPressure3(redeclare package Medium
              = Modelica.Media.Water.WaterIF97_ph,
            p0=2037000,
            use_in_p0=true)
            annotation (Placement(transformation(extent={{-160,30},{-180,50}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,70})));
          Modelica.Blocks.Tables.CombiTable1D SP5_sinkP(table=[20,3.522e5; 30,
                5.618e5; 40,7.694e5; 50,9.776e5; 60,11.86e5; 70,13.77e5; 80,15.96e5;
                90,18.18e5; 100,20.37e5])
            annotation (Placement(transformation(extent={{-220,60},{-200,80}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={50,180})));
          Modelica.Blocks.Tables.CombiTable1D LPT_sinkP(table=[20,0.0479e5; 30,
                0.0537e5; 40,0.0599e5; 50,0.0666e5; 60,0.0738e5; 70,0.0809e5; 80,
                0.0897e5; 90,0.0994e5; 100,0.1101e5])
            annotation (Placement(transformation(extent={{80,170},{100,190}})));
          ThermoPower.Water.SourceMassFlow sourceMassFlow_DR(
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
            w0=7.727,
            h=782000,
            use_in_w0=true,
            use_in_h=true)
            annotation (Placement(transformation(extent={{-180,-160},{-160,-140}})));
          ThermoPower.Water.SinkMassFlow    waterPump(
            allowFlowReversal=false,
            use_in_w0=true,
            w0=88.59,
            redeclare package Medium = Modelica.Media.Water.WaterIF97_ph)
                   annotation (Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-100,-194})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-90})));
          Modelica.Blocks.Tables.CombiTable1D DR_sourceH(table=[20,522.3e3; 30,
                590.3e3; 40,637.4e3; 50,676.7e3; 60,711.5e3; 70,736.5e3; 80,756.1e3;
                90,772.2e3; 100,782e3])
            annotation (Placement(transformation(extent={{-220,-100},{-200,-80}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-250,-120})));
          Modelica.Blocks.Tables.CombiTable1D DR_sourceW(table=[20,1.937; 30,3.374;
                40,5.125; 50,7.147; 60,9.391; 70,10.42; 80,10; 90,9.282; 100,7.727])
            annotation (Placement(transformation(extent={{-220,-130},{-200,-110}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-190,-190})));
          Modelica.Blocks.Sources.Ramp LOAD8(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={250,-10})));
          Modelica.Blocks.Tables.CombiTable1D cond_sourceH(table=[20,127.8e3; 30,
                139.1e3; 40,148.1e3; 50,156.6e3; 60,164.8e3; 70,172.2e3; 80,180.7e3;
                90,189.1e3; 100,197.6e3])
            annotation (Placement(transformation(extent={{220,-20},{200,0}})));
          Modelica.Blocks.Sources.Ramp LOAD9(
            height=loadCalc.load_end - loadCalc.load_start,
            duration=loadCalc.t_ramp,
            offset=loadCalc.load_start,
            startTime=loadCalc.t_start)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-100})));
          Modelica.Blocks.Tables.CombiTable1D cond_sourceW(table=[20,13.21; 30,
                19.64; 40,25.96; 50,32.26; 60,38.52; 70,44.24; 80,50.82; 90,57.47;
                100,64.26])
            annotation (Placement(transformation(extent={{240,-110},{220,-90}})));
          Modelica.Blocks.Sources.Ramp step(
            offset=0,
            startTime=2000,
            height=-0.8,
            duration=2)
            annotation (Placement(transformation(extent={{260,-78},{240,-58}})));
          Modelica.Blocks.Tables.CombiTable1D FW_sinkW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments,
              table=[4,3.54; 20,17.04; 30,26.36; 40,36.01; 50,46.02; 60,56.19; 70,
                64.64; 80,72.9; 90,81.03; 100,88.59]) annotation (Placement(
                transformation(extent={{-160,-200},{-140,-180}})));
          Modelica.Blocks.Math.Add add
            annotation (Placement(transformation(extent={{180,-90},{160,-70}})));
          IndustrialControlSystems.Controllers.PI
                                              PID_level(
            CSmin=0,
            CSmax=100,
            Ti=10000,
            Kp=-500,
            AntiWindup=true,
            CS_start=88.59,
            useTS=true)    annotation (
              Placement(transformation(
                extent={{-10,-10},{10,10}},
                rotation=-90,
                origin={-40,-190})));
          Modelica.Blocks.Continuous.FirstOrder pumpDynamic(k=1, T=5)
                  annotation (Placement(
                transformation(
                extent={{10,-10},{-10,10}},
                rotation=0,
                origin={-62,-220})));
          Modelica.Blocks.Sources.Constant zl_SP(k=2.0559)
            annotation (Placement(transformation(extent={{20,-186},{0,-166}})));
          Modelica.Blocks.Math.Product product
            annotation (Placement(transformation(extent={{208,-84},{188,-64}})));
          Modelica.Blocks.Sources.BooleanStep booleanStep(startValue=false,
              startTime=2000)
            annotation (Placement(transformation(extent={{20,-220},{0,-200}})));
        equation
          connect(IPTurb.flange_IP_out, LPTurb.flange_LP_in) annotation (Line(
              points={{-69.9,110},{13.9,110}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(LPTurb.flange_LP_out, constantSpeed.flange) annotation (Line(
              points={{104.1,110},{130,110}},
              color={0,0,0},
              smooth=Smooth.None));

          connect(LPTurb.vap_out, sinkPressure.flange) annotation (Line(
              points={{104.1,132.8},{104.1,160},{120,160}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));
          connect(IPTurb.SP5, deaerator.steam_in) annotation (Line(
              points={{-119.1,68.2},{-119.1,-132},{-107.6,-132}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.vap_out, LPTurb.vap_in) annotation (Line(
              points={{-69.9,132.8},{13.9,132.8}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5));

          connect(deaerator.water_in, LPHs.FW_out) annotation (Line(
              points={{-92.8,-120},{-92.8,-120},{-63.75,-120}},
              color={0,0,255},
              thickness=0.5));
          connect(LPHs.FW_in, sourceMassFlow_FW.flange) annotation (Line(
              points={{123.75,-120},{123.75,-120},{140,-120}},
              color={0,0,255},
              thickness=0.5));
          connect(LPTurb.SP1, LPHs.SP7) annotation (Line(
              points={{73.76,68.2},{73.76,39.1},{90,39.1},{90,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LPTurb.SP2, LPHs.SP6) annotation (Line(
              points={{54.9,68.2},{54.9,40},{48.75,40},{48.75,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LPTurb.SP3, LPHs.SP5) annotation (Line(
              points={{36.86,68.2},{36.86,40},{7.5,40},{7.5,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(IPTurb.SP4, LPHs.SP4) annotation (Line(
              points={{-100.24,68.2},{-100.24,40},{-33.75,40},{-33.75,-76}},
              color={0,127,0},
              thickness=0.5));
          connect(LOAD1.y,IPT_sourceH. u[1]) annotation (Line(points={{-239,210},{
                  -230,210},{-222,210}},  color={0,0,127}));
          connect(LOAD2.y,IPT_sourceP. u[1]) annotation (Line(points={{-239,180},{
                  -230,180},{-222,180}},  color={0,0,127}));
          connect(sourcePressure.flange, IPTurb.vap_in) annotation (Line(
              points={{-180,160},{-172,160},{-160.1,160},{-160.1,132.8}},
              color={0,0,255},
              thickness=0.5));
          connect(IPTurb.SP6, sinkPressure3.flange) annotation (Line(
              points={{-137.14,68.2},{-137.14,40},{-160,40}},
              color={0,127,0},
              thickness=0.5));
          connect(IPT_sourceP.y[1], sourcePressure.in_p0) annotation (Line(points={
                  {-199,180},{-194,180},{-194,169.2}}, color={0,0,127}));
          connect(IPT_sourceH.y[1], sourcePressure.in_h) annotation (Line(points={{
                  -199,210},{-186,210},{-186,169}}, color={0,0,127}));
          connect(LOAD3.y, SP5_sinkP.u[1]) annotation (Line(points={{-239,70},{-230,
                  70},{-222,70}}, color={0,0,127}));
          connect(SP5_sinkP.y[1], sinkPressure3.in_p0) annotation (Line(points={{
                  -199,70},{-174,70},{-166,70},{-166,48.8}}, color={0,0,127}));
          connect(LPT_sinkP.y[1], sinkPressure.in_p0) annotation (Line(points={{101,
                  180},{114,180},{126,180},{126,168.8}}, color={0,0,127}));
          connect(deaerator.drained_out, waterPump.flange) annotation (Line(
              points={{-100,-158},{-100,-184}},
              color={0,0,255},
              thickness=0.5));
          connect(sourceMassFlow_DR.flange, deaerator.drained_in) annotation (Line(
              points={{-160,-150},{-126,-150}},
              color={0,0,255},
              thickness=0.5));
          connect(LOAD4.y, DR_sourceH.u[1]) annotation (Line(points={{-239,-90},{
                  -230,-90},{-222,-90}}, color={0,0,127}));
          connect(LOAD6.y, DR_sourceW.u[1]) annotation (Line(points={{-239,-120},{
                  -239,-120},{-222,-120}}, color={0,0,127}));
          connect(DR_sourceH.y[1], sourceMassFlow_DR.in_h) annotation (Line(points=
                  {{-199,-90},{-166,-90},{-166,-144}}, color={0,0,127}));
          connect(DR_sourceW.y[1], sourceMassFlow_DR.in_w0) annotation (Line(points=
                 {{-199,-120},{-199,-118},{-174,-118},{-174,-144}}, color={0,0,127}));
          connect(LOAD8.y, cond_sourceH.u[1]) annotation (Line(points={{239,-10},
                  {239,-10},{222,-10}},color={0,0,127}));
          connect(LOAD9.y, cond_sourceW.u[1]) annotation (Line(points={{259,-100},
                  {259,-100},{242,-100}},color={0,0,127}));
          connect(cond_sourceH.y[1], sourceMassFlow_FW.in_h) annotation (Line(
                points={{199,-10},{146,-10},{146,-114}}, color={0,0,127}));
          connect(LOAD7.y, FW_sinkW.u[1])
            annotation (Line(points={{-179,-190},{-162,-190}}, color={0,0,127}));
          connect(add.y, sourceMassFlow_FW.in_w0) annotation (Line(points={{159,-80},
                  {154,-80},{154,-114}}, color={0,0,127}));
          connect(cond_sourceW.y[1], add.u2) annotation (Line(points={{219,-100},
                  {194,-100},{194,-86},{182,-86}},color={0,0,127}));
          connect(LOAD5.y, LPT_sinkP.u[1]) annotation (Line(points={{61,180},{70,
                  180},{78,180}}, color={0,0,127}));
          connect(PID_level.CS,pumpDynamic. u) annotation (Line(
              points={{-40,-199},{-40,-220},{-50,-220}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(zl_SP.y,PID_level. SP) annotation (Line(
              points={{-1,-176},{-34,-176},{-34,-182}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(deaerator.level,PID_level. PV) annotation (Line(
              points={{-74,-152},{-66,-152},{-66,-176},{-41,-176},{-41,-182}},
              color={0,0,127},
              smooth=Smooth.None));
          connect(pumpDynamic.y, waterPump.in_w0) annotation (Line(points={{-73,
                  -220},{-80,-220},{-80,-190},{-94,-190}}, color={0,0,127}));
          connect(add.u1, product.y) annotation (Line(points={{182,-74},{187,-74}},
                             color={0,0,127}));
          connect(product.u2, cond_sourceW.y[1]) annotation (Line(points={{210,-80},
                  {214,-80},{214,-100},{219,-100}}, color={0,0,127}));
          connect(product.u1, step.y)
            annotation (Line(points={{210,-68},{239,-68}}, color={0,0,127}));
          connect(PID_level.CS, PID_level.TR) annotation (Line(points={{-40,-199},{
                  -40,-208},{-24,-208},{-24,-190},{-32,-190}}, color={0,0,127}));
          connect(booleanStep.y, PID_level.TS) annotation (Line(points={{-1,-210},{
                  -14,-210},{-14,-194},{-32,-194}}, color={255,0,255}));
          annotation (Diagram(coordinateSystem(extent={{-300,-240},{300,240}},
                  preserveAspectRatio=false)),           Icon(coordinateSystem(extent={{-300,
                    -240},{300,240}})),
            experiment(StopTime=2500, __Dymola_NumberOfIntervals=5000),
            __Dymola_experimentSetupOutput);
        end plant_LP_checkPrimaryLoad;
      end Test;

      package Old "Package containing old control schemes and FF tables"

        model plant_controller_HPpart_highLoad
          "Model of the HP plant control system "

          //Controllers parameter

          //-- Plant load --
          parameter Real load_start "Simulation start load [%]" annotation (Dialog(tab="Plant load"));
          parameter Real load_end "Simulation end load [%]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]" annotation (Dialog(tab="Plant load"));
          parameter Modelica.SIunits.Time t_start_ramp "Ramp start time [s]" annotation (Dialog(tab="Plant load"));

          //-- pumpMS --
          parameter Real Kp_pumpMS "Controller proportional gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ti_pumpMS "Controller integral time" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Td_pumpMS
            "Controller derivative time"                                         annotation (Dialog(tab="pumpMS"));
          parameter Real Nd_pumpMS
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpMS"));
          parameter Real CSmin_pumpMS
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSmax_pumpMS
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpMS"));
          parameter Real CSstart_pumpMS "Start value of CS" annotation (Dialog(tab="pumpMS"));
          parameter Real actuatorGain_pumpMS "Actuator gain" annotation (Dialog(tab="pumpMS"));
          parameter Modelica.SIunits.Time Ta_pumpMS "Actuator time constant" annotation (Dialog(tab="pumpMS"));
          parameter Boolean useTS_pumpMS "Tracking reference mode" annotation (Dialog(tab="pumpMS"));
          parameter Real TS_pumpMS "Tracking signal" annotation (Dialog(tab="pumpMS"));

          //-- valveTURB --
          parameter Real Kp_valveTURB "Controller proportional gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ti_valveTURB
            "Controller integral time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Td_valveTURB
            "Controller derivative time"                                            annotation (Dialog(tab="valveTURB"));
          parameter Real Nd_valveTURB
            "Controller derivative action up to Nd/Td rad/s"                           annotation (Dialog(tab="valveTURB"));
          parameter Real CSmin_valveTURB
            "Minimum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSmax_valveTURB
            "Maximum value of control signal for scaling"                              annotation (Dialog(tab="valveTURB"));
          parameter Real CSstart_valveTURB "Start value of CS" annotation (Dialog(tab="valveTURB"));
          parameter Real actuatorGain_valveTURB "Actuator gain" annotation (Dialog(tab="valveTURB"));
          parameter Modelica.SIunits.Time Ta_valveTURB "Actuator time constant"
                                                                                annotation (Dialog(tab="valveTURB"));
          parameter Boolean useTS_valveTURB "Tracking reference mode" annotation (Dialog(tab="valveTURB"));
          parameter Real TS_valveTURB "Tracking signal" annotation (Dialog(tab="valveTURB"));

          //-- pumpFW --
          parameter Modelica.SIunits.TemperatureDifference DT_SH_sp
            "Degree of superheating set point"     annotation (Dialog(tab="pumpFW"));
          parameter Real Kp_pumpFW "Controller proportional gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ti_pumpFW "Controller integral time" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Td_pumpFW
            "Controller derivative time"                                         annotation (Dialog(tab="pumpFW"));
          parameter Real Nd_pumpFW
            "Controller derivative action up to Nd/Td rad/s"                        annotation (Dialog(tab="pumpFW"));
          parameter Real CSmin_pumpFW
            "Minimum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSmax_pumpFW
            "Maximum value of control signal for scaling"                           annotation (Dialog(tab="pumpFW"));
          parameter Real CSstart_pumpFW "Start value of CS" annotation (Dialog(tab="pumpFW"));
          parameter Real actuatorGain_pumpFW "Actuator gain" annotation (Dialog(tab="pumpFW"));
          parameter Modelica.SIunits.Time Ta_pumpFW "Actuator time constant" annotation (Dialog(tab="pumpFW"));
          parameter Boolean useTS_pumpFW "Tracking reference mode" annotation (Dialog(tab="pumpFW"));
          parameter Real TS_pumpFW "Tracking signal" annotation (Dialog(tab="pumpFW"));

          //-- valveBP --
          parameter Modelica.SIunits.Temperature T_FW_sp
            "Feedwater temperature set point"  annotation (Dialog(tab="valveBP"));
          parameter Real Kp_valveBP "Controller proportional gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ti_valveBP "Controller integral time"
                                                                                annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Td_valveBP
            "Controller derivative time"                                          annotation (Dialog(tab="valveBP"));
          parameter Real Nd_valveBP
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="valveBP"));
          parameter Real CSmin_valveBP
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSmax_valveBP
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="valveBP"));
          parameter Real CSstart_valveBP "Start value of CS" annotation (Dialog(tab="valveBP"));
          parameter Real actuatorGain_valveBP "Actuator gain" annotation (Dialog(tab="valveBP"));
          parameter Modelica.SIunits.Time Ta_valveBP "Actuator time constant" annotation (Dialog(tab="valveBP"));
          parameter Boolean useTS_valveBP "Tracking reference mode" annotation (Dialog(tab="valveBP"));
          parameter Real TS_valveBP "Tracking signal" annotation (Dialog(tab="valveBP"));

          //-- pumpHPH --
          parameter Modelica.SIunits.Temperature T_MS_sp
            "Molten salt outlet temperature set point"     annotation (Dialog(tab="pumpHPH"));
          parameter Real Kp_pumpHPH "Controller proportional gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ti_pumpHPH "Controller integral time"
                                                                                annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Td_pumpHPH
            "Controller derivative time"                                          annotation (Dialog(tab="pumpHPH"));
          parameter Real Nd_pumpHPH
            "Controller derivative action up to Nd/Td rad/s"                         annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmin_pumpHPH
            "Minimum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSmax_pumpHPH
            "Maximum value of control signal for scaling"                            annotation (Dialog(tab="pumpHPH"));
          parameter Real CSstart_pumpHPH "Start value of CS" annotation (Dialog(tab="pumpHPH"));
          parameter Real actuatorGain_pumpHPH "Actuator gain" annotation (Dialog(tab="pumpHPH"));
          parameter Modelica.SIunits.Time Ta_pumpHPH "Actuator time constant" annotation (Dialog(tab="pumpHPH"));
          parameter Boolean useTS_pumpHPH "Tracking reference mode" annotation (Dialog(tab="pumpHPH"));
          parameter Real TS_pumpHPH "Tracking signal" annotation (Dialog(tab="pumpHPH"));

          Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
                  extent={{-20,40},{20,80}}),  iconTransformation(
                extent={{-40,-40},{40,40}},
                rotation=90,
                origin={420,0})));
          IndustrialControlSystems.Controllers.PID PID_pumpFW(
            AntiWindup=true,
            useTS=useTS_pumpFW,
            useBIAS=false,
            CSmin=CSmin_pumpFW,
            CSmax=CSmax_pumpFW,
            CS_start=CSstart_pumpFW,
            Kp=Kp_pumpFW,
            Ti=Ti_pumpFW,
            Td=Td_pumpFW,
            N=Nd_pumpFW)
            annotation (Placement(transformation(extent={{-300,-160},{-260,-120}})));
         Modelica.Blocks.Continuous.FirstOrder pumpFW_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpFW,
            T=Ta_pumpFW) annotation (Placement(transformation(
                extent={{20,20},{-20,-20}},
                rotation=180,
                origin={-60,-140})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep2
            annotation (Placement(transformation(extent={{-240,-110},{-260,-90}})));
          Modelica.Blocks.Sources.Constant pumpFW_TS(k=TS_pumpFW)
            annotation (Placement(transformation(extent={{-320,-110},{-300,-90}})));
          Modelica.Blocks.Continuous.FirstOrder pumpHPH_dynamic(
            k=actuatorGain_pumpHPH,
            T=Ta_pumpHPH,
            initType=Modelica.Blocks.Types.Init.SteadyState)
            annotation (Placement(transformation(extent={{80,-160},{40,-120}})));
          IndustrialControlSystems.Controllers.PI  PID_pumpHPH(
            AntiWindup=true,
            useTS=useTS_pumpHPH,
            CSmin=CSmin_pumpHPH,
            CSmax=CSmax_pumpHPH,
            CS_start=CSstart_pumpHPH,
            Kp=Kp_pumpHPH,
            Ti=Ti_pumpHPH)
            annotation (Placement(transformation(extent={{300,-160},{260,-120}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep4
            annotation (Placement(transformation(extent={{240,-110},{260,-90}})));
          Modelica.Blocks.Sources.Constant pumpHPH_TS(k=TS_pumpHPH)
            annotation (Placement(transformation(extent={{320,-110},{300,-90}})));
         Modelica.Blocks.Continuous.FirstOrder pumpMS_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_pumpMS,
            T=Ta_pumpMS)
                 annotation (Placement(transformation(
                extent={{-20,20},{20,-20}},
                rotation=180,
                origin={60,240})));
          IndustrialControlSystems.Controllers.PID PID_pumpMS(
            AntiWindup=true,
            useTS=useTS_pumpMS,
            CSmin=CSmin_pumpMS,
            CSmax=CSmax_pumpMS,
            CS_start=CSstart_pumpMS,
            Kp=Kp_pumpMS,
            Ti=Ti_pumpMS,
            Td=Td_pumpMS,
            N=Nd_pumpMS)
            annotation (Placement(transformation(extent={{300,220},{260,260}})));
          Modelica.Blocks.Sources.Constant T_MS_SP(k=T_MS_sp)
            annotation (Placement(transformation(extent={{400,-178},{380,-158}})));
          Modelica.Blocks.Sources.Constant pumpMS_TS(k=TS_pumpMS)
            annotation (Placement(transformation(extent={{320,270},{300,290}})));
          Modelica.Blocks.Continuous.FirstOrder valveTURB_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveTURB,
            T=Ta_valveTURB)
            annotation (Placement(transformation(extent={{80,40},{40,80}})));
          IndustrialControlSystems.Controllers.PI  PID_valveTURB(
            AntiWindup=true,
            useTS=useTS_valveTURB,
            CS_start=CSstart_valveTURB,
            CSmin=CSmin_valveTURB,
            CSmax=CSmax_valveTURB,
            Kp=Kp_valveTURB,
            Ti=Ti_valveTURB)
            annotation (Placement(transformation(extent={{300,40},{260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep6
            annotation (Placement(transformation(extent={{242,90},{262,110}})));
          Modelica.Blocks.Sources.Constant valveTURB_TS(k=TS_valveTURB)
            annotation (Placement(transformation(extent={{320,90},{300,110}})));
          Modelica.Blocks.Sources.Ramp LOAD(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,242},{380,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_P_MEC(
                                                      smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,14.887e6; 30,24.6221e6; 40,33.3568e6; 50,42.178e6; 60,
                51.134e6; 70,59.394e6; 80,66.8384e6; 90,74.4169e6; 100,
                82.3774e6])
            annotation (Placement(transformation(extent={{360,242},{340,262}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_MS(  smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                534.15; 20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,563.15; 70,
                563.15; 80,563.15; 90,563.15; 100,563.15])
            annotation (Placement(transformation(extent={{360,-138},{340,-118}})));
          Modelica.Blocks.Sources.Ramp LOAD2(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,62},{380,82}})));
          Modelica.Blocks.Sources.Ramp LOAD3(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{400,-138},{380,-118}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_FW(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,1.928; 30,2.414; 40,2.715; 50,2.435; 60,1.105; 70,1.269; 80,
                1.436; 90,1.605; 100,1.757])
                                            annotation (Placement(transformation(
                  extent={{-260,-200},{-240,-180}})));
          Modelica.Blocks.Sources.Ramp LOAD4(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,-190})));
          Modelica.Blocks.Math.Add add1 annotation (Placement(transformation(extent={{-140,
                    -150},{-120,-130}})));
          Modelica.Blocks.Math.Product product annotation (Placement(transformation(
                  extent={{-180,-144},{-160,-124}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_HPH(
                        smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[
                20,0.02; 30,0.02; 40,0.02; 50,0.02; 60,0.02; 70,0.02; 80,0.02;
                90,0.1245; 100,0.4717])
            annotation (Placement(transformation(extent={{240,-202},{220,-182}})));
          Modelica.Blocks.Math.Add add2
            annotation (Placement(transformation(extent={{120,-150},{100,-130}})));
          Modelica.Blocks.Math.Product product1
            annotation (Placement(transformation(extent={{160,-144},{140,-124}})));
          Modelica.Blocks.Sources.Ramp LOAD5(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,-192})));
          Modelica.Blocks.Tables.CombiTable1D table_Y_tTOtheta(smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
                0; 4.1407017192796e-07,0.00999999977648258;
                8.28140343855921e-07,0.0199999995529652; 1.24221048736217e-06,
                0.0299999993294477; 1.6396938917751e-06,0.0395999997854233;
                2.04812727133685e-06,0.049600001424551; 2.43941963162797e-06,
                0.0595999993383884; 2.80321296486363e-06,0.0696000009775162;
                3.13163786813675e-06,0.0795999988913536; 3.42091243510367e-06,
                0.089599996805191; 3.67116581401206e-06,0.0996000021696091;
                3.88521993954782e-06,0.109600000083447; 4.0672412069398e-06,
                0.119599997997284; 4.22174571212963e-06,0.129600003361702;
                4.35302490586764e-06,0.139599993824959; 4.46488320449134e-06,
                0.149599999189377; 4.56056841358077e-06,0.159600004553795;
                4.64279128209455e-06,0.169599995017052; 4.71378916699905e-06,
                0.17960000038147; 4.7753978833498e-06,0.189600005745888;
                4.82912173538352e-06,0.199599996209145; 4.87619445266319e-06,
                0.209600001573563; 4.91763012178126e-06,0.219600006937981;
                4.95426547786337e-06,0.229599997401238; 4.98679264637758e-06,
                0.239600002765656; 5.0157882469648e-06,0.249599993228912;
                5.04173385706963e-06,0.259600013494492; 5.06503420183435e-06,
                0.269600003957748; 5.08603034177213e-06,0.279599994421005;
                5.10501058670343e-06,0.289600014686585; 5.12222140969243e-06,
                0.299600005149841; 5.13787290401524e-06,0.309599995613098;
                5.15214514962281e-06,0.319599986076355; 5.16519367010915e-06,
                0.329600006341934; 5.17715261594276e-06,0.339599996805191;
                5.18813931194018e-06,0.349599987268448; 5.1982547120133e-06,
                0.359600007534027; 5.20758794664289e-06,0.369599997997284;
                5.21621677762596e-06,0.379599988460541; 5.22420987181249e-06,
                0.38960000872612; 5.23162771060015e-06,0.399599999189377;
                5.23852395417634e-06,0.409599989652634; 5.24494544151821e-06,
                0.419600009918213; 5.25093537362409e-06,0.42960000038147;
                5.25653013028204e-06,0.439599990844727; 5.2617647270381e-06,
                0.449600011110306; 5.26666872247006e-06,0.459600001573563;
                5.27126894667163e-06,0.469599992036819; 5.2755904107471e-06,
                0.479600012302399; 5.27965448782197e-06,0.489600002765656;
                5.28348164152703e-06,0.499599993228912; 5.28708960700897e-06,
                0.509599983692169; 5.2904947551724e-06,0.519599974155426;
                5.29371163793257e-06,0.529600024223328; 5.29675480720471e-06,
                0.539600014686585; 5.29963517692522e-06,0.549600005149841;
                5.30236502527259e-06,0.559599995613098; 5.30495435668854e-06,
                0.569599986076355; 5.30741272086743e-06,0.579599976539612;
                5.30974875800894e-06,0.589600026607513; 5.31197019881802e-06,
                0.59960001707077; 5.31408431925229e-06,0.609600007534027;
                5.31609839526936e-06,0.619599997997284; 5.31801833858481e-06,
                0.629599988460541; 5.31985006091418e-06,0.639599978923798;
                5.32159856447834e-06,0.649600028991699; 5.32326885149814e-06,
                0.659600019454956; 5.32486592419446e-06,0.669600009918213;
                5.32639342054608e-06,0.67960000038147; 5.32785543327918e-06,
                0.689599990844727; 5.32925605511991e-06,0.699599981307983;
                5.33059846929973e-06,0.70959997177124; 5.33188585905009e-06,
                0.719600021839142; 5.3331209528551e-06,0.729600012302399;
                5.33430647919886e-06,0.739600002765656; 5.33544562131283e-06,
                0.749599993228912; 5.33654019818641e-06,0.759599983692169;
                5.33759293830372e-06,0.769599974155426; 5.33860520590679e-06,
                0.779600024223328; 5.33958018422709e-06,0.789600014686585;
                5.34051878275932e-06,0.799600005149841; 5.34142282049288e-06,
                0.809599995613098; 5.34229457116453e-06,0.819599986076355;
                5.34313494426897e-06,0.829599976539612; 5.3439457587956e-06,
                0.839600026607513; 5.34472837898647e-06,0.84960001707077;
                5.3454837143363e-06,0.859600007534027; 5.34621358383447e-06,
                0.869599997997284; 5.34691889697569e-06,0.879599988460541;
                5.34760056325467e-06,0.889599978923798; 5.34825949216611e-06,
                0.899600028991699; 5.34889704795205e-06,0.909600019454956;
                5.3495141401072e-06,0.919600009918213; 5.35011167812627e-06,
                0.92960000038147; 5.3506901167566e-06,0.939599990844727;
                5.35125036549289e-06,0.949599981307983; 5.35179333382985e-06,
                0.95959997177124; 5.35231993126217e-06,0.969600021839142;
                5.35283061253722e-06,0.979600012302399; 5.35332537765498e-06,
                0.989600002765656; 5.35380604560487e-06,0.999599993228912])
            annotation (Placement(transformation(extent={{130,50},{110,70}})));
          Modelica.Blocks.Tables.CombiTable1D table_w_MS(
                                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,2.392; 30,3.588; 40,4.784; 50,5.98; 60,7.17; 70,8.365; 80,
                9.56; 90,10.76; 100,11.95])
            annotation (Placement(transformation(extent={{240,180},{220,200}})));
          Modelica.Blocks.Math.Add add4
            annotation (Placement(transformation(extent={{120,230},{100,250}})));
          Modelica.Blocks.Sources.Ramp LOAD7(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                rotation=0,
                origin={270,190})));
          Modelica.Blocks.Math.Add add5
            annotation (Placement(transformation(extent={{170,50},{150,70}})));
          Modelica.Blocks.Sources.Ramp LOAD6(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{280,0},{260,20}})));
          Modelica.Blocks.Tables.CombiTable1D table_Yt(
              smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,2.0794604e-6; 30,2.70451e-6; 40,3.80023e-6; 50,4.99271e-6;
                60,5.01396e-6; 70,5.01726e-6; 80,5.01213e-6; 90,5.0123e-6; 100,
                4.98849e-6])
            annotation (Placement(transformation(extent={{240,0},{220,20}})));
          Modelica.Blocks.Sources.Ramp LOAD10(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-290,10})));
          Modelica.Blocks.Tables.CombiTable1D table_thetaBP(   smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[4,
                0; 20,0; 30,0; 40,0; 50,0; 60,0; 70,0.145652; 80,0.208685; 90,
                0.349201; 100,0.866205])
            annotation (Placement(transformation(extent={{-260,0},{-240,20}})));
          Modelica.Blocks.Sources.Constant DT_SH_SP(k=DT_SH_sp)
            annotation (Placement(transformation(extent={{-360,-138},{-340,-118}})));
          Modelica.Blocks.Continuous.FirstOrder valveBP_dynamic(
            initType=Modelica.Blocks.Types.Init.SteadyState,
            k=actuatorGain_valveBP,
            T=Ta_valveBP)
            annotation (Placement(transformation(extent={{-80,40},{-40,80}})));
          IndustrialControlSystems.Controllers.PI PID_valveBP(
            AntiWindup=true,
            useTS=useTS_valveBP,
            CSmin=CSmin_valveBP,
            CSmax=CSmax_valveBP,
            CS_start=CSstart_valveBP,
            Kp=Kp_valveBP,
            Ti=Ti_valveBP)
            annotation (Placement(transformation(extent={{-300,40},{-260,80}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep3
            annotation (Placement(transformation(extent={{-240,90},{-260,110}})));
          Modelica.Blocks.Sources.Constant valveBP_TS(k=TS_valveBP)
            annotation (Placement(transformation(extent={{-320,90},{-300,110}})));
          Modelica.Blocks.Math.Add add8 annotation (Placement(transformation(extent={{-140,50},
                    {-120,70}})));
          Modelica.Blocks.Sources.BooleanConstant
                                              booleanStep5
            annotation (Placement(transformation(extent={{230,270},{250,290}})));
          Modelica.Blocks.Interfaces.RealInput u_Pmec annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=180,
                origin={360,160}), iconTransformation(
                extent={{-20,-20},{20,20}},
                rotation=270,
                origin={0,320})));
          Modelica.Blocks.Sources.Ramp LOAD1(
            height=load_end - load_start,
            duration=t_ramp,
            offset=load_start,
            startTime=t_start_ramp)
            annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,
                origin={-390,72})));
          Modelica.Blocks.Tables.CombiTable1D table_P(
                                       smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,85.08e5; 30,85.18e5; 40,85.33e5; 50,88.82e5; 60,107.9e5; 70,
                124.1e5; 80,139.7e5; 90,155.1e5; 100,171e5])
            annotation (Placement(transformation(extent={{360,62},{340,82}})));
          Modelica.Blocks.Tables.CombiTable1D table_T_FW(
                                     smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
                20,558.15; 30,558.15; 40,558.15; 50,558.15; 60,529.85; 70,
                518.15; 80,518.15; 90,518.15; 100,518.15])
            annotation (Placement(transformation(extent={{-360,62},{-340,82}})));
        equation
          connect(PID_pumpFW.TS, booleanStep2.y) annotation (Line(points={{-272,-124},{-272,
                  -124},{-272,-112},{-272,-100},{-261,-100}}, color={255,0,255}));
          connect(booleanStep4.y, PID_pumpHPH.TS) annotation (Line(points={{261,-100},{272,
                  -100},{272,-124}}, color={255,0,255}));
          connect(pumpHPH_TS.y, PID_pumpHPH.TR) annotation (Line(points={{299,-100},{299,
                  -100},{280,-100},{280,-124}}, color={0,0,127}));
          connect(signalBus.pumpHPH_CS, pumpHPH_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-142},{0,-140},{38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpHPH_PV, PID_pumpHPH.PV) annotation (Line(
              points={{0,60},{0,60},{0,-240},{320,-240},{320,-142},{296,-142}},
              color={255,204,51},
              thickness=0.5));
          connect(pumpMS_TS.y, PID_pumpMS.TR) annotation (Line(points={{299,280},{
                  299,280},{280,280},{280,256}},
                                        color={0,0,127}));
          connect(signalBus.pumpMS_CS, pumpMS_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,242},{0,240},{38,240}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep6.y, PID_valveTURB.TS) annotation (Line(points={{263,100},
                  {272,100},{272,76}}, color={255,0,255}));
          connect(signalBus.valveTURB_CS, valveTURB_dynamic.y) annotation (Line(
              points={{0,60},{2,60},{38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.valveTURB_PV, PID_valveTURB.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{320,-60},{320,58},{296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(PID_pumpMS.SP, table_P_MEC.y[1])
            annotation (Line(points={{296,252},{296,252},{339,252}}, color={0,0,127}));
          connect(table_P_MEC.u[1], LOAD.y)
            annotation (Line(points={{362,252},{368,252},{379,252}},
                                                           color={0,0,127}));
          connect(LOAD4.y, table_w_FW.u[1])
            annotation (Line(points={{-279,-190},{-262,-190}}, color={0,0,127}));
          connect(product.y, add1.u1)
            annotation (Line(points={{-159,-134},{-150,-134},{-142,-134}},
                                                               color={0,0,127}));
          connect(table_w_FW.y[1], add1.u2) annotation (Line(points={{-239,-190},
                  {-152,-190},{-152,-146},{-142,-146}},color={0,0,127}));
          connect(LOAD5.y, table_w_HPH.u[1]) annotation (Line(points={{259,-192},{
                  250,-192},{242,-192}}, color={0,0,127}));
          connect(product1.y, add2.u1) annotation (Line(points={{139,-134},{139,
                  -134},{122,-134}}, color={0,0,127}));
          connect(table_w_HPH.y[1], add2.u2) annotation (Line(points={{219,-192},{
                  131,-192},{131,-146},{122,-146}}, color={0,0,127}));
          connect(pumpHPH_dynamic.u, add2.y) annotation (Line(points={{84,-140},
                  {99,-140}},       color={0,0,127}));
          connect(LOAD7.y, table_w_MS.u[1]) annotation (Line(points={{259,190},{250,
                  190},{242,190}}, color={0,0,127}));
          connect(table_w_MS.y[1], add4.u2) annotation (Line(points={{219,190},{131,
                  190},{131,234},{122,234}}, color={0,0,127}));
          connect(pumpMS_dynamic.u, add4.y) annotation (Line(points={{84,240},{99,
                  240}},          color={0,0,127}));
          connect(table_w_FW.y[1], product.u2) annotation (Line(points={{-239,-190},
                  {-239,-190},{-190,-190},{-190,-140},{-182,-140}}, color={0,0,127}));
          connect(table_w_HPH.y[1], product1.u2) annotation (Line(points={{219,-192},
                  {172,-192},{172,-140},{162,-140}}, color={0,0,127}));
          connect(valveTURB_dynamic.u, table_Y_tTOtheta.y[1])
            annotation (Line(points={{84,60},{109,60}}, color={0,0,127}));
          connect(table_Y_tTOtheta.u[1], add5.y)
            annotation (Line(points={{132,60},{149,60}}, color={0,0,127}));
          connect(table_Yt.u[1], LOAD6.y)
            annotation (Line(points={{242,10},{259,10}}, color={0,0,127}));
          connect(add5.u2, table_Yt.y[1]) annotation (Line(points={{172,54},{180,54},
                  {180,10},{219,10}}, color={0,0,127}));
          connect(LOAD10.y, table_thetaBP.u[1]) annotation (Line(points={{-279,10},{-270.5,
                  10},{-262,10}}, color={0,0,127}));
          connect(add1.y, pumpFW_dynamic.u) annotation (Line(points={{-119,-140},
                  {-84,-140}}, color={0,0,127}));
          connect(PID_pumpHPH.SP, table_T_MS.y[1]) annotation (Line(points={{296,-128},{
                  339,-128},{339,-128}}, color={0,0,127}));
          connect(table_T_MS.u[1], LOAD3.y) annotation (Line(points={{362,-128},{379,-128},
                  {379,-128}}, color={0,0,127}));
          connect(DT_SH_SP.y, PID_pumpFW.SP) annotation (Line(points={{-339,-128},{-296,-128}},
                                      color={0,0,127}));
          connect(signalBus.pumpFW_CS, pumpFW_dynamic.y) annotation (Line(
              points={{0,60},{0,60},{0,-140},{-38,-140}},
              color={255,204,51},
              thickness=0.5));
          connect(signalBus.pumpFW_PV_high, PID_pumpFW.PV) annotation (Line(
              points={{0,60},{0,60},{0,-242},{0,-240},{-320,-240},{-320,-142},{-296,-142}},
              color={255,204,51},
              thickness=0.5));

          connect(add8.y, valveBP_dynamic.u)
            annotation (Line(points={{-119,60},{-84,60}}, color={0,0,127}));
          connect(table_thetaBP.y[1], add8.u2) annotation (Line(points={{-239,10},{-192,
                  10},{-152,10},{-152,54},{-142,54}}, color={0,0,127}));
          connect(signalBus.valveBP_CS, valveBP_dynamic.y) annotation (Line(
              points={{0,60},{-19,60},{-38,60}},
              color={255,204,51},
              thickness=0.5));
          connect(valveBP_TS.y, PID_valveBP.TR) annotation (Line(points={{-299,100},{-280,
                  100},{-280,76}}, color={0,0,127}));
          connect(booleanStep3.y, PID_valveBP.TS) annotation (Line(points={{-261,100},{-266,
                  100},{-272,100},{-272,76}}, color={255,0,255}));
          connect(signalBus.valveBP_PV, PID_valveBP.PV) annotation (Line(
              points={{0,60},{0,60},{0,-60},{-320,-60},{-320,58},{-296,58}},
              color={255,204,51},
              thickness=0.5));
          connect(booleanStep5.y, PID_pumpMS.TS) annotation (Line(points={{251,280},{272,
                  280},{272,256}}, color={255,0,255}));
          connect(pumpFW_TS.y, PID_pumpFW.TR) annotation (Line(points={{-299,-100},{-280,
                  -100},{-280,-124}}, color={0,0,127}));
          connect(valveTURB_TS.y, PID_valveTURB.TR)
            annotation (Line(points={{299,100},{280,100},{280,76}}, color={0,0,127}));
          connect(add4.u1, PID_pumpMS.CS) annotation (Line(points={{122,246},{172,
                  246},{220,246},{220,240},{262,240}}, color={0,0,127}));
          connect(PID_valveBP.CS, add8.u1) annotation (Line(points={{-262,60},{
                  -210,60},{-158,60},{-158,66},{-142,66}}, color={0,0,127}));
          connect(PID_pumpFW.CS, product.u1) annotation (Line(points={{-262,-140},
                  {-224,-140},{-224,-128},{-182,-128}}, color={0,0,127}));
          connect(product1.u1, PID_pumpHPH.CS) annotation (Line(points={{162,-128},
                  {214,-128},{214,-140},{262,-140}}, color={0,0,127}));
          connect(add5.u1, PID_valveTURB.CS) annotation (Line(points={{172,66},{
                  216,66},{216,60},{262,60}}, color={0,0,127}));
          connect(PID_pumpMS.PV, u_Pmec) annotation (Line(points={{296,238},{324,
                  238},{324,160},{360,160}}, color={0,0,127}));
          connect(table_P.u[1], LOAD2.y)
            annotation (Line(points={{362,72},{379,72}}, color={0,0,127}));
          connect(PID_valveTURB.SP, table_P.y[1])
            annotation (Line(points={{296,72},{339,72}}, color={0,0,127}));
          connect(LOAD1.y, table_T_FW.u[1]) annotation (Line(points={{-379,72},
                  {-362,72}},           color={0,0,127}));
          connect(table_T_FW.y[1], PID_valveBP.SP) annotation (Line(points={{
                  -339,72},{-318,72},{-296,72}}, color={0,0,127}));
          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-400,
                    -300},{400,300}})),           Icon(coordinateSystem(
                  preserveAspectRatio=false, extent={{-400,-300},{400,300}}), graphics={
                  Rectangle(extent={{-100,100},{100,-100}}, pattern=LinePattern.None),
                  Text(
                  extent={{-360,240},{360,-240}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  textString="PLANT
controller"),   Rectangle(
                  extent={{-100,100},{100,-100}},
                  pattern=LinePattern.None,
                  lineColor={0,0,0},
                  lineThickness=0.5),
                Rectangle(
                  extent={{-400,300},{400,-300}},
                  lineColor={0,0,0},
                  lineThickness=0.5)}));
        end plant_controller_HPpart_highLoad;
      end Old;
    end Control;

    package ComponentEmulator
      "Package containing emulator models to be implemented in the DCS"

      model turbineEmulator
        "Model that emulates the turbine mechanical power output"

        replaceable package Medium = Modelica.Media.Water.WaterIF97_ph
          constrainedby Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        parameter Real eta_iso_HPT "Isentropic efficiency of the HPT";
        parameter Real eta_iso_IPT "Isentropic efficiency of the IPT";
        parameter Real a "HPT power correction due to extractions";
        parameter Real b "IPT power correction due to extractions";

        Medium.ThermodynamicState inletFluidState_HPT
          "Thermodynamic state of the HPT inlet vapour";
        Medium.SpecificEntropy s_in_HPT "HPT inlet entropy";
        Medium.SpecificEnthalpy hout_iso_HPT
          "HPT outlet isentropic specific enthalpy";

        Medium.ThermodynamicState inletFluidState_IPT
          "Thermodynamic state of the IPT inlet vapour";
        Medium.SpecificEntropy s_in_IPT "IPT inlet entropy";
        Medium.SpecificEnthalpy hout_iso_IPT
          "IPT outlet isentropic specific enthalpy";
        Modelica.SIunits.AbsolutePressure p_out_IPT "IPT outlet pressure";

        Modelica.SIunits.Power P_mec_HPT "HPT mechanical power";
        Modelica.SIunits.Power P_mec_IPT "IPT mechanical power";

        Modelica.Blocks.Interfaces.RealInput w_in_HPT
          "HPT inlet mass flow rate"                                             annotation (Placement(transformation(
                extent={{-140,50},{-100,90}}), iconTransformation(extent={{-120,70},{-100,
                  90}})));
        Modelica.Blocks.Interfaces.RealInput h_in_HPT "HPT inlet enthalpy" annotation (Placement(transformation(
                extent={{-140,0},{-100,40}}),   iconTransformation(extent={{-120,20},{
                  -100,40}})));
        Modelica.Blocks.Interfaces.RealInput p_in_HPT "HPT inlet pressure" annotation (Placement(transformation(
                extent={{-140,-60},{-100,-20}}), iconTransformation(extent={{-120,-40},
                  {-100,-20}})));
        Modelica.Blocks.Interfaces.RealInput p_out_HPT "HPT outlet pressure" annotation (Placement(transformation(
                extent={{-120,-100},{-80,-60}}), iconTransformation(extent={{-120,-90},
                  {-100,-70}})));

        Modelica.Blocks.Interfaces.RealInput w_in_IPT
          "HPT inlet mass flow rate"                                            annotation (Placement(transformation(
                extent={{-140,50},{-100,90}}), iconTransformation(extent={{-10,-10},{10,
                  10}},
              rotation=270,
              origin={-80,110})));
        Modelica.Blocks.Interfaces.RealInput h_in_IPT "HPT inlet enthalpy"
                                                                          annotation (Placement(transformation(
                extent={{-140,0},{-100,40}}),   iconTransformation(extent={{-10,-10},{
                  10,10}},
              rotation=270,
              origin={-30,110})));
        Modelica.Blocks.Interfaces.RealInput p_in_IPT "HPT inlet pressure"
                                                                          annotation (Placement(transformation(
                extent={{-140,-60},{-100,-20}}), iconTransformation(extent={{-10,-10},
                  {10,10}},
              rotation=270,
              origin={30,110})));
        Modelica.Blocks.Interfaces.RealInput load "OTSG load"             annotation (Placement(transformation(
                extent={{-140,-60},{-100,-20}}), iconTransformation(extent={{-10,-10},
                  {10,10}},
              rotation=270,
              origin={80,110})));

        Modelica.Blocks.Interfaces.RealOutput P_mec "Mechanical power output" annotation (Placement(transformation(
                extent={{100,-10},{120,10}}), iconTransformation(extent={{100,-10},{120,
                  10}})));

      equation
        // Fluid properties
        inletFluidState_HPT = Medium.setState_ph(p_in_HPT, h_in_HPT);
        s_in_HPT = Medium.specificEntropy(inletFluidState_HPT);
        hout_iso_HPT = Medium.specificEnthalpy_ps(p_out_HPT,s_in_HPT);

        inletFluidState_IPT = Medium.setState_ph(p_in_IPT, h_in_IPT);
        s_in_IPT = Medium.specificEntropy(inletFluidState_IPT);
        hout_iso_IPT = Medium.specificEnthalpy_ps(p_out_IPT,s_in_IPT);
        p_out_IPT = (0.0343*load + 0.0103)*10^5;

        P_mec_HPT = (1 - a)*w_in_HPT*eta_iso_HPT*(h_in_HPT - hout_iso_HPT);
        P_mec_IPT = (1 - b)*w_in_IPT*eta_iso_IPT*(h_in_IPT - hout_iso_IPT);
        P_mec = P_mec_HPT + P_mec_IPT;

        annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
              Polygon(
                points={{40,20},{40,-20},{68,-46},{68,48},{40,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-60,20},{-60,-20},{-34,-44},{-34,48},{-60,20}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,8},{-60,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{-34,8},{40,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{68,8},{100,-8}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Text(
                extent={{-80,100},{80,60}},
                lineColor={28,108,200},
                textString="%name")}),      Diagram(coordinateSystem(
                preserveAspectRatio=false)));
      end turbineEmulator;

      model turbineExtractionCondenserEmulator
        "Static model of the power unit, turbine, extractions and condenser"

        replaceable package Medium = Modelica.Media.Water.WaterIF97_ph constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium"
          annotation (choicesAllMatching=true);

        parameter Integer n = 8 "Turbine corps number";
        parameter Real F_red_coeff[n,3]=
            [0.2847, -0.2685, 0.9371;
             0,       0,      0.9780;
             0.0253, -0.0602, 0.9990;
             0,      -0.0409, 0.9563;
             0.0065, -0.0222, 1.0007;
             0.0229, -0.0549, 0.9660;
             0.0452, -0.0836, 0.9915;
             0,       0,      1.0000] "Mass flow reduction matrix";
        parameter Real beta_coeff[n,4]=
            [0,      -0.4838, 0.3984, 2.1588;
             0,       0,      0,      1.7200;
             0,      -0.0665, 0.1919, 2.3597;
             0,       0,      0.0492, 1.5775;
             0,      -0.0839, 0.1900, 3.2110;
             0,      -0.0583, 0.1150, 1.7082;
             1.5004, -3.4960, 2.6320, 2.8019;
             0,      -3.9550, 7.1428, 1.2771]
          "Pressure ratio coefficients matrix";
        parameter Modelica.SIunits.ThermalConductance UA
          "Condenser thermal conductance";
        parameter Modelica.SIunits.MassFlowRate w_air "Nominal air mass flow";
        parameter Modelica.SIunits.SpecificHeatCapacity cp_air
          "Air specific heat capacity";
        parameter Real eta_mec "Mechanical turbine efficiency";
        Real eta_is[n] "Isentropi efficiency of turbine corps";
        Modelica.SIunits.AbsolutePressure p_valve "Turbine inlet pressure";
        Real F_red[n] "Mass flow reduction coefficients due to extractions";
        Real beta_nom[n] "Pressure ratios at nominal condensing pressure";
        Real beta[n] "Pressure ratios at actual condensing pressure";
        Real beta_tot_nom
          "Total pressure ratios at nominal condensing pressure";
        Real beta_tot "Total pressure ratios at actual condensing pressure";
        Modelica.SIunits.Power P_mec_sing[n] "Single corps power output";
        Modelica.SIunits.Power P_mec "Total mechanical power output";
        Modelica.SIunits.Power P_aux "Auxiliary power consumption";
        Modelica.SIunits.Power P_net "Net power output";
        Modelica.SIunits.Power Q_cond "Condenser thermal load";
        Real eta_I "First principle efficiency";
        Modelica.SIunits.MassFlowRate w_in[n]
          "Medium mass flow rate at corps inlet";
        Medium.AbsolutePressure p_cond "Actual condensation pressure";
        Medium.AbsolutePressure p_cond_nom "Nominal condensation pressure";
        Medium.Temperature T_cond "Actual condensation temperature";
        Medium.Temperature T_out_air "Outlet air temperature";
        Medium.SpecificEnthalpy h_in[n]
          "Medium inlet specific enthalpy at nth corp";
        Medium.SpecificEnthalpy h_out[n]
          "Medium outlet specific enthalpy at nth corp";
        Medium.SpecificEnthalpy hl
          "Bubble point specific enthalpy at condenser pressure";
        Medium.AbsolutePressure p_in[n] "Medium inlet pressure at nth corp";
        Medium.AbsolutePressure p_out[n] "Medium outlet pressure at nth corp";
        Medium.ThermodynamicState state_in[n]
          "Thermodynamic state of the inlet steam at nth corp";
          Medium.ThermodynamicState state_out[n]
          "Thermodynamic state of the outlet steam at nth corp";
        Medium.SaturationProperties sat
          "Saturation properties of the condenser";
        Real a(start=1,fixed=false);
        Modelica.Blocks.Interfaces.RealInput load annotation (Placement(
              transformation(extent={{-140,-60},{-100,-20}}), iconTransformation(
                extent={{-120,-50},{-100,-30}})));
        Modelica.Blocks.Interfaces.RealInput T_amb annotation (Placement(
              transformation(extent={{-140,20},{-100,60}}), iconTransformation(extent={{-120,30},
                  {-100,50}})));
        Modelica.Blocks.Interfaces.RealInput w_SH annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={-40,-120}), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={-60,-110})));
        Modelica.Blocks.Interfaces.RealInput T_SH annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={40,-120}), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,-110})));
        Modelica.Blocks.Interfaces.RealOutput Pm = P_net annotation (Placement(transformation(
                extent={{100,-10},{120,10}}), iconTransformation(extent={{100,10},{120,
                  30}})));

        Modelica.Blocks.Interfaces.RealInput T_RH annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={40,-120}), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={60,-110})));
      equation
        //Thermodynamic state definition
        sat = Medium.setSat_p(p_cond);
        p_cond_nom = (0.0338*load^2 + 0.053*load + 0.0369)*10^5;
        beta_tot = p_valve/p_cond;
        beta_tot_nom = p_valve/p_cond_nom;
        a^n = beta_tot/beta_tot_nom;
        hl = Medium.bubbleEnthalpy(sat);
        T_cond = Medium.saturationTemperature(p_cond);

        //Parameters definition
        eta_is[1] = if load > 0.50 then 0.8699 else 1.4285*load+0.14063;
        eta_is[2] = 0.86;
        eta_is[3] = 0.897;
        eta_is[4] = 0.8931;
        eta_is[5] = 0.8939;
        eta_is[6] = 0.9040;
        eta_is[7] = 0.9050;
        eta_is[8] = if load > 0.50 then 0.8931 else (-343.96*load^2 + 311.28*load + 18.991)/100;
        p_valve = (-27.006*load^2 + 203.24*load - 6.2262)*10^5;

        for j in 1:n loop
          F_red[j] = F_red_coeff[j,1]*load^2 + F_red_coeff[j,2]*load + F_red_coeff[j,3];
          beta_nom[j] = beta_coeff[j,1]*load^3 + beta_coeff[j,2]*load^2 + beta_coeff[j,3]*load + beta_coeff[j,4];
          beta[j] = beta_nom[j]*a;
          if j == 1 then
            w_in[j] = w_SH;
            p_in[j] = p_valve;
          else
            w_in[j] = w_in[j-1]*F_red[j];
            p_in[j] = p_out[j-1];
          end if;
          if j == 1 then
            state_in[j] = Medium.setState_pT(p_valve,T_SH);
            h_in[j] = Medium.specificEnthalpy(state_in[j]);
          elseif j == 3 then
            state_in[j] = Medium.setState_pT(p_in[j],T_RH);
            h_in[j] = Medium.specificEnthalpy(state_in[j]);
          else
            state_in[j] = Medium.setState_ph(p_in[j],h_in[j]);
            h_in[j] = h_out[j-1];
          end if;
          if j == 8 then
            p_out[j] = p_cond;
          else
            p_out[j] = p_in[j]/beta[j];
          end if;
          state_out[j] = Medium.setState_ph(p_out[j],h_out[j]);
          h_out[j] = h_in[j] - eta_is[j]*(h_in[j] - Medium.isentropicEnthalpy(p_out[j], state_in[j]));
          P_mec_sing[j] = w_in[j]*(h_in[j] - h_out[j]);
        end for;

        //Power definition
        P_mec = sum(P_mec_sing);
        P_net = P_mec*eta_mec - P_aux;
        Q_cond = w_in[8]*(h_out[8] - hl);
        Q_cond = UA*((T_out_air - T_amb)/log((T_cond - T_amb)/(T_cond - T_out_air)));
        Q_cond = w_air*cp_air*(T_out_air - T_amb);
        P_aux = (1.35*load^2 + 1.4563*load + 3.0135)*1e6*5/260;
        eta_I = P_net/(P_mec + Q_cond);

        annotation (Icon(graphics={
              Polygon(
                points={{40,40},{40,0},{68,-26},{68,68},{40,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-60,40},{-60,0},{-34,-24},{-34,68},{-60,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,28},{-60,12}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{-34,28},{40,12}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Rectangle(
                extent={{68,28},{100,12}},
                lineColor={0,0,0},
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={160,160,164}),
              Polygon(
                points={{-80,-40},{-60,-80},{60,-80},{80,-40},{-80,-40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={85,170,255}),
              Text(
                extent={{-26,86},{30,60}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={85,170,255},
                textString="Turbine"),
              Text(
                extent={{-28,-46},{28,-72}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={85,170,255},
                textString="Condenser")}));
      end turbineExtractionCondenserEmulator;

      model test_turbineExtractionCondenser
        "Test model of the power unit emulator"

        turbineExtractionCondenserEmulator turbineExtractionCondenserEmulator1(
          UA=246474.4,
          w_air=181.737,
          cp_air=1020,
          eta_mec=0.98)
          annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
        Modelica.Blocks.Sources.Ramp T_amb(
          duration=10,
          offset=301.15,
          startTime=100,
          height=2)
          annotation (Placement(transformation(extent={{-80,10},{-60,30}})));
        Modelica.Blocks.Sources.Ramp load(
          offset=100,
          startTime=100,
          duration=40,
          height=0)
          annotation (Placement(transformation(extent={{-80,-30},{-60,-10}})));
        Modelica.Blocks.Sources.Ramp w_SH(
          height=0,
          duration=10,
          startTime=100,
          offset=1.757)
          annotation (Placement(transformation(extent={{-40,-80},{-20,-60}})));
        Modelica.Blocks.Sources.Ramp T_SH(
          height=0,
          duration=10,
          startTime=100,
          offset=823.95)
          annotation (Placement(transformation(extent={{40,-80},{20,-60}})));
        Modelica.Blocks.Math.Gain gain(k=0.01)
          annotation (Placement(transformation(extent={{-52,-24},{-44,-16}})));
        Modelica.Blocks.Sources.Ramp T_RH(
          height=0,
          duration=10,
          startTime=100,
          offset=823.95)
          annotation (Placement(transformation(extent={{60,-50},{40,-30}})));
      equation
        connect(T_amb.y, turbineExtractionCondenserEmulator1.T_amb) annotation (
           Line(points={{-59,20},{-40,20},{-40,8},{-22,8}}, color={0,0,127}));
        connect(w_SH.y, turbineExtractionCondenserEmulator1.w_SH) annotation (
            Line(points={{-19,-70},{-12,-70},{-12,-22}}, color={0,0,127}));
        connect(load.y, gain.u)
          annotation (Line(points={{-59,-20},{-52.8,-20}}, color={0,0,127}));
        connect(gain.y, turbineExtractionCondenserEmulator1.load) annotation (
            Line(points={{-43.6,-20},{-40,-20},{-40,-8},{-22,-8}}, color={0,0,
                127}));
        connect(T_SH.y, turbineExtractionCondenserEmulator1.T_SH) annotation (
            Line(points={{19,-70},{10,-70},{0,-70},{0,-22}}, color={0,0,127}));
        connect(T_RH.y, turbineExtractionCondenserEmulator1.T_RH) annotation (
            Line(points={{39,-40},{24,-40},{12,-40},{12,-22}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)));
      end test_turbineExtractionCondenser;
    end ComponentEmulator;

    package Graphics "Package containing models used only for graphic purpose"

      block Label_input "Simple block to tag the input of the model"

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{100,24},{140,0},{100,-24},{100,24}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-100,40},{100,-40}},
                lineColor={0,0,0},
                fillColor={215,253,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-142,20},{148,-20}},
                lineColor={0,0,0},
                textString="%name"),
              Line(
                points={{140,0},{200,0}},
                color={0,0,0},
                thickness=0.5)}),       Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_input;

      block Label_output "Simple block to tag the output of the model"

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Rectangle(
                extent={{-100,40},{100,-40}},
                lineColor={0,0,0},
                fillColor={215,253,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-146,22},{144,-18}},
                lineColor={0,0,0},
                textString="%name"),
              Polygon(
                points={{-140,24},{-100,0},{-140,-24},{-140,24}},
                lineColor={0,0,0},
                fillColor={0,0,127},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-200,0},{-140,0}},
                color={0,0,0},
                thickness=0.5)}),       Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_output;

      block Label_flange_input "Simple block to tag the flanges of the model"

        parameter string flowName;
        parameter string from_to;

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{-100,40},{100,40},{140,0},{100,-40},{-100,-40},{-100,40}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-94,36},{100,0}},
                lineColor={0,0,0},
                textString="%flowName"),
              Text(
                extent={{-94,-4},{100,-40}},
                lineColor={0,0,0},
                textString="%from_to")}),  Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_flange_input;

      block Label_flange_output "Simple block to tag the flanges of the model"

        parameter string flowName;
        parameter string from_to;

        annotation (Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-40},{100,40}}),   graphics={
              Polygon(
                points={{-100,40},{100,40},{140,0},{100,-40},{-100,-40},{-100,40}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-94,36},{100,0}},
                lineColor={0,0,0},
                textString="%flowName"),
              Text(
                extent={{-94,-4},{100,-40}},
                lineColor={0,0,0},
                textString="%from_to")}),  Documentation(info="<html>
<p>
The (time varying) Real output signal of this block can be defined in its
parameter menu via variable <b>y</b>. The purpose is to support the
easy definition of Real expressions in a block diagram. For example,
in the y-menu the definition \"if time &lt; 1 then 0 else 1\" can be given in order
to define that the output signal is one, if time &ge; 1 and otherwise
it is zero. Note, that \"time\" is a built-in variable that is always
accessible and represents the \"model time\" and that
Variable <b>y</b> is both a variable and a connector.
</p>
</html>"),Diagram(coordinateSystem(extent={{-100,-40},{100,40}})));

      end Label_flange_output;
    end Graphics;
  end Pilot_245degC;

  package Auxiliaries
    "Package containing all the auxiliaries models (pumps, valves..)"

    package Components "Package containing auxiliaries models"

      model loadCalculator "Auxiliary box to evaluate the actual OTSG load"

        //-- Plant load --
        parameter Real load_start "Simulation start load [%]";
        parameter Real load_end "Simulation end load [%]";
        parameter Modelica.SIunits.Time t_ramp "Load ramp time [s]";
        parameter Modelica.SIunits.Time t_start "Start time [s]";

        Modelica.Blocks.Interfaces.RealOutput load annotation (Placement(transformation(
                extent={{-8,100},{12,120}}), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=0,
              origin={110,0})));

      equation
        load = load_start + (if time < t_start then 0 else if time < (t_start +
        t_ramp) then (time - t_start)*(load_end - load_start)/t_ramp else (load_end - load_start));

       annotation (Diagram(graphics), Icon(coordinateSystem(preserveAspectRatio=false,
                extent={{-100,-100},{100,100}}),
                                           graphics={Ellipse(
                    extent={{-70,70},{70,-70}},
                    lineColor={0,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid),Line(points={{0,70},{0,40}},
                color={0,0,0}),Line(points={{22.9,32.8},{40.2,57.3}}, color={0,0,0}),
                Line(points={{-22.9,32.8},{-40.2,57.3}}, color={0,0,0}),Line(points=
                 {{37.6,13.7},{65.8,23.9}}, color={0,0,0}),Line(points={{-37.6,13.7},
                {-65.8,23.9}}, color={0,0,0}),Line(points={{0,0},{9.02,28.6}},
                color={0,0,0}),Polygon(
                    points={{-0.48,31.6},{18,26},{18,57.2},{-0.48,31.6}},
                    lineColor={0,0,0},
                    fillColor={0,0,0},
                    fillPattern=FillPattern.Solid),Ellipse(
                    extent={{-5,5},{5,-5}},
                    lineColor={0,0,0},
                    fillColor={0,0,0},
                    fillPattern=FillPattern.Solid),Text(
                    extent={{-29,-11},{30,-70}},
                    lineColor={0,0,0},
                textString="L"),    Line(points={{-70,0},{-90,0}}, color={0,0,0}),
                Line(points={{100,0},{70,0}}, color={0,0,0}),Text(extent={{-100,72},{100,
                    100}},
                lineColor={0,0,0},
                textString="plant load"),       Line(points={{0,-70},{0,-84}},
                color={0,0,0})}));
      end loadCalculator;

      block Ramp_smooth
        "Generate ramp signal with an hyperbolical tangent or sinusoidal"
        parameter Real height=1 "Height of ramps";
        parameter Modelica.SIunits.Time duration(min=0.0, start=2)
          "Duration of ramp";
        parameter Real offset=0 "Offset of output signal";
        parameter Modelica.SIunits.Time startTime=0
          "Output = offset for time < startTime";
        parameter Integer sigType "1 = tanh, 2 = sin";
        Real alpha "Steep factor for tanh";
        Real omega "Sin frequency";
        extends Modelica.Blocks.Interfaces.SO;

        Modelica.Blocks.Interfaces.RealInput u annotation (Placement(transformation(
                extent={{-140,-20},{-100,20}}), iconTransformation(extent={{-140,-20},
                  {-100,20}})));
      equation
        tanh(-alpha*duration/2) = -1 + 1e-2;
        omega = Modelica.Constants.pi/duration;
        if sigType == 1 then
          y = height/2*tanh(alpha*(u - startTime - duration/2)) + height/2 + offset;
        elseif sigType == 2 then
          if u < startTime then
            y = offset;
          elseif u > startTime + duration then
            y = offset + height;
          else
            y = height/2*sin(omega*(u - startTime - duration/2)) + height/2 + offset;
          end if;
        else
            y = 0;
          assert(false, "Unsupported load signal option");
        end if;
        annotation (
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}}), graphics={
              Line(points={{-80,68},{-80,-80}}, color={192,192,192}),
              Polygon(
                points={{-80,90},{-88,68},{-72,68},{-80,90}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-90,-70},{82,-70}}, color={192,192,192}),
              Polygon(
                points={{90,-70},{68,-62},{68,-78},{90,-70}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-80,-70},{-40,-70},{31,38}}, color={0,0,0}),
              Text(
                extent={{-150,-150},{150,-110}},
                lineColor={0,0,0},
                textString="duration=%duration"),
              Line(points={{31,38},{86,38}}, color={0,0,0})}),
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}}), graphics={
              Polygon(
                points={{-80,90},{-86,68},{-74,68},{-80,90}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(points={{-80,68},{-80,-80}}, color={95,95,95}),
              Line(
                points={{-80,-20},{-20,-20},{50,50}},
                color={0,0,255},
                thickness=0.5),
              Line(points={{-90,-70},{82,-70}}, color={95,95,95}),
              Polygon(
                points={{90,-70},{68,-64},{68,-76},{90,-70}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-40,-20},{-42,-30},{-38,-30},{-40,-20}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-40,-20},{-40,-70}},
                color={95,95,95},
                thickness=0.25,
                arrow={Arrow.None,Arrow.None}),
              Polygon(
                points={{-40,-70},{-42,-60},{-38,-60},{-40,-70},{-40,-70}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-72,-39},{-34,-50}},
                lineColor={0,0,0},
                textString="offset"),
              Text(
                extent={{-38,-72},{6,-83}},
                lineColor={0,0,0},
                textString="startTime"),
              Text(
                extent={{-78,92},{-37,72}},
                lineColor={0,0,0},
                textString="y"),
              Text(
                extent={{70,-80},{94,-91}},
                lineColor={0,0,0},
                textString="time"),
              Line(points={{-20,-20},{-20,-70}}, color={95,95,95}),
              Line(
                points={{-19,-20},{50,-20}},
                color={95,95,95},
                thickness=0.25,
                arrow={Arrow.None,Arrow.None}),
              Line(
                points={{50,50},{101,50}},
                color={0,0,255},
                thickness=0.5),
              Line(
                points={{50,50},{50,-20}},
                color={95,95,95},
                thickness=0.25,
                arrow={Arrow.None,Arrow.None}),
              Polygon(
                points={{50,-20},{42,-18},{42,-22},{50,-20}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-20,-20},{-11,-18},{-11,-22},{-20,-20}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{50,50},{48,40},{52,40},{50,50}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{50,-20},{48,-10},{52,-10},{50,-20},{50,-20}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{53,23},{82,10}},
                lineColor={0,0,0},
                textString="height"),
              Text(
                extent={{-2,-21},{37,-33}},
                lineColor={0,0,0},
                textString="duration")}),
          Documentation(info="<html>
<p>
The Real output y is a ramp signal:
</p>

<p>
<img src=\"modelica://Modelica/Resources/Images/Blocks/Sources/Ramp.png\"
     alt=\"Ramp.png\">
</p>

<p>
If parameter duration is set to 0.0, the limiting case of a Step signal is achieved.
</p>
</html>"));
      end Ramp_smooth;

      model powerSensor
        "Component with mechanical flange to create the mechanical power signal in bus-form"

        parameter Real eta_mec = 0.98;

        Modelica.Mechanics.Rotational.Sensors.PowerSensor powerSensor
          annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
        Modelica.Mechanics.Rotational.Interfaces.Flange_b shaft_flange_out
          annotation (Placement(transformation(extent={{70,-10},{90,10}}),
              iconTransformation(extent={{100,-10},{120,10}})));
        Modelica.Icons.SignalBus signalBus annotation (Placement(transformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={-60,-60}), iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=180,
              origin={0,-100})));
        Modelica.Mechanics.Rotational.Interfaces.Flange_a shaft_flange_out1
          annotation (Placement(transformation(extent={{-90,-10},{-70,10}}),
              iconTransformation(extent={{-120,-10},{-100,10}})));
        Modelica.Blocks.Math.Gain gain(k=-eta_mec)
                                             annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-16,-42})));
      equation
        connect(powerSensor.flange_b, shaft_flange_out)
          annotation (Line(points={{20,0},{80,0}}, color={0,0,0}));
        connect(powerSensor.flange_a, shaft_flange_out1)
          annotation (Line(points={{-20,0},{-26,0},{-80,0}}, color={0,0,0}));
        connect(powerSensor.power, gain.u)
          annotation (Line(points={{-16,-22},{-16,-30}}, color={0,0,127}));
        connect(signalBus.pumpMS_PV, gain.y) annotation (Line(
            points={{-60,-60},{-16,-60},{-16,-53}},
            color={255,204,51},
            thickness=0.5));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
                Rectangle(
                extent={{-100,100},{100,-100}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid), Text(
                extent={{-44,46},{52,-46}},
                lineColor={0,0,0},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid,
                textString="Power
sensor")}),   Diagram(coordinateSystem(preserveAspectRatio=false)));
      end powerSensor;

      model SensDT_sh "Degree of superheating sensor for water-steam"
        extends ThermoPower.Icons.Water.SensThrough;
        replaceable package Medium = ThermoPower.Water.StandardWater constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);
        parameter Boolean allowFlowReversal=system.allowFlowReversal
          "= true to allow flow reversal, false restricts to design direction";
        outer ThermoPower.System system "System wide properties";
        Medium.SpecificEnthalpy h "Specific enthalpy of the fluid";
        Medium.SpecificEnthalpy hv "Specific dew enthalpy of the fluid";
        Medium.ThermodynamicState fluidState "Thermodynamic state of the fluid";
        Medium.SaturationProperties sat "Saturation state of the fluid";
        Medium.Temperature T "Actual temperature of the fluid";
        Medium.Temperature T_sat "Saturation temperature of the fluid";
        ThermoPower.Water.FlangeA inlet(redeclare package Medium = Medium, m_flow(min=
               if allowFlowReversal then -Modelica.Constants.inf else 0)) annotation (
           Placement(transformation(extent={{-80,-60},{-40,-20}}, rotation=0)));
        ThermoPower.Water.FlangeB outlet(redeclare package Medium = Medium, m_flow(
              max=if allowFlowReversal then +Modelica.Constants.inf else 0))
          annotation (Placement(transformation(extent={{40,-60},{80,-20}}, rotation=0)));
        Modelica.Blocks.Interfaces.RealOutput DT_sh annotation (Placement(
              transformation(extent={{60,40},{100,80}}, rotation=0)));
      equation
        inlet.m_flow + outlet.m_flow = 0 "Mass balance";
        inlet.p = outlet.p "No pressure drop";
        // Set fluid properties
        h = homotopy(if not allowFlowReversal then inStream(inlet.h_outflow) else
          actualStream(inlet.h_outflow), inStream(inlet.h_outflow));
        fluidState = Medium.setState_ph(inlet.p, h);
        sat = Medium.setSat_p(inlet.p);
        hv = Medium.dewEnthalpy(sat);
        T = Medium.temperature(fluidState);
        T_sat = Medium.saturationTemperature(inlet.p);
        DT_sh = if h <= hv then 0  else T - T_sat;

        // Boundary conditions
        inlet.h_outflow = inStream(outlet.h_outflow);
        inStream(inlet.h_outflow) = outlet.h_outflow;
        annotation (
          Diagram(graphics),
          Icon(graphics={Text(
                extent={{-40,84},{38,34}},
                lineColor={0,0,0},
                textString="DT")}),
          Documentation(info="<HTML>
<p>This component can be inserted in a hydraulic circuit to measure the temperature of the fluid flowing through it.
<p>Flow reversal is supported.
</HTML>",     revisions="<html>
<ul>
<li><i>16 Dec 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Standard medium definition added.</li>
<li><i>1 Jul 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted to Modelica.Media.</li>
<li><i>1 Oct 2003</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       First release.</li>
</ul>
</html>"));
      end SensDT_sh;

      model SensDT_sc "Degree of subcooling sensor for water-steam"
        extends ThermoPower.Icons.Water.SensThrough;
        replaceable package Medium = ThermoPower.Water.StandardWater constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);
        parameter Boolean allowFlowReversal=system.allowFlowReversal
          "= true to allow flow reversal, false restricts to design direction";
        outer ThermoPower.System system "System wide properties";
        Medium.SpecificEnthalpy h "Specific enthalpy of the fluid";
        Medium.SpecificEnthalpy hl "Specific dew enthalpy of the fluid";
        Medium.ThermodynamicState fluidState "Thermodynamic state of the fluid";
        Medium.SaturationProperties sat "Saturation state of the fluid";
        Medium.Temperature T "Actual temperature of the fluid";
        Medium.Temperature T_sat "Saturation temperature of the fluid";
        ThermoPower.Water.FlangeA inlet(redeclare package Medium = Medium, m_flow(min=
               if allowFlowReversal then -Modelica.Constants.inf else 0)) annotation (
           Placement(transformation(extent={{-80,-60},{-40,-20}}, rotation=0)));
        ThermoPower.Water.FlangeB outlet(redeclare package Medium = Medium, m_flow(
              max=if allowFlowReversal then +Modelica.Constants.inf else 0))
          annotation (Placement(transformation(extent={{40,-60},{80,-20}}, rotation=0)));
        Modelica.Blocks.Interfaces.RealOutput DT_sc annotation (Placement(
              transformation(extent={{60,40},{100,80}}, rotation=0)));
      equation
        inlet.m_flow + outlet.m_flow = 0 "Mass balance";
        inlet.p = outlet.p "No pressure drop";
        // Set fluid properties
        h = homotopy(if not allowFlowReversal then inStream(inlet.h_outflow) else
          actualStream(inlet.h_outflow), inStream(inlet.h_outflow));
        fluidState = Medium.setState_ph(inlet.p, h);
        sat = Medium.setSat_p(inlet.p);
        hl = Medium.bubbleEnthalpy(sat);
        T = Medium.temperature(fluidState);
        T_sat = Medium.saturationTemperature(inlet.p);
        DT_sc = if h >= hl then 0  else T_sat - T;

        // Boundary conditions
        inlet.h_outflow = inStream(outlet.h_outflow);
        inStream(inlet.h_outflow) = outlet.h_outflow;
        annotation (
          Icon(graphics={Text(
                extent={{-40,84},{38,34}},
                lineColor={0,0,0},
                textString="DT")}),
          Documentation(info="<HTML>
<p>This component can be inserted in a hydraulic circuit to measure the temperature of the fluid flowing through it.
<p>Flow reversal is supported.
</HTML>",     revisions="<html>
<ul>
<li><i>16 Dec 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Standard medium definition added.</li>
<li><i>1 Jul 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted to Modelica.Media.</li>
<li><i>1 Oct 2003</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       First release.</li>
</ul>
</html>"));
      end SensDT_sc;

      model pump_constEfficiency
        "Pump model with ideally mass flow control and constant isentropic efficiency"

        replaceable package Medium =
            Modelica.Media.Water.WaterIF97_ph "Water/steam fluid medium model";
        parameter Boolean use_in_w0 = false
          "Use connector input for the mass flow"
          annotation(Dialog(group="External inputs"), choices(checkBox=true));
        parameter Modelica.SIunits.MassFlowRate w0 "Nominal mass flow rate";
        parameter Real eta_iso "Constant isentropic efficiency";

        Modelica.Blocks.Interfaces.RealInput in_w0 if use_in_w0 "kg/s" annotation (Placement(
              transformation(
              origin={-26,80},
              extent={{-10,-10},{10,10}},
              rotation=270), iconTransformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={0,90})));
        Medium.ThermodynamicState inletFluidState
          "Thermodynamic state of the inlet liquid";
        Medium.ThermodynamicState outletFluidState
          "Thermodynamic state of the inlet liquid";
        Medium.Density rho "Inlet density";
        Medium.Temperature Tin "Inlet temperature";
        Medium.Temperature Tout "Outlet temperature";
        Medium.SpecificEntropy sin "Inlet entropy";
        Medium.SpecificEnthalpy hin "Inlet specific enthalpy";
        Medium.SpecificEnthalpy hout "Outlet specific enthalpy";
        Medium.SpecificEnthalpy hout_iso "Outlet isentropic specific enthalpy";
        Modelica.SIunits.MassFlowRate w "Mass flow rate";
        Modelica.SIunits.AbsolutePressure dp "Pressure increase";

      protected
        Modelica.Blocks.Interfaces.RealInput in_w0_int
          "Internal connector for mass flow";

      public
        ThermoPower.Water.FlangeA
                infl(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{-100,0},{-60,40}},
                rotation=0), iconTransformation(extent={{-100,0},{-60,40}})));
        ThermoPower.Water.FlangeB
                outfl(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{40,50},{80,90}}, rotation=
                 0), iconTransformation(extent={{40,50},{80,90}})));

      equation
        // Fluid properties
        inletFluidState = Medium.setState_ph(infl.p, hin);
        rho = Medium.density(inletFluidState);
        Tin = Medium.temperature(inletFluidState);
        sin = Medium.specificEntropy(inletFluidState);
        hout_iso = Medium.specificEnthalpy_ps(outfl.p,sin);
        outletFluidState = Medium.setState_ph(outfl.p, hout);
        Tout = Medium.temperature(outletFluidState);

        // Boundary conditions
        connect(in_w0,in_w0_int);
        dp = outfl.p - infl.p;
        w = in_w0_int;
        w = infl.m_flow;
        if not use_in_w0 then
          in_w0_int = w0 "Flow rate set by parameter";
        end if;
        hin = homotopy(if w >= 0 then inStream(infl.h_outflow)
                       else inStream(outfl.h_outflow),
                       inStream(infl.h_outflow));
        infl.h_outflow = hout;
        outfl.h_outflow = hout;

        // Mass and energy balances
        infl.m_flow + outfl.m_flow = 0 "Mass balance";
        hout - hin = (hout_iso - hin)/eta_iso "Energy balance";

        annotation (Icon(graphics={
              Polygon(
                points={{-40,-24},{-60,-60},{60,-60},{40,-24},{-40,-24}},
                lineColor={0,0,255},
                pattern=LinePattern.None,
                fillColor={0,0,191},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-60,80},{60,-40}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Sphere,
                fillColor={0,0,255}),
              Polygon(
                points={{-30,52},{-30,-8},{48,20},{-30,52}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={255,255,255}),
              Text(extent={{-100,-64},{100,-90}}, textString="%name")}));
      end pump_constEfficiency;

      model EletHeater
        "Model of an electrical heater with resistance walls inertia"
        extends ThermoPower.Icons.Water.Header;
        replaceable package Medium = ThermoPower.Water.StandardWater constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);
        Medium.ThermodynamicState fluidState "Thermodynamic state of the fluid";
        parameter Modelica.SIunits.Volume V "Inner volume";
        parameter Modelica.SIunits.Area S=0 "Internal surface";
        parameter Modelica.SIunits.Position H=0
          "Elevation of outlet over inlet"
          annotation (Evaluate=true);
        parameter Modelica.SIunits.CoefficientOfHeatTransfer gamma=0
          "Heat Transfer Coefficient" annotation (Evaluate=true);
        parameter Modelica.SIunits.Mass Mm "Metal wall mass";
        parameter Modelica.SIunits.SpecificHeatCapacity cm=0
          "Metal Specific Heat Capacity"
          annotation (Evaluate=true);
        parameter Boolean allowFlowReversal=system.allowFlowReversal
          "= true to allow flow reversal, false restricts to design direction";
        outer ThermoPower.System system "System wide properties";
        parameter ThermoPower.Choices.FluidPhase.FluidPhases FluidPhaseStart=
            ThermoPower.Choices.FluidPhase.FluidPhases.Liquid
          "Fluid phase (only for initialization!)"
          annotation (Dialog(tab="Initialisation"));
        parameter Medium.AbsolutePressure pstart "Pressure start value"
          annotation (Dialog(tab="Initialisation"));
        parameter Medium.SpecificEnthalpy hstart=if FluidPhaseStart ==ThermoPower.Choices.FluidPhase.FluidPhases.Liquid
             then 1e5 else if FluidPhaseStart ==ThermoPower.Choices.FluidPhase.FluidPhases.Steam
             then 3e6 else 1e6 "Specific enthalpy start value"
          annotation (Dialog(tab="Initialisation"));
        parameter Medium.Temperature Tmstart=300
          "Metal wall temperature start value"
          annotation (Dialog(tab="Initialisation"));
        parameter ThermoPower.Choices.Init.Options initOpt=system.initOpt
          "Initialisation option" annotation (Dialog(tab="Initialisation"));
        parameter Boolean noInitialPressure=false
          "Remove initial equation on pressure"
          annotation (Dialog(tab="Initialisation"),choices(checkBox=true));

        ThermoPower.Water.FlangeA inlet(
          h_outflow(start=hstart),
          redeclare package Medium = Medium,
          m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0))
          annotation (Placement(transformation(extent={{-122,-20},{-80,20}}, rotation=
                 0), iconTransformation(extent={{-120,-20},{-80,20}})));
        ThermoPower.Water.FlangeB outlet(
          h_outflow(start=hstart),
          redeclare package Medium = Medium,
          m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0))
          annotation (Placement(transformation(extent={{80,-20},{120,20}}, rotation=0)));
        Medium.AbsolutePressure p(start=pstart, stateSelect=if Medium.singleState then StateSelect.avoid
               else StateSelect.prefer) "Fluid pressure at the outlet";
        Medium.SpecificEnthalpy h(start=hstart, stateSelect=StateSelect.prefer)
          "Fluid specific enthalpy";
        Medium.SpecificEnthalpy hi "Inlet specific enthalpy";
        Medium.SpecificEnthalpy ho "Outlet specific enthalpy";
        Modelica.SIunits.Mass M "Fluid mass";
        Modelica.SIunits.Energy E "Fluid energy";
        Medium.Temperature T "Fluid temperature";
        Medium.Temperature Tm(start=Tmstart) "Wall temperature";
        Modelica.SIunits.Time Tr "Residence time";
        Real dM_dt;
        Real dE_dt;
        Modelica.Blocks.Interfaces.RealInput Q_th annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=270,
              origin={0,80})));
      equation
        // Set fluid properties
        fluidState = Medium.setState_ph(p, h);
        T = Medium.temperature(fluidState);

        M = V*Medium.density(fluidState) "Fluid mass";
        E = M*h - p*V "Fluid energy";
        dM_dt = V*(Medium.density_derp_h(fluidState)*der(p) + Medium.density_derh_p(
          fluidState)*der(h));
        dE_dt = h*dM_dt + M*der(h) - V*der(p);
        dM_dt = inlet.m_flow + outlet.m_flow "Fluid mass balance";
        dE_dt = inlet.m_flow*hi + outlet.m_flow*ho + gamma*S*(Tm - T)
          "Fluid energy balance";
        if cm > 0 and gamma > 0 then
          Mm*cm*der(Tm) = gamma*S*(T - Tm) + Q_th
            "Energy balance of the built-in wall model";
        else
          Tm = T "Trivial equation for metal temperature";
        end if;

        // Boundary conditions
        hi = homotopy(if not allowFlowReversal then inStream(inlet.h_outflow) else
          actualStream(inlet.h_outflow), inStream(inlet.h_outflow));
        ho = homotopy(if not allowFlowReversal then h else actualStream(outlet.h_outflow),
          h);
        inlet.h_outflow = h;
        outlet.h_outflow = h;
        inlet.p = p + Medium.density(fluidState)*Modelica.Constants.g_n*H;
        outlet.p = p;

        Tr = noEvent(M/max(abs(inlet.m_flow), Modelica.Constants.eps))
          "Residence time";
      initial equation
        // Initial conditions
        if initOpt == ThermoPower.Choices.Init.Options.noInit then
          // do nothing
        elseif initOpt == ThermoPower.Choices.Init.Options.fixedState then
          if not noInitialPressure then
            p = pstart;
          end if;
          h = hstart;
          if (cm > 0 and gamma > 0) then
            Tm = Tmstart;
          end if;
        elseif initOpt == ThermoPower.Choices.Init.Options.steadyState then
          der(h) = 0;
          if (not Medium.singleState and not noInitialPressure) then
            der(p) = 0;
          end if;
          if (cm > 0 and gamma > 0) then
            der(Tm) = 0;
          end if;
        elseif initOpt == ThermoPower.Choices.Init.Options.steadyStateNoP then
          der(h) = 0;
          if (cm > 0 and gamma > 0) then
            der(Tm) = 0;
          end if;
        else
          assert(false, "Unsupported initialisation option");
        end if;
        annotation (
          Documentation(info="<HTML>
<p>This model describes a constant volume header with metal walls. The fluid can be water, steam, or a two-phase mixture.
<p>It is possible to take into account the heat storage and transfer in the metal wall in two ways:
<ul>
<li>
  Leave <tt>InternalSurface</tt> unconnected, and set the appropriate
  values for the total wall heat capacity <tt>Cm</tt>, surface <tt>S</tt>
  and heat transfer coefficient <tt>gamma</tt>. In this case, the metal
  wall temperature is considered as uniform, and the wall is thermally
  insulated from the outside.
</li>
<li>
  Set <tt>Cm = 0</tt>, and connect a suitable thermal model of the the
  wall to the <tt>InternalSurface</tt> connector instead. This can be
  useful in case a more detailed thermal model is needed, e.g. for
  thermal stress studies.
</li>
</ul>
<p>The model can represent an actual header when connected to the model of a bank of tubes (e.g., <tt>Flow1D</tt> with <tt>Nt>1</tt>).</p>
</HTML>",     revisions="<html>
<ul>
<li><i>30 May 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Initialisation support added.</li>
<li><i>12 Apr 2005</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       <tt>InternalSurface</tt> connector added.</li>
<li><i>16 Dec 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Standard medium definition added.</li>
<li><i>28 Jul 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Added head between inlet and outlet.</li>
<li><i>7 Jul 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Changed name from <tt>Collector</tt> to <tt>Header</tt>.</li>
<li><i>18 Jun 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted to Modelica.Media.</li>
<li><i>1 Oct 2003</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       First release.</li>
</ul>
</html>
"));
      end EletHeater;

      model ThreeWayValve_2out "Model of a liquid three way valve"

        replaceable package Medium = Modelica.Media.Water.WaterIF97OnePhase_ph constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        ThermoPower.Water.FlangeA inlet(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{-110,-10},{-90,10}}),
              iconTransformation(extent={{-120,-20},{-80,20}})));
        ThermoPower.Water.FlangeB outlet2(redeclare package Medium = Medium)
                                          annotation (Placement(transformation(extent=
                 {{-10,90},{10,110}}), iconTransformation(extent={{-20,80},{20,120}})));
        ThermoPower.Water.FlangeB outlet1(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{90,-10},{110,10}}),
              iconTransformation(extent={{80,-20},{120,20}})));
        Modelica.Blocks.Interfaces.RealInput theta "Valve opening in per unit"
          annotation (Placement(transformation(
              origin={-80,-40},
              extent={{-20,-20},{20,20}},
              rotation=0), iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={0,-80})));
        ThermoPower.Water.ValveLiq valve2(
          redeclare package Medium = Medium,
          wnom=1.6,
          CheckValve=true,
          useThetaInput=true,
          Av=3e-4,
          pnom=9150000,
          dpnom=30000,
          pin_start=9150000) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=90,
              origin={0,50})));
        ThermoPower.Water.ValveLiq valve1(
          redeclare package Medium = Medium,
          wnom=1.6,
          CheckValve=true,
          useThetaInput=true,
          Av=3e-4,
          pnom=9150000,
          dpnom=30000,
          pin_start=9150000)
          annotation (Placement(transformation(extent={{30,10},{50,-10}})));
        Modelica.Blocks.Math.Add add(k2=-1)
          annotation (Placement(transformation(extent={{-36,44},{-24,56}})));
        Modelica.Blocks.Sources.Constant const(k=1)
          annotation (Placement(transformation(extent={{-80,60},{-60,80}})));
      equation
        connect(const.y, add.u1) annotation (Line(points={{-59,70},{-54,70},{-50,70},{
                -50,53.6},{-37.2,53.6}}, color={0,0,127}));
        connect(theta, add.u2) annotation (Line(points={{-80,-40},{-80,-40},{-50,-40},
                {-50,46.4},{-37.2,46.4}}, color={0,0,127}));
        connect(theta,valve1. theta)
          annotation (Line(points={{-80,-40},{40,-40},{40,-8}}, color={0,0,127}));
        connect(add.y, valve2.theta) annotation (Line(points={{-23.4,50},{-15.7,
                50},{-8,50}}, color={0,0,127}));
        connect(valve1.outlet, outlet1)
          annotation (Line(points={{50,0},{76,0},{100,0}}, color={0,0,255}));
        connect(inlet, valve1.inlet)
          annotation (Line(points={{-100,0},{30,0}}, color={0,0,255}));
        connect(inlet, valve2.inlet) annotation (Line(points={{-100,0},{-50,0},
                {0,0},{0,40}}, color={0,0,255}));
        connect(outlet2, valve2.outlet)
          annotation (Line(points={{0,100},{0,60}}, color={0,0,255}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
              Polygon(
                points={{-80,40},{-80,-40},{0,0},{-80,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255}),
              Polygon(
                points={{80,40},{0,0},{80,-40},{80,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255}),
              Rectangle(
                extent={{-20,-40},{20,-60}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Line(
                points={{0,0},{0,-40}},
                color={0,0,0},
                thickness=0.5),
                         Text(extent={{-244,92},{-44,52}},   textString="%name"),
              Polygon(
                points={{40,40},{-40,0},{40,-40},{40,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255},
                origin={0,40},
                rotation=90)}), Diagram(coordinateSystem(preserveAspectRatio=false)),
          Documentation(info="<html>
<p>Theta = 1 --&GT; branch 2 closed, theta = 0 --&GT; branch 1 closed.</p>
</html>"));
      end ThreeWayValve_2out;

      model ThreeWayValve_2in "Model of a liquid three way valve"

        replaceable package Medium = Modelica.Media.Water.WaterIF97OnePhase_ph constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);

        ThermoPower.Water.FlangeB outlet(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{-110,-10},{-90,10}}),
              iconTransformation(extent={{-120,-20},{-80,20}})));
        ThermoPower.Water.FlangeA inlet2(redeclare package Medium = Medium)
                                          annotation (Placement(transformation(extent=
                 {{-10,90},{10,110}}), iconTransformation(extent={{-20,80},{20,120}})));
        ThermoPower.Water.FlangeA inlet1(redeclare package Medium = Medium)
          annotation (Placement(transformation(extent={{90,-10},{110,10}}),
              iconTransformation(extent={{80,-20},{120,20}})));
        Modelica.Blocks.Interfaces.RealInput theta "Valve opening in per unit"
          annotation (Placement(transformation(
              origin={-80,-40},
              extent={{-20,-20},{20,20}},
              rotation=0), iconTransformation(
              extent={{-20,-20},{20,20}},
              rotation=90,
              origin={0,-80})));
        ThermoPower.Water.ValveLiq valve2(
          redeclare package Medium = Medium,
          wnom=1.6,
          CheckValve=true,
          useThetaInput=true,
          Av=3e-4,
          pnom=9150000,
          dpnom=30000,
          pin_start=9150000) annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=90,
              origin={0,50})));
        ThermoPower.Water.ValveLiq valve1(
          redeclare package Medium = Medium,
          wnom=1.6,
          CheckValve=true,
          useThetaInput=true,
          Av=3e-4,
          pnom=9150000,
          dpnom=30000,
          pin_start=9150000)
          annotation (Placement(transformation(extent={{50,10},{30,-10}})));
        Modelica.Blocks.Math.Add add(k2=-1)
          annotation (Placement(transformation(extent={{-36,44},{-24,56}})));
        Modelica.Blocks.Sources.Constant const(k=1)
          annotation (Placement(transformation(extent={{-80,60},{-60,80}})));
      equation
        connect(const.y, add.u1) annotation (Line(points={{-59,70},{-54,70},{-50,70},{
                -50,53.6},{-37.2,53.6}}, color={0,0,127}));
        connect(theta, add.u2) annotation (Line(points={{-80,-40},{-80,-40},{-50,-40},
                {-50,46.4},{-37.2,46.4}}, color={0,0,127}));
        connect(theta,valve1. theta)
          annotation (Line(points={{-80,-40},{40,-40},{40,-8}}, color={0,0,127}));
        connect(add.y, valve2.theta) annotation (Line(points={{-23.4,50},{-15.7,
                50},{-8,50}}, color={0,0,127}));
        connect(inlet2, valve2.inlet)
          annotation (Line(points={{0,100},{0,100},{0,60}}, color={0,0,255}));
        connect(valve1.inlet, inlet1)
          annotation (Line(points={{50,0},{76,0},{100,0}}, color={0,0,255}));
        connect(outlet, valve1.outlet)
          annotation (Line(points={{-100,0},{-36,0},{30,0}}, color={0,0,255}));
        connect(valve2.outlet, outlet) annotation (Line(points={{-6.66134e-016,
                40},{0,40},{0,22},{0,0},{-100,0}}, color={0,0,255}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
              Polygon(
                points={{-80,40},{-80,-40},{0,0},{-80,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255}),
              Polygon(
                points={{80,40},{0,0},{80,-40},{80,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255}),
              Rectangle(
                extent={{-20,-40},{20,-60}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Line(
                points={{0,0},{0,-40}},
                color={0,0,0},
                thickness=0.5),
                         Text(extent={{-244,92},{-44,52}},   textString="%name"),
              Polygon(
                points={{40,40},{-40,0},{40,-40},{40,40}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillPattern=FillPattern.Solid,
                fillColor={0,0,255},
                origin={0,40},
                rotation=90)}), Diagram(coordinateSystem(preserveAspectRatio=false)),
          Documentation(info="<html>
<p>Theta = 1 --&GT; branch 2 closed, theta = 0 --&GT; branch 1 closed.</p>
</html>"));
      end ThreeWayValve_2in;

      model MSmixer "Model of the hot/cold molten salt mixing for hot start up"

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-140,30},{-120,50}})));
        ThermoPower.Water.Pump coldPump(
          use_in_n=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          rho0=1905.6,
          n0=1750,
          w0=9,
          redeclare function efficiencyCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.constantEfficiency (
                eta_nom=0.8),
          allowFlowReversal=false,
          s(start=1),
          redeclare function flowCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.polynomialFlow (
                head_nom={22.8,22.1,21.5,20.8,19.1,17.5,14.5,13}, q_nom={0.1/
                  3600,3.4/3600,6.8/3600,10.2/3600,13.6/3600,17/3600,20.4/3600,
                  21.505/3600}),
          CheckValve=true,
          V=0.001,
          dp0=327137)
          annotation (Placement(transformation(extent={{-62,28},{-42,48}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-98,34},{-78,54}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{20,6},{40,-14}})));
        ThermoPower.Water.SourceMassFlow hotPump(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-100,0},{-80,-20}})));
        Modelica.Blocks.Sources.Constant const2(k=4.43137e5)
          annotation (Placement(transformation(extent={{140,70},{120,90}})));
        IndustrialControlSystems.Controllers.PI pI(
          AntiWindup=true,
          CSmax=14,
          CSmin=0.001,
          Kp=0.05,
          Ti=20,
          useTS=true,
          CS_start=2.392)
          annotation (Placement(transformation(extent={{10,-60},{-10,-80}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-20,-80},{-40,-60}})));
        Modelica.Blocks.Math.Add3 add3
          annotation (Placement(transformation(extent={{60,-86},{40,-66}})));
        Modelica.Blocks.Sources.Constant const3(k=0)
          annotation (Placement(transformation(extent={{100,-60},{80,-40}})));
        Modelica.Blocks.Sources.Step step(
          offset=0,
          startTime=10000,
          height=0)
          annotation (Placement(transformation(extent={{100,-90},{80,-70}})));
        Modelica.Blocks.Sources.Ramp ramp(
          height=-275,
          duration=4000,
          offset=838.15,
          startTime=4000)
          annotation (Placement(transformation(extent={{100,-120},{80,-100}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          V=0.01,
          noInitialPressure=false,
          pstart=443000,
          initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-20,60},{-40,80}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(
            startValue=true, startTime=4000)
          annotation (Placement(transformation(extent={{-40,-130},{-20,-110}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{60,-6},{80,14}})));
        IndustrialControlSystems.Controllers.PI pI1(
          CSmax=1750,
          Ti=5,
          Kp=0.1,
          useTS=true,
          CSmin=100,
          CS_start=1500)
          annotation (Placement(transformation(extent={{20,60},{0,80}})));
        Modelica.Blocks.Sources.Ramp w_tot(
          offset=1.5,
          height=11.96 - w_tot.offset,
          startTime=4000,
          duration=4000)
          annotation (Placement(transformation(extent={{80,100},{60,120}})));
        Modelica.Blocks.Sources.Constant const5(k=1000)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        ThermoPower.Water.FlangeB flangeB(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{150,-10},{170,10}})));
        Modelica.Icons.SignalBus signalBus
          annotation (Placement(transformation(extent={{-100,-140},{-60,-100}}),
              iconTransformation(extent={{-20,-160},{20,-120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(
            startValue=true, startTime=4000)
          annotation (Placement(transformation(extent={{-40,100},{-20,120}})));
        Modelica.Blocks.Logical.Switch switch
          annotation (Placement(transformation(extent={{-60,-68},{-80,-88}})));
        Modelica.Blocks.Sources.Constant const1(k=2.392)
          annotation (Placement(transformation(extent={{34,-110},{14,-90}})));
        ThermoPower.Water.PressDrop pressDrop(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          wnom=11.96,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          rhonom=1900,
          w(start=1.5),
          dpnom=950000)
          annotation (Placement(transformation(extent={{100,-10},{120,10}})));
        Modelica.Blocks.Sources.Ramp w_tot1(
          startTime=4000,
          duration=4000,
          height=-1,
          offset=2.392)
          annotation (Placement(transformation(extent={{80,66},{60,86}})));
      equation
        connect(sensT_cold.outlet, coldPump.infl) annotation (Line(points={{-82,
                40},{-70,40},{-66,40},{-60,40}}, color={0,0,255}));
        connect(sourcePressure.flange,sensT_cold. inlet)
          annotation (Line(points={{-120,40},{-108,40},{-102,40},{-94,40}},
                                                     color={0,0,255}));
        connect(sensT_mix.T,pI. PV) annotation (Line(points={{38,-10},{40,-10},
                {40,-30},{20,-30},{20,-69},{8,-69}},
                                                   color={0,0,127}));
        connect(firstOrder.u,pI. CS)
          annotation (Line(points={{-18,-70},{-9,-70}},  color={0,0,127}));
        connect(pI.SP,add3. y)
          annotation (Line(points={{8,-76},{39,-76}},  color={0,0,127}));
        connect(const3.y,add3. u1) annotation (Line(points={{79,-50},{72,-50},{
                72,-68},{62,-68}},
                           color={0,0,127}));
        connect(step.y,add3. u2) annotation (Line(points={{79,-80},{72,-80},{72,
                -76},{62,-76}},
                          color={0,0,127}));
        connect(ramp.y,add3. u3) annotation (Line(points={{79,-110},{72,-110},{
                72,-84},{62,-84}},
                          color={0,0,127}));
        connect(coldPump.outfl, mixer.in1) annotation (Line(points={{-46,45},{
                -46,46},{-8,46},{-8,6}}, color={0,0,255}));
        connect(hotPump.flange, mixer.in2) annotation (Line(points={{-80,-10},{
                -8,-10},{-8,-6}},                  color={0,0,255}));
        connect(mixer.out,sensT_mix. inlet)
          annotation (Line(points={{10,0},{10,0},{24,0}}, color={0,0,255}));
        connect(firstOrder1.y, coldPump.in_n) annotation (Line(points={{-41,70},
                {-54.6,70},{-54.6,46}}, color={0,0,127}));
        connect(sensT_mix.outlet,sensW. inlet)
          annotation (Line(points={{36,0},{64,0}}, color={0,0,255}));
        connect(firstOrder1.u,pI1. CS)
          annotation (Line(points={{-18,70},{1,70}},color={0,0,127}));
        connect(sensW.w,pI1. PV) annotation (Line(points={{78,10},{80,10},{80,
                48},{30,48},{30,69},{18,69}},
                      color={0,0,127}));
        connect(const5.y, pI1.TR) annotation (Line(points={{19,110},{10,110},{
                10,78}}, color={0,0,127}));
        connect(booleanStep1.y, pI1.TS) annotation (Line(points={{-19,110},{6,
                110},{6,78}}, color={255,0,255}));
        connect(const1.y, pI.TR) annotation (Line(points={{13,-100},{0,-100},{0,
                -78}}, color={0,0,127}));
        connect(booleanStep.y, pI.TS) annotation (Line(points={{-19,-120},{-4,
                -120},{-4,-78}}, color={255,0,255}));
        connect(booleanStep.y, switch.u2) annotation (Line(points={{-19,-120},{
                -4,-120},{-4,-92},{-46,-92},{-46,-78},{-58,-78}}, color={255,0,
                255}));
        connect(switch.u3, firstOrder.y) annotation (Line(points={{-58,-70},{
                -41,-70},{-41,-70}}, color={0,0,127}));
        connect(signalBus.pumpMS_CS, switch.u1) annotation (Line(
            points={{-80,-120},{-52,-120},{-52,-86},{-58,-86}},
            color={255,204,51},
            thickness=0.5));
        connect(switch.y, hotPump.in_w0) annotation (Line(points={{-81,-78},{
                -94,-78},{-94,-16}}, color={0,0,127}));
        connect(sensW.outlet, pressDrop.inlet)
          annotation (Line(points={{76,0},{100,0}}, color={0,0,255}));
        connect(pressDrop.outlet, flangeB)
          annotation (Line(points={{120,0},{160,0}}, color={0,0,255}));
        connect(pI1.SP, w_tot1.y)
          annotation (Line(points={{18,76},{40,76},{59,76}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                  -160,-140},{160,140}}), graphics={
              Rectangle(
                extent={{-160,140},{160,-140}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-122,-44},{-60,-104}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-60,-36},{-122,-52}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-60,-96},{-122,-112}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-116,-62},{-66,-90}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid,
                textString="COLD MS"),
              Rectangle(
                extent={{-120,98},{-58,38}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-58,106},{-120,90}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-58,46},{-120,30}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-110,76},{-68,56}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid,
                textString="HOT MS"),
              Line(
                points={{-60,-80},{0,-80}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Ellipse(
                extent={{0,-72},{16,-88}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Sphere,
                fillColor={0,0,255}),
              Polygon(
                points={{4,-76},{4,-84},{14,-80},{4,-76}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={255,255,255}),
              Ellipse(
                extent={{0,68},{16,52}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Sphere,
                fillColor={0,0,255}),
              Polygon(
                points={{4,64},{4,56},{14,60},{4,64}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={255,255,255}),
              Line(
                points={{-58,60},{0,60}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Line(
                points={{16,60},{40,60},{40,0},{150,0}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Line(
                points={{16,-80},{40,-80},{40,0}},
                color={0,0,0},
                thickness=0.5)}),          Diagram(coordinateSystem(
                preserveAspectRatio=false, extent={{-160,-140},{160,140}})));
      end MSmixer;

      model MSmixer_simp
        "Model of the hot/cold molten salt mixing for hot start up"

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-140,30},{-120,50}})));
        ThermoPower.Water.ThroughMassFlow
                               coldPump(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          w0=9,
          allowFlowReversal=false,
          use_in_w0=true)
          annotation (Placement(transformation(extent={{-62,30},{-42,50}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-98,34},{-78,54}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{20,6},{40,-14}})));
        ThermoPower.Water.SourceMassFlow hotPump(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-100,0},{-80,-20}})));
        IndustrialControlSystems.Controllers.PI pI(
          AntiWindup=true,
          CSmax=14,
          CSmin=0.001,
          Kp=0.05,
          Ti=20,
          useTS=true,
          CS_start=2.392)
          annotation (Placement(transformation(extent={{10,-60},{-10,-80}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-20,-80},{-40,-60}})));
        Modelica.Blocks.Math.Add3 add3
          annotation (Placement(transformation(extent={{120,-92},{100,-72}})));
        Modelica.Blocks.Sources.Constant const3(k=0)
          annotation (Placement(transformation(extent={{160,-66},{140,-46}})));
        Modelica.Blocks.Sources.Step step(
          offset=0,
          height=100,
          startTime=20000)
          annotation (Placement(transformation(extent={{160,-96},{140,-76}})));
        Modelica.Blocks.Sources.Ramp ramp(
          height=-275,
          duration=4000,
          offset=838.15,
          startTime=4000)
          annotation (Placement(transformation(extent={{100,-50},{80,-30}})));
        ThermoPower.Water.FlowJoin
                                mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-20,60},{-40,80}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(
            startValue=true, startTime=4000)
          annotation (Placement(transformation(extent={{-40,-130},{-20,-110}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{60,-6},{80,14}})));
        IndustrialControlSystems.Controllers.PI pI1(
          Ti=5,
          useTS=true,
          CSmin=0,
          CSmax=11,
          CS_start=0,
          Kp=0.1)
          annotation (Placement(transformation(extent={{20,60},{0,80}})));
        Modelica.Blocks.Sources.Constant const5(k=0)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        ThermoPower.Water.FlangeB flangeB(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{150,-10},{170,10}})));
        Modelica.Icons.SignalBus signalBus
          annotation (Placement(transformation(extent={{-100,-140},{-60,-100}}),
              iconTransformation(extent={{-20,-160},{20,-120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(
            startValue=true, startTime=4000)
          annotation (Placement(transformation(extent={{-40,100},{-20,120}})));
        Modelica.Blocks.Logical.Switch switch
          annotation (Placement(transformation(extent={{-60,-68},{-80,-88}})));
        Modelica.Blocks.Sources.Constant const1(k=2.392)
          annotation (Placement(transformation(extent={{34,-110},{14,-90}})));
        ThermoPower.Water.PressDrop pressDrop(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          wnom=11.96,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          rhonom=1900,
          w(start=1.5),
          dpnom=950000)
          annotation (Placement(transformation(extent={{100,-10},{120,10}})));
        Modelica.Blocks.Sources.Ramp w_tot1(
          height=10.598,
          duration=1080,
          offset=0,
          startTime=20000)
          annotation (Placement(transformation(extent={{140,102},{120,122}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{60,-86},{40,-66}})));
        Modelica.Blocks.Math.Add add1
          annotation (Placement(transformation(extent={{60,66},{40,86}})));
        Modelica.Blocks.Sources.Ramp ramp1(
          height=175,
          duration=1080,
          offset=0,
          startTime=20000)
          annotation (Placement(transformation(extent={{160,-130},{140,-110}})));
        Modelica.Blocks.Sources.Ramp w_tot2(
          startTime=4000,
          duration=4000,
          height=-1,
          offset=2.392)
          annotation (Placement(transformation(extent={{100,90},{80,110}})));
        Modelica.Blocks.Nonlinear.Limiter pumpCold_lim(uMin=0, uMax=14)
          annotation (Placement(transformation(extent={{-46,68},{-50,72}})));
        Modelica.Blocks.Nonlinear.Limiter pumpHot_lim(uMin=0, uMax=14)
          annotation (Placement(transformation(extent={{-46,-72},{-50,-68}})));
        Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_plus(
          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
          extrapolation=Modelica.Blocks.Types.Extrapolation.HoldLastPoint,
          table=[19999,0; 20000,0; 20200,3; 20400,6; 20600,8; 20800,9; 21080,
              10.598; 21100,10.598])
          annotation (Placement(transformation(extent={{140,62},{120,82}})));
        Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_minus(
          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
          extrapolation=Modelica.Blocks.Types.Extrapolation.HoldLastPoint,
          table=[19999,0; 20000,0; 20200,1.5; 20400,3; 20600,4.5; 20800,7;
              21080,10.598; 21100,10.598])
          annotation (Placement(transformation(extent={{140,10},{120,30}})));
        Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_plusplus(
          smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative,
          extrapolation=Modelica.Blocks.Types.Extrapolation.HoldLastPoint,
          table=[19999,0; 20000,0; 20200,4; 20400,7; 20600,9; 20800,10; 21080,
              10.598; 21100,10.598])
          annotation (Placement(transformation(extent={{140,36},{120,56}})));
      equation
        connect(sourcePressure.flange,sensT_cold. inlet)
          annotation (Line(points={{-120,40},{-108,40},{-102,40},{-94,40}},
                                                     color={0,0,255}));
        connect(sensT_mix.T,pI. PV) annotation (Line(points={{38,-10},{40,-10},
                {40,-30},{20,-30},{20,-69},{8,-69}},
                                                   color={0,0,127}));
        connect(firstOrder.u,pI. CS)
          annotation (Line(points={{-18,-70},{-9,-70}},  color={0,0,127}));
        connect(const3.y,add3. u1) annotation (Line(points={{139,-56},{132,-56},
                {132,-74},{122,-74}},
                           color={0,0,127}));
        connect(step.y,add3. u2) annotation (Line(points={{139,-86},{132,-86},{
                132,-82},{122,-82}},
                          color={0,0,127}));
        connect(hotPump.flange, mixer.in2) annotation (Line(points={{-80,-10},{
                -6,-10},{-6,-4}},                  color={0,0,255}));
        connect(mixer.out,sensT_mix. inlet)
          annotation (Line(points={{6,0},{6,0},{24,0}},   color={0,0,255}));
        connect(sensT_mix.outlet,sensW. inlet)
          annotation (Line(points={{36,0},{64,0}}, color={0,0,255}));
        connect(firstOrder1.u,pI1. CS)
          annotation (Line(points={{-18,70},{1,70}},color={0,0,127}));
        connect(sensW.w,pI1. PV) annotation (Line(points={{78,10},{80,10},{80,
                48},{30,48},{30,69},{18,69}},
                      color={0,0,127}));
        connect(const5.y, pI1.TR) annotation (Line(points={{19,110},{10,110},{
                10,78}}, color={0,0,127}));
        connect(booleanStep1.y, pI1.TS) annotation (Line(points={{-19,110},{6,
                110},{6,78}}, color={255,0,255}));
        connect(const1.y, pI.TR) annotation (Line(points={{13,-100},{0,-100},{0,
                -78}}, color={0,0,127}));
        connect(booleanStep.y, pI.TS) annotation (Line(points={{-19,-120},{-4,
                -120},{-4,-78}}, color={255,0,255}));
        connect(booleanStep.y, switch.u2) annotation (Line(points={{-19,-120},{
                -4,-120},{-4,-92},{-46,-92},{-46,-78},{-58,-78}}, color={255,0,
                255}));
        connect(signalBus.pumpMS_CS, switch.u1) annotation (Line(
            points={{-80,-120},{-52,-120},{-52,-86},{-58,-86}},
            color={255,204,51},
            thickness=0.5));
        connect(switch.y, hotPump.in_w0) annotation (Line(points={{-81,-78},{
                -94,-78},{-94,-16}}, color={0,0,127}));
        connect(sensW.outlet, pressDrop.inlet)
          annotation (Line(points={{76,0},{100,0}}, color={0,0,255}));
        connect(pressDrop.outlet, flangeB)
          annotation (Line(points={{120,0},{160,0}}, color={0,0,255}));
        connect(sensT_cold.outlet, coldPump.inlet) annotation (Line(points={{
                -82,40},{-62,40},{-62,40}}, color={0,0,255}));
        connect(coldPump.outlet, mixer.in1)
          annotation (Line(points={{-42,40},{-6,40},{-6,4}}, color={0,0,255}));
        connect(pI.SP, add.y)
          annotation (Line(points={{8,-76},{39,-76}}, color={0,0,127}));
        connect(add3.y, add.u2) annotation (Line(points={{99,-82},{80,-82},{62,
                -82}}, color={0,0,127}));
        connect(pI1.SP, add1.y) annotation (Line(points={{18,76},{30,76},{30,76},
                {39,76}}, color={0,0,127}));
        connect(ramp.y, add.u1) annotation (Line(points={{79,-40},{72,-40},{72,
                -70},{62,-70}}, color={0,0,127}));
        connect(ramp1.y, add3.u3) annotation (Line(points={{139,-120},{132,-120},
                {132,-90},{122,-90}}, color={0,0,127}));
        connect(w_tot2.y, add1.u1) annotation (Line(points={{79,100},{70,100},{
                70,82},{62,82}}, color={0,0,127}));
        connect(pumpCold_lim.u, firstOrder1.y)
          annotation (Line(points={{-45.6,70},{-41,70}}, color={0,0,127}));
        connect(pumpCold_lim.y, coldPump.in_w0) annotation (Line(points={{-50.2,
                70},{-56,70},{-56,46}}, color={0,0,127}));
        connect(switch.u3, pumpHot_lim.y) annotation (Line(points={{-58,-70},{
                -50.2,-70},{-50.2,-70}}, color={0,0,127}));
        connect(pumpHot_lim.u, firstOrder.y) annotation (Line(points={{-45.6,
                -70},{-41,-70},{-41,-70}}, color={0,0,127}));
        connect(combiTimeTable_plusplus.y[1], add1.u2) annotation (Line(points=
                {{119,46},{112,46},{100,46},{100,70},{62,70}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                  -160,-140},{160,140}}), graphics={
              Rectangle(
                extent={{-160,140},{160,-140}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Rectangle(
                extent={{-122,-44},{-60,-104}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-60,-36},{-122,-52}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={0,0,255},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-60,-96},{-122,-112}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-116,-62},{-66,-90}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid,
                textString="COLD MS"),
              Rectangle(
                extent={{-120,98},{-58,38}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-58,106},{-120,90}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={255,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-58,46},{-120,30}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-110,76},{-68,56}},
                lineColor={0,0,0},
                lineThickness=0.5,
                fillColor={175,175,175},
                fillPattern=FillPattern.Solid,
                textString="HOT MS"),
              Line(
                points={{-60,-80},{0,-80}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Ellipse(
                extent={{0,-72},{16,-88}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Sphere,
                fillColor={0,0,255}),
              Polygon(
                points={{4,-76},{4,-84},{14,-80},{4,-76}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={255,255,255}),
              Ellipse(
                extent={{0,68},{16,52}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Sphere,
                fillColor={0,0,255}),
              Polygon(
                points={{4,64},{4,56},{14,60},{4,64}},
                lineColor={0,0,0},
                pattern=LinePattern.None,
                fillPattern=FillPattern.HorizontalCylinder,
                fillColor={255,255,255}),
              Line(
                points={{-58,60},{0,60}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Line(
                points={{16,60},{40,60},{40,0},{150,0}},
                color={0,0,0},
                thickness=0.5,
                arrow={Arrow.None,Arrow.Filled}),
              Line(
                points={{16,-80},{40,-80},{40,0}},
                color={0,0,0},
                thickness=0.5)}),          Diagram(coordinateSystem(
                preserveAspectRatio=false, extent={{-160,-140},{160,140}})));
      end MSmixer_simp;

      block ModulatedTrapezoid
        "Generate modulated trapezoidal signal depending on two boolean conditions acting on the plant"
        parameter Real amplitude=1 "Amplitude of trapezoid";
        parameter Modelica.SIunits.Time rising(final min=0)=0
          "Rising duration of trapezoid";
        parameter Modelica.SIunits.Time width(final min=0)=0.5
          "Width duration of trapezoid";
        parameter Modelica.SIunits.Time falling(final min=0)=0
          "Falling duration of trapezoid";
        parameter Modelica.SIunits.Time period(final min=Modelica.Constants.small,
            start=1) "Time for one period";
        parameter Integer nperiod=-1
          "Number of periods (< 0 means infinite number of periods)";
          Real ytrap;
      extends Modelica.Blocks.Interfaces.SignalSource;

       Modelica.Blocks.Interfaces.BooleanInput cond1
          "Connector 1 of Boolean input signals (CONDITION 1)"
          annotation (Placement(transformation(extent={{-140,40},{-100,80}},
            rotation=0), iconTransformation(extent={{-140,40},{-100,80}})));
        Modelica.Blocks.Interfaces.BooleanInput cond2
          "Connector 2 of Boolean input signals (CONDITION 2)"
          annotation (Placement(transformation(extent={{-140,-80},{-100,-40}},
            rotation=0), iconTransformation(extent={{-140,-80},{-100,-40}})));

      protected
        parameter Modelica.SIunits.Time T_rising=rising
          "End time of rising phase within one period";
        parameter Modelica.SIunits.Time T_width=T_rising + width
          "End time of width phase within one period";
        parameter Modelica.SIunits.Time T_falling=T_width + falling
          "End time of falling phase within one period";
        Modelica.SIunits.Time T_start "Start time of current period";
        Integer count "Period count";

      initial equation
        y=offset;
      initial algorithm
        count := integer((time - startTime)/period);
        T_start := startTime + count*period;
      equation
        when integer((time - startTime)/period) > pre(count) then
          count = pre(count) + 1;
          T_start = time;
        end when;

        ytrap = offset + (
        if (time < startTime or nperiod == 0 or (nperiod > 0 and count >= nperiod)) then 0
        else if (time < T_start + T_rising)  then amplitude*(time - T_start)/rising
        else if (time < T_start + T_width)   then amplitude
        else if (time < T_start + T_falling) then amplitude*(T_start + T_falling - time)/falling
        else 0);

        der(y) =
        if (time < startTime or nperiod == 0 or (nperiod > 0 and count >= nperiod)) then 0
        else if (time < T_start + T_rising)  then (if
                                                     (cond1) then amplitude/rising else 0)
        else if (time < T_start + T_width)   then 0
        else if (time < T_start + T_falling) then (if
                                                     (cond2) then -amplitude/falling else 0)
        else 0;

        annotation (
          Icon(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}}), graphics={
              Line(points={{-80,68},{-80,-80}}, color={192,192,192}),
              Polygon(
                points={{-80,90},{-88,68},{-72,68},{-80,90}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-90,-70},{82,-70}}, color={192,192,192}),
              Polygon(
                points={{90,-70},{68,-62},{68,-78},{90,-70}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-147,-152},{153,-112}},
                lineColor={0,0,0},
                textString="period=%period"),
              Line(points={{-81,-70},{-60,-70},{-30,40},{9,40},{39,-70},{61,-70},{
                    90,40}}, color={0,0,0},
                pattern=LinePattern.Dash),
              Line(
                points={{-100,100},{-100,-100},{100,-100},{100,100},{-100,100}},
                color={0,0,0},
                smooth=Smooth.None),
              Line(
                points={{-80,-70},{-60,-70},{-36,20},{14,20},{34,-50},{66,-50},{82,8},
                    {88,8}},
                color={255,0,0},
                smooth=Smooth.None)}),
          Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}}), graphics={
              Polygon(
                points={{-81,90},{-87,68},{-75,68},{-81,90}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(points={{-81,68},{-81,-80}}, color={95,95,95}),
              Line(points={{-91,-70},{81,-70}}, color={95,95,95}),
              Polygon(
                points={{89,-70},{67,-65},{67,-76},{89,-70}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-46,-30},{-48,-41},{-44,-41},{-46,-30}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-46,-30},{-46,-70}},
                color={95,95,95},
                pattern=LinePattern.Solid,
                arrow={Arrow.None,Arrow.None}),
              Polygon(
                points={{-46,-70},{-48,-60},{-44,-60},{-46,-70},{-46,-70}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-80,-46},{-42,-55}},
                lineColor={0,0,0},
                textString="offset"),
              Text(
                extent={{-49,-71},{-6,-81}},
                lineColor={0,0,0},
                textString="startTime"),
              Text(
                extent={{-80,95},{-47,80}},
                lineColor={0,0,0},
                textString="y"),
              Text(
                extent={{66,-78},{89,-89}},
                lineColor={0,0,0},
                textString="time"),
              Line(
                points={{-31,82},{-31,-70}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Line(
                points={{-11,59},{-11,40}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Line(
                points={{19,59},{19,40}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Line(
                points={{39,59},{39,-30}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Line(points={{-31,76},{59,76}}, color={95,95,95}),
              Line(points={{-31,56},{39,56}}, color={95,95,95}),
              Text(
                extent={{-3,86},{24,77}},
                lineColor={0,0,0},
                textString="period"),
              Text(
                extent={{-11,68},{18,59}},
                lineColor={0,0,0},
                textString="width"),
              Line(
                points={{-43,40},{-11,40}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Line(
                points={{-40,40},{-40,-30}},
                color={95,95,95},
                pattern=LinePattern.Solid,
                arrow={Arrow.None,Arrow.None}),
              Text(
                extent={{-77,11},{-44,1}},
                lineColor={0,0,0},
                textString="amplitude"),
              Polygon(
                points={{-31,56},{-24,58},{-24,54},{-31,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-11,56},{-18,58},{-18,54},{-11,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-31,76},{-22,78},{-22,74},{-31,76}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{59,76},{51,78},{51,74},{59,76}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(
                points={{-81,-30},{-31,-30},{-11,40},{19,40},{39,-30},{59,-30},{79,
                    40},{99,40}},
                color={0,0,255},
                thickness=0.5,
                pattern=LinePattern.Dot),
              Polygon(
                points={{-40,40},{-42,29},{-38,29},{-40,40}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-40,-30},{-42,-20},{-38,-20},{-40,-30},{-40,-30}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(
                points={{59,84},{59,-30}},
                color={95,95,95},
                pattern=LinePattern.Dash),
              Polygon(
                points={{39,56},{32,58},{32,54},{39,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{19,56},{26,58},{26,54},{19,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{19,56},{12,58},{12,54},{19,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-11,56},{-4,58},{-4,54},{-11,56}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-35,68},{-6,60}},
                lineColor={0,0,0},
                textString="rising"),
              Text(
                extent={{16,68},{44,60}},
                lineColor={0,0,0},
                textString="falling"),
              Line(
                points={{-80,-30},{-30,-30},{-14,26},{22,26},{38,-30},{60,-30},{70,6},
                    {100,6}},
                color={255,0,0},
                smooth=Smooth.None,
                thickness=0.5),
              Text(
                extent={{14,32},{-6,32}},
                lineColor={255,0,0},
                pattern=LinePattern.Dot,
                lineThickness=0.5,
                fontSize=14,
                textString="cond1"),
              Text(
                extent={{60,-36},{40,-36}},
                lineColor={255,0,0},
                pattern=LinePattern.Dot,
                lineThickness=0.5,
                fontSize=14,
                textString="cond2"),
              Line(
                points={{-100,100},{100,100},{100,-100},{-100,-100},{-100,100}},
                color={0,0,0},
                smooth=Smooth.None,
                thickness=1)}),
          Documentation(info="<html>
<p>
The Real output y is a trapezoid signal:
</p>

<p>
<img src=\"modelica://Modelica/Resources/Images/Blocks/Sources/Trapezoid.png\"
     alt=\"Trapezoid\">
</p>
</html>"));
      end ModulatedTrapezoid;

      block StepSequence
        "This block generates a sequence of steps of constant amplitude"
        parameter Real N=(T_max - T_min)/res "Number of Steps";
        parameter Real res=1 "Temperature step variation";
        parameter Modelica.SIunits.Temperature T_min
          "Minimum ambient temperature value";
        parameter Modelica.SIunits.Temperature T_max
          "Maximum ambient temperature value";
        parameter Real T=1000 "Step Duration";
        Real aux;
        extends Modelica.Blocks.Interfaces.SignalSource;

      algorithm
        aux:=0;
        for i in 1:N loop
         aux := aux + (if
                         (time < (i*T+startTime)) then 0 else res);
        end for;

      equation
        y=offset + aux;
        annotation (                                 Icon(coordinateSystem(
                preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
                Line(
                points={{-100,100},{100,100},{100,-100},{-100,-100},{-100,100}},
                color={0,0,255},
                smooth=Smooth.None), Line(
                points={{-80,60},{-40,60},{-40,20},{0,20},{0,-20},{40,-20},{40,-60},{80,
                    -60}},
                color={0,0,0},
                smooth=Smooth.None)}));
      end StepSequence;

      package Spline

        function MakeSpline
          extends Modelica.Icons.Function;
          input Integer n;
          input Real xp[n] "abscissa";
          input Real yp[n] "ordinates";
          input Real dydxl=Modelica.Constants.inf "left slope";
          input Real dydxr=Modelica.Constants.inf "right slope";
          output Real y2[n] "2nd derivatives";
        protected
          Real uh[n] "auxiliaey array";
          Real sig;
          Real p;
        algorithm
          if dydxl == Modelica.Constants.inf then
        //natural spline i.e. left curvature = 0
            y2[1]:= 0;
            uh[1]:= 0;
          else
        //given slope at the left border
            y2[1]:= -0.5;
            uh[1]:= +3/(xp[2] - xp[1])*((yp[2] - yp[1])/(xp[2] - xp[1]) - dydxl);
          end if;
        //decomposition of tridiagonal algorithm
          for i in 2:n - 1 loop
            sig:= (xp[i] - xp[i-1])/(xp[i+1] - xp[i-1]);
            p:= sig*y2[i-1] + 2;
            y2[i]:= (sig - 1)/p;
            uh[i]:= (6*((yp[i+1] - yp[i])/(xp[i+1] - xp[i]) -
                        (yp[i] - yp[i-1])/(xp[i] - xp[i-1]))/
                        (xp[i+1] - xp[i-1]) - sig*uh[i-1])/p;
          end for;
          if dydxr == Modelica.Constants.inf then
        //natural spline i.e. right curvature = 0
            y2[n]:= 0;
            uh[n]:= 0;
          else
        //given slope at the right border
            y2[n]:= +0.5;
            uh[n]:= -3/(xp[n] - xp[n-1])*((yp[n] - yp[n-1])/(xp[n] - xp[n-1]) - dydxr);
          end if;
        //backsubstitution of tridiagonal algorithm
          y2[n]:= (uh[n] - y2[n]*uh[n-1])/(y2[n]*y2[n-1] + 1);
          for i in 1:n - 1 loop
            y2[n-i]:= y2[n-i]*y2[n-i+1] + uh[n-i];
          end for;
        end MakeSpline;

        function EvalSpline
          extends Modelica.Icons.Function;
          input Real x;
          input Real xp[:] "abscissa";
          input Real yp[:] "ordinates";
          input Real y2[:] "2nd derivatives";
          output Real y;
        protected
          Integer n = size(xp,1);
          Integer i;
          Real h;
          Real a;
          Real b;
        algorithm
          i:= Bisection(x, xp);
          if i == 0 then
        //extrapolation below first point
            h:= (xp[2] - xp[1]);
            h:= (yp[2] - yp[1])/h - (2*y2[1] - (-1)*y2[2])*h/6;
            y:= yp[1] + h*(x - xp[1]);
          elseif i == n then
        //extrapolation above last point
            h:= (xp[n] - xp[n-1]);
            h:= (yp[n] - yp[n-1])/h - ((-1)*y2[n-1] - 2*y2[n])*h/6;
            y:= yp[n] + h*(x - xp[n]);
          else
        //evaluation of cubic spline
            h:= (xp[i+1] - xp[i]);
            a:= (xp[i+1] - x)/h;
            b:= (x - xp[i])/h;
            y:= a*yp[i] + b*yp[i+1] + ((a^3 - a)*y2[i] + (b^3 - b)*y2[i+1])*h^2/6;
          end if;
          annotation(derivative(noDerivative=xp, noDerivative=yp, noDerivative=y2)=Der1Spline);
        end EvalSpline;

        function Der1Spline
          extends Modelica.Icons.Function;
          input Real x;
          input Real xp[:] "abscissa";
          input Real yp[:] "ordinates";
          input Real y2[:] "2nd derivatives";
          input Real der_x;
          output Real der_y;
        protected
          Integer n = size(xp,1);
          Integer i;
          Real h;
          Real a;
          Real b;
        algorithm
          i:= Bisection(x, xp);
          if i == 0 then
        //extrapolation below first point
            h:= (xp[2] - xp[1]);
            der_y:= ((yp[2] - yp[1])/h - (2*y2[1] - (-1)*y2[2])*h/6)*der_x;
          elseif i == n then
        //extrapolation above last point
            h:= (xp[n] - xp[n-1]);
            der_y:= ((yp[n] - yp[n-1])/h - ((-1)*y2[n-1] - 2*y2[n])*h/6)*der_x;
          else
        //1st derivative of cubic spline
            h:= (xp[i+1] - xp[i]);
            a:= (xp[i+1] - x)/h;
            b:= (x - xp[i])/h;
            der_y:= ((yp[i+1] - yp[i])/h - ((3*a^2 - 1)*y2[i] - (3*b^2-1)*y2[i+1])*h/6)*der_x;
          end if;
        end Der1Spline;

        function Bisection
          extends Modelica.Icons.Function;
          input Real x;
          input Real xp[:] "abscissa";
          output Integer i;
        protected
          Integer n = size(xp,1);
          Integer ilo;
          Integer ihi;
        algorithm
          if x <= xp[1] then
        //below first point
            i:= 0;
          elseif x >= xp[n] then
        //above last point
            i:= n;
          else
        //bisectional search for the interval
            ilo:= 1;
            ihi:= n;
            while (ihi - ilo) > 1 loop
              i:= integer((ihi + ilo)/2);
              if (xp[i] > x) then
                ihi:= i;
              else
                ilo:= i;
              end if;
            end while;
        //xp[i] <= x < xp[i+1]
            i:= ilo;
          end if;
        end Bisection;

        model SplineFunction
          extends Modelica.Blocks.Interfaces.SISO;
          parameter Real table[:,2]
            "u data on first column, y data on y column";
          parameter Integer n = size(table,1) "Number of data points";
        protected
          parameter Real y2[n]= MakeSpline(n, table[:,1], table[:,2],0,0)
            "Spline derivative data";
        equation
          y = EvalSpline(u, table[:,1], table[:,2], y2);
          annotation (Icon(graphics={
                Line(points={{-78,82},{-78,-82}}, color={0,0,0}),
                Line(points={{-86,-72},{84,-72}}, color={0,0,0}),
                Line(points={{70,-64},{84,-72},{70,-78}}, color={0,0,0}),
                Line(points={{-84,68},{-78,82},{-72,68}}, color={0,0,0}),
                Line(points={{-70,-22},{-60,-14},{-46,-6},{-32,-2},{-18,-4},{-8,-10},{
                      2,-16},{14,-22},{28,-26},{38,-26},{48,-20},{56,-10},{62,2},{66,14}},
                    color={0,0,0})}));
        end SplineFunction;

        model SplineSignal
          extends Modelica.Blocks.Interfaces.SO;
          parameter Real table[:,2]
            "time data on first column, y data on y column";
        protected
          parameter Integer n = size(table,1) "Number of data points";
          parameter Real y2[n]= MakeSpline(n, table[:,1], table[:,2],0,0)
            "Spline derivative data";
        equation
          y = EvalSpline(time, table[:,1], table[:,2], y2);
          annotation (Icon(graphics={
                Line(points={{-78,82},{-78,-82}}, color={0,0,0}),
                Line(points={{-86,-72},{84,-72}}, color={0,0,0}),
                Line(points={{70,-64},{84,-72},{70,-78}}, color={0,0,0}),
                Line(points={{-84,68},{-78,82},{-72,68}}, color={0,0,0}),
                Line(points={{-70,-22},{-60,-14},{-46,-6},{-32,-2},{-18,-4},{-8,-10},{
                      2,-16},{14,-22},{28,-26},{38,-26},{48,-20},{56,-10},{62,2},{66,14}},
                    color={0,0,0})}));
        end SplineSignal;

        model Test

          SplineFunction SplineFunction1(table=[0,300; 0.5,350; 0.8,400; 1,420])
            annotation (Placement(transformation(extent={{-40,20},{-20,40}}, rotation=
                   0)));
          Modelica.Blocks.Sources.Ramp Ramp1(
            height=1,
            duration=0.9,
            offset=0,
            startTime=0.1)
                      annotation (Placement(transformation(extent={{-80,22},{-60,42}},
                  rotation=0)));
          Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
            PrescribedTemperature1
            annotation (Placement(transformation(extent={{20,0},{40,20}}, rotation=0)));
          Modelica.Thermal.HeatTransfer.Components.HeatCapacitor HeatCapacitor1(
                                                                     C=1)
            annotation (Placement(transformation(extent={{52,10},{72,30}}, rotation=0)));
          Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
            PrescribedTemperature2
            annotation (Placement(transformation(extent={{20,-40},{40,-20}}, rotation=
                   0)));
          Modelica.Thermal.HeatTransfer.Components.HeatCapacitor HeatCapacitor2(
                                                                     C=1)
            annotation (Placement(transformation(extent={{52,-30},{72,-10}}, rotation=
                   0)));
          SplineFunction SplineFunction2(table=[0,300; 1,350])
            annotation (Placement(transformation(extent={{-40,-40},{-20,-20}},
                  rotation=0)));
        equation
          connect(Ramp1.y, SplineFunction1.u)
            annotation (Line(points={{-59,32},{-42,32},{-42,30}}, color={0,0,127}));
          connect(SplineFunction1.y, PrescribedTemperature1.T)
            annotation (Line(points={{-19,30},{8,30},{8,10},{18,10}}, color={0,0,127}));
          connect(PrescribedTemperature1.port, HeatCapacitor1.port)
            annotation (Line(points={{40,10},{62,10}}, color={191,0,0}));
          connect(PrescribedTemperature2.port,HeatCapacitor2. port)
            annotation (Line(points={{40,-30},{62,-30}}, color={191,0,0}));
          connect(SplineFunction2.y, PrescribedTemperature2.T)
            annotation (Line(points={{-19,-30},{18,-30}}, color={0,0,127}));
          connect(Ramp1.y, SplineFunction2.u) annotation (Line(points={{-59,32},{-54,32},
                  {-54,-30},{-42,-30}}, color={0,0,127}));
          annotation (Diagram(graphics));
        end Test;

        model Test2

          SplineSignal splineSignal(table=[0,10; 1,10; 2,15; 3,17; 4,20; 10,20; 12,20;
                100,20])
            annotation (Placement(transformation(extent={{-40,60},{-20,80}})));
          SplineSignal                               splineSignal2(table=[5000,
                20; 5050,35; 5100,47; 5150,60; 5200,70; 5250,80; 5300,90; 5360,
                100])
            annotation (Placement(transformation(extent={{-40,-20},{-20,0}})));
          annotation (experiment(
              StartTime=4950,
              StopTime=5400,
              __Dymola_NumberOfIntervals=5000),experimentSetupOutput);
        end Test2;
        annotation (
          preferedView="info",
          Documentation(info="<html>
<p>
This package implements cubic spline interpolation as described in<br>
Numerical Recipes in FORTRAN 77, Chapter 3.3 Cubic Spline Interpolation
</p>
<p>
Copyright &copy; 2005 <a href=\"http://www.haumer.at\">Anton Haumer</a>.
</p>
</html>"));
      end Spline;

      model PressDropLin_noReverseFlow
        "Linear pressure drop for water/steam flows"
        extends ThermoPower.Icons.Water.PressDrop;
        replaceable package Medium = ThermoPower.Water.StandardWater constrainedby
          Modelica.Media.Interfaces.PartialMedium "Medium model"
          annotation(choicesAllMatching = true);
        parameter ThermoPower.Units.HydraulicResistance R
          "Hydraulic resistance";
        parameter Boolean allowFlowReversal=system.allowFlowReversal
          "= true to allow flow reversal, false restricts to design direction";
        outer ThermoPower.System system "System wide properties";

        Modelica.SIunits.Pressure dp "Actual pressure drop";
        ThermoPower.Water.FlangeA inlet(redeclare package Medium = Medium, m_flow(min=
               if allowFlowReversal then -Modelica.Constants.inf else 0)) annotation (
           Placement(transformation(extent={{-120,-20},{-80,20}}, rotation=0)));
        ThermoPower.Water.FlangeB outlet(redeclare package Medium = Medium, m_flow(
              max=if allowFlowReversal then +Modelica.Constants.inf else 0))
          annotation (Placement(transformation(extent={{80,-20},{120,20}}, rotation=0)));
      equation
        dp = inlet.p - outlet.p;
        inlet.m_flow + outlet.m_flow = 0;
        if dp > 0 then
          dp = R*inlet.m_flow "Flow characteristics";
        else
          outlet.m_flow = 0;
        end if;

        // Energy balance
        inlet.h_outflow = inStream(outlet.h_outflow);
        inStream(inlet.h_outflow) = outlet.h_outflow;
        annotation (
          Icon(graphics={Text(extent={{-100,-44},{100,-76}}, textString="%name")}),
          Documentation(info="<HTML>
<p>This very simple model provides a pressure drop which is proportional to the flowrate, without computing any fluid property.</p>
</HTML>",     revisions="<html>
<ul>
<li><i>16 Dec 2004</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Medium model and standard medium definition added.</li>
<li><i>1 Oct 2003</i>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       First release.</li>
</ul>
</html>
"),       Diagram(graphics));
      end PressDropLin_noReverseFlow;
    end Components;

    package Tests "Package containing auxiliaries models tests"

      model test_valveAdmittance
        "Test to evaluate the turbine admittance as function of the valve position, valveVap"

        ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          thetanom=0.8,
          Fxt_full=0.4542722663,
          Av=1.6633023e-4,
          pnom=17100000,
          dpnom=12320000,
          wnom=1.757)
          annotation (Placement(transformation(extent={{100,10},{120,-10}})));
        Components.loadCalculator loadCalc(
          t_ramp=5000,
          t_start=100,
          load_start=100,
          load_end=100)
          annotation (Placement(transformation(extent={{-54,60},{-14,100}})));
        Modelica.Blocks.Sources.Ramp LOAD1(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-144,20})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
              40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
              100,171e5])
          annotation (Placement(transformation(extent={{-124,10},{-104,30}})));
        Modelica.Blocks.Sources.Ramp LOAD2(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-144,60})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceH(table=[20,3542e3; 30,3535e3;
              40,3529e3; 50,3518e3; 60,3499e3; 70,3476e3; 80,3453e3; 90,3429e3; 100,3428e3])
          annotation (Placement(transformation(extent={{-124,50},{-104,70}})));
        Modelica.Blocks.Sources.Ramp LOAD3(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={202,22})));
        Modelica.Blocks.Tables.CombiTable1D RH_sinkP(table=[20,8.753e5; 30,13.35e5; 40,
              18.05e5; 50,22.89e5; 60,27.74e5; 70,33.04e5; 80,37.62e5; 90,42.52e5; 100,
              47.81e5])
          annotation (Placement(transformation(extent={{180,12},{160,32}})));
        ThermoPower.Water.SinkPressure   sourcePressure4(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=17610000,
          use_in_h=false)
          annotation (Placement(transformation(extent={{140,-10},{160,10}})));
        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-220,100},{-200,120}})));
        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_h=true,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
        Modelica.Blocks.Sources.Ramp theta(
          duration=100,
          height=0,
          offset=0.8,
          startTime=0)
          annotation (Placement(transformation(extent={{6,80},{26,100}})));
      Real Yt = valveVap.w/valveVap.p;
      Real A = sqrt(valveVap.Y*valveVap.xs*valveVap.rho/valveVap.p);

        Modelica.Blocks.Sources.Ramp LOAD4(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-140,-60})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,0.3336;
              30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,1.436; 90,
              1.605; 100,1.757])
          annotation (Placement(transformation(extent={{-120,-70},{-100,-50}})));
        ThermoPower.Water.SensP sensP(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{-4,6},{-24,-14}})));
        IndustrialControlSystems.Controllers.PID PID_valveSH_RH(
          AntiWindup=true,
          Td=0,
          N=10,
          CSmax=1,
          CS_start=0.8,
          Ti=10,
          Kp=1e9,
          useTS=true,
          CSmin=0)
          annotation (Placement(transformation(extent={{0,-38},{20,-58}})));
        Modelica.Blocks.Math.Division division
          annotation (Placement(transformation(extent={{-18,-40},{-10,-48}})));
        Modelica.Blocks.Continuous.FirstOrder valveSH_RH_dynamic(
          k=1,
          T=0.3,
          y_start=0.8,
          initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{40,-60},{60,-40}})));
        Modelica.Blocks.Sources.Ramp LOAD5(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-80,-90})));
        Modelica.Blocks.Tables.CombiTable1D Yv_SP(table=[20,0; 30,0; 40,0; 50,0;
              60,0; 70,0; 80,0; 90,0; 100,1.02748538e-7])
          annotation (Placement(transformation(extent={{-60,-100},{-40,-80}})));
        Modelica.Blocks.Sources.Ramp const(
          duration=100,
          startTime=0,
          height=1,
          offset=0)
          annotation (Placement(transformation(extent={{-20,-118},{0,-98}})));
        Modelica.Blocks.Sources.BooleanConstant booleanConstant
          annotation (Placement(transformation(extent={{40,-120},{20,-100}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{-52,6},{-32,-14}})));
        Modelica.Blocks.Math.Division division1
          annotation (Placement(transformation(extent={{-64,-56},{-56,-64}})));
      equation
        connect(LOAD1.y, valveSH_RH_sourceP.u[1])
          annotation (Line(points={{-133,20},{-133,20},{-126,20}},
                                                                color={0,0,127}));
        connect(LOAD2.y, valveSH_RH_sourceH.u[1])
          annotation (Line(points={{-133,60},{-133,60},{-126,60}},
                                                                color={0,0,127}));
        connect(LOAD3.y, RH_sinkP.u[1])
          annotation (Line(points={{191,22},{191,22},{182,22}},
                                                             color={0,0,127}));
        connect(RH_sinkP.y[1], sourcePressure4.in_p0) annotation (Line(points={{159,22},
                {159,22},{146,22},{146,8.8}},
                                           color={0,0,127}));

        connect(valveSH_RH_sourceH.y[1], sourcePressure.in_h)
          annotation (Line(points={{-103,60},{-66,60},{-66,9}},color={0,0,127}));
        connect(valveVap.outlet, sourcePressure4.flange)
          annotation (Line(points={{120,0},{120,0},{140,0}},
                                                   color={0,0,255}));
        connect(LOAD4.y, valveSH_RH_sourceW.u[1]) annotation (Line(points={{-129,
                -60},{-129,-60},{-122,-60}}, color={0,0,127}));
        connect(sensP.flange, valveVap.inlet)
          annotation (Line(points={{-14,0},{-14,0},{100,0}}, color={0,0,255}));
        connect(division.y, PID_valveSH_RH.PV) annotation (Line(points={{-9.6,-44},
                {-6,-44},{-6,-47},{2,-47}}, color={0,0,127}));
        connect(PID_valveSH_RH.CS, valveSH_RH_dynamic.u) annotation (Line(points=
                {{19,-48},{19,-50},{38,-50}}, color={0,0,127}));
        connect(valveSH_RH_dynamic.y, valveVap.theta) annotation (Line(points={{
                61,-50},{110,-50},{110,-8}}, color={0,0,127}));
        connect(sensP.p, division.u2) annotation (Line(points={{-22,-10},{-22,
                -41.6},{-18.8,-41.6}}, color={0,0,127}));
        connect(LOAD5.y, Yv_SP.u[1]) annotation (Line(points={{-69,-90},{-65.5,
                -90},{-62,-90}}, color={0,0,127}));
        connect(const.y, PID_valveSH_RH.TR) annotation (Line(points={{1,-108},{
                10,-108},{10,-56}},
                                 color={0,0,127}));
        connect(booleanConstant.y, PID_valveSH_RH.TS) annotation (Line(points={{
                19,-110},{14,-110},{14,-56}}, color={255,0,255}));
        connect(sensW.outlet, sensP.flange)
          annotation (Line(points={{-36,0},{-36,0},{-14,0}}, color={0,0,255}));
        connect(sourcePressure.flange, sensW.inlet)
          annotation (Line(points={{-60,0},{-48,0}}, color={0,0,255}));
        connect(sensW.w, division.u1) annotation (Line(points={{-34,-10},{-32,-10},
                {-32,-46.4},{-18.8,-46.4}}, color={0,0,127}));
        connect(valveSH_RH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
              points={{-103,20},{-74,20},{-74,9.2}}, color={0,0,127}));
        connect(division1.y, PID_valveSH_RH.SP) annotation (Line(points={{-55.6,
                -60},{-6,-60},{-6,-54},{2,-54}}, color={0,0,127}));
        connect(valveSH_RH_sourceW.y[1], division1.u1) annotation (Line(points={{
                -99,-60},{-76,-60},{-76,-62.4},{-64.8,-62.4}}, color={0,0,127}));
        connect(valveSH_RH_sourceP.y[1], division1.u2) annotation (Line(points={{
                -103,20},{-84,20},{-84,-50},{-68,-50},{-68,-57.6},{-64.8,-57.6}},
              color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-220,-120},{220,120}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-220,
                  -120},{220,120}})),
          Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The result of this test is that the linear model of the valve saturates, so that the pressure inlet set point cannot be satisfied at very low loads.</span></p>
</html>"),experiment(StopTime=100, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput);
      end test_valveAdmittance;

      model test_valveAdmittance_2valves
        "Test to evaluate the turbine admittance as function of the valve position, valveVap"

        ThermoPower.Water.ValveVap valveVap(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          thetanom=0.8,
          Fxt_full=0.4542722663,
          wnom=1.757,
          Av=1.6681872e-4,
          pnom=17000000,
          dpnom=12320000)
          annotation (Placement(transformation(extent={{100,10},{120,-10}})));
        Components.loadCalculator loadCalc(
          load_start=100,
          load_end=20,
          t_start=120,
          t_ramp=5000)
          annotation (Placement(transformation(extent={{-54,60},{-14,100}})));
        Modelica.Blocks.Sources.Ramp LOAD1(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-144,20})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceP(table=[20,85.08e5; 30,85.18e5;
              40,85.33e5; 50,88.82e5; 60,107.9e5; 70,124.1e5; 80,139.7e5; 90,155.1e5;
              100,171e5], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
          annotation (Placement(transformation(extent={{-124,10},{-104,30}})));
        Modelica.Blocks.Sources.Ramp LOAD2(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-144,60})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceH(table=[20,3542e3; 30,3535e3;
              40,3529e3; 50,3518e3; 60,3499e3; 70,3476e3; 80,3453e3; 90,3429e3; 100,3428e3])
          annotation (Placement(transformation(extent={{-124,50},{-104,70}})));
        Modelica.Blocks.Sources.Ramp LOAD3(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{10,-10},{-10,10}},
              rotation=0,
              origin={202,22})));
        Modelica.Blocks.Tables.CombiTable1D RH_sinkP(table=[20,8.753e5; 30,13.35e5; 40,
              18.05e5; 50,22.89e5; 60,27.74e5; 70,33.04e5; 80,37.62e5; 90,42.52e5; 100,
              47.81e5])
          annotation (Placement(transformation(extent={{180,12},{160,32}})));
        ThermoPower.Water.SinkPressure   sourcePressure4(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_p0=true,
          p0=17610000,
          use_in_h=false)
          annotation (Placement(transformation(extent={{140,-10},{160,10}})));
        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-220,100},{-200,120}})));
        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_h=true,
          use_in_p0=true)
          annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
        Modelica.Blocks.Sources.Constant
                                     theta(k=0.8)
          annotation (Placement(transformation(extent={{140,-60},{120,-40}})));
      Real Yt = valveVap.w/valveVap.p;
      Real A = sqrt(valveVap.Y*valveVap.xs*valveVap.rho/valveVap.p);

        Modelica.Blocks.Sources.Ramp LOAD4(
          height=loadCalc.load_end - loadCalc.load_start,
          duration=loadCalc.t_ramp,
          offset=loadCalc.load_start,
          startTime=loadCalc.t_start)
          annotation (Placement(transformation(extent={{-10,-10},{10,10}},
              rotation=0,
              origin={-144,-68})));
        Modelica.Blocks.Tables.CombiTable1D valveSH_RH_sourceW(table=[20,0.3336;
              30,0.5167; 40,0.7059; 50,0.9009; 60,1.105; 70,1.269; 80,1.436; 90,
              1.605; 100,1.757], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
          annotation (Placement(transformation(extent={{-124,-78},{-104,-58}})));
        ThermoPower.Water.SensP sensP(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{-4,6},{-24,-14}})));
        IndustrialControlSystems.Controllers.PID PID_valveSH_RH(
          AntiWindup=true,
          Td=0,
          N=10,
          CSmax=1,
          CS_start=0.8,
          Ti=10,
          useTS=false,
          CSmin=0.01,
          Kp=1e10)
          annotation (Placement(transformation(extent={{0,-40},{20,-60}})));
        Modelica.Blocks.Math.Division division
          annotation (Placement(transformation(extent={{-18,-40},{-10,-48}})));
        Modelica.Blocks.Continuous.FirstOrder valveSH_RH_dynamic(
          k=1,
          T=0.3,
          y_start=0.8,
          initType=Modelica.Blocks.Types.Init.InitialState)
          annotation (Placement(transformation(extent={{40,-60},{60,-40}})));
        Modelica.Blocks.Sources.Ramp const(
          duration=100,
          startTime=0,
          height=0.6,
          offset=0.4)
          annotation (Placement(transformation(extent={{-20,-120},{0,-100}})));
        Modelica.Blocks.Sources.BooleanConstant booleanConstant
          annotation (Placement(transformation(extent={{40,-120},{20,-100}})));
        ThermoPower.Water.ValveVap valveVap1(
                                            redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph,
          thetanom=0.8,
          Fxt_full=0.4542722663,
          wnom=1.757,
          Av=15.815302e-4,
          pnom=17100000,
          dpnom=100000)
          annotation (Placement(transformation(extent={{60,10},{80,-10}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{-52,6},{-32,-14}})));
        Modelica.Blocks.Math.Division division1
          annotation (Placement(transformation(extent={{-66,-56},{-58,-64}})));
      equation
        connect(LOAD1.y, valveSH_RH_sourceP.u[1])
          annotation (Line(points={{-133,20},{-133,20},{-126,20}},
                                                                color={0,0,127}));
        connect(LOAD2.y, valveSH_RH_sourceH.u[1])
          annotation (Line(points={{-133,60},{-133,60},{-126,60}},
                                                                color={0,0,127}));
        connect(LOAD3.y, RH_sinkP.u[1])
          annotation (Line(points={{191,22},{191,22},{182,22}},
                                                             color={0,0,127}));
        connect(RH_sinkP.y[1], sourcePressure4.in_p0) annotation (Line(points={{159,22},
                {159,22},{146,22},{146,8.8}},
                                           color={0,0,127}));

        connect(valveSH_RH_sourceH.y[1], sourcePressure.in_h)
          annotation (Line(points={{-103,60},{-66,60},{-66,9}},color={0,0,127}));
        connect(valveVap.outlet, sourcePressure4.flange)
          annotation (Line(points={{120,0},{120,0},{140,0}},
                                                   color={0,0,255}));
        connect(LOAD4.y, valveSH_RH_sourceW.u[1]) annotation (Line(points={{-133,
                -68},{-133,-68},{-126,-68}}, color={0,0,127}));
        connect(division.y, PID_valveSH_RH.PV) annotation (Line(points={{-9.6,-44},
                {-6,-44},{-6,-49},{2,-49}}, color={0,0,127}));
        connect(PID_valveSH_RH.CS, valveSH_RH_dynamic.u) annotation (Line(points=
                {{19,-50},{19,-50},{38,-50}}, color={0,0,127}));
        connect(sensP.p, division.u2) annotation (Line(points={{-22,-10},{-22,
                -41.6},{-18.8,-41.6}}, color={0,0,127}));
        connect(const.y, PID_valveSH_RH.TR) annotation (Line(points={{1,-110},{10,
                -110},{10,-58}}, color={0,0,127}));
        connect(booleanConstant.y, PID_valveSH_RH.TS) annotation (Line(points={{
                19,-110},{14,-110},{14,-58}}, color={255,0,255}));
        connect(theta.y, valveVap.theta) annotation (Line(points={{119,-50},{110,
                -50},{110,-8}}, color={0,0,127}));
        connect(valveVap1.outlet, valveVap.inlet)
          annotation (Line(points={{80,0},{100,0}}, color={0,0,255}));
        connect(valveVap1.inlet, sensP.flange)
          annotation (Line(points={{60,0},{-14,0}}, color={0,0,255}));
        connect(valveSH_RH_dynamic.y, valveVap1.theta)
          annotation (Line(points={{61,-50},{70,-50},{70,-8}}, color={0,0,127}));
        connect(valveSH_RH_sourceP.y[1], sourcePressure.in_p0) annotation (Line(
              points={{-103,20},{-74,20},{-74,9.2}}, color={0,0,127}));
        connect(sourcePressure.flange, sensW.inlet)
          annotation (Line(points={{-60,0},{-54,0},{-48,0}}, color={0,0,255}));
        connect(sensW.outlet, sensP.flange)
          annotation (Line(points={{-36,0},{-26,0},{-14,0}}, color={0,0,255}));
        connect(sensW.w, division.u1) annotation (Line(points={{-34,-10},{-32,-10},
                {-32,-12},{-32,-46.4},{-18.8,-46.4}}, color={0,0,127}));
        connect(valveSH_RH_sourceW.y[1], division1.u1) annotation (Line(points={{
                -103,-68},{-80,-68},{-80,-62.4},{-66.8,-62.4}}, color={0,0,127}));
        connect(valveSH_RH_sourceP.y[1], division1.u2) annotation (Line(points={{
                -103,20},{-94,20},{-94,-57.6},{-66.8,-57.6}}, color={0,0,127}));
        connect(division1.y, PID_valveSH_RH.SP) annotation (Line(points={{-57.6,
                -60},{-32,-60},{-6,-60},{-6,-56},{2,-56}}, color={0,0,127}));
        annotation (Diagram(coordinateSystem(extent={{-220,-120},{220,120}},
                preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-220,
                  -120},{220,120}})),
          Documentation(revisions="<html>
</html>",   info="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">The result of this test is that the linear model of the valve saturates, so that the pressure inlet set point cannot be satisfied at very low loads.</span></p>
</html>"),experiment(StopTime=6000, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput);
      end test_valveAdmittance_2valves;

      model test_volumetricPump_RC_5
        "Test to check the mass flow control on the volumetric pump"

        Modelica.Blocks.Sources.Sine sine(
          amplitude=0.342,
          phase=0,
          offset=0,
          freqHz=9.6)
          annotation (Placement(transformation(extent={{-190,-100},{-170,-80}})));
        Modelica.Blocks.Math.Abs noise
          annotation (Placement(transformation(extent={{-160,-100},{-140,-80}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          use_in_w0=true,
          use_in_h=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=981.7e3)
          annotation (Placement(transformation(extent={{-20,10},{0,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{110,-10},{130,10}})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=2.5,
          thetanom=0.5,
          Av=1.4753e-4,
          pnom=17800000,
          dpnom=400000)
          annotation (Placement(transformation(extent={{42,-10},{62,10}})));
        Modelica.Blocks.Sources.Step     FW_media(
          offset=2.5,
          startTime=26,
          height=0)
          annotation (Placement(transformation(extent={{-160,20},{-140,40}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-200,120},{-180,140}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{78,-6},{98,14}})));
        IndustrialControlSystems.Controllers.PI PID_valve(
          AntiWindup=true,
          CSmin=0,
          CS_start=0.5,
          CSmax=1,
          useTS=true,
          Ti=0.1419,
          Kp=20)
          annotation (Placement(transformation(extent={{0,56},{20,76}})));
        ThermoPower.Water.Accumulator accumulator(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          hl_start=1e6,
          wg_out0=0,
          zl_start=0,
          V=0.2,
          Vl0=0.1,
          A=0.25,
          zl0=0.4,
          pg_start=25000000,
          Tg_start=498.15,
          Tgin=293.15,
          pg0=19000000)
          annotation (Placement(transformation(extent={{2,-2},{40,36}})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-10,36},{0,46}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{42,48},{32,58}})));
        Modelica.Blocks.Continuous.FirstOrder valve_dynamic(
          k=1,
          y_start=0.5,
          initType=Modelica.Blocks.Types.Init.InitialOutput,
          T=0.2)  annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=270,
              origin={52,36})));

        Real R = 2*valveLiq.dp/valveLiq.w;
        Real C = accumulator.rho*accumulator.Vg/accumulator.pg;
        Real RC = R*C;
        Real var_per_in = (add.y - w_FW_SP.y)/w_FW_SP.y*100;
        Real var_per_out = (valveLiq.w - w_FW_SP.y)/w_FW_SP.y*100;

        Modelica.Blocks.Logical.Switch switch1
          annotation (Placement(transformation(extent={{-74,-48},{-54,-28}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(             startValue=
              true, startTime=10)
          annotation (Placement(transformation(extent={{-120,-48},{-100,-28}})));
        Modelica.Blocks.Math.Add add1(k1=-1)
          annotation (Placement(transformation(extent={{-120,-100},{-100,-80}})));
        Modelica.Blocks.Sources.Constant const3(k=0.228)
          annotation (Placement(transformation(extent={{-160,-70},{-140,-50}})));
        Modelica.Blocks.Nonlinear.Limiter valve_lim(uMax=0.9, uMin=0.1)
          annotation (Placement(transformation(
              extent={{6,-6},{-6,6}},
              rotation=90,
              origin={52,18})));
        Modelica.Blocks.Sources.Constant const5(k=0.5)
          annotation (Placement(transformation(extent={{-20,100},{0,120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(            startValue=
              true, startTime=1000)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        Modelica.Blocks.Sources.Constant w_FW_SP(k=2.4897)
          annotation (Placement(transformation(extent={{-160,62},{-140,82}})));
        Modelica.Blocks.Math.Add add3(k2=-1)
          annotation (Placement(transformation(extent={{-120,-14},{-100,6}})));
      equation
        connect(sine.y, noise.u)
          annotation (Line(points={{-169,-90},{-162,-90}},
                                                         color={0,0,127}));
        connect(FW_media.y, add.u1) annotation (Line(points={{-139,30},{-80,30},{-80,-14},
                {-42,-14}},           color={0,0,127}));
        connect(valveLiq.outlet, sensW.inlet)
          annotation (Line(points={{62,0},{82,0}}, color={0,0,255}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{94,0},{110,0}}, color={0,0,255}));
        connect(sensW.w, PID_valve.PV) annotation (Line(points={{96,10},{100,10},{100,
                86},{-20,86},{-20,65},{2,65}},      color={0,0,127}));
        connect(accumulator.WaterOutfl, valveLiq.inlet) annotation (Line(points={
                {27.46,-0.1},{34.73,-0.1},{34.73,0},{42,0}}, color={0,0,255}));
        connect(sourceMassFlow.flange, accumulator.WaterInfl) annotation (Line(
              points={{0,0},{14.54,0},{14.54,-0.1}}, color={0,0,255}));
        connect(const.y, accumulator.GasInfl) annotation (Line(points={{0.5,41},{3.25,
                41},{3.25,34.1},{6.94,34.1}},      color={0,0,127}));
        connect(const1.y, accumulator.OutletValveOpening) annotation (Line(points={{31.5,53},
                {29.36,53},{29.36,34.1}},           color={0,0,127}));
        connect(switch1.y, add.u2) annotation (Line(points={{-53,-38},{-52,-38},{
                -52,-26},{-42,-26}}, color={0,0,127}));
        connect(booleanStep.y, switch1.u2) annotation (Line(points={{-99,-38},{-86,-38},
                {-76,-38}},                    color={255,0,255}));
        connect(add.y, sourceMassFlow.in_w0) annotation (Line(points={{-19,-20},{
                -14,-20},{-14,-6}}, color={0,0,127}));
        connect(const3.y, add1.u1) annotation (Line(points={{-139,-60},{-130,-60},{-130,
                -84},{-122,-84}},      color={0,0,127}));
        connect(noise.y, add1.u2) annotation (Line(points={{-139,-90},{-130,-90},{-130,
                -96},{-122,-96}},       color={0,0,127}));
        connect(add1.y, switch1.u3) annotation (Line(points={{-99,-90},{-88,-90},{-88,
                -46},{-86,-46},{-86,-46},{-76,-46},{-76,-46}},
                            color={0,0,127}));
        connect(valve_dynamic.y, valve_lim.u)
          annotation (Line(points={{52,29.4},{52,25.2}}, color={0,0,127}));
        connect(valveLiq.theta, valve_lim.y)
          annotation (Line(points={{52,8},{52,11.4}}, color={0,0,127}));
        connect(booleanStep1.y, PID_valve.TS)
          annotation (Line(points={{19,110},{14,110},{14,74}}, color={255,0,255}));
        connect(const5.y, PID_valve.TR)
          annotation (Line(points={{1,110},{10,110},{10,74}}, color={0,0,127}));
        connect(w_FW_SP.y, PID_valve.SP)
          annotation (Line(points={{-139,72},{-38,72},{2,72}}, color={0,0,127}));
        connect(FW_media.y, add3.u2) annotation (Line(points={{-139,30},{-132,30},{-132,
                -10},{-122,-10}}, color={0,0,127}));
        connect(w_FW_SP.y, add3.u1) annotation (Line(points={{-139,72},{-128,72},{-128,
                2},{-122,2}}, color={0,0,127}));
        connect(add3.y, switch1.u1) annotation (Line(points={{-99,-4},{-90,-4},{-90,-30},
                {-76,-30}}, color={0,0,127}));
        connect(PID_valve.CS, valve_dynamic.u)
          annotation (Line(points={{19,66},{52,66},{52,43.2}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},
                  {200,140}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},{200,140}})),
          experiment(StopTime=26, __Dymola_NumberOfIntervals=50000),
          __Dymola_experimentSetupOutput);
      end test_volumetricPump_RC_5;

      model test_volumetricPump_RC_05
        "Test to check the mass flow control on the volumetric pump"

        Modelica.Blocks.Sources.Sine sine(
          amplitude=0.342,
          phase=0,
          offset=0,
          freqHz=9.6)
          annotation (Placement(transformation(extent={{-190,-100},{-170,-80}})));
        Modelica.Blocks.Math.Abs noise
          annotation (Placement(transformation(extent={{-160,-100},{-140,-80}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          use_in_w0=true,
          use_in_h=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=981.7e3)
          annotation (Placement(transformation(extent={{-20,10},{0,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{110,-10},{130,10}})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=2.5,
          thetanom=0.5,
          Av=1.3801e-4,
          pnom=19000000,
          dpnom=1600000)
          annotation (Placement(transformation(extent={{42,-10},{62,10}})));
        Modelica.Blocks.Sources.Step     FW_media(
          offset=2.5,
          startTime=26,
          height=0)
          annotation (Placement(transformation(extent={{-160,20},{-140,40}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-200,120},{-180,140}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{78,-6},{98,14}})));
        IndustrialControlSystems.Controllers.PI PID_valve(
          AntiWindup=true,
          CSmin=0,
          CS_start=0.5,
          CSmax=1,
          useTS=true,
          Ti=0.1419,
          Kp=20)
          annotation (Placement(transformation(extent={{0,56},{20,76}})));
        ThermoPower.Water.Accumulator accumulator(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          hl_start=1e6,
          wg_out0=0,
          zl_start=0,
          zl0=0.1,
          V=0.02,
          Vl0=0.01,
          A=0.1,
          pg_start=25000000,
          Tg_start=498.15,
          Tgin=293.15,
          pg0=19000000)
          annotation (Placement(transformation(extent={{2,-2},{40,36}})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-10,36},{0,46}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{42,48},{32,58}})));
        Modelica.Blocks.Continuous.FirstOrder valve_dynamic(
          k=1,
          y_start=0.5,
          initType=Modelica.Blocks.Types.Init.InitialOutput,
          T=0.2)  annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=270,
              origin={52,36})));

        Real R = 2*valveLiq.dp/valveLiq.w;
        Real C = accumulator.rho*accumulator.Vg/accumulator.pg;
        Real RC = R*C;
        Real var_per_in = (add.y - w_FW_SP.y)/w_FW_SP.y*100;
        Real var_per_out = (valveLiq.w - w_FW_SP.y)/w_FW_SP.y*100;

        Modelica.Blocks.Logical.Switch switch1
          annotation (Placement(transformation(extent={{-74,-48},{-54,-28}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(             startValue=
              true, startTime=10)
          annotation (Placement(transformation(extent={{-120,-48},{-100,-28}})));
        Modelica.Blocks.Math.Add add1(k1=-1)
          annotation (Placement(transformation(extent={{-120,-100},{-100,-80}})));
        Modelica.Blocks.Sources.Constant const3(k=0.228)
          annotation (Placement(transformation(extent={{-160,-70},{-140,-50}})));
        Modelica.Blocks.Nonlinear.Limiter valve_lim(uMax=0.9, uMin=0.1)
          annotation (Placement(transformation(
              extent={{6,-6},{-6,6}},
              rotation=90,
              origin={52,18})));
        Modelica.Blocks.Sources.Constant const5(k=0.5)
          annotation (Placement(transformation(extent={{-20,100},{0,120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(            startValue=
              true, startTime=1000)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        Modelica.Blocks.Sources.Constant w_FW_SP(k=2.4897)
          annotation (Placement(transformation(extent={{-160,62},{-140,82}})));
        Modelica.Blocks.Math.Add add3(k2=-1)
          annotation (Placement(transformation(extent={{-120,-14},{-100,6}})));
      equation
        connect(sine.y, noise.u)
          annotation (Line(points={{-169,-90},{-162,-90}},
                                                         color={0,0,127}));
        connect(FW_media.y, add.u1) annotation (Line(points={{-139,30},{-80,30},{-80,-14},
                {-42,-14}},           color={0,0,127}));
        connect(valveLiq.outlet, sensW.inlet)
          annotation (Line(points={{62,0},{82,0}}, color={0,0,255}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{94,0},{110,0}}, color={0,0,255}));
        connect(sensW.w, PID_valve.PV) annotation (Line(points={{96,10},{100,10},{100,
                86},{-20,86},{-20,65},{2,65}},      color={0,0,127}));
        connect(accumulator.WaterOutfl, valveLiq.inlet) annotation (Line(points={
                {27.46,-0.1},{34.73,-0.1},{34.73,0},{42,0}}, color={0,0,255}));
        connect(sourceMassFlow.flange, accumulator.WaterInfl) annotation (Line(
              points={{0,0},{14.54,0},{14.54,-0.1}}, color={0,0,255}));
        connect(const.y, accumulator.GasInfl) annotation (Line(points={{0.5,41},{3.25,
                41},{3.25,34.1},{6.94,34.1}},      color={0,0,127}));
        connect(const1.y, accumulator.OutletValveOpening) annotation (Line(points={{31.5,53},
                {29.36,53},{29.36,34.1}},           color={0,0,127}));
        connect(switch1.y, add.u2) annotation (Line(points={{-53,-38},{-52,-38},{
                -52,-26},{-42,-26}}, color={0,0,127}));
        connect(booleanStep.y, switch1.u2) annotation (Line(points={{-99,-38},{-86,-38},
                {-76,-38}},                    color={255,0,255}));
        connect(add.y, sourceMassFlow.in_w0) annotation (Line(points={{-19,-20},{
                -14,-20},{-14,-6}}, color={0,0,127}));
        connect(const3.y, add1.u1) annotation (Line(points={{-139,-60},{-130,-60},{-130,
                -84},{-122,-84}},      color={0,0,127}));
        connect(noise.y, add1.u2) annotation (Line(points={{-139,-90},{-130,-90},{-130,
                -96},{-122,-96}},       color={0,0,127}));
        connect(add1.y, switch1.u3) annotation (Line(points={{-99,-90},{-88,-90},{-88,
                -46},{-86,-46},{-86,-46},{-76,-46},{-76,-46}},
                            color={0,0,127}));
        connect(valve_dynamic.y, valve_lim.u)
          annotation (Line(points={{52,29.4},{52,25.2}}, color={0,0,127}));
        connect(valveLiq.theta, valve_lim.y)
          annotation (Line(points={{52,8},{52,11.4}}, color={0,0,127}));
        connect(booleanStep1.y, PID_valve.TS)
          annotation (Line(points={{19,110},{14,110},{14,74}}, color={255,0,255}));
        connect(const5.y, PID_valve.TR)
          annotation (Line(points={{1,110},{10,110},{10,74}}, color={0,0,127}));
        connect(w_FW_SP.y, PID_valve.SP)
          annotation (Line(points={{-139,72},{-38,72},{2,72}}, color={0,0,127}));
        connect(FW_media.y, add3.u2) annotation (Line(points={{-139,30},{-132,30},{-132,
                -10},{-122,-10}}, color={0,0,127}));
        connect(w_FW_SP.y, add3.u1) annotation (Line(points={{-139,72},{-128,72},{-128,
                2},{-122,2}}, color={0,0,127}));
        connect(add3.y, switch1.u1) annotation (Line(points={{-99,-4},{-90,-4},{-90,-30},
                {-76,-30}}, color={0,0,127}));
        connect(PID_valve.CS, valve_dynamic.u)
          annotation (Line(points={{19,66},{52,66},{52,43.2}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},
                  {200,140}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},{200,140}})),
          experiment(StopTime=26, __Dymola_NumberOfIntervals=50000),
          __Dymola_experimentSetupOutput);
      end test_volumetricPump_RC_05;

      model test_volumetricPump_RC_50
        "Test to check the mass flow control on the volumetric pump"

        Modelica.Blocks.Sources.Sine sine(
          amplitude=0.342,
          phase=0,
          offset=0,
          freqHz=9.6)
          annotation (Placement(transformation(extent={{-190,-100},{-170,-80}})));
        Modelica.Blocks.Math.Abs noise
          annotation (Placement(transformation(extent={{-160,-100},{-140,-80}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          use_in_w0=true,
          use_in_h=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=981.7e3)
          annotation (Placement(transformation(extent={{-20,10},{0,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{110,-10},{130,10}})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=2.5,
          thetanom=0.5,
          Av=1.4753e-4,
          pnom=17800000,
          dpnom=400000)
          annotation (Placement(transformation(extent={{42,-10},{62,10}})));
        Modelica.Blocks.Sources.Step     FW_media(
          offset=2.5,
          startTime=26,
          height=0)
          annotation (Placement(transformation(extent={{-160,20},{-140,40}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-200,120},{-180,140}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{78,-6},{98,14}})));
        IndustrialControlSystems.Controllers.PI PID_valve(
          AntiWindup=true,
          CSmin=0,
          CS_start=0.5,
          CSmax=1,
          useTS=true,
          Ti=0.1419,
          Kp=20)
          annotation (Placement(transformation(extent={{0,56},{20,76}})));
        ThermoPower.Water.Accumulator accumulator(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          hl_start=1e6,
          wg_out0=0,
          zl_start=0,
          V=2,
          Vl0=1,
          A=1,
          zl0=1,
          pg_start=25000000,
          Tg_start=498.15,
          Tgin=293.15,
          pg0=19000000)
          annotation (Placement(transformation(extent={{2,-2},{40,36}})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-10,36},{0,46}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{42,48},{32,58}})));
        Modelica.Blocks.Continuous.FirstOrder valve_dynamic(
          k=1,
          y_start=0.5,
          initType=Modelica.Blocks.Types.Init.InitialOutput,
          T=0.2)  annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=270,
              origin={52,36})));

        Real R = 2*valveLiq.dp/valveLiq.w;
        Real C = accumulator.rho*accumulator.Vg/accumulator.pg;
        Real RC = R*C;
        Real var_per_in = (add.y - w_FW_SP.y)/w_FW_SP.y*100;
        Real var_per_out = (valveLiq.w - w_FW_SP.y)/w_FW_SP.y*100;

        Modelica.Blocks.Logical.Switch switch1
          annotation (Placement(transformation(extent={{-74,-48},{-54,-28}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(             startValue=
              true, startTime=10)
          annotation (Placement(transformation(extent={{-120,-48},{-100,-28}})));
        Modelica.Blocks.Math.Add add1(k1=-1)
          annotation (Placement(transformation(extent={{-120,-100},{-100,-80}})));
        Modelica.Blocks.Sources.Constant const3(k=0.228)
          annotation (Placement(transformation(extent={{-160,-70},{-140,-50}})));
        Modelica.Blocks.Nonlinear.Limiter valve_lim(uMax=0.9, uMin=0.1)
          annotation (Placement(transformation(
              extent={{6,-6},{-6,6}},
              rotation=90,
              origin={52,18})));
        Modelica.Blocks.Sources.Constant const5(k=0.5)
          annotation (Placement(transformation(extent={{-20,100},{0,120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(            startValue=
              true, startTime=1000)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        Modelica.Blocks.Sources.Constant w_FW_SP(k=2.4897)
          annotation (Placement(transformation(extent={{-160,62},{-140,82}})));
        Modelica.Blocks.Math.Add add3(k2=-1)
          annotation (Placement(transformation(extent={{-120,-14},{-100,6}})));
      equation
        connect(sine.y, noise.u)
          annotation (Line(points={{-169,-90},{-162,-90}},
                                                         color={0,0,127}));
        connect(FW_media.y, add.u1) annotation (Line(points={{-139,30},{-80,30},{-80,-14},
                {-42,-14}},           color={0,0,127}));
        connect(valveLiq.outlet, sensW.inlet)
          annotation (Line(points={{62,0},{82,0}}, color={0,0,255}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{94,0},{110,0}}, color={0,0,255}));
        connect(sensW.w, PID_valve.PV) annotation (Line(points={{96,10},{100,10},{100,
                86},{-20,86},{-20,65},{2,65}},      color={0,0,127}));
        connect(accumulator.WaterOutfl, valveLiq.inlet) annotation (Line(points={
                {27.46,-0.1},{34.73,-0.1},{34.73,0},{42,0}}, color={0,0,255}));
        connect(sourceMassFlow.flange, accumulator.WaterInfl) annotation (Line(
              points={{0,0},{14.54,0},{14.54,-0.1}}, color={0,0,255}));
        connect(const.y, accumulator.GasInfl) annotation (Line(points={{0.5,41},{3.25,
                41},{3.25,34.1},{6.94,34.1}},      color={0,0,127}));
        connect(const1.y, accumulator.OutletValveOpening) annotation (Line(points={{31.5,53},
                {29.36,53},{29.36,34.1}},           color={0,0,127}));
        connect(switch1.y, add.u2) annotation (Line(points={{-53,-38},{-52,-38},{
                -52,-26},{-42,-26}}, color={0,0,127}));
        connect(booleanStep.y, switch1.u2) annotation (Line(points={{-99,-38},{-86,-38},
                {-76,-38}},                    color={255,0,255}));
        connect(add.y, sourceMassFlow.in_w0) annotation (Line(points={{-19,-20},{
                -14,-20},{-14,-6}}, color={0,0,127}));
        connect(const3.y, add1.u1) annotation (Line(points={{-139,-60},{-130,-60},{-130,
                -84},{-122,-84}},      color={0,0,127}));
        connect(noise.y, add1.u2) annotation (Line(points={{-139,-90},{-130,-90},{-130,
                -96},{-122,-96}},       color={0,0,127}));
        connect(add1.y, switch1.u3) annotation (Line(points={{-99,-90},{-88,-90},{-88,
                -46},{-86,-46},{-86,-46},{-76,-46},{-76,-46}},
                            color={0,0,127}));
        connect(valve_dynamic.y, valve_lim.u)
          annotation (Line(points={{52,29.4},{52,25.2}}, color={0,0,127}));
        connect(valveLiq.theta, valve_lim.y)
          annotation (Line(points={{52,8},{52,11.4}}, color={0,0,127}));
        connect(booleanStep1.y, PID_valve.TS)
          annotation (Line(points={{19,110},{14,110},{14,74}}, color={255,0,255}));
        connect(const5.y, PID_valve.TR)
          annotation (Line(points={{1,110},{10,110},{10,74}}, color={0,0,127}));
        connect(w_FW_SP.y, PID_valve.SP)
          annotation (Line(points={{-139,72},{-38,72},{2,72}}, color={0,0,127}));
        connect(FW_media.y, add3.u2) annotation (Line(points={{-139,30},{-132,30},{-132,
                -10},{-122,-10}}, color={0,0,127}));
        connect(w_FW_SP.y, add3.u1) annotation (Line(points={{-139,72},{-128,72},{-128,
                2},{-122,2}}, color={0,0,127}));
        connect(add3.y, switch1.u1) annotation (Line(points={{-99,-4},{-90,-4},{-90,-30},
                {-76,-30}}, color={0,0,127}));
        connect(PID_valve.CS, valve_dynamic.u) annotation (Line(points={{19,66},{
                36,66},{52,66},{52,43.2}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},
                  {200,140}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},{200,140}})),
          experiment(StopTime=26, __Dymola_NumberOfIntervals=5000),
          __Dymola_experimentSetupOutput);
      end test_volumetricPump_RC_50;

      model test_volumetricPump_RC_500
        "Test to check the mass flow control on the volumetric pump"

        Modelica.Blocks.Sources.Sine sine(
          amplitude=0.342,
          phase=0,
          offset=0,
          freqHz=9.6)
          annotation (Placement(transformation(extent={{-190,-100},{-170,-80}})));
        Modelica.Blocks.Math.Abs noise
          annotation (Placement(transformation(extent={{-160,-100},{-140,-80}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-40,-30},{-20,-10}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          use_in_w0=true,
          use_in_h=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=981.7e3)
          annotation (Placement(transformation(extent={{-20,10},{0,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{110,-10},{130,10}})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=2.5,
          thetanom=0.5,
          Av=1.4753e-4,
          pnom=17800000,
          dpnom=400000)
          annotation (Placement(transformation(extent={{42,-10},{62,10}})));
        Modelica.Blocks.Sources.Step     FW_media(
          offset=2.5,
          startTime=26,
          height=0)
          annotation (Placement(transformation(extent={{-160,20},{-140,40}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-200,120},{-180,140}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{78,-6},{98,14}})));
        IndustrialControlSystems.Controllers.PI PID_valve(
          AntiWindup=true,
          CSmin=0,
          CS_start=0.5,
          CSmax=1,
          useTS=true,
          Ti=0.1419,
          Kp=20)
          annotation (Placement(transformation(extent={{0,56},{20,76}})));
        ThermoPower.Water.Accumulator accumulator(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          hl_start=1e6,
          wg_out0=0,
          zl_start=0,
          V=20,
          Vl0=10,
          A=5,
          zl0=2,
          pg_start=25000000,
          Tg_start=498.15,
          Tgin=293.15,
          pg0=19000000)
          annotation (Placement(transformation(extent={{2,-2},{40,36}})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-10,36},{0,46}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{42,48},{32,58}})));
        Modelica.Blocks.Continuous.FirstOrder valve_dynamic(
          k=1,
          y_start=0.5,
          initType=Modelica.Blocks.Types.Init.InitialOutput,
          T=0.2)  annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=270,
              origin={52,36})));

        Real R = 2*valveLiq.dp/valveLiq.w;
        Real C = accumulator.rho*accumulator.Vg/accumulator.pg;
        Real RC = R*C;
        Real var_per_in = (add.y - w_FW_SP.y)/w_FW_SP.y*100;
        Real var_per_out = (valveLiq.w - w_FW_SP.y)/w_FW_SP.y*100;

        Modelica.Blocks.Logical.Switch switch1
          annotation (Placement(transformation(extent={{-74,-48},{-54,-28}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(             startValue=
              true, startTime=10)
          annotation (Placement(transformation(extent={{-120,-48},{-100,-28}})));
        Modelica.Blocks.Math.Add add1(k1=-1)
          annotation (Placement(transformation(extent={{-120,-100},{-100,-80}})));
        Modelica.Blocks.Sources.Constant const3(k=0.228)
          annotation (Placement(transformation(extent={{-160,-70},{-140,-50}})));
        Modelica.Blocks.Nonlinear.Limiter valve_lim(uMax=0.9, uMin=0.1)
          annotation (Placement(transformation(
              extent={{6,-6},{-6,6}},
              rotation=90,
              origin={52,18})));
        Modelica.Blocks.Sources.Constant const5(k=0.5)
          annotation (Placement(transformation(extent={{-20,100},{0,120}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(            startValue=
              true, startTime=1000)
          annotation (Placement(transformation(extent={{40,100},{20,120}})));
        Modelica.Blocks.Sources.Constant w_FW_SP(k=2.4897)
          annotation (Placement(transformation(extent={{-160,62},{-140,82}})));
        Modelica.Blocks.Math.Add add3(k2=-1)
          annotation (Placement(transformation(extent={{-120,-14},{-100,6}})));
      equation
        connect(sine.y, noise.u)
          annotation (Line(points={{-169,-90},{-162,-90}},
                                                         color={0,0,127}));
        connect(FW_media.y, add.u1) annotation (Line(points={{-139,30},{-80,30},{-80,-14},
                {-42,-14}},           color={0,0,127}));
        connect(valveLiq.outlet, sensW.inlet)
          annotation (Line(points={{62,0},{82,0}}, color={0,0,255}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{94,0},{110,0}}, color={0,0,255}));
        connect(sensW.w, PID_valve.PV) annotation (Line(points={{96,10},{100,10},{100,
                86},{-20,86},{-20,65},{2,65}},      color={0,0,127}));
        connect(accumulator.WaterOutfl, valveLiq.inlet) annotation (Line(points={
                {27.46,-0.1},{34.73,-0.1},{34.73,0},{42,0}}, color={0,0,255}));
        connect(sourceMassFlow.flange, accumulator.WaterInfl) annotation (Line(
              points={{0,0},{14.54,0},{14.54,-0.1}}, color={0,0,255}));
        connect(const.y, accumulator.GasInfl) annotation (Line(points={{0.5,41},{3.25,
                41},{3.25,34.1},{6.94,34.1}},      color={0,0,127}));
        connect(const1.y, accumulator.OutletValveOpening) annotation (Line(points={{31.5,53},
                {29.36,53},{29.36,34.1}},           color={0,0,127}));
        connect(switch1.y, add.u2) annotation (Line(points={{-53,-38},{-52,-38},{
                -52,-26},{-42,-26}}, color={0,0,127}));
        connect(booleanStep.y, switch1.u2) annotation (Line(points={{-99,-38},{-86,-38},
                {-76,-38}},                    color={255,0,255}));
        connect(add.y, sourceMassFlow.in_w0) annotation (Line(points={{-19,-20},{
                -14,-20},{-14,-6}}, color={0,0,127}));
        connect(const3.y, add1.u1) annotation (Line(points={{-139,-60},{-130,-60},{-130,
                -84},{-122,-84}},      color={0,0,127}));
        connect(noise.y, add1.u2) annotation (Line(points={{-139,-90},{-130,-90},{-130,
                -96},{-122,-96}},       color={0,0,127}));
        connect(add1.y, switch1.u3) annotation (Line(points={{-99,-90},{-88,-90},{-88,
                -46},{-86,-46},{-86,-46},{-76,-46},{-76,-46}},
                            color={0,0,127}));
        connect(valve_dynamic.y, valve_lim.u)
          annotation (Line(points={{52,29.4},{52,25.2}}, color={0,0,127}));
        connect(valveLiq.theta, valve_lim.y)
          annotation (Line(points={{52,8},{52,11.4}}, color={0,0,127}));
        connect(booleanStep1.y, PID_valve.TS)
          annotation (Line(points={{19,110},{14,110},{14,74}}, color={255,0,255}));
        connect(const5.y, PID_valve.TR)
          annotation (Line(points={{1,110},{10,110},{10,74}}, color={0,0,127}));
        connect(w_FW_SP.y, PID_valve.SP)
          annotation (Line(points={{-139,72},{-38,72},{2,72}}, color={0,0,127}));
        connect(FW_media.y, add3.u2) annotation (Line(points={{-139,30},{-132,30},{-132,
                -10},{-122,-10}}, color={0,0,127}));
        connect(w_FW_SP.y, add3.u1) annotation (Line(points={{-139,72},{-128,72},{-128,
                2},{-122,2}}, color={0,0,127}));
        connect(add3.y, switch1.u1) annotation (Line(points={{-99,-4},{-90,-4},{-90,-30},
                {-76,-30}}, color={0,0,127}));
        connect(PID_valve.CS, valve_dynamic.u) annotation (Line(points={{19,66},{
                36,66},{52,66},{52,43.2}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},
                  {200,140}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-200,-100},{200,140}})),
          experiment(StopTime=26, __Dymola_NumberOfIntervals=50000),
          __Dymola_experimentSetupOutput);
      end test_volumetricPump_RC_500;

      model lin_volumetricPump
        "Test to linearize the model of the volumetric pump"

        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          use_in_h=false,
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=981.7e3,
          p0=19000000,
          use_in_w0=true)
          annotation (Placement(transformation(extent={{-80,10},{-60,-10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{80,-10},{100,10}})));
        ThermoPower.Water.ValveLiq valveLiq(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          wnom=2.5,
          thetanom=0.5,
          Av=0.000276012,
          pnom=19000000,
          dpnom=1600000)
          annotation (Placement(transformation(extent={{0,-10},{20,10}})));
        Modelica.Blocks.Sources.Step     FW_media(          offset=2.5,
          startTime=10,
          height=0)
          annotation (Placement(transformation(extent={{-120,-80},{-100,-60}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-140,80},{-120,100}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{40,-6},{60,14}})));
        ThermoPower.Water.Accumulator accumulator(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          hl_start=1e6,
          wg_out0=0,
          zl_start=0,
          noInitialPressure=true,
          Vl0=0.1,
          A=0.125,
          zl0=0.8,
          V=0.2,
          pg_start=25000000,
          Tg_start=498.15,
          Tgin=293.15,
          pg0=19000000)
          annotation (Placement(transformation(extent={{-54,-2},{-16,36}})));
        Modelica.Blocks.Sources.Constant const(k=0)
          annotation (Placement(transformation(extent={{-66,36},{-56,46}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{-14,36},{-24,46}})));

        Real R = 2*valveLiq.dp/valveLiq.w;
        Real C = accumulator.rho*accumulator.Vg/accumulator.pg;
        Real RC = R*C;

        Modelica.Blocks.Sources.Constant theta_nom(k=0.5)
          annotation (Placement(transformation(extent={{-40,60},{-20,80}})));
        Modelica.Blocks.Math.Add add annotation (Placement(transformation(
              extent={{-6,-6},{6,6}},
              rotation=270,
              origin={10,46})));
        Modelica.Blocks.Sources.Step step(
          offset=0,
          startTime=10,
          height=0.1)
          annotation (Placement(transformation(extent={{100,74},{80,94}})));
        Modelica.Blocks.Continuous.FirstOrder valve_dynamic(
          k=1,
          y_start=0.5,
          initType=Modelica.Blocks.Types.Init.InitialOutput,
          T=0.3)  annotation (Placement(transformation(extent={{-6,-6},{6,6}},
              rotation=-90,
              origin={10,24})));

        Modelica.Blocks.Math.Add add1
                                     annotation (Placement(transformation(
              extent={{-6,-6},{6,6}},
              rotation=90,
              origin={-74,-40})));
        ThermoPower.Water.SensP sensP(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph) annotation (Placement(transformation(
              extent={{10,-10},{-10,10}},
              rotation=180,
              origin={-14,-4})));
        Modelica.Blocks.Interfaces.RealInput dtheta annotation (Placement(
              transformation(
              extent={{-20,-20},{20,20}},
              rotation=180,
              origin={60,70})));
        Modelica.Blocks.Interfaces.RealInput di annotation (Placement(transformation(
              extent={{-20,-20},{20,20}},
              rotation=180,
              origin={-40,-70})));
        Modelica.Blocks.Interfaces.RealOutput y_w  annotation (Placement(transformation(extent={{100,30},{120,50}})));
        Modelica.Blocks.Interfaces.RealOutput y_p
          annotation (Placement(transformation(extent={{20,-50},{40,-30}})));
      equation
        connect(valveLiq.outlet, sensW.inlet)
          annotation (Line(points={{20,0},{44,0}}, color={0,0,255}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{56,0},{68,0},{80,0}},
                                                    color={0,0,255}));
        connect(sourceMassFlow.flange, accumulator.WaterInfl) annotation (Line(
              points={{-60,0},{-41.46,0},{-41.46,-0.1}},
                                                     color={0,0,255}));
        connect(const.y, accumulator.GasInfl) annotation (Line(points={{-55.5,41},
                {-52.75,41},{-52.75,34.1},{-49.06,34.1}},
                                                   color={0,0,127}));
        connect(const1.y, accumulator.OutletValveOpening) annotation (Line(points={{-24.5,
                41},{-26.64,41},{-26.64,34.1}},     color={0,0,127}));
        connect(theta_nom.y, add.u2) annotation (Line(points={{-19,70},{6.4,70},{
                6.4,53.2}}, color={0,0,127}));
        connect(sensW.w, y_w) annotation (Line(points={{58,10},{64,10},{64,40},{
                110,40}}, color={0,0,127}));
        connect(add.y, valve_dynamic.u)
          annotation (Line(points={{10,39.4},{10,31.2}}, color={0,0,127}));
        connect(valve_dynamic.y, valveLiq.theta)
          annotation (Line(points={{10,17.4},{10,8}}, color={0,0,127}));
        connect(FW_media.y, add1.u1) annotation (Line(points={{-99,-70},{-77.6,-70},{-77.6,
                -47.2}}, color={0,0,127}));
        connect(sourceMassFlow.in_w0, add1.y) annotation (Line(points={{-74,-6},{-74,-33.4},
                {-74,-33.4}}, color={0,0,127}));
        connect(di, add1.u2) annotation (Line(points={{-40,-70},{-70.4,-70},{-70.4,-47.2}},
              color={0,0,127}));
        connect(dtheta, add.u1)
          annotation (Line(points={{60,70},{13.6,70},{13.6,53.2}}, color={0,0,127}));
        connect(accumulator.WaterOutfl, sensP.flange) annotation (Line(points={{-28.54,
                -0.1},{-20.27,-0.1},{-20.27,0},{-14,0}}, color={0,0,255}));
        connect(sensP.flange, valveLiq.inlet)
          annotation (Line(points={{-14,0},{0,0},{0,0}}, color={0,0,255}));
        connect(sensP.p, y_p) annotation (Line(points={{-6,-10},{0,-10},{0,-40},{30,-40}},
              color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                  -140,-100},{140,100}})),                             Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-140,-100},{
                  140,100}})),
          experiment(StopTime=16),
          __Dymola_experimentSetupOutput);
      end lin_volumetricPump;

      model test_pump_constEfficiency
        "Test model of the component pump_constEfficiency"

        Components.pump_constEfficiency pumpFW(
          use_in_w0=true,
          w0=1.757,
          eta_iso=0.8945)
          annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          p0=2705000,
          h=981.7e3)
          annotation (Placement(transformation(extent={{-80,-6},{-60,14}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=17400000)
          annotation (Placement(transformation(extent={{54,4},{74,24}})));
        Modelica.Blocks.Sources.Constant const(k=1.757)
          annotation (Placement(transformation(extent={{-40,40},{-20,60}})));
        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
      equation
        connect(sourcePressure.flange, pumpFW.infl)
          annotation (Line(points={{-60,4},{-40,4},{-16,4}}, color={0,0,255}));
        connect(pumpFW.outfl, sinkPressure.flange)
          annotation (Line(points={{12,14},{54,14}}, color={0,0,255}));
        connect(const.y, pumpFW.in_w0) annotation (Line(points={{-19,50},{-10,50},
                {0,50},{0,18}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)));
      end test_pump_constEfficiency;

      model attemperator_tuning
        "Test model to tune the SH attemperator controller"

        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
        ThermoPower.Water.SourceMassFlow sourceSH(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=3500000,
          w0=20)
          annotation (Placement(transformation(extent={{-60,30},{-40,50}})));
        ThermoPower.Water.SourceMassFlow sourceATT(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          use_in_w0=true,
          h=565.4e3)
          annotation (Placement(transformation(extent={{-60,-30},{-40,-10}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          noInitialPressure=true,
          hstart=3200000,
          initOpt=ThermoPower.Choices.Init.Options.fixedState,
          FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Steam,
          V=0.5)
          annotation (Placement(transformation(extent={{-20,-10},{0,10}})));
        ThermoPower.Water.SinkPressure sinkTURB(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=14000000)
          annotation (Placement(transformation(extent={{40,-10},{60,10}})));
        ThermoPower.Water.SensT sensT(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{10,-6},{30,14}})));
        Modelica.Blocks.Interfaces.RealInput dw_att
          annotation (Placement(transformation(extent={{-120,20},{-80,60}})));
        Modelica.Blocks.Interfaces.RealOutput T_SHout
          annotation (Placement(transformation(extent={{90,10},{110,30}})));
        Modelica.Blocks.Math.Add add
          annotation (Placement(transformation(extent={{-72,-6},{-60,6}})));
        IndustrialControlSystems.Controllers.PI PI_valveATT(
          useTS=true,
          CS_start=1,
          CSmin=0,
          CSmax=20,
          Ti=0.5,
          Kp=-0.1)
                annotation (Placement(transformation(extent={{0,-40},{-20,-60}})));
        Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=false)
          annotation (Placement(transformation(extent={{-60,-90},{-40,-70}})));
        Modelica.Blocks.Sources.Constant const(k=8.89013)
          annotation (Placement(transformation(extent={{40,-90},{20,-70}})));
        Modelica.Blocks.Sources.Ramp SP(
          duration=20*60,
          offset=733.15,
          startTime=100,
          height=0)
          annotation (Placement(transformation(extent={{80,-66},{60,-46}})));
        Modelica.Blocks.Sources.Step step(startTime=100)
          annotation (Placement(transformation(extent={{-100,0},{-80,20}})));
      equation
        connect(sourceSH.flange, mixer.in1) annotation (Line(points={{-40,40},{
                -30,40},{-30,6},{-18,6}}, color={0,0,255}));
        connect(sourceATT.flange, mixer.in2) annotation (Line(points={{-40,-20},{
                -30,-20},{-30,-6},{-18,-6}}, color={0,0,255}));
        connect(sensT.outlet, sinkTURB.flange)
          annotation (Line(points={{26,0},{40,0}}, color={0,0,255}));
        connect(mixer.out, sensT.inlet)
          annotation (Line(points={{0,0},{7,0},{14,0}}, color={0,0,255}));
        connect(sensT.T, T_SHout) annotation (Line(points={{28,10},{34,10},{34,20},
                {100,20}}, color={0,0,127}));
        connect(add.y, sourceATT.in_w0) annotation (Line(points={{-59.4,0},{-54,0},
                {-54,-14}}, color={0,0,127}));
        connect(booleanConstant.y, PI_valveATT.TS) annotation (Line(points={{-39,
                -80},{-14,-80},{-14,-58}}, color={255,0,255}));
        connect(const.y, PI_valveATT.TR) annotation (Line(points={{19,-80},{-10,
                -80},{-10,-58}}, color={0,0,127}));
        connect(SP.y, PI_valveATT.SP)
          annotation (Line(points={{59,-56},{-2,-56}}, color={0,0,127}));
        connect(sensT.T, PI_valveATT.PV) annotation (Line(points={{28,10},{28,10},
                {34,10},{34,20},{80,20},{80,-30},{20,-30},{20,-49},{-2,-49}},
              color={0,0,127}));
        connect(PI_valveATT.CS, add.u2) annotation (Line(points={{-19,-50},{-78,
                -50},{-78,-3.6},{-73.2,-3.6}}, color={0,0,127}));
        connect(step.y, add.u1) annotation (Line(points={{-79,10},{-78,10},{-78,
                3.6},{-73.2,3.6}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)));
      end attemperator_tuning;

      model test_EletHeater "Test model for the electrical heaters"

        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
        Components.EletHeater eletHeaters(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          V=0.14,
          gamma=1500,
          Mm=90,
          cm=500,
          FluidPhaseStart=ThermoPower.Choices.FluidPhase.FluidPhases.Liquid,
          initOpt=ThermoPower.Choices.Init.Options.steadyState,
          noInitialPressure=true,
          S=50,
          pstart=18000000,
          Tmstart=573.15)
          annotation (Placement(transformation(extent={{-20,10},{0,30}})));
        Modelica.Blocks.Sources.Step Q_th(
          offset=94000,
          startTime=100,
          height=1000)
          annotation (Placement(transformation(extent={{-40,40},{-20,60}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          h=996.9e3,
          use_in_w0=true)
          annotation (Placement(transformation(extent={{-60,10},{-40,30}})));
        Modelica.Blocks.Sources.Step w_FW(
          offset=1.43,
          startTime=100,
          height=0.5)
          annotation (Placement(transformation(extent={{-80,40},{-60,60}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=14190000)
          annotation (Placement(transformation(extent={{60,10},{80,30}})));
        ThermoPower.Water.SensT sensT(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph)
          annotation (Placement(transformation(extent={{20,14},{40,34}})));
        IndustrialControlSystems.Controllers.PI pI(
          AntiWindup=true,
          CSmin=0,
          CSmax=2e5,
          CS_start=94000,
          Kp=540000,
          Ti=10) annotation (Placement(transformation(extent={{20,60},{0,80}})));
        Modelica.Blocks.Sources.Constant const(k=245 + 273.15)
          annotation (Placement(transformation(extent={{80,66},{60,86}})));
      equation
        connect(sourceMassFlow.flange, eletHeaters.inlet)
          annotation (Line(points={{-40,20},{-20,20}}, color={0,0,255}));
        connect(eletHeaters.outlet, sensT.inlet)
          annotation (Line(points={{0,20},{12,20},{24,20}}, color={0,0,255}));
        connect(sensT.outlet, sinkPressure.flange)
          annotation (Line(points={{36,20},{60,20}}, color={0,0,255}));
        connect(sensT.T, pI.PV) annotation (Line(points={{38,30},{46,30},{46,69},
                {18,69}}, color={0,0,127}));
        connect(pI.SP, const.y)
          annotation (Line(points={{18,76},{59,76}}, color={0,0,127}));
        connect(pI.CS, eletHeaters.Q_th) annotation (Line(points={{1,70},{-10,
                70},{-10,28}}, color={0,0,127}));
        connect(w_FW.y, sourceMassFlow.in_w0) annotation (Line(points={{-59,50},
                {-54,50},{-54,26}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)),
          experiment(StopTime=500),
          __Dymola_experimentSetupOutput);
      end test_EletHeater;

      model test_coldMS_pump
        "Test model of the cold molten salt pump and T_MSin control tuning"

        Modelica.SIunits.Mass M_MS_tot;

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
        ThermoPower.Water.Pump pump(
          use_in_n=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          rho0=1905.6,
          n0=1750,
          w0=9,
          redeclare function efficiencyCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.constantEfficiency (
                eta_nom=0.8),
          allowFlowReversal=false,
          s(start=1),
          redeclare function flowCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.polynomialFlow (head_nom={22.8,
                  22.1,21.5,20.8,19.1,17.5,14.5,13}, q_nom={0.1/3600,3.4/3600,6.8/3600,
                  10.2/3600,13.6/3600,17/3600,20.4/3600,21.505/3600}),
          V=0,
          CheckValve=true,
          dp0=327137)
          annotation (Placement(transformation(extent={{-30,-12},{-10,8}})));
        ThermoPower.Water.SinkPressure sinkPressure(use_in_p0=true, redeclare
            package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{60,-4},{80,16}})));
        Modelica.Blocks.Sources.Ramp RPM(
          startTime=100,
          duration=1820,
          offset=1535,
          height=-13.2)
          annotation (Placement(transformation(extent={{-80,40},{-60,60}})));
        Modelica.Blocks.Sources.Ramp const(
          duration=100,
          startTime=10,
          height=1.8e5,
          offset=3.6e5)
          annotation (Placement(transformation(extent={{0,70},{20,90}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-62,-6},{-42,14}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{34,12},{54,-8}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-80,-20},{-60,-40}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{-100,-70},{-80,-50}})));
        Modelica.Blocks.Sources.Constant const2(k=4.43137e5)
          annotation (Placement(transformation(extent={{0,40},{20,60}})));
        IndustrialControlSystems.Controllers.PI pI(
          CS_start=0,
          AntiWindup=true,
          CSmax=14,
          CSmin=0.001,
          Ti=20,
          useTS=true,
          Kp=0.05)
          annotation (Placement(transformation(extent={{0,-40},{-20,-60}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-40,-60},{-60,-40}})));
        Modelica.Blocks.Math.Add3 add3
          annotation (Placement(transformation(extent={{40,-66},{20,-46}})));
        Modelica.Blocks.Sources.Constant const3(k=563.15)
          annotation (Placement(transformation(extent={{80,-40},{60,-20}})));
        Modelica.Blocks.Sources.Step step(
          height=100,
          offset=0,
          startTime=100)
          annotation (Placement(transformation(extent={{80,-70},{60,-50}})));
        Modelica.Blocks.Sources.Ramp ramp(
          duration=1800,
          startTime=100,
          height=175)
          annotation (Placement(transformation(extent={{80,-100},{60,-80}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          V=0.01,
          initOpt=ThermoPower.Choices.Init.Options.steadyState,
          noInitialPressure=true)
          annotation (Placement(transformation(extent={{6,-4},{26,16}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-50,40},{-30,60}})));
        Modelica.Blocks.Sources.Constant
                                     const4(k=11.96)
          annotation (Placement(transformation(extent={{20,-100},{0,-80}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=1900,
            startValue=false)
          annotation (Placement(transformation(extent={{-60,-100},{-40,-80}})));
      equation

        if time >= 100 and time <= 1900 then
          der(M_MS_tot) = sourceMassFlow.w;
        else
          der(M_MS_tot) = 0;
        end if;

        connect(sensT_cold.outlet, pump.infl)
          annotation (Line(points={{-46,0},{-28,0}}, color={0,0,255}));
        connect(sourcePressure.flange, sensT_cold.inlet)
          annotation (Line(points={{-80,0},{-58,0}}, color={0,0,255}));
        connect(sensT_mix.outlet, sinkPressure.flange)
          annotation (Line(points={{50,6},{60,6}}, color={0,0,255}));
        connect(const2.y, sinkPressure.in_p0) annotation (Line(points={{21,50},
                {66,50},{66,14.8}}, color={0,0,127}));
        connect(sensT_mix.T, pI.PV) annotation (Line(points={{52,-4},{54,-4},{54,-20},
                {10,-20},{10,-49},{-2,-49}},       color={0,0,127}));
        connect(firstOrder.u, pI.CS)
          annotation (Line(points={{-38,-50},{-19,-50}}, color={0,0,127}));
        connect(firstOrder.y, sourceMassFlow.in_w0) annotation (Line(points={{-61,-50},
                {-74,-50},{-74,-36}},          color={0,0,127}));
        connect(pI.SP, add3.y)
          annotation (Line(points={{-2,-56},{19,-56}}, color={0,0,127}));
        connect(const3.y, add3.u1) annotation (Line(points={{59,-30},{52,-30},{52,-48},
                {42,-48}}, color={0,0,127}));
        connect(step.y, add3.u2) annotation (Line(points={{59,-60},{52,-60},{52,-56},{
                42,-56}}, color={0,0,127}));
        connect(ramp.y, add3.u3) annotation (Line(points={{59,-90},{52,-90},{52,-64},{
                42,-64}}, color={0,0,127}));
        connect(pump.outfl, mixer.in1)
          annotation (Line(points={{-14,5},{-14,12},{8,12}}, color={0,0,255}));
        connect(sourceMassFlow.flange, mixer.in2) annotation (Line(points={{-60,-30},
                {0,-30},{0,0},{8,0}},        color={0,0,255}));
        connect(mixer.out, sensT_mix.inlet)
          annotation (Line(points={{26,6},{32,6},{38,6}}, color={0,0,255}));
        connect(firstOrder1.y, pump.in_n) annotation (Line(points={{-29,50},{
                -22.6,50},{-22.6,6}}, color={0,0,127}));
        connect(RPM.y, firstOrder1.u)
          annotation (Line(points={{-59,50},{-52,50}}, color={0,0,127}));
        connect(const4.y, pI.TR) annotation (Line(points={{-1,-90},{-10,-90},{
                -10,-58}}, color={0,0,127}));
        connect(booleanStep.y, pI.TS) annotation (Line(points={{-39,-90},{-14,
                -90},{-14,-58}}, color={255,0,255}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)),
          experiment(StopTime=2000, __Dymola_NumberOfIntervals=2000),
          __Dymola_experimentSetupOutput);
      end test_coldMS_pump;

      model test_coldMS_pump2
        "Test model of the cold molten salt pump and T_MSin control tuning"

        Modelica.SIunits.Mass M_MS_tot;

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-118,-50},{-98,-30}})));
        ThermoPower.Water.Pump pump(
          use_in_n=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          rho0=1905.6,
          n0=1750,
          V=0.001,
          CheckValve=true,
          w0=9,
          redeclare function efficiencyCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.constantEfficiency (
                eta_nom=0.8),
          allowFlowReversal=false,
          s(start=1),
          redeclare function flowCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.polynomialFlow (head_nom={22.8,
                  22.1,21.5,20.8,19.1,17.5,14.5,13}, q_nom={0.1/3600,3.4/3600,6.8/3600,
                  10.2/3600,13.6/3600,17/3600,20.4/3600,21.505/3600}),
          dp0=327137)
          annotation (Placement(transformation(extent={{-48,-52},{-28,-32}})));
        ThermoPower.Water.SinkPressure sinkPressure(use_in_p0=true, redeclare
            package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{100,-44},{120,-24}})));
        Modelica.Blocks.Sources.Ramp RPM(
          offset=1750,
          duration=1000,
          height=-250,
          startTime=830)
          annotation (Placement(transformation(extent={{-120,0},{-100,20}})));
        Modelica.Blocks.Sources.Constant
                                     const(k=1600)
          annotation (Placement(transformation(extent={{-20,80},{0,100}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-80,-46},{-60,-26}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{34,-40},{54,-20}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-80,-60},{-60,-80}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{-100,-110},{-80,-90}})));
        Modelica.Blocks.Sources.Constant const2(k=4.43e5)
          annotation (Placement(transformation(extent={{140,0},{120,20}})));
        IndustrialControlSystems.Controllers.PI pI(
          AntiWindup=true,
          CS_start=1750,
          CSmin=1000,
          useTS=true,
          CSmax=1950,
          Kp=-0.5,
          Ti=20)
          annotation (Placement(transformation(extent={{40,0},{20,20}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-40,-100},{-60,-80}})));
        Modelica.Blocks.Math.Add add3
          annotation (Placement(transformation(extent={{20,-100},{0,-80}})));
        Modelica.Blocks.Sources.Step step(
          startTime=100,
          offset=0.01,
          height=1.1)
          annotation (Placement(transformation(extent={{60,-90},{40,-70}})));
        Modelica.Blocks.Sources.Ramp ramp(
          duration=1800,
          startTime=100,
          height=11.96 - step.height)
          annotation (Placement(transformation(extent={{60,-120},{40,-100}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          V=0.01,
          noInitialPressure=false,
          pstart=443137,
          initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-12,-44},{8,-24}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{0,0},{-20,20}})));
        Modelica.Blocks.Math.Add3 add1
          annotation (Placement(transformation(extent={{100,74},{80,94}})));
        Modelica.Blocks.Sources.Constant const3(k=563.15)
          annotation (Placement(transformation(extent={{140,100},{120,120}})));
        Modelica.Blocks.Sources.Step step1(
          offset=0,
          startTime=100,
          height=50)
          annotation (Placement(transformation(extent={{140,70},{120,90}})));
        Modelica.Blocks.Sources.Ramp ramp1(
          duration=1800,
          startTime=100,
          height=225)
          annotation (Placement(transformation(extent={{140,40},{120,60}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=100, startValue=true)
          annotation (Placement(transformation(extent={{-20,40},{0,60}})));
      equation

        if time >= 100 and time <= 1900 then
          der(M_MS_tot) = sourceMassFlow.w;
        else
          der(M_MS_tot) = 0;
        end if;

        connect(sensT_cold.outlet, pump.infl)
          annotation (Line(points={{-64,-40},{-46,-40}},
                                                     color={0,0,255}));
        connect(sourcePressure.flange, sensT_cold.inlet)
          annotation (Line(points={{-98,-40},{-76,-40}},
                                                     color={0,0,255}));
        connect(const2.y, sinkPressure.in_p0) annotation (Line(points={{119,10},{106,10},
                {106,-25.2}},       color={0,0,127}));
        connect(firstOrder.y, sourceMassFlow.in_w0) annotation (Line(points={{-61,-90},
                {-74,-90},{-74,-76}},          color={0,0,127}));
        connect(pump.outfl, mixer.in1)
          annotation (Line(points={{-32,-35},{-32,-28},{-10,-28}},
                                                             color={0,0,255}));
        connect(sourceMassFlow.flange, mixer.in2) annotation (Line(points={{-60,-70},{
                -20,-70},{-20,-40},{-10,-40}},
                                             color={0,0,255}));
        connect(mixer.out, sensT_mix.inlet)
          annotation (Line(points={{8,-34},{38,-34}},     color={0,0,255}));
        connect(firstOrder1.y, pump.in_n) annotation (Line(points={{-21,10},{-40.6,10},
                {-40.6,-34}},         color={0,0,127}));
        connect(firstOrder.u, add3.y)
          annotation (Line(points={{-38,-90},{-1,-90}}, color={0,0,127}));
        connect(step.y, add3.u1) annotation (Line(points={{39,-80},{32,-80},{32,-84},{
                22,-84}}, color={0,0,127}));
        connect(ramp.y, add3.u2) annotation (Line(points={{39,-110},{32,-110},{32,-96},
                {22,-96}}, color={0,0,127}));
        connect(firstOrder1.u, pI.CS)
          annotation (Line(points={{2,10},{21,10}}, color={0,0,127}));
        connect(sensT_mix.T, pI.PV) annotation (Line(points={{52,-24},{60,-24},{60,9},
                {38,9}}, color={0,0,127}));
        connect(const3.y, add1.u1) annotation (Line(points={{119,110},{112,110},{112,92},
                {102,92}}, color={0,0,127}));
        connect(step1.y, add1.u2) annotation (Line(points={{119,80},{112,80},{112,84},
                {102,84}}, color={0,0,127}));
        connect(ramp1.y, add1.u3) annotation (Line(points={{119,50},{112,50},{112,76},
                {102,76}}, color={0,0,127}));
        connect(add1.y, pI.SP) annotation (Line(points={{79,84},{60,84},{60,16},{38,16}},
              color={0,0,127}));
        connect(booleanStep.y, pI.TS)
          annotation (Line(points={{1,50},{26,50},{26,18}}, color={255,0,255}));
        connect(const.y, pI.TR)
          annotation (Line(points={{1,90},{30,90},{30,18}}, color={0,0,127}));
        connect(sensT_mix.outlet, sinkPressure.flange)
          annotation (Line(points={{50,-34},{75,-34},{100,-34}}, color={0,0,255}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},
                  {140,140}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-140,-140},{140,140}})),
          experiment(StopTime=2000, __Dymola_NumberOfIntervals=2000),
          __Dymola_experimentSetupOutput);
      end test_coldMS_pump2;

      model test_coldMS_pump3
        "Test model of the cold molten salt pump and T_MSin control tuning"

        Modelica.SIunits.Mass M_MS_tot;

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
        ThermoPower.Water.Pump pump(
          use_in_n=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          rho0=1905.6,
          n0=1750,
          w0=9,
          redeclare function efficiencyCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.constantEfficiency (
                eta_nom=0.8),
          allowFlowReversal=false,
          s(start=1),
          redeclare function flowCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.polynomialFlow (head_nom={22.8,
                  22.1,21.5,20.8,19.1,17.5,14.5,13}, q_nom={0.1/3600,3.4/3600,6.8/3600,
                  10.2/3600,13.6/3600,17/3600,20.4/3600,21.505/3600}),
          CheckValve=true,
          V=0.001,
          dp0=327137)
          annotation (Placement(transformation(extent={{-30,-12},{-10,8}})));
        ThermoPower.Water.SinkPressure sinkPressure(use_in_p0=true, redeclare
            package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{120,-4},{140,16}})));
        Modelica.Blocks.Sources.Ramp RPM(
          startTime=100,
          duration=1820,
          offset=1535,
          height=-13.2)
          annotation (Placement(transformation(extent={{-100,40},{-80,60}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-62,-6},{-42,14}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{30,12},{50,-8}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-80,-20},{-60,-40}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{-100,-70},{-80,-50}})));
        Modelica.Blocks.Sources.Constant const2(k=4.43137e5)
          annotation (Placement(transformation(extent={{160,60},{140,80}})));
        IndustrialControlSystems.Controllers.PI pI(
          CS_start=0,
          AntiWindup=true,
          CSmax=14,
          CSmin=0.001,
          Kp=0.05,
          Ti=20,
          useTS=false)
          annotation (Placement(transformation(extent={{0,-40},{-20,-60}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-40,-60},{-60,-40}})));
        Modelica.Blocks.Math.Add3 add3
          annotation (Placement(transformation(extent={{40,-66},{20,-46}})));
        Modelica.Blocks.Sources.Constant const3(k=563.15)
          annotation (Placement(transformation(extent={{80,-40},{60,-20}})));
        Modelica.Blocks.Sources.Step step(
          height=100,
          offset=0,
          startTime=100)
          annotation (Placement(transformation(extent={{80,-70},{60,-50}})));
        Modelica.Blocks.Sources.Ramp ramp(
          startTime=100,
          height=175,
          duration=1050)
          annotation (Placement(transformation(extent={{80,-100},{60,-80}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          V=0.01,
          noInitialPressure=false,
          pstart=443000,
          initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{6,-4},{26,16}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{6,40},{-14,60}})));
        Modelica.Blocks.Sources.Constant
                                     const4(k=0.001)
          annotation (Placement(transformation(extent={{20,-100},{0,-80}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=100,
            startValue=true)
          annotation (Placement(transformation(extent={{-60,-100},{-40,-80}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{56,0},{76,20}})));
        ThermoPower.PowerPlants.Control.PID     pI1(
          CSmax=1750,
          Ti=5,
          PVmin=0,
          PVmax=15,
          PVstart=0.1,
          CSstart=0.126,
          steadyStateInit=true,
          Kp=0.1,
          CSmin=750)
          annotation (Placement(transformation(extent={{40,40},{20,60}})));
        Modelica.Blocks.Sources.Ramp w_tot(
          startTime=100,
          offset=1.5,
          height=11.96 - w_tot.offset,
          duration=1050)
          annotation (Placement(transformation(extent={{100,80},{80,100}})));
        Modelica.Blocks.Sources.CombiTimeTable combiTimeTable(smoothness=
              Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,1.3;
              100,1.3; 300,1.4; 500,2; 700,3; 900,6; 1150,11.96; 3000,11.96])
          annotation (Placement(transformation(extent={{100,50},{80,70}})));
        Modelica.Blocks.Sources.Constant const5(k=1e5)
          annotation (Placement(transformation(extent={{160,20},{140,40}})));
        ThermoPower.Water.PressDrop pressDrop(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          wnom=11.96,
          FFtype=ThermoPower.Choices.PressDrop.FFtypes.OpPoint,
          rhonom=1900,
          w(start=1.5),
          dpnom=950000)
          annotation (Placement(transformation(extent={{86,-4},{106,16}})));
      equation

        if time >= 100 and time <= 1150 then
          der(M_MS_tot) = sourceMassFlow.w;
        else
          der(M_MS_tot) = 0;
        end if;

        connect(sensT_cold.outlet, pump.infl)
          annotation (Line(points={{-46,0},{-28,0}}, color={0,0,255}));
        connect(sourcePressure.flange, sensT_cold.inlet)
          annotation (Line(points={{-80,0},{-58,0}}, color={0,0,255}));
        connect(sensT_mix.T, pI.PV) annotation (Line(points={{48,-4},{52,-4},{
                52,-20},{8,-20},{8,-49},{-2,-49}}, color={0,0,127}));
        connect(firstOrder.u, pI.CS)
          annotation (Line(points={{-38,-50},{-19,-50}}, color={0,0,127}));
        connect(firstOrder.y, sourceMassFlow.in_w0) annotation (Line(points={{-61,-50},
                {-74,-50},{-74,-36}},          color={0,0,127}));
        connect(pI.SP, add3.y)
          annotation (Line(points={{-2,-56},{19,-56}}, color={0,0,127}));
        connect(const3.y, add3.u1) annotation (Line(points={{59,-30},{52,-30},{52,-48},
                {42,-48}}, color={0,0,127}));
        connect(step.y, add3.u2) annotation (Line(points={{59,-60},{52,-60},{52,-56},{
                42,-56}}, color={0,0,127}));
        connect(ramp.y, add3.u3) annotation (Line(points={{59,-90},{52,-90},{52,-64},{
                42,-64}}, color={0,0,127}));
        connect(pump.outfl, mixer.in1)
          annotation (Line(points={{-14,5},{-14,12},{8,12}}, color={0,0,255}));
        connect(sourceMassFlow.flange, mixer.in2) annotation (Line(points={{-60,-30},{
                0,-30},{0,0},{8,0}},         color={0,0,255}));
        connect(mixer.out, sensT_mix.inlet)
          annotation (Line(points={{26,6},{34,6}},        color={0,0,255}));
        connect(firstOrder1.y, pump.in_n) annotation (Line(points={{-15,50},{-22.6,50},
                {-22.6,6}},           color={0,0,127}));
        connect(const4.y, pI.TR)
          annotation (Line(points={{-1,-90},{-10,-90},{-10,-58}}, color={0,0,127}));
        connect(booleanStep.y, pI.TS) annotation (Line(points={{-39,-90},{-14,-90},{-14,
                -58}}, color={255,0,255}));
        connect(sensT_mix.outlet, sensW.inlet)
          annotation (Line(points={{46,6},{60,6}}, color={0,0,255}));
        connect(firstOrder1.u, pI1.CS)
          annotation (Line(points={{8,50},{20,50}}, color={0,0,127}));
        connect(sensW.w, pI1.PV) annotation (Line(points={{74,16},{76,16},{76,
                40},{50,40},{50,46},{40,46}},
                      color={0,0,127}));
        connect(combiTimeTable.y[1], pI1.SP) annotation (Line(points={{79,60},{
                60,60},{60,54},{40,54}}, color={0,0,127}));
        connect(sensW.outlet, pressDrop.inlet)
          annotation (Line(points={{72,6},{86,6}}, color={0,0,255}));
        connect(pressDrop.outlet, sinkPressure.flange)
          annotation (Line(points={{106,6},{120,6}}, color={0,0,255}));
        connect(const5.y, sinkPressure.in_p0) annotation (Line(points={{139,30},
                {126,30},{126,14.8}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-160,-100},
                  {160,100}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-160,-100},{160,100}})),
          experiment(StopTime=3000, __Dymola_NumberOfIntervals=2000),
          __Dymola_experimentSetupOutput);
      end test_coldMS_pump3;

      model test_coldMS_pumpSimp
        "Test model of the cold molten salt pump and T_MSin control tuning"

        Modelica.SIunits.Mass M_MS_tot;

        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          h=101200,
          p0=116000)
          annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
        ThermoPower.Water.Pump pump(
          use_in_n=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          rho0=1905.6,
          n0=1750,
          w0=9,
          redeclare function efficiencyCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.constantEfficiency (
                eta_nom=0.8),
          allowFlowReversal=false,
          s(start=1),
          redeclare function flowCharacteristic =
              ThermoPower.Functions.PumpCharacteristics.polynomialFlow (head_nom={22.8,
                  22.1,21.5,20.8,19.1,17.5,14.5,13}, q_nom={0.1/3600,3.4/3600,6.8/3600,
                  10.2/3600,13.6/3600,17/3600,20.4/3600,21.505/3600}),
          CheckValve=true,
          V=0.001,
          dp0=327137)
          annotation (Placement(transformation(extent={{-30,-12},{-10,8}})));
        ThermoPower.Water.SinkPressure sinkPressure(use_in_p0=true, redeclare
            package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{120,-4},{140,16}})));
        Modelica.Blocks.Sources.Ramp RPM(
          startTime=100,
          duration=1820,
          offset=1535,
          height=-13.2)
          annotation (Placement(transformation(extent={{-100,40},{-80,60}})));
        ThermoPower.Water.SensT sensT_cold(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-62,-6},{-42,14}})));
        ThermoPower.Water.SensT sensT_mix(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{30,12},{50,-8}})));
        ThermoPower.Water.SourceMassFlow sourceMassFlow(
          h=518322,
          use_in_w0=true,
          redeclare package Medium = Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{-80,-20},{-60,-40}})));
        Modelica.Blocks.Sources.Constant const1(k=0)
          annotation (Placement(transformation(extent={{-100,-70},{-80,-50}})));
        Modelica.Blocks.Sources.Constant const2(k=4.43137e5)
          annotation (Placement(transformation(extent={{160,60},{140,80}})));
        IndustrialControlSystems.Controllers.PI pI(
          CS_start=0,
          AntiWindup=true,
          CSmax=14,
          CSmin=0.001,
          Kp=0.05,
          Ti=20,
          useTS=false)
          annotation (Placement(transformation(extent={{0,-40},{-20,-60}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T=2, initType=Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{-40,-60},{-60,-40}})));
        Modelica.Blocks.Math.Add3 add3
          annotation (Placement(transformation(extent={{40,-66},{20,-46}})));
        Modelica.Blocks.Sources.Constant const3(k=563.15)
          annotation (Placement(transformation(extent={{80,-40},{60,-20}})));
        Modelica.Blocks.Sources.Step step(
          height=100,
          offset=0,
          startTime=100)
          annotation (Placement(transformation(extent={{80,-70},{60,-50}})));
        Modelica.Blocks.Sources.Ramp ramp(
          startTime=100,
          height=175,
          duration=1050)
          annotation (Placement(transformation(extent={{80,-100},{60,-80}})));
        ThermoPower.Water.Mixer mixer(
          redeclare package Medium = Media.MoltenSalt60_40_quad,
          V=0.01,
          noInitialPressure=false,
          pstart=443000,
          initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{6,-4},{26,16}})));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T=2, initType=
              Modelica.Blocks.Types.Init.SteadyState)
          annotation (Placement(transformation(extent={{6,40},{-14,60}})));
        Modelica.Blocks.Sources.Constant
                                     const4(k=0.001)
          annotation (Placement(transformation(extent={{20,-100},{0,-80}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=100,
            startValue=true)
          annotation (Placement(transformation(extent={{-60,-100},{-40,-80}})));
        inner ThermoPower.System system(initOpt=ThermoPower.Choices.Init.Options.steadyState)
          annotation (Placement(transformation(extent={{-160,80},{-140,100}})));
        ThermoPower.Water.SensW sensW(redeclare package Medium =
              Media.MoltenSalt60_40_quad)
          annotation (Placement(transformation(extent={{56,0},{76,20}})));
        IndustrialControlSystems.Controllers.PI pI1(
          CSmax=1750,
          Ti=5,
          Kp=3,
          CSmin=1522,
          useTS=true,
          CS_start=1550)
          annotation (Placement(transformation(extent={{40,40},{20,60}})));
        Modelica.Blocks.Sources.Ramp w_tot(
          startTime=100,
          offset=1.5,
          height=11.96 - w_tot.offset,
          duration=1050)
          annotation (Placement(transformation(extent={{100,80},{80,100}})));
        Modelica.Blocks.Sources.CombiTimeTable combiTimeTable(smoothness=
              Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,1.3;
              100,1.3; 300,1.4; 500,2; 700,3; 900,6; 1150,11.96; 3000,11.96])
          annotation (Placement(transformation(extent={{100,50},{80,70}})));
        Modelica.Blocks.Sources.Constant const5(k=1e5)
          annotation (Placement(transformation(extent={{160,20},{140,40}})));
        Modelica.Blocks.Sources.BooleanStep booleanStep1(startTime=1150,
            startValue=false)
          annotation (Placement(transformation(extent={{-40,60},{-20,80}})));
        Modelica.Blocks.Sources.Constant
                                     RPM1(k=1500)
          annotation (Placement(transformation(extent={{0,80},{20,100}})));
      equation

        if time >= 100 and time <= 1150 then
          der(M_MS_tot) = sourceMassFlow.w;
        else
          der(M_MS_tot) = 0;
        end if;

        connect(sensT_cold.outlet, pump.infl)
          annotation (Line(points={{-46,0},{-28,0}}, color={0,0,255}));
        connect(sourcePressure.flange, sensT_cold.inlet)
          annotation (Line(points={{-80,0},{-58,0}}, color={0,0,255}));
        connect(sensT_mix.T, pI.PV) annotation (Line(points={{48,-4},{52,-4},{
                52,-20},{8,-20},{8,-49},{-2,-49}}, color={0,0,127}));
        connect(firstOrder.u, pI.CS)
          annotation (Line(points={{-38,-50},{-19,-50}}, color={0,0,127}));
        connect(firstOrder.y, sourceMassFlow.in_w0) annotation (Line(points={{-61,-50},
                {-74,-50},{-74,-36}},          color={0,0,127}));
        connect(pI.SP, add3.y)
          annotation (Line(points={{-2,-56},{19,-56}}, color={0,0,127}));
        connect(const3.y, add3.u1) annotation (Line(points={{59,-30},{52,-30},{52,-48},
                {42,-48}}, color={0,0,127}));
        connect(step.y, add3.u2) annotation (Line(points={{59,-60},{52,-60},{52,-56},{
                42,-56}}, color={0,0,127}));
        connect(ramp.y, add3.u3) annotation (Line(points={{59,-90},{52,-90},{52,-64},{
                42,-64}}, color={0,0,127}));
        connect(pump.outfl, mixer.in1)
          annotation (Line(points={{-14,5},{-14,12},{8,12}}, color={0,0,255}));
        connect(sourceMassFlow.flange, mixer.in2) annotation (Line(points={{-60,-30},{
                0,-30},{0,0},{8,0}},         color={0,0,255}));
        connect(mixer.out, sensT_mix.inlet)
          annotation (Line(points={{26,6},{34,6}},        color={0,0,255}));
        connect(firstOrder1.y, pump.in_n) annotation (Line(points={{-15,50},{-22.6,50},
                {-22.6,6}},           color={0,0,127}));
        connect(const4.y, pI.TR)
          annotation (Line(points={{-1,-90},{-10,-90},{-10,-58}}, color={0,0,127}));
        connect(booleanStep.y, pI.TS) annotation (Line(points={{-39,-90},{-14,-90},{-14,
                -58}}, color={255,0,255}));
        connect(sensT_mix.outlet, sensW.inlet)
          annotation (Line(points={{46,6},{60,6}}, color={0,0,255}));
        connect(firstOrder1.u, pI1.CS)
          annotation (Line(points={{8,50},{21,50}}, color={0,0,127}));
        connect(sensW.w, pI1.PV) annotation (Line(points={{74,16},{76,16},{76,
                40},{50,40},{50,49},{38,49}},
                      color={0,0,127}));
        connect(const2.y, sinkPressure.in_p0) annotation (Line(points={{139,70},
                {126,70},{126,14.8}}, color={0,0,127}));
        connect(sensW.outlet, sinkPressure.flange)
          annotation (Line(points={{72,6},{94,6},{120,6}}, color={0,0,255}));
        connect(booleanStep1.y, pI1.TS) annotation (Line(points={{-19,70},{26,
                70},{26,58}}, color={255,0,255}));
        connect(RPM1.y, pI1.TR)
          annotation (Line(points={{21,90},{30,90},{30,58}}, color={0,0,127}));
        connect(combiTimeTable.y[1], pI1.SP) annotation (Line(points={{79,60},{
                68,60},{50,60},{50,56},{38,56}}, color={0,0,127}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-160,-100},
                  {160,100}})),                                        Diagram(
              coordinateSystem(preserveAspectRatio=false, extent={{-160,-100},{160,100}})),
          experiment(StopTime=3000, __Dymola_NumberOfIntervals=2000),
          __Dymola_experimentSetupOutput);
      end test_coldMS_pumpSimp;

      model test_threeWayValve "Test model of the three way valve"

        inner ThermoPower.System system
          annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
        ThermoPower.Water.SourcePressure sourcePressure(
          redeclare package Medium = Modelica.Media.Water.WaterIF97_ph,
          p0=9158000,
          h=1257.9e3)
          annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
        ThermoPower.Water.SinkPressure sinkPressure(redeclare package Medium =
              Modelica.Media.Water.WaterIF97_ph, p0=9077000)
          annotation (Placement(transformation(extent={{0,70},{20,90}})));
        ThermoPower.Water.SinkPressure sinkPressure1(redeclare package Medium
            = Modelica.Media.Water.WaterIF97_ph, p0=9077000)
          annotation (Placement(transformation(extent={{60,-10},{80,10}})));
        Components.ThreeWayValve_2out threeWayValve
          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
        Modelica.Blocks.Sources.Ramp ramp(
          offset=1,
          height=-1,
          duration=10,
          startTime=10)
          annotation (Placement(transformation(extent={{-40,-60},{-20,-40}})));
      equation
        connect(ramp.y, threeWayValve.theta) annotation (Line(points={{-19,-50},
                {0,-50},{0,-8}}, color={0,0,127}));
        connect(sourcePressure.flange, threeWayValve.inlet)
          annotation (Line(points={{-60,0},{-35,0},{-10,0}}, color={0,0,255}));
        connect(sinkPressure.flange, threeWayValve.outlet2)
          annotation (Line(points={{0,80},{0,80},{0,10}}, color={0,0,255}));
        connect(threeWayValve.outlet1, sinkPressure1.flange)
          annotation (Line(points={{10,0},{36,0},{60,0}}, color={0,0,255}));
        annotation (
          Icon(coordinateSystem(preserveAspectRatio=false)),
          Diagram(coordinateSystem(preserveAspectRatio=false)),
          experiment(StopTime=10),
          __Dymola_experimentSetupOutput);
      end test_threeWayValve;

      model test_TrapezoidSignal
        "Test model of the trapezoidal wave signal generator"

        Components.StepSequence T_amb(
          startTime=5000,
          offset=T_amb.T_min,
          T_min=278.15,
          T_max=318.15,
          T=60000)
          annotation (Placement(transformation(extent={{-60,60},{-40,80}})));
        Components.ModulatedTrapezoid modulatedTrapezoid(startTime=5000,
          offset=54,
          amplitude=-34,
          rising=50000,
          width=10000,
          falling=50000,
          period=120000)
          annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
        Modelica.Blocks.Sources.BooleanConstant booleanConstant(k=true)
          annotation (Placement(transformation(extent={{-80,10},{-60,30}})));
        Modelica.Blocks.Sources.BooleanConstant booleanConstant1(k=true)
          annotation (Placement(transformation(extent={{-80,-22},{-60,-2}})));
      equation
        connect(booleanConstant.y, modulatedTrapezoid.cond1) annotation (Line(
              points={{-59,20},{-52,20},{-52,6},{-42,6}}, color={255,0,255}));
        connect(booleanConstant1.y, modulatedTrapezoid.cond2) annotation (Line(
              points={{-59,-12},{-52,-12},{-52,-6},{-42,-6}}, color={255,0,255}));
        annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
              coordinateSystem(preserveAspectRatio=false)));
      end test_TrapezoidSignal;
    end Tests;
  end Auxiliaries;

  package Media
    "Package containing the thermodynamic models of molten salt (60% NaNO3 - 40% KNO3)"
    package Interfaces "Partial models of molten salt mixture"
      extends Modelica.Icons.InterfacesPackage;
      partial package PartialLinearFluid
        "Generic pure liquid model with constant cp, compressibility and thermal expansion coefficients"

        extends Modelica.Media.Interfaces.PartialPureSubstance(ThermoStates=
              Modelica.Media.Interfaces.Choices.IndependentVariables.pTX,
            singleState=false);
        constant SpecificHeatCapacity cp_const
          "Specific heat capacity at constant pressure";
        constant IsobaricExpansionCoefficient beta_const
          "Thermal expansion coefficient at constant pressure";
        constant Modelica.SIunits.IsothermalCompressibility kappa_const
          "Isothermal compressibility";
        constant MolarMass MM_const "Molar mass";
        constant Density reference_d "Density in reference conditions";
        constant SpecificEnthalpy reference_h
          "Specific enthalpy in reference conditions";
        constant SpecificEntropy reference_s
          "Specific entropy in reference conditions";
        constant Boolean constantJacobian
          "If true, entries in thermodynamic Jacobian are constant, taken at reference conditions";

        redeclare record ThermodynamicState
          "A selection of variables that uniquely defines the thermodynamic state"
          extends Modelica.Icons.Record;
          AbsolutePressure p "Absolute pressure of medium";
          Temperature T "Temperature of medium";
        end ThermodynamicState;

        redeclare model extends BaseProperties(T(stateSelect=if
                preferredMediumStates then StateSelect.prefer else StateSelect.default),
            p(stateSelect=if preferredMediumStates then StateSelect.prefer else
                StateSelect.default)) "Base properties of medium"
        equation
          d = (1 + (p - reference_p)*kappa_const - (T - reference_T)*beta_const)*
            reference_d;
          h = reference_h + (T - reference_T)*cp_const + (p - reference_p)*(1 -
            beta_const*reference_T)/reference_d;
          u = h - p/d;
          p = state.p;
          T = state.T;
          MM = MM_const;
          R = 8.3144/MM;
        end BaseProperties;

        redeclare function extends setState_pTX
          "Set the thermodynamic state record from p and T (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=T);
        end setState_pTX;

        redeclare function extends setState_phX
          "Set the thermodynamic state record from p and h (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=(h - reference_h - (p - reference_p)*(
            (1 - beta_const*reference_T)/reference_d))/cp_const + reference_T);
        end setState_phX;

        redeclare function extends setState_psX
          "Set the thermodynamic state record from p and s (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=reference_T*cp_const/(cp_const - s +
            reference_s + (p - reference_p)*(-beta_const/reference_d)));
        end setState_psX;

        redeclare function extends setState_dTX
          "Set the thermodynamic state record from d and T (X not needed)"
        algorithm
          state := ThermodynamicState(p=((d - reference_d) + (state.T - reference_T)
            *beta_const*reference_d)/(reference_d*kappa_const) + reference_p, T=T);
        end setState_dTX;

        redeclare function extends setSmoothState
          "Return thermodynamic state so that it smoothly approximates: if x > 0 then state_a else state_b"
        algorithm
          state := ThermodynamicState(p=Modelica.Media.Common.smoothStep(
                    x,
                    state_a.p,
                    state_b.p,
                    x_small), T=Modelica.Media.Common.smoothStep(
                    x,
                    state_a.T,
                    state_b.T,
                    x_small));
        end setSmoothState;

        redeclare function extends pressure
          "Return the pressure from the thermodynamic state"
        algorithm
          p := state.p;
        end pressure;

        redeclare function extends temperature
          "Return the temperature from the thermodynamic state"
        algorithm
          T := state.T;
        end temperature;

        redeclare function extends density
          "Return the density from the thermodynamic state"
        algorithm
          d := (1 + (state.p - reference_p)*kappa_const - (state.T - reference_T)*
            beta_const)*reference_d;
        end density;

        redeclare function extends specificEnthalpy
          "Return the specific enthalpy from the thermodynamic state"
        algorithm
          h := reference_h + (state.T - reference_T)*cp_const + (state.p -
            reference_p)*(1 - beta_const*reference_T)/reference_d;
        end specificEnthalpy;

        redeclare function extends specificEntropy
          "Return the specific entropy from the thermodynamic state"
        algorithm
          s := reference_s + (state.T - reference_T)*cp_const/state.T + (state.p -
            reference_p)*(-beta_const/reference_d);
        end specificEntropy;

        redeclare function extends specificInternalEnergy
          "Return the specific internal energy from the thermodynamic state"
        algorithm
          u := specificEnthalpy(state) - state.p/reference_d;
        end specificInternalEnergy;

        redeclare function extends specificGibbsEnergy
          "Return specific Gibbs energy from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          g := specificEnthalpy(state) - state.T*specificEntropy(state);
        end specificGibbsEnergy;

        redeclare function extends specificHelmholtzEnergy
          "Return specific Helmholtz energy from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          f := specificInternalEnergy(state) - state.T*specificEntropy(state);
        end specificHelmholtzEnergy;

        redeclare function extends velocityOfSound
          "Return velocity of sound from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          a := sqrt(max(0, 1/(kappa_const*density(state) - beta_const*beta_const*
            state.T/cp_const)));
        end velocityOfSound;

        redeclare function extends isentropicExponent
          "Return isentropic exponent from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          gamma := 1/(state.p*kappa_const)*cp_const/specificHeatCapacityCv(state);
        end isentropicExponent;

        redeclare function extends isentropicEnthalpy
          "Return isentropic enthalpy"

          /* Previous wrong equation:

protected
  SpecificEntropy s_upstream = specificEntropy(refState)
    "Specific entropy at component inlet";
  ThermodynamicState downstreamState "State at downstream location";
algorithm
  downstreamState.p := p_downstream;
  downstreamState.T := reference_T*cp_const/
    (s_upstream -reference_s -(p_downstream-reference_p)*(-beta_const/reference_d) - cp_const);
  h_is := specificEnthalpy(downstreamState);
*/
        algorithm
          /* s := reference_s + (refState.T-reference_T)*cp_const/refState.T +
                        (refState.p-reference_p)*(-beta_const/reference_d)
        = reference_s + (state.T-reference_T)*cp_const/state.T +
                        (p_downstream-reference_p)*(-beta_const/reference_d);

      (state.T-reference_T)*cp_const/state.T
     = (refState.T-reference_T)*cp_const/refState.T + (refState.p-reference_p)*(-beta_const/reference_d)
       - (p_downstream-reference_p)*(-beta_const/reference_d)
     = (refState.T-reference_T)*cp_const/refState.T + (refState.p-p_downstream)*(-beta_const/reference_d)

     (x - reference_T)/x = k
     x - reference_T = k*x
     (1-k)*x = reference_T
     x = reference_T/(1-k);

     state.T = reference_T/(1 - ((refState.T-reference_T)*cp_const/refState.T + (refState.p-p_downstream)*(-beta_const/reference_d))/cp_const)
  */

          h_is := specificEnthalpy(setState_pTX(
                  p_downstream,
                  reference_T/(1 - ((refState.T - reference_T)/refState.T + (
              refState.p - p_downstream)*(-beta_const/(reference_d*cp_const)))),
                  reference_X));
          annotation (Documentation(info="<html>
<p>
A minor approximation is used: the reference density is used instead of the real
one, which would require a numeric solution.
</p>
</html>"));
        end isentropicEnthalpy;

        redeclare function extends specificHeatCapacityCp
          "Return specific heat capacity at constant volume"
        algorithm
          cp := cp_const;
        end specificHeatCapacityCp;

        redeclare function extends specificHeatCapacityCv
          "Return specific heat capacity at constant volume from the thermodynamic state"
        algorithm
          cv := if constantJacobian then cp_const - reference_T*beta_const*
            beta_const/(kappa_const*reference_d) else state.T*beta_const*beta_const
            /(kappa_const*reference_d);
        end specificHeatCapacityCv;

        redeclare function extends isothermalCompressibility
          "Return the isothermal compressibility kappa"
        algorithm
          kappa := kappa_const;
        end isothermalCompressibility;

        redeclare function extends isobaricExpansionCoefficient
          "Return the isobaric expansion coefficient"
        algorithm
          beta := beta_const;
        end isobaricExpansionCoefficient;

        redeclare function extends density_derp_h
          "Return density derivative w.r.t. pressure at const specific enthalpy"
        algorithm
          ddph := if constantJacobian then kappa_const*reference_d + (beta_const*(1
             - reference_T*beta_const))/cp_const else kappa_const*density(state) +
            (beta_const*(1 - temperature(state)*beta_const))/cp_const;
        end density_derp_h;

        redeclare function extends density_derh_p
          "Return density derivative w.r.t. specific enthalpy at constant pressure"
        algorithm
          ddhp := if constantJacobian then -beta_const*reference_d/cp_const else -
            beta_const*density(state)/cp_const;
        end density_derh_p;

        redeclare function extends density_derp_T
          "Return density derivative w.r.t. pressure at const temperature"
        algorithm
          ddpT := if constantJacobian then kappa_const*reference_d else kappa_const
            *density(state);
        end density_derp_T;

        redeclare function extends density_derT_p
          "Return density derivative w.r.t. temperature at constant pressure"
        algorithm
          ddTp := if constantJacobian then -beta_const*reference_d else -beta_const
            *density(state);
        end density_derT_p;

        redeclare function extends density_derX
          "Returns the partial derivative of density with respect to mass fractions at constant pressure and temperature"
        algorithm
          dddX := fill(0, nX);
        end density_derX;

        redeclare function extends molarMass "Return molar mass"
        algorithm
          MM := MM_const;
        end molarMass;

        function T_ph "Return temperature from pressure and specific enthalpy"
          extends Modelica.Icons.Function;
          input SpecificEnthalpy h "Specific enthalpy";
          input AbsolutePressure p "Pressure";
          output Temperature T "Temperature";
        algorithm
          T := (h - reference_h - (p - reference_p)*((1 - beta_const*reference_T)/
            reference_d))/cp_const + reference_T;
        end T_ph;

        function T_ps "Return temperature from pressure and specific entropy"
          extends Modelica.Icons.Function;
          input AbsolutePressure p "Pressure";
          input SpecificEntropy s "Specific entropy";
          output Temperature T "Temperature";
        algorithm
          T := reference_T*cp_const/(s - reference_s - (p - reference_p)*(-
            beta_const/reference_d) - cp_const);
        end T_ps;

        annotation (Documentation(info="<html>
<h4>Linear Compressibility Fluid Model</h4>
<p>This linear compressibility fluid model is based on the assumptions that:
</p>
<ul>
<li>The specific heat capacity at constant pressure (cp) is constant</li>
<li>The isobaric expansion coefficient (beta) is constant</li>
<li>The isothermal compressibility (kappa) is constant</li>
<li>Pressure and temperature are used as states</li>
<li>The influence of density on specific enthalpy (h), entropy (s), inner energy (u) and heat capacity (cv) at constant volume is neglected.
</ul>
<p>
That means that the density is a linear function in temperature and in pressure.
In order to define the complete model, a number of constant reference values are needed which
are computed at the reference values of the states pressure p and temperature T. The model can
be interpreted as a linearization of a full non-linear fluid model (but it is not linear in all
thermodynamic coordinates). Reference values are needed for
</p>
<ol>
<li>the density (reference_d),</li>
<li>the specific enthalpy (reference_h),</li>
<li>the specific entropy (reference_s).</li>
</ol>
<p>
Apart from that, a user needs to define the molar mass, MM_const.
Note that it is possible to define a fluid by computing the reference
values from a full non-linear fluid model by computing the package constants
using the standard functions defined in a fluid package (see example in liquids package).
</p>
<p>
In order to avoid numerical inversion of the temperature in the T_ph and T_ps functions, the density
is always taken to be the reference density in the computation of h, s, u and cv. For liquids (and this
model is intended only for liquids) the relative error of doing so is 1e-3 to 1e-4 at most. The model would
be more \"correct\" based on the other assumptions, if occurrences of reference_d in the computations of h,s,u
and cv would be replaced by a call to density(state). That would require a numerical solution for T_ps, while T_ph can be solved symbolically from a quadratic function. Errors from this approximation are small because liquid density varies little.</p>
<h4>Efficiency considerations</h4>
<p>One of the main reasons to use a simple, linear fluid model is to achieve high performance
in simulations. There are a number of possible compromises and possibilities to improve performance.
Some of them can be influenced by a flag. The following rules where used in this model:</p>
<ul>
<li>All forward evaluations (using the ThermodynamicState record as input) are exactly following
the assumptions above.</li>
<li>If the flag <b>constantJacobian</b> is set to true in the package, all functions that
typically appear in thermodynamic Jacobians (specificHeatCapacityCv, density_derp_h, density_derh_p,
density_derp_T, density_derT_p) are evaluated at reference conditions (that means using the reference
density) instead of the density of the current pressure and temperature. This makes it possible to evaluate
the thermodynamic Jacobian at compile time.</li>
<li>For inverse functions using other inputs than the states (e.g pressure p and specific enthalpy h),
the inversion is using the reference state whenever that is necessary to achieve a symbolic inversion.</li>
<li>If <b>constantJacobian</b> is set to false, the above list of functions is computed exactly according
to the above list of assumptions</li>
</ul>
<dl>
<dt><b>Authors:</b></dt>
<dd>Francesco Casella<br>
    Dipartimento di Elettronica e Informazione<br>
    Politecnico di Milano<br>
    Via Ponzio 34/5<br>
    I-20133 Milano, Italy<br>
    email: <A HREF=\"mailto:casella@elet.polimi.it\">casella@elet.polimi.it</A><br>
    and <br>
    Hubertus Tummescheit<br>
    Modelon AB<br>
    Ideon Science Park<br>
    SE-22730 Lund, Sweden<br>
    email: <A HREF=\"mailto:Hubertus.Tummescheit@Modelon.se\">Hubertus.Tummescheit@Modelon.se</A>
</dd>
</dl>
</html>"));
      end PartialLinearFluid;

      partial package PartialQuadraticFluid
        "Generic pure liquid model with linear cp, compressibility and thermal expansion coefficients"

        extends Modelica.Media.Interfaces.PartialPureSubstance(ThermoStates=
              Modelica.Media.Interfaces.Choices.IndependentVariables.pTX,
            singleState=false);
        constant SpecificHeatCapacity cp_const
          "Reference specific heat capacity at constant pressure";
        constant Real A
          "First term of specific heat capacity at constant pressure function";
        constant Real B
          "Second term of specific heat capacity at constant pressure function";
        constant IsobaricExpansionCoefficient beta_const
          "Thermal expansion coefficient at constant pressure";
        constant Modelica.SIunits.IsothermalCompressibility kappa_const
          "Isothermal compressibility";
        constant MolarMass MM_const "Molar mass";
        constant Density reference_d "Density in reference conditions";
        constant SpecificEnthalpy reference_h
          "Specific enthalpy in reference conditions";
        constant SpecificEntropy reference_s
          "Specific entropy in reference conditions";
        constant Boolean constantJacobian
          "If true, entries in thermodynamic Jacobian are constant, taken at reference conditions";

        redeclare record ThermodynamicState
          "A selection of variables that uniquely defines the thermodynamic state"
          extends Modelica.Icons.Record;
          AbsolutePressure p "Absolute pressure of medium";
          Temperature T "Temperature of medium";
        end ThermodynamicState;

        redeclare model extends BaseProperties(T(stateSelect=if
                preferredMediumStates then StateSelect.prefer else StateSelect.default),
            p(stateSelect=if preferredMediumStates then StateSelect.prefer else
                StateSelect.default)) "Base properties of medium"
        equation
          d = (1 + (p - reference_p)*kappa_const - (T - reference_T)*beta_const)*
            reference_d;
          h = reference_h + A*(T - reference_T) + B/2*(T^2 - reference_T^2);
          u = h - p/d;
          p = state.p;
          T = state.T;
          MM = MM_const;
          R = 8.3144/MM;
        end BaseProperties;

        redeclare function extends setState_pTX
          "Set the thermodynamic state record from p and T (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=T);
        end setState_pTX;

        redeclare function extends setState_phX
          "Set the thermodynamic state record from p and h (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=(-A+sqrt(A^2 - 2*B*(reference_h - h - A*reference_T - B/2*reference_T^2)))/B);
        end setState_phX;

        redeclare function extends setState_psX
          "Set the thermodynamic state record from p and s (X not needed)"
        algorithm
          state := ThermodynamicState(p=p, T=reference_T*cp_const/(cp_const - s +
            reference_s + (p - reference_p)*(-beta_const/reference_d)));
        end setState_psX;

        redeclare function extends setState_dTX
          "Set the thermodynamic state record from d and T (X not needed)"
        algorithm
          state := ThermodynamicState(p=((d - reference_d) + (state.T - reference_T)
            *beta_const*reference_d)/(reference_d*kappa_const) + reference_p, T=T);
        end setState_dTX;

        redeclare function extends setSmoothState
          "Return thermodynamic state so that it smoothly approximates: if x > 0 then state_a else state_b"
        algorithm
          state := ThermodynamicState(p=Modelica.Media.Common.smoothStep(
                    x,
                    state_a.p,
                    state_b.p,
                    x_small), T=Modelica.Media.Common.smoothStep(
                    x,
                    state_a.T,
                    state_b.T,
                    x_small));
        end setSmoothState;

        redeclare function extends pressure
          "Return the pressure from the thermodynamic state"
        algorithm
          p := state.p;
        end pressure;

        redeclare function extends temperature
          "Return the temperature from the thermodynamic state"
        algorithm
          T := state.T;
        end temperature;

        redeclare function extends density
          "Return the density from the thermodynamic state"
        algorithm
          d := (1 + (state.p - reference_p)*kappa_const - (state.T - reference_T)*
            beta_const)*reference_d;
        end density;

        redeclare function extends specificEnthalpy
          "Return the specific enthalpy from the thermodynamic state"
        algorithm
          h := reference_h + A*(state.T - reference_T) + B/2*(state.T^2 - reference_T^2);
        end specificEnthalpy;

        redeclare function extends specificEntropy
          "Return the specific entropy from the thermodynamic state"
        algorithm
          s := reference_s + (state.T - reference_T)*cp_const/state.T + (state.p -
            reference_p)*(-beta_const/reference_d);
        end specificEntropy;

        redeclare function extends specificInternalEnergy
          "Return the specific internal energy from the thermodynamic state"
        algorithm
          u := specificEnthalpy(state) - state.p/reference_d;
        end specificInternalEnergy;

        redeclare function extends specificGibbsEnergy
          "Return specific Gibbs energy from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          g := specificEnthalpy(state) - state.T*specificEntropy(state);
        end specificGibbsEnergy;

        redeclare function extends specificHelmholtzEnergy
          "Return specific Helmholtz energy from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          f := specificInternalEnergy(state) - state.T*specificEntropy(state);
        end specificHelmholtzEnergy;

        redeclare function extends velocityOfSound
          "Return velocity of sound from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          a := sqrt(max(0, 1/(kappa_const*density(state) - beta_const*beta_const*
            state.T/cp_const)));
        end velocityOfSound;

        redeclare function extends isentropicExponent
          "Return isentropic exponent from the thermodynamic state"
          extends Modelica.Icons.Function;
        algorithm
          gamma := 1/(state.p*kappa_const)*cp_const/specificHeatCapacityCv(state);
        end isentropicExponent;

        redeclare function extends isentropicEnthalpy
          "Return isentropic enthalpy"

          /* Previous wrong equation:

protected
  SpecificEntropy s_upstream = specificEntropy(refState)
    "Specific entropy at component inlet";
  ThermodynamicState downstreamState "State at downstream location";
algorithm
  downstreamState.p := p_downstream;
  downstreamState.T := reference_T*cp_const/
    (s_upstream -reference_s -(p_downstream-reference_p)*(-beta_const/reference_d) - cp_const);
  h_is := specificEnthalpy(downstreamState);
*/
        algorithm
          /* s := reference_s + (refState.T-reference_T)*cp_const/refState.T +
                        (refState.p-reference_p)*(-beta_const/reference_d)
        = reference_s + (state.T-reference_T)*cp_const/state.T +
                        (p_downstream-reference_p)*(-beta_const/reference_d);

      (state.T-reference_T)*cp_const/state.T
     = (refState.T-reference_T)*cp_const/refState.T + (refState.p-reference_p)*(-beta_const/reference_d)
       - (p_downstream-reference_p)*(-beta_const/reference_d)
     = (refState.T-reference_T)*cp_const/refState.T + (refState.p-p_downstream)*(-beta_const/reference_d)

     (x - reference_T)/x = k
     x - reference_T = k*x
     (1-k)*x = reference_T
     x = reference_T/(1-k);

     state.T = reference_T/(1 - ((refState.T-reference_T)*cp_const/refState.T + (refState.p-p_downstream)*(-beta_const/reference_d))/cp_const)
  */

          h_is := specificEnthalpy(setState_pTX(
                  p_downstream,
                  reference_T/(1 - ((refState.T - reference_T)/refState.T + (
              refState.p - p_downstream)*(-beta_const/(reference_d*cp_const)))),
                  reference_X));
          annotation (Documentation(info="<html>
<p>
A minor approximation is used: the reference density is used instead of the real
one, which would require a numeric solution.
</p>
</html>"));
        end isentropicEnthalpy;

        redeclare function extends specificHeatCapacityCp
          "Return specific heat capacity at constant volume"
        algorithm
          cp := A +B*state.T;
        end specificHeatCapacityCp;

        redeclare function extends specificHeatCapacityCv
          "Return specific heat capacity at constant volume from the thermodynamic state"
        algorithm
          cv := if constantJacobian then cp_const - reference_T*beta_const*
            beta_const/(kappa_const*reference_d) else state.T*beta_const*beta_const
            /(kappa_const*reference_d);
        end specificHeatCapacityCv;

        redeclare function extends isothermalCompressibility
          "Return the isothermal compressibility kappa"
        algorithm
          kappa := kappa_const;
        end isothermalCompressibility;

        redeclare function extends isobaricExpansionCoefficient
          "Return the isobaric expansion coefficient"
        algorithm
          beta := beta_const;
        end isobaricExpansionCoefficient;

        redeclare function extends density_derp_h
          "Return density derivative w.r.t. pressure at const specific enthalpy"
        algorithm
          ddph := if constantJacobian then kappa_const*reference_d + (beta_const*(1
             - reference_T*beta_const))/cp_const else kappa_const*density(state) +
            (beta_const*(1 - temperature(state)*beta_const))/cp_const;
        end density_derp_h;

        redeclare function extends density_derh_p
          "Return density derivative w.r.t. specific enthalpy at constant pressure"
        algorithm
          ddhp := if constantJacobian then -beta_const*reference_d/cp_const else -
            beta_const*density(state)/cp_const;
        end density_derh_p;

        redeclare function extends density_derp_T
          "Return density derivative w.r.t. pressure at const temperature"
        algorithm
          ddpT := if constantJacobian then kappa_const*reference_d else kappa_const
            *density(state);
        end density_derp_T;

        redeclare function extends density_derT_p
          "Return density derivative w.r.t. temperature at constant pressure"
        algorithm
          ddTp := if constantJacobian then -beta_const*reference_d else -beta_const
            *density(state);
        end density_derT_p;

        redeclare function extends density_derX
          "Returns the partial derivative of density with respect to mass fractions at constant pressure and temperature"
        algorithm
          dddX := fill(0, nX);
        end density_derX;

        redeclare function extends molarMass "Return molar mass"
        algorithm
          MM := MM_const;
        end molarMass;

        function T_ph "Return temperature from pressure and specific enthalpy"
          extends Modelica.Icons.Function;
          input SpecificEnthalpy h "Specific enthalpy";
          input AbsolutePressure p "Pressure";
          output Temperature T "Temperature";
        algorithm
          T := (h - reference_h - (p - reference_p)*((1 - beta_const*reference_T)/
            reference_d))/cp_const + reference_T;
        end T_ph;

        function T_ps "Return temperature from pressure and specific entropy"
          extends Modelica.Icons.Function;
          input AbsolutePressure p "Pressure";
          input SpecificEntropy s "Specific entropy";
          output Temperature T "Temperature";
        algorithm
          T := reference_T*cp_const/(s - reference_s - (p - reference_p)*(-
            beta_const/reference_d) - cp_const);
        end T_ps;

        annotation (Documentation(info="<html>
<h4>Linear Compressibility Fluid Model</h4>
<p>This linear compressibility fluid model is based on the assumptions that:
</p>
<ul>
<li>The specific heat capacity at constant pressure (cp) is constant</li>
<li>The isobaric expansion coefficient (beta) is constant</li>
<li>The isothermal compressibility (kappa) is constant</li>
<li>Pressure and temperature are used as states</li>
<li>The influence of density on specific enthalpy (h), entropy (s), inner energy (u) and heat capacity (cv) at constant volume is neglected.
</ul>
<p>
That means that the density is a linear function in temperature and in pressure.
In order to define the complete model, a number of constant reference values are needed which
are computed at the reference values of the states pressure p and temperature T. The model can
be interpreted as a linearization of a full non-linear fluid model (but it is not linear in all
thermodynamic coordinates). Reference values are needed for
</p>
<ol>
<li>the density (reference_d),</li>
<li>the specific enthalpy (reference_h),</li>
<li>the specific entropy (reference_s).</li>
</ol>
<p>
Apart from that, a user needs to define the molar mass, MM_const.
Note that it is possible to define a fluid by computing the reference
values from a full non-linear fluid model by computing the package constants
using the standard functions defined in a fluid package (see example in liquids package).
</p>
<p>
In order to avoid numerical inversion of the temperature in the T_ph and T_ps functions, the density
is always taken to be the reference density in the computation of h, s, u and cv. For liquids (and this
model is intended only for liquids) the relative error of doing so is 1e-3 to 1e-4 at most. The model would
be more \"correct\" based on the other assumptions, if occurrences of reference_d in the computations of h,s,u
and cv would be replaced by a call to density(state). That would require a numerical solution for T_ps, while T_ph can be solved symbolically from a quadratic function. Errors from this approximation are small because liquid density varies little.</p>
<h4>Efficiency considerations</h4>
<p>One of the main reasons to use a simple, linear fluid model is to achieve high performance
in simulations. There are a number of possible compromises and possibilities to improve performance.
Some of them can be influenced by a flag. The following rules where used in this model:</p>
<ul>
<li>All forward evaluations (using the ThermodynamicState record as input) are exactly following
the assumptions above.</li>
<li>If the flag <b>constantJacobian</b> is set to true in the package, all functions that
typically appear in thermodynamic Jacobians (specificHeatCapacityCv, density_derp_h, density_derh_p,
density_derp_T, density_derT_p) are evaluated at reference conditions (that means using the reference
density) instead of the density of the current pressure and temperature. This makes it possible to evaluate
the thermodynamic Jacobian at compile time.</li>
<li>For inverse functions using other inputs than the states (e.g pressure p and specific enthalpy h),
the inversion is using the reference state whenever that is necessary to achieve a symbolic inversion.</li>
<li>If <b>constantJacobian</b> is set to false, the above list of functions is computed exactly according
to the above list of assumptions</li>
</ul>
<dl>
<dt><b>Authors:</b></dt>
<dd>Francesco Casella<br>
    Dipartimento di Elettronica e Informazione<br>
    Politecnico di Milano<br>
    Via Ponzio 34/5<br>
    I-20133 Milano, Italy<br>
    email: <A HREF=\"mailto:casella@elet.polimi.it\">casella@elet.polimi.it</A><br>
    and <br>
    Hubertus Tummescheit<br>
    Modelon AB<br>
    Ideon Science Park<br>
    SE-22730 Lund, Sweden<br>
    email: <A HREF=\"mailto:Hubertus.Tummescheit@Modelon.se\">Hubertus.Tummescheit@Modelon.se</A>
</dd>
</dl>
</html>"));
      end PartialQuadraticFluid;
    end Interfaces;

    package MoltenSalt60_40_lin
      "Molten salt linear model (60% NaNO3 - 40% KNO3)"
      extends PreFlexMS.Media.Interfaces.PartialLinearFluid(
        reference_T=693.15,
        reference_p=2e5,
        constantJacobian=true,
        reference_d=1822.88,
        reference_h=297908,
        reference_s=0,
        cp_const=1515.24,
        beta_const=3.48898e-4,
        kappa_const=0,
        MM_const=90.7793);

    redeclare function extends dynamicViscosity
        "Dynamic viscosity of molten salt"
    algorithm
      eta := (22.714 - 0.12*(state.T - 273.15) + 2.281e-4*(state.T - 273.15)^2 - 1.474e-7*(state.T - 273.15)^3)*10^(-3);
    end dynamicViscosity;

    redeclare function extends thermalConductivity
        "Thermal conductivity of molten salt"
    algorithm
      lambda := 0.3911015 + 0.00019*state.T;
    end thermalConductivity;

    end MoltenSalt60_40_lin;

    model test_MoltenSalt60_40_lin "Test model of the molten salt mixture"
      extends Modelica.Icons.Example;

      package Medium = MoltenSalt60_40_lin "Medium model (MoltenSalt60_40)";
      Medium.BaseProperties medium;
      Medium.DynamicViscosity eta=Medium.dynamicViscosity(medium.state);
      Medium.ThermalConductivity lambda=Medium.thermalConductivity(medium.state);
      //Medium.SpecificEntropy s=Medium.specificEntropy(medium.state);
      //Medium.SpecificHeatCapacity cv=Medium.specificHeatCapacityCv(medium.state);
      //Medium.SpecificInternalEnergy u=Medium.specificInternalEnergy(medium.state);
      //Medium.SpecificInternalEnergy h=Medium.specificEnthalpy(medium.state);
      //Medium.SpecificInternalEnergy d=Medium.density(medium.state);
    protected
      constant Modelica.SIunits.Time timeUnit = 1;
      constant Modelica.SIunits.Temperature T_min = 523.15;
    equation
      medium.p = 2e5;
      medium.T = T_min + (time-250)/timeUnit;

    end test_MoltenSalt60_40_lin;

    package MoltenSalt60_40_quad
      "Molten salt quadratic model (60% NaNO3 - 40% KNO3)"
      extends PreFlexMS.Media.Interfaces.PartialQuadraticFluid(
        reference_T=693.15,
        reference_p=2e5,
        constantJacobian=true,
        reference_d=1822.88,
        reference_h=296804,
        reference_s=0,
        A=1396.0182,
        B=0.172,
        cp_const=1515.2,
        beta_const=3.48898e-4,
        kappa_const=0,
        MM_const=90.7793);

    redeclare function extends dynamicViscosity
        "Dynamic viscosity of molten salt"
    algorithm
      eta := (22.714 - 0.12*(state.T - 273.15) + 2.281e-4*(state.T - 273.15)^2 - 1.474e-7*(state.T - 273.15)^3)*10^(-3);
    end dynamicViscosity;

    redeclare function extends thermalConductivity
        "Thermal conductivity of molten salt"
    algorithm
      lambda := 0.3911015 + 0.00019*state.T;
    end thermalConductivity;

    end MoltenSalt60_40_quad;

    model test_MoltenSalt60_40_quad "Test model of the molten salt mixture"
      extends Modelica.Icons.Example;

      package Medium = MoltenSalt60_40_quad "Medium model (MoltenSalt60_40)";
      Medium.BaseProperties medium;
      Medium.DynamicViscosity eta=Medium.dynamicViscosity(medium.state);
      Medium.ThermalConductivity lambda=Medium.thermalConductivity(medium.state);
      //Medium.SpecificEntropy s=Medium.specificEntropy(medium.state);
      //Medium.SpecificHeatCapacity cv=Medium.specificHeatCapacityCv(medium.state);
      //Medium.SpecificInternalEnergy u=Medium.specificInternalEnergy(medium.state);
      Medium.SpecificInternalEnergy h=Medium.specificEnthalpy(medium.state);
      //Medium.SpecificInternalEnergy d=Medium.density(medium.state);
    protected
      constant Modelica.SIunits.Time timeUnit = 1;
      constant Modelica.SIunits.Temperature T_min = 523.15;
    equation
      medium.p = 2e5;
      medium.T = T_min + (time-250)/timeUnit;

    end test_MoltenSalt60_40_quad;
  end Media;
  annotation (uses(Modelica(version="3.2.1"),
      ORC(version="1.1"),
      ThermoPower(version="3.1"),
      IndustrialControlSystems(version="2")), version="1",
    Documentation(info="<html>
<p><b><span style=\"font-family: MS Shell Dlg 2; font-size: 14pt;\">General Information</span></b></p>
<p><br><span style=\"font-family: MS Shell Dlg 2;\">The present Modelica library contains the components, the models, and the simulation test cases regarding the project of a Concentrated Solar Powered (CSP) power plant, as part of the H2020 European project &QUOT;PreFlexMS&QUOT;. Some of the components used in the present library refer to other libraries, in particular:</span></p>
<ul>
<li><span style=\"font-family: MS Shell Dlg 2;\">&QUOT;<b>ThermoPower</b>&QUOT;, an open-source Modelica library for the dynamic modelling of thermal power plants and energy conversion system (<a href=\"svn://svn.code.sf.net/p/thermopower/svn/trunk\">http://svn.code.sf.net/p/thermopower/svn/trunk</a>); </span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">&QUOT;<b>IndustrialControlSystems</b>&QUOT;, an open-source Modelica library containing models of commonly used industrial controllers (PI/PID) (http://marcobonvini.altervista.org/ics.php);</span></li>
<li><span style=\"font-family: MS Shell Dlg 2;\">&QUOT;<b>Modelica Standard Library 3.2.1</b>&QUOT;.</span></li>
</ul>
<p><br><span style=\"font-family: MS Shell Dlg 2;\">The library has been developed by Stefano Trabucchi, with the preciuos help of Francesco Casella and Tommaso Maioli. Its aim is the study of the system dynamic, the control strategies evaluation, the procedures optimization and possible plant malfunctioning evaluation. </span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\">The structure of the library is the following:</span></p>
<ol>
<li><i><span style=\"font-family: MS Shell Dlg 2;\">FullScale_280degC</span></i> package: these models refer to the full scale power plant equipment design with an Once Through Steam Generator (OTSG) inlet feedwater temperature of 280&deg;C. At a certain point during the project the latter temperature design value has been changed, so that the present package development has stopped (no further documentation is provided);</li>
<li><i><b><span style=\"font-family: MS Shell Dlg 2;\">FullScale_245degC package</span></b></i>:<i> </i>these models refer to the full scale power plant equipment design with an OTSG inlet feedwater temperature of 245&deg;C, related to the official OTSG component design. The package covers both the test cases used for tuning of components parameters and the partial or complete power plant models. It is worth to notice that only the OTSG components design has been performed, while other components design (such as turbine corps, deaerator, high and low pressure preheaters) has been has been derived from similar power plants under reasonable assumptions.</li>
<li><i><b><span style=\"font-family: MS Shell Dlg 2;\">Pilot_245degC package</span></b>: </i>these models refer to the pilot equipment design, which is basically a down-scaled version of the full scale power plant. The OTSG model structure is the same of the full scale&apos;s one, while the turbine and feedewater preheaters train design has been replaced by the Water-Steam Cycle (WSC). The WSC purpose is to recreate the same boundary conditions the OTSG has on the full scale version, from both static and dynamic point of view.</li>
<li><i>Auxiliaries</i> package<i>: </i>this package contains models in common between the previous two packages, plus other minor models which are not specifically a part of the power plant components list;</li>
<li><i>Media </i>package: this package contains the models of the molten salt media.</li>
</ol>
<p><br>The reference and final design is the one with <span style=\"font-family: MS Shell Dlg 2;\">an OTSG inlet feedwater temperature of 245&deg;C, thus for official results please refer to package number 2 for full scale design and number 3 for pilot design.</span></p>
<p><img src=\"modelica://PreFlexMS/Images/preflex-ms-slide-top.jpg\"/></p>
</html>"));
end PreFlexMS;
